########################################
##### Deteco de Eventos - Cmbio #####
########################################

################
##### Data #####
################

library(tibble)
library(EventDetectR)
source("https://raw.githubusercontent.com/cefet-rj-dal/harbinger/master/harbinger.R")

attach(df_currency)
head(df_currency)
str(df_currency)

test_ars_brl <- subset(df_currency, select = c(Data, ars_brl))
test_aud_brl <- subset(df_currency, select = c(Data, aud_brl))
test_cad_brl <- subset(df_currency, select = c(Data, cad_brl))
test_chf_brl <- subset(df_currency, select = c(Data, chf_brl))
test_eur_brl <- subset(df_currency, select = c(Data, eur_brl))
test_gbp_brl <- subset(df_currency, select = c(Data, gbp_brl))
test_sgd_brl <- subset(df_currency, select = c(Data, sgd_brl))
test_usd_brl <- subset(df_currency, select = c(Data, usd_brl))
test_cny_brl <- subset(df_currency, select = c(Data, cny_brl))
test_dkk_brl <- subset(df_currency, select = c(Data, dkk_brl))
test_mxn_brl <- subset(df_currency, select = c(Data, mxn_brl))
test_nok_brl <- subset(df_currency, select = c(Data, nok_brl))
test_nzd_brl <- subset(df_currency, select = c(Data, nzd_brl))
test_pln_brl <- subset(df_currency, select = c(Data, pln_brl))
test_sek_brl <- subset(df_currency, select = c(Data, sek_brl))
test_try_brl <- subset(df_currency, select = c(Data, try_brl))
test_zar_brl <- subset(df_currency, select = c(Data, zar_brl))
test_pen_brl <- subset(df_currency, select = c(Data, pen_brl))
reference <- subset(df_currency, select = c(Data, event))

#####################
##### Anomalize #####
#####################

##### 1. ars_brl #####
#Detect
anomalize_ars_brl <- evtdet.anomalize(test_ars_brl, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_ars_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     11     4    
# FALSE    54     180    

round(evaluate(anomalize_ars_brl, reference, metric = "F1"), 2)          # 0.28
round(evaluate(anomalize_ars_brl, reference, metric = "accuracy"), 2)    # 0.77
round(evaluate(anomalize_ars_brl, reference, metric = "sensitivity"), 2) # 0.17
round(evaluate(anomalize_ars_brl, reference, metric = "specificity"), 2) # 0.98
round(evaluate(anomalize_ars_brl, reference, metric = "precision"), 2)   # 0.73
round(evaluate(anomalize_ars_brl, reference, metric = "recall"), 2)      # 0.17

#Plot
print(evtplot(test_ars_brl, anomalize_ars_brl, reference))

##### 2. aud_brl #####
#Detect
anomalize_aud_brl <- evtdet.anomalize(test_aud_brl, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_aud_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     18     15
# FALSE    47     169  

round(evaluate(anomalize_aud_brl, reference, metric = "F1"), 2)          # 0.37
round(evaluate(anomalize_aud_brl, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(anomalize_aud_brl, reference, metric = "sensitivity"), 2) # 0.28
round(evaluate(anomalize_aud_brl, reference, metric = "specificity"), 2) # 0.92
round(evaluate(anomalize_aud_brl, reference, metric = "precision"), 2)   # 0.55
round(evaluate(anomalize_aud_brl, reference, metric = "recall"), 2)      # 0.28

#Plot
print(evtplot(test_aud_brl, anomalize_aud_brl, reference))

##### 3. cad_brl #####
#Detect
anomalize_cad_brl <- evtdet.anomalize(test_cad_brl, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_cad_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     9      6     
# FALSE    56     178  

round(evaluate(anomalize_cad_brl, reference, metric = "F1"), 2)          # 0.22
round(evaluate(anomalize_cad_brl, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(anomalize_cad_brl, reference, metric = "sensitivity"), 2) # 0.14
round(evaluate(anomalize_cad_brl, reference, metric = "specificity"), 2) # 0.97
round(evaluate(anomalize_cad_brl, reference, metric = "precision"), 2)   # 0.60
round(evaluate(anomalize_cad_brl, reference, metric = "recall"), 2)      # 0.14

#Plot
print(evtplot(test_cad_brl, anomalize_cad_brl, reference))

##### 4. chf_brl #####
#Detect
anomalize_chf_brl <- evtdet.anomalize(test_chf_brl, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_chf_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     18     6  
# FALSE    47     178 

round(evaluate(anomalize_chf_brl, reference, metric = "F1"), 2)          # 0.40
round(evaluate(anomalize_chf_brl, reference, metric = "accuracy"), 2)    # 0.79
round(evaluate(anomalize_chf_brl, reference, metric = "sensitivity"), 2) # 0.28
round(evaluate(anomalize_chf_brl, reference, metric = "specificity"), 2) # 0.97
round(evaluate(anomalize_chf_brl, reference, metric = "precision"), 2)   # 0.75
round(evaluate(anomalize_chf_brl, reference, metric = "recall"), 2)      # 0.28

#Plot
print(evtplot(test_chf_brl, anomalize_chf_brl, reference))

##### 5. eur_brl #####
#Detect
anomalize_eur_brl <- evtdet.anomalize(test_eur_brl, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_eur_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     9      7 
# FALSE    56     177  

round(evaluate(anomalize_eur_brl, reference, metric = "F1"), 2)          # 0.22
round(evaluate(anomalize_eur_brl, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(anomalize_eur_brl, reference, metric = "sensitivity"), 2) # 0.14
round(evaluate(anomalize_eur_brl, reference, metric = "specificity"), 2) # 0.96
round(evaluate(anomalize_eur_brl, reference, metric = "precision"), 2)   # 0.56
round(evaluate(anomalize_eur_brl, reference, metric = "recall"), 2)      # 0.14

#Plot
print(evtplot(test_eur_brl, anomalize_eur_brl, reference))

##### 6. gbp_brl #####
#Detect
anomalize_gbp_brl <- evtdet.anomalize(test_gbp_brl, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_gbp_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     9      7    
# FALSE    56     177  

round(evaluate(anomalize_gbp_brl, reference, metric = "F1"), 2)          # 0.22
round(evaluate(anomalize_gbp_brl, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(anomalize_gbp_brl, reference, metric = "sensitivity"), 2) # 0.14
round(evaluate(anomalize_gbp_brl, reference, metric = "specificity"), 2) # 0.96
round(evaluate(anomalize_gbp_brl, reference, metric = "precision"), 2)   # 0.56
round(evaluate(anomalize_gbp_brl, reference, metric = "recall"), 2)      # 0.14

#Plot
print(evtplot(test_gbp_brl, anomalize_gbp_brl, reference))

##### 7. sgd_brl #####
#Detect
anomalize_sgd_brl <- evtdet.anomalize(test_sgd_brl, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_sgd_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     9      6    
# FALSE    56     178  

round(evaluate(anomalize_sgd_brl, reference, metric = "F1"), 2)          # 0.22
round(evaluate(anomalize_sgd_brl, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(anomalize_sgd_brl, reference, metric = "sensitivity"), 2) # 0.14
round(evaluate(anomalize_sgd_brl, reference, metric = "specificity"), 2) # 0.97
round(evaluate(anomalize_sgd_brl, reference, metric = "precision"), 2)   # 0.60
round(evaluate(anomalize_sgd_brl, reference, metric = "recall"), 2)      # 0.14

#Plot
print(evtplot(test_sgd_brl, anomalize_sgd_brl, reference))

##### 8. usd_brl #####
#Detect
anomalize_usd_brl <- evtdet.anomalize(test_usd_brl, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_usd_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     14     7 
# FALSE    51     177  

round(evaluate(anomalize_usd_brl, reference, metric = "F1"), 2)          # 0.33
round(evaluate(anomalize_usd_brl, reference, metric = "accuracy"), 2)    # 0.77
round(evaluate(anomalize_usd_brl, reference, metric = "sensitivity"), 2) # 0.22
round(evaluate(anomalize_usd_brl, reference, metric = "specificity"), 2) # 0.96
round(evaluate(anomalize_usd_brl, reference, metric = "precision"), 2)   # 0.67
round(evaluate(anomalize_usd_brl, reference, metric = "recall"), 2)      # 0.22

#Plot
print(evtplot(test_usd_brl, anomalize_usd_brl, reference))

##### 9. cny_brl #####
#Detect
anomalize_cny_brl <- evtdet.anomalize(test_cny_brl, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_cny_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     23     13  
# FALSE    42     171 

round(evaluate(anomalize_cny_brl, reference, metric = "F1"), 2)          # 0.46
round(evaluate(anomalize_cny_brl, reference, metric = "accuracy"), 2)    # 0.78
round(evaluate(anomalize_cny_brl, reference, metric = "sensitivity"), 2) # 0.35
round(evaluate(anomalize_cny_brl, reference, metric = "specificity"), 2) # 0.93
round(evaluate(anomalize_cny_brl, reference, metric = "precision"), 2)   # 0.64
round(evaluate(anomalize_cny_brl, reference, metric = "recall"), 2)      # 0.35

#Plot
print(evtplot(test_cny_brl, anomalize_cny_brl, reference))

##### 10. dkk_brl #####
#Detect
anomalize_dkk_brl <- evtdet.anomalize(test_dkk_brl, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_dkk_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     8      6
# FALSE    57     178  

round(evaluate(anomalize_dkk_brl, reference, metric = "F1"), 2)          # 0.20
round(evaluate(anomalize_dkk_brl, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(anomalize_dkk_brl, reference, metric = "sensitivity"), 2) # 0.12
round(evaluate(anomalize_dkk_brl, reference, metric = "specificity"), 2) # 0.97
round(evaluate(anomalize_dkk_brl, reference, metric = "precision"), 2)   # 0.57
round(evaluate(anomalize_dkk_brl, reference, metric = "recall"), 2)      # 0.12

#Plot
print(evtplot(test_dkk_brl, anomalize_dkk_brl, reference))

##### 11. mxn_brl #####
#Detect
anomalize_mxn_brl <- evtdet.anomalize(test_mxn_brl, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_mxn_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     11     9      
# FALSE    54     175  

round(evaluate(anomalize_mxn_brl, reference, metric = "F1"), 2)          # 0.26
round(evaluate(anomalize_mxn_brl, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(anomalize_mxn_brl, reference, metric = "sensitivity"), 2) # 0.17
round(evaluate(anomalize_mxn_brl, reference, metric = "specificity"), 2) # 0.95
round(evaluate(anomalize_mxn_brl, reference, metric = "precision"), 2)   # 0.55
round(evaluate(anomalize_mxn_brl, reference, metric = "recall"), 2)      # 0.17

#Plot
print(evtplot(test_mxn_brl, anomalize_mxn_brl, reference))

##### 12. nok_brl #####
#Detect
anomalize_nok_brl <- evtdet.anomalize(test_nok_brl, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_nok_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     3      5  
# FALSE    62     179  

round(evaluate(anomalize_nok_brl, reference, metric = "F1"), 2)          # 0.08
round(evaluate(anomalize_nok_brl, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(anomalize_nok_brl, reference, metric = "sensitivity"), 2) # 0.05
round(evaluate(anomalize_nok_brl, reference, metric = "specificity"), 2) # 0.97
round(evaluate(anomalize_nok_brl, reference, metric = "precision"), 2)   # 0.38
round(evaluate(anomalize_nok_brl, reference, metric = "recall"), 2)      # 0.05

#Plot
print(evtplot(test_nok_brl, anomalize_nok_brl, reference))

##### 13. nzd_brl #####
#Detect
anomalize_nzd_brl <- evtdet.anomalize(test_nzd_brl, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_nzd_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     16     15  
# FALSE    49     169  

round(evaluate(anomalize_nzd_brl, reference, metric = "F1"), 2)          # 0.33
round(evaluate(anomalize_nzd_brl, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(anomalize_nzd_brl, reference, metric = "sensitivity"), 2) # 0.25
round(evaluate(anomalize_nzd_brl, reference, metric = "specificity"), 2) # 0.92
round(evaluate(anomalize_nzd_brl, reference, metric = "precision"), 2)   # 0.52
round(evaluate(anomalize_nzd_brl, reference, metric = "recall"), 2)      # 0.25

#Plot
print(evtplot(test_nzd_brl, anomalize_nzd_brl, reference))

##### 14. pln_brl #####
#Detect
anomalize_pln_brl <- evtdet.anomalize(test_pln_brl, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_pln_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     7      5     
# FALSE    58     179  

round(evaluate(anomalize_pln_brl, reference, metric = "F1"), 2)          # 0.18
round(evaluate(anomalize_pln_brl, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(anomalize_pln_brl, reference, metric = "sensitivity"), 2) # 0.11
round(evaluate(anomalize_pln_brl, reference, metric = "specificity"), 2) # 0.97
round(evaluate(anomalize_pln_brl, reference, metric = "precision"), 2)   # 0.58
round(evaluate(anomalize_pln_brl, reference, metric = "recall"), 2)      # 0.11

#Plot
print(evtplot(test_pln_brl, anomalize_pln_brl, reference))

##### 15. sek_brl #####
#Detect
anomalize_sek_brl <- evtdet.anomalize(test_sek_brl, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_sek_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     16     14 
# FALSE    49     170

round(evaluate(anomalize_sek_brl, reference, metric = "F1"), 2)          # 0.34
round(evaluate(anomalize_sek_brl, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(anomalize_sek_brl, reference, metric = "sensitivity"), 2) # 0.25
round(evaluate(anomalize_sek_brl, reference, metric = "specificity"), 2) # 0.92
round(evaluate(anomalize_sek_brl, reference, metric = "precision"), 2)   # 0.53
round(evaluate(anomalize_sek_brl, reference, metric = "recall"), 2)      # 0.25

#Plot
print(evtplot(test_sek_brl, anomalize_sek_brl, reference))

##### 16. try_brl #####
#Detect
anomalize_try_brl <- evtdet.anomalize(test_try_brl, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_try_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     7      10   
# FALSE    58     174  

round(evaluate(anomalize_try_brl, reference, metric = "F1"), 2)          # 0.17
round(evaluate(anomalize_try_brl, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(anomalize_try_brl, reference, metric = "sensitivity"), 2) # 0.11
round(evaluate(anomalize_try_brl, reference, metric = "specificity"), 2) # 0.95
round(evaluate(anomalize_try_brl, reference, metric = "precision"), 2)   # 0.41
round(evaluate(anomalize_try_brl, reference, metric = "recall"), 2)      # 0.11

#Plot
print(evtplot(test_try_brl, anomalize_try_brl, reference))

##### 17. zar_brl #####
#Detect
anomalize_zar_brl <- evtdet.anomalize(test_zar_brl, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_zar_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     1      22   
# FALSE    64     162  

round(evaluate(anomalize_zar_brl, reference, metric = "F1"), 2)          # 0.02
round(evaluate(anomalize_zar_brl, reference, metric = "accuracy"), 2)    # 0.65
round(evaluate(anomalize_zar_brl, reference, metric = "sensitivity"), 2) # 0.02
round(evaluate(anomalize_zar_brl, reference, metric = "specificity"), 2) # 0.88
round(evaluate(anomalize_zar_brl, reference, metric = "precision"), 2)   # 0.04
round(evaluate(anomalize_zar_brl, reference, metric = "recall"), 2)      # 0.02

#Plot
print(evtplot(test_zar_brl, anomalize_zar_brl, reference))

##### 18. pen_brl #####
#Detect
anomalize_pen_brl <- evtdet.anomalize(test_pen_brl, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_pen_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     17     6 
# FALSE    48     178  

round(evaluate(anomalize_pen_brl, reference, metric = "F1"), 2)          # 0.39
round(evaluate(anomalize_pen_brl, reference, metric = "accuracy"), 2)    # 0.78
round(evaluate(anomalize_pen_brl, reference, metric = "sensitivity"), 2) # 0.26
round(evaluate(anomalize_pen_brl, reference, metric = "specificity"), 2) # 0.97
round(evaluate(anomalize_pen_brl, reference, metric = "precision"), 2)   # 0.74
round(evaluate(anomalize_pen_brl, reference, metric = "recall"), 2)      # 0.26

#Plot
print(evtplot(test_pen_brl, anomalize_pen_brl, reference))

###########################################
##### Adaptive Normalization Outliers #####
###########################################

##### 1. ars_brl #####
#Detect
an_ars_brl <- evtdet.an_outliers(test_ars_brl, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_ars_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     8      1  
# FALSE    57     183

round(evaluate(an_ars_brl, reference, metric = "F1"), 2)          # 0.22
round(evaluate(an_ars_brl, reference, metric = "accuracy"), 2)    # 0.77
round(evaluate(an_ars_brl, reference, metric = "sensitivity"), 2) # 0.12
round(evaluate(an_ars_brl, reference, metric = "specificity"), 2) # 0.99
round(evaluate(an_ars_brl, reference, metric = "precision"), 2)   # 0.89
round(evaluate(an_ars_brl, reference, metric = "recall"), 2)      # 0.12

#Plot
print(evtplot(test_ars_brl, an_ars_brl, reference))

##### 2. aud_brl #####
#Detect
an_aud_brl <- evtdet.an_outliers(test_aud_brl, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_aud_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     9      5    
# FALSE   56     179  

round(evaluate(an_aud_brl, reference, metric = "F1"), 2)          # 0.23
round(evaluate(an_aud_brl, reference, metric = "accuracy"), 2)    # 0.76
round(evaluate(an_aud_brl, reference, metric = "sensitivity"), 2) # 0.14
round(evaluate(an_aud_brl, reference, metric = "specificity"), 2) # 0.97
round(evaluate(an_aud_brl, reference, metric = "precision"), 2)   # 0.64
round(evaluate(an_aud_brl, reference, metric = "recall"), 2)      # 0.14

#Plot
print(evtplot(test_aud_brl, an_aud_brl, reference))

##### 3. cad_brl #####
#Detect
an_cad_brl <- evtdet.an_outliers(test_cad_brl, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_cad_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     7      3 
# FALSE    58     181   

round(evaluate(an_cad_brl, reference, metric = "F1"), 2)          # 0.19
round(evaluate(an_cad_brl, reference, metric = "accuracy"), 2)    # 0.76
round(evaluate(an_cad_brl, reference, metric = "sensitivity"), 2) # 0.11
round(evaluate(an_cad_brl, reference, metric = "specificity"), 2) # 0.98
round(evaluate(an_cad_brl, reference, metric = "precision"), 2)   # 0.70
round(evaluate(an_cad_brl, reference, metric = "recall"), 2)      # 0.11

#Plot
print(evtplot(test_cad_brl, an_cad_brl, reference))

##### 4. chf_brl #####
#Detect
an_chf_brl <- evtdet.an_outliers(test_chf_brl, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_chf_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     11     4 
# FALSE    54     180  

round(evaluate(an_chf_brl, reference, metric = "F1"), 2)          # 0.28
round(evaluate(an_chf_brl, reference, metric = "accuracy"), 2)    # 0.77
round(evaluate(an_chf_brl, reference, metric = "sensitivity"), 2) # 0.17
round(evaluate(an_chf_brl, reference, metric = "specificity"), 2) # 0.98
round(evaluate(an_chf_brl, reference, metric = "precision"), 2)   # 0.73
round(evaluate(an_chf_brl, reference, metric = "recall"), 2)      # 0.17

#Plot
print(evtplot(test_chf_brl, an_chf_brl, reference))

##### 5. eur_brl #####
#Detect
an_eur_brl <- evtdet.an_outliers(test_eur_brl, w = 30, alpha = 1.5, na.action = na.omit)

#Error in data.frame(..., check.names = FALSE) : 
#  arguments imply differing number of rows: 0, 1

#Evaluate
evaluate(an_eur_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE       

round(evaluate(an_eur_brl, reference, metric = "F1"), 2)          # 
round(evaluate(an_eur_brl, reference, metric = "accuracy"), 2)    # 
round(evaluate(an_eur_brl, reference, metric = "sensitivity"), 2) # 
round(evaluate(an_eur_brl, reference, metric = "specificity"), 2) # 
round(evaluate(an_eur_brl, reference, metric = "precision"), 2)   # 
round(evaluate(an_eur_brl, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_eur_brl, an_eur_brl, reference))

##### 6. gbp_brl #####
#Detect
an_gbp_brl <- evtdet.an_outliers(test_gbp_brl, w = 30, alpha = 1.5, na.action = na.omit)

#Error in data.frame(..., check.names = FALSE) : 
#  arguments imply differing number of rows: 0, 1

#Evaluate
evaluate(an_gbp_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE     

round(evaluate(an_gbp_brl, reference, metric = "F1"), 2)          # 
round(evaluate(an_gbp_brl, reference, metric = "accuracy"), 2)    # 
round(evaluate(an_gbp_brl, reference, metric = "sensitivity"), 2) # 
round(evaluate(an_gbp_brl, reference, metric = "specificity"), 2) # 
round(evaluate(an_gbp_brl, reference, metric = "precision"), 2)   # 
round(evaluate(an_gbp_brl, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_gbp_brl, an_gbp_brl, reference))

##### 7. sgd_brl #####
#Detect
an_sgd_brl <- evtdet.an_outliers(test_sgd_brl, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_sgd_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     8      4   
# FALSE    57     180       

round(evaluate(an_sgd_brl, reference, metric = "F1"), 2)          # 0.21
round(evaluate(an_sgd_brl, reference, metric = "accuracy"), 2)    # 0.76
round(evaluate(an_sgd_brl, reference, metric = "sensitivity"), 2) # 0.12
round(evaluate(an_sgd_brl, reference, metric = "specificity"), 2) # 0.98
round(evaluate(an_sgd_brl, reference, metric = "precision"), 2)   # 0.67
round(evaluate(an_sgd_brl, reference, metric = "recall"), 2)      # 0.12

#Plot
print(evtplot(test_sgd_brl, an_sgd_brl, reference))

##### 8. usd_brl #####
#Detect
an_usd_brl <- evtdet.an_outliers(test_usd_brl, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_usd_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     5      2    
# FALSE    60     182    

round(evaluate(an_usd_brl, reference, metric = "F1"), 2)          # 0.14
round(evaluate(an_usd_brl, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(an_usd_brl, reference, metric = "sensitivity"), 2) # 0.08
round(evaluate(an_usd_brl, reference, metric = "specificity"), 2) # 0.99
round(evaluate(an_usd_brl, reference, metric = "precision"), 2)   # 0.71
round(evaluate(an_usd_brl, reference, metric = "recall"), 2)      # 0.08

#Plot
print(evtplot(test_usd_brl, an_usd_brl, reference))

##### 9. cny_brl #####
#Detect
an_cny_brl <- evtdet.an_outliers(test_cny_brl, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_cny_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     4      1    
# FALSE    61     183    

round(evaluate(an_cny_brl, reference, metric = "F1"), 2)          # 0.11
round(evaluate(an_cny_brl, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(an_cny_brl, reference, metric = "sensitivity"), 2) # 0.06
round(evaluate(an_cny_brl, reference, metric = "specificity"), 2) # 0.99
round(evaluate(an_cny_brl, reference, metric = "precision"), 2)   # 0.80
round(evaluate(an_cny_brl, reference, metric = "recall"), 2)      # 0.06

#Plot
print(evtplot(test_cny_brl, an_cny_brl, reference))

##### 10. dkk_brl #####
#Detect
an_dkk_brl <- evtdet.an_outliers(test_dkk_brl, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_dkk_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     7      4 
# FALSE    58     180  

round(evaluate(an_dkk_brl, reference, metric = "F1"), 2)          # 0.18
round(evaluate(an_dkk_brl, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(an_dkk_brl, reference, metric = "sensitivity"), 2) # 0.11
round(evaluate(an_dkk_brl, reference, metric = "specificity"), 2) # 0.98
round(evaluate(an_dkk_brl, reference, metric = "precision"), 2)   # 0.64
round(evaluate(an_dkk_brl, reference, metric = "recall"), 2)      # 0.11

#Plot
print(evtplot(test_dkk_brl, an_dkk_brl, reference))

##### 11. mxn_brl #####
#Detect
an_mxn_brl <- evtdet.an_outliers(test_mxn_brl, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_mxn_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     1      1     
# FALSE    64     183 

round(evaluate(an_mxn_brl, reference, metric = "F1"), 2)          # 0.03
round(evaluate(an_mxn_brl, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(an_mxn_brl, reference, metric = "sensitivity"), 2) # 0.02
round(evaluate(an_mxn_brl, reference, metric = "specificity"), 2) # 0.99
round(evaluate(an_mxn_brl, reference, metric = "precision"), 2)   # 0.50
round(evaluate(an_mxn_brl, reference, metric = "recall"), 2)      # 0.02

#Plot
print(evtplot(test_mxn_brl, an_mxn_brl, reference))

##### 12. nok_brl #####
#Detect
an_nok_brl <- evtdet.an_outliers(test_nok_brl, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_nok_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     4      8 
# FALSE    61     176  

round(evaluate(an_nok_brl, reference, metric = "F1"), 2)          # 0.10
round(evaluate(an_nok_brl, reference, metric = "accuracy"), 2)    # 0.72
round(evaluate(an_nok_brl, reference, metric = "sensitivity"), 2) # 0.06
round(evaluate(an_nok_brl, reference, metric = "specificity"), 2) # 0.96
round(evaluate(an_nok_brl, reference, metric = "precision"), 2)   # 0.33
round(evaluate(an_nok_brl, reference, metric = "recall"), 2)      # 0.06

#Plot
print(evtplot(test_nok_brl, an_nok_brl, reference))

##### 13. nzd_brl #####
#Detect
an_nzd_brl <- evtdet.an_outliers(test_nzd_brl, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_nzd_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     6      3      
# FALSE    59     181  

round(evaluate(an_nzd_brl, reference, metric = "F1"), 2)          # 0.16
round(evaluate(an_nzd_brl, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(an_nzd_brl, reference, metric = "sensitivity"), 2) # 0.09
round(evaluate(an_nzd_brl, reference, metric = "specificity"), 2) # 0.98
round(evaluate(an_nzd_brl, reference, metric = "precision"), 2)   # 0.67
round(evaluate(an_nzd_brl, reference, metric = "recall"), 2)      # 0.09

#Plot
print(evtplot(test_nzd_brl, an_nzd_brl, reference))

##### 14. pln_brl #####
#Detect
an_pln_brl <- evtdet.an_outliers(test_pln_brl, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_pln_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     8      3 
# FALSE    57     181   

round(evaluate(an_pln_brl, reference, metric = "F1"), 2)          # 0.21
round(evaluate(an_pln_brl, reference, metric = "accuracy"), 2)    # 0.76
round(evaluate(an_pln_brl, reference, metric = "sensitivity"), 2) # 0.12
round(evaluate(an_pln_brl, reference, metric = "specificity"), 2) # 0.98
round(evaluate(an_pln_brl, reference, metric = "precision"), 2)   # 0.73
round(evaluate(an_pln_brl, reference, metric = "recall"), 2)      # 0.12

#Plot
print(evtplot(test_pln_brl, an_pln_brl, reference))

##### 15. sek_brl #####
#Detect
an_sek_brl <- evtdet.an_outliers(test_sek_brl, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_sek_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     6      6    
# FALSE    59     178 

round(evaluate(an_sek_brl, reference, metric = "F1"), 2)          # 0.16
round(evaluate(an_sek_brl, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(an_sek_brl, reference, metric = "sensitivity"), 2) # 0.09
round(evaluate(an_sek_brl, reference, metric = "specificity"), 2) # 0.97
round(evaluate(an_sek_brl, reference, metric = "precision"), 2)   # 0.50
round(evaluate(an_sek_brl, reference, metric = "recall"), 2)      # 0.09

#Plot
print(evtplot(test_sek_brl, an_sek_brl, reference))

##### 16. try_brl #####
#Detect
an_try_brl <- evtdet.an_outliers(test_try_brl, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_try_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     0      6    
# FALSE    65     178  

round(evaluate(an_try_brl, reference, metric = "F1"), 2)          # NaN
round(evaluate(an_try_brl, reference, metric = "accuracy"), 2)    # 0.71
round(evaluate(an_try_brl, reference, metric = "sensitivity"), 2) # 0.00
round(evaluate(an_try_brl, reference, metric = "specificity"), 2) # 0.97
round(evaluate(an_try_brl, reference, metric = "precision"), 2)   # 0.00
round(evaluate(an_try_brl, reference, metric = "recall"), 2)      # 0.00

#Plot
print(evtplot(test_try_brl, an_try_brl, reference))

##### 17. zar_brl #####
#Detect
an_zar_brl <- evtdet.an_outliers(test_zar_brl, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_zar_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     1      43  
# FALSE    64     141  

round(evaluate(an_zar_brl, reference, metric = "F1"), 2)          # 0.02
round(evaluate(an_zar_brl, reference, metric = "accuracy"), 2)    # 0.57
round(evaluate(an_zar_brl, reference, metric = "sensitivity"), 2) # 0.02
round(evaluate(an_zar_brl, reference, metric = "specificity"), 2) # 0.77
round(evaluate(an_zar_brl, reference, metric = "precision"), 2)   # 0.02
round(evaluate(an_zar_brl, reference, metric = "recall"), 2)      # 0.02

#Plot
print(evtplot(test_zar_brl, an_zar_brl, reference))

##### 18. pen_brl #####
#Detect
an_pen_brl <- evtdet.an_outliers(test_pen_brl, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_pen_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     4      0
# FALSE    61     184    

round(evaluate(an_pen_brl, reference, metric = "F1"), 2)          # 0.12
round(evaluate(an_pen_brl, reference, metric = "accuracy"), 2)    # 0.76
round(evaluate(an_pen_brl, reference, metric = "sensitivity"), 2) # 0.06
round(evaluate(an_pen_brl, reference, metric = "specificity"), 2) # 1.00
round(evaluate(an_pen_brl, reference, metric = "precision"), 2)   # 1.00
round(evaluate(an_pen_brl, reference, metric = "recall"), 2)      # 0.06

#Plot
print(evtplot(test_pen_brl, an_pen_brl, reference))

#######################
##### EventDetect #####
#######################

##### 1. ars_brl #####
#Detect
eventdetect_ars_brl <- evtdet.eventdetect(na.omit(test_ars_brl), w = 30)

#Evaluate
evaluate(eventdetect_ars_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     44     67   
# FALSE    21     117  

round(evaluate(eventdetect_ars_brl, reference, metric = "F1"), 2)          # 0.50
round(evaluate(eventdetect_ars_brl, reference, metric = "accuracy"), 2)    # 0.65
round(evaluate(eventdetect_ars_brl, reference, metric = "sensitivity"), 2) # 0.68
round(evaluate(eventdetect_ars_brl, reference, metric = "specificity"), 2) # 0.64
round(evaluate(eventdetect_ars_brl, reference, metric = "precision"), 2)   # 0.40
round(evaluate(eventdetect_ars_brl, reference, metric = "recall"), 2)      # 0.68

#Plot
print(evtplot(test_ars_brl, eventdetect_ars_brl, reference))

##### 2. aud_brl #####
#Detect
eventdetect_aud_brl <- evtdet.eventdetect(na.omit(test_aud_brl), w = 30)

#Evaluate
evaluate(eventdetect_aud_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     36     34 
# FALSE    29     150

round(evaluate(eventdetect_aud_brl, reference, metric = "F1"), 2)          # 0.53
round(evaluate(eventdetect_aud_brl, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(eventdetect_aud_brl, reference, metric = "sensitivity"), 2) # 0.55
round(evaluate(eventdetect_aud_brl, reference, metric = "specificity"), 2) # 0.82
round(evaluate(eventdetect_aud_brl, reference, metric = "precision"), 2)   # 0.51
round(evaluate(eventdetect_aud_brl, reference, metric = "recall"), 2)      # 0.55

#Plot
print(evtplot(test_aud_brl, eventdetect_aud_brl, reference))

##### 3. cad_brl #####
#Detect
eventdetect_cad_brl <- evtdet.eventdetect(na.omit(test_cad_brl), w = 30)

#Evaluate
evaluate(eventdetect_cad_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     3      1    
# FALSE    62     183  

round(evaluate(eventdetect_cad_brl, reference, metric = "F1"), 2)          # 0.09
round(evaluate(eventdetect_cad_brl, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(eventdetect_cad_brl, reference, metric = "sensitivity"), 2) # 0.05
round(evaluate(eventdetect_cad_brl, reference, metric = "specificity"), 2) # 0.99
round(evaluate(eventdetect_cad_brl, reference, metric = "precision"), 2)   # 0.75
round(evaluate(eventdetect_cad_brl, reference, metric = "recall"), 2)      # 0.05

#Plot
print(evtplot(test_cad_brl, eventdetect_cad_brl, reference))

##### 4. chf_brl #####
#Detect
eventdetect_chf_brl <- evtdet.eventdetect(na.omit(test_chf_brl), w = 30)

#Evaluate
evaluate(eventdetect_chf_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     3      1   
# FALSE    62     183  

round(evaluate(eventdetect_chf_brl, reference, metric = "F1"), 2)          # 0.09
round(evaluate(eventdetect_chf_brl, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(eventdetect_chf_brl, reference, metric = "sensitivity"), 2) # 0.05
round(evaluate(eventdetect_chf_brl, reference, metric = "specificity"), 2) # 0.99
round(evaluate(eventdetect_chf_brl, reference, metric = "precision"), 2)   # 0.75
round(evaluate(eventdetect_chf_brl, reference, metric = "recall"), 2)      # 0.05

#Plot
print(evtplot(test_chf_brl, eventdetect_chf_brl, reference))

##### 5. eur_brl #####
#Detect
eventdetect_eur_brl <- evtdet.eventdetect(na.omit(test_eur_brl), w = 30)

#Evaluate
evaluate(eventdetect_eur_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     21     28   
# FALSE    44     156 

round(evaluate(eventdetect_eur_brl, reference, metric = "F1"), 2)          # 0.37
round(evaluate(eventdetect_eur_brl, reference, metric = "accuracy"), 2)    # 0.71
round(evaluate(eventdetect_eur_brl, reference, metric = "sensitivity"), 2) # 0.32
round(evaluate(eventdetect_eur_brl, reference, metric = "specificity"), 2) # 0.85
round(evaluate(eventdetect_eur_brl, reference, metric = "precision"), 2)   # 0.43
round(evaluate(eventdetect_eur_brl, reference, metric = "recall"), 2)      # 0.32

#Plot
print(evtplot(test_eur_brl, eventdetect_eur_brl, reference))

##### 6. gbp_brl #####
#Detect
eventdetect_gbp_brl <- evtdet.eventdetect(na.omit(test_gbp_brl), w = 30)

#Evaluate
evaluate(eventdetect_gbp_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     21     28 
# FALSE    44     156  

round(evaluate(eventdetect_gbp_brl, reference, metric = "F1"), 2)          # 0.37
round(evaluate(eventdetect_gbp_brl, reference, metric = "accuracy"), 2)    # 0.71
round(evaluate(eventdetect_gbp_brl, reference, metric = "sensitivity"), 2) # 0.32
round(evaluate(eventdetect_gbp_brl, reference, metric = "specificity"), 2) # 0.85
round(evaluate(eventdetect_gbp_brl, reference, metric = "precision"), 2)   # 0.43
round(evaluate(eventdetect_gbp_brl, reference, metric = "recall"), 2)      # 0.32

#Plot
print(evtplot(test_gbp_brl, eventdetect_gbp_brl, reference))

##### 7. sgd_brl #####
#Detect
eventdetect_sgd_brl <- evtdet.eventdetect(na.omit(test_sgd_brl), w = 30)

#Evaluate
evaluate(eventdetect_sgd_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     49     39    
# FALSE    16     145   

round(evaluate(eventdetect_sgd_brl, reference, metric = "F1"), 2)          # 0.64
round(evaluate(eventdetect_sgd_brl, reference, metric = "accuracy"), 2)    # 0.78
round(evaluate(eventdetect_sgd_brl, reference, metric = "sensitivity"), 2) # 0.75
round(evaluate(eventdetect_sgd_brl, reference, metric = "specificity"), 2) # 0.79
round(evaluate(eventdetect_sgd_brl, reference, metric = "precision"), 2)   # 0.56
round(evaluate(eventdetect_sgd_brl, reference, metric = "recall"), 2)      # 0.75

#Plot
print(evtplot(test_sgd_brl, eventdetect_sgd_brl, reference))

##### 8. usd_brl #####
#Detect
eventdetect_usd_brl <- evtdet.eventdetect(na.omit(test_usd_brl), w = 30)

#Evaluate
evaluate(eventdetect_usd_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     26     34       
# FALSE    39     150  

round(evaluate(eventdetect_usd_brl, reference, metric = "F1"), 2)          # 0.42
round(evaluate(eventdetect_usd_brl, reference, metric = "accuracy"), 2)    # 0.71
round(evaluate(eventdetect_usd_brl, reference, metric = "sensitivity"), 2) # 0.40
round(evaluate(eventdetect_usd_brl, reference, metric = "specificity"), 2) # 0.82
round(evaluate(eventdetect_usd_brl, reference, metric = "precision"), 2)   # 0.43
round(evaluate(eventdetect_usd_brl, reference, metric = "recall"), 2)      # 0.40

#Plot
print(evtplot(test_usd_brl, eventdetect_usd_brl, reference))

##### 9. cny_brl #####
#Detect
eventdetect_cny_brl <- evtdet.eventdetect(na.omit(test_cny_brl), w = 30)

#Evaluate
evaluate(eventdetect_cny_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     49     38 
# FALSE    16     146  

round(evaluate(eventdetect_cny_brl, reference, metric = "F1"), 2)          # 0.64
round(evaluate(eventdetect_cny_brl, reference, metric = "accuracy"), 2)    # 0.78
round(evaluate(eventdetect_cny_brl, reference, metric = "sensitivity"), 2) # 0.75
round(evaluate(eventdetect_cny_brl, reference, metric = "specificity"), 2) # 0.79
round(evaluate(eventdetect_cny_brl, reference, metric = "precision"), 2)   # 0.56
round(evaluate(eventdetect_cny_brl, reference, metric = "recall"), 2)      # 0.75

#Plot
print(evtplot(test_cny_brl, eventdetect_cny_brl, reference))

##### 10. dkk_brl #####
#Detect
eventdetect_dkk_brl <- evtdet.eventdetect(na.omit(test_dkk_brl), w = 30)

#Evaluate
evaluate(eventdetect_dkk_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     3      1
# FALSE    62     183  

round(evaluate(eventdetect_dkk_brl, reference, metric = "F1"), 2)          # 0.09
round(evaluate(eventdetect_dkk_brl, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(eventdetect_dkk_brl, reference, metric = "sensitivity"), 2) # 0.05
round(evaluate(eventdetect_dkk_brl, reference, metric = "specificity"), 2) # 0.99
round(evaluate(eventdetect_dkk_brl, reference, metric = "precision"), 2)   # 0.75
round(evaluate(eventdetect_dkk_brl, reference, metric = "recall"), 2)      # 0.05

#Plot
print(evtplot(test_dkk_brl, eventdetect_dkk_brl, reference))

##### 11. mxn_brl #####
#Detect
eventdetect_mxn_brl <- evtdet.eventdetect(na.omit(test_mxn_brl), w = 30)

#Evaluate
evaluate(eventdetect_mxn_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     7      51
# FALSE    58     133  

round(evaluate(eventdetect_mxn_brl, reference, metric = "F1"), 2)          # 0.11
round(evaluate(eventdetect_mxn_brl, reference, metric = "accuracy"), 2)    # 0.56
round(evaluate(eventdetect_mxn_brl, reference, metric = "sensitivity"), 2) # 0.11
round(evaluate(eventdetect_mxn_brl, reference, metric = "specificity"), 2) # 0.72
round(evaluate(eventdetect_mxn_brl, reference, metric = "precision"), 2)   # 0.12
round(evaluate(eventdetect_mxn_brl, reference, metric = "recall"), 2)      # 0.11

#Plot
print(evtplot(test_mxn_brl, eventdetect_mxn_brl, reference))

##### 12. nok_brl #####
#Detect
eventdetect_nok_brl <- evtdet.eventdetect(na.omit(test_nok_brl), w = 30)

#Evaluate
evaluate(eventdetect_nok_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     2      1    
# FALSE    63     183

round(evaluate(eventdetect_nok_brl, reference, metric = "F1"), 2)          # 0.06
round(evaluate(eventdetect_nok_brl, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(eventdetect_nok_brl, reference, metric = "sensitivity"), 2) # 0.03
round(evaluate(eventdetect_nok_brl, reference, metric = "specificity"), 2) # 0.99
round(evaluate(eventdetect_nok_brl, reference, metric = "precision"), 2)   # 0.67
round(evaluate(eventdetect_nok_brl, reference, metric = "recall"), 2)      # 0.03

#Plot
print(evtplot(test_nok_brl, eventdetect_nok_brl, reference))

##### 13. nzd_brl #####
#Detect
eventdetect_nzd_brl <- evtdet.eventdetect(na.omit(test_nzd_brl), w = 30)

#Evaluate
evaluate(eventdetect_nzd_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     2      1    
# FALSE    63     183 

round(evaluate(eventdetect_nzd_brl, reference, metric = "F1"), 2)          # 0.06
round(evaluate(eventdetect_nzd_brl, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(eventdetect_nzd_brl, reference, metric = "sensitivity"), 2) # 0.03
round(evaluate(eventdetect_nzd_brl, reference, metric = "specificity"), 2) # 0.99
round(evaluate(eventdetect_nzd_brl, reference, metric = "precision"), 2)   # 0.67
round(evaluate(eventdetect_nzd_brl, reference, metric = "recall"), 2)      # 0.03

#Plot
print(evtplot(test_nzd_brl, eventdetect_nzd_brl, reference))

##### 14. pln_brl #####
#Detect
eventdetect_pln_brl <- evtdet.eventdetect(na.omit(test_pln_brl), w = 30)

#Evaluate
evaluate(eventdetect_pln_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     3      1   
# FALSE    62     183  

round(evaluate(eventdetect_pln_brl, reference, metric = "F1"), 2)          # 0.09
round(evaluate(eventdetect_pln_brl, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(eventdetect_pln_brl, reference, metric = "sensitivity"), 2) # 0.05
round(evaluate(eventdetect_pln_brl, reference, metric = "specificity"), 2) # 0.99
round(evaluate(eventdetect_pln_brl, reference, metric = "precision"), 2)   # 0.75
round(evaluate(eventdetect_pln_brl, reference, metric = "recall"), 2)      # 0.05

#Plot
print(evtplot(test_pln_brl, eventdetect_pln_brl, reference))

##### 15. sek_brl #####
#Detect
eventdetect_sek_brl <- evtdet.eventdetect(na.omit(test_sek_brl), w = 30)

#Evaluate
evaluate(eventdetect_sek_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     2      1    
# FALSE    63     183  

round(evaluate(eventdetect_sek_brl, reference, metric = "F1"), 2)          # 0.06
round(evaluate(eventdetect_sek_brl, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(eventdetect_sek_brl, reference, metric = "sensitivity"), 2) # 0.03
round(evaluate(eventdetect_sek_brl, reference, metric = "specificity"), 2) # 0.99
round(evaluate(eventdetect_sek_brl, reference, metric = "precision"), 2)   # 0.67
round(evaluate(eventdetect_sek_brl, reference, metric = "recall"), 2)      # 0.03

#Plot
print(evtplot(test_sek_brl, eventdetect_sek_brl, reference))

##### 16. try_brl #####
#Detect
eventdetect_try_brl <- evtdet.eventdetect(na.omit(test_try_brl), w = 30)

#Evaluate
evaluate(eventdetect_try_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     59     99
# FALSE    6      85    

round(evaluate(eventdetect_try_brl, reference, metric = "F1"), 2)          # 0.53
round(evaluate(eventdetect_try_brl, reference, metric = "accuracy"), 2)    # 0.58
round(evaluate(eventdetect_try_brl, reference, metric = "sensitivity"), 2) # 0.91
round(evaluate(eventdetect_try_brl, reference, metric = "specificity"), 2) # 0.46
round(evaluate(eventdetect_try_brl, reference, metric = "precision"), 2)   # 0.37
round(evaluate(eventdetect_try_brl, reference, metric = "recall"), 2)      # 0.91

#Plot
print(evtplot(test_try_brl, eventdetect_try_brl, reference))

##### 17. zar_brl #####
#Detect
eventdetect_zar_brl <- evtdet.eventdetect(na.omit(test_zar_brl), w = 30)

#Evaluate
evaluate(eventdetect_zar_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     19     18   
# FALSE    46     166

round(evaluate(eventdetect_zar_brl, reference, metric = "F1"), 2)          # 0.37
round(evaluate(eventdetect_zar_brl, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(eventdetect_zar_brl, reference, metric = "sensitivity"), 2) # 0.29
round(evaluate(eventdetect_zar_brl, reference, metric = "specificity"), 2) # 0.90
round(evaluate(eventdetect_zar_brl, reference, metric = "precision"), 2)   # 0.51
round(evaluate(eventdetect_zar_brl, reference, metric = "recall"), 2)      # 0.29

#Plot
print(evtplot(test_zar_brl, eventdetect_zar_brl, reference))

##### 18. pen_brl #####
#Detect
eventdetect_pen_brl <- evtdet.eventdetect(na.omit(test_pen_brl), w = 30)

#Error in data.frame(..., check.names = FALSE) : 
#  arguments imply differing number of rows: 0, 1 

#Evaluate
evaluate(eventdetect_pen_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE    

round(evaluate(eventdetect_pen_brl, reference, metric = "F1"), 2)          # 
round(evaluate(eventdetect_pen_brl, reference, metric = "accuracy"), 2)    # 
round(evaluate(eventdetect_pen_brl, reference, metric = "sensitivity"), 2) # 
round(evaluate(eventdetect_pen_brl, reference, metric = "specificity"), 2) # 
round(evaluate(eventdetect_pen_brl, reference, metric = "precision"), 2)   # 
round(evaluate(eventdetect_pen_brl, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_pen_brl, eventdetect_pen_brl, reference))

#######################################
##### Auxiliary Model definitions #####
#######################################

ARIMA <- function(data) forecast::auto.arima(data)
AR <- function(data,p) forecast::Arima(data, order = c(p, 0, 0), seasonal = c(0, 0, 0))
garch <- function(data,spec,...) rugarch::ugarchfit(spec=spec,data=data,solver="hybrid", ...)@fit
ets <- function(data) forecast::ets(ts(data))
linreg <- function(data) {
  #browser()
  data <- as.data.frame(data)
  colnames(data) <- "x"
  data$t <- 1:nrow(data)
  
  #Adjusting a linear regression to the whole window
  lm(x~t, data)
}

#Garch specs
garch11 <- rugarch::ugarchspec(variance.model = list(model = "sGARCH", garchOrder = c(1, 1)), 
                               mean.model = list(armaOrder = c(1, 1), include.mean = TRUE), 
                               distribution.model = "norm")

####################################
##### Garch Volatility Outlier #####
####################################

##### 1. ars_brl #####
#Detect
garch_volatility_ars_brl <- evtdet.garch_volatility_outlier(test_ars_brl, spec = garch11, alpha = 1.5,
                                                            na.action = na.omit)

# Error in data.frame(..., check.names = FALSE) : 
#   arguments imply differing number of rows: 0, 1 

#Evaluate
evaluate(garch_volatility_ars_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE    

round(evaluate(garch_volatility_ars_brl, reference, metric = "F1"), 2)          # 
round(evaluate(garch_volatility_ars_brl, reference, metric = "accuracy"), 2)    # 
round(evaluate(garch_volatility_ars_brl, reference, metric = "sensitivity"), 2) # 
round(evaluate(garch_volatility_ars_brl, reference, metric = "specificity"), 2) # 
round(evaluate(garch_volatility_ars_brl, reference, metric = "precision"), 2)   # 
round(evaluate(garch_volatility_ars_brl, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_ars_brl, garch_volatility_ars_brl, reference))

##### 2. aud_brl #####
#Detect
garch_volatility_aud_brl <- evtdet.garch_volatility_outlier(test_aud_brl,
                                                            spec = garch11, alpha = 1.5,
                                                            na.action = na.omit)

#Evaluate
evaluate(garch_volatility_aud_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     13     12  
# FALSE    52     172 

round(evaluate(garch_volatility_aud_brl, reference, metric = "F1"), 2)          # 0.29
round(evaluate(garch_volatility_aud_brl, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(garch_volatility_aud_brl, reference, metric = "sensitivity"), 2) # 0.20
round(evaluate(garch_volatility_aud_brl, reference, metric = "specificity"), 2) # 0.93
round(evaluate(garch_volatility_aud_brl, reference, metric = "precision"), 2)   # 0.52
round(evaluate(garch_volatility_aud_brl, reference, metric = "recall"), 2)      # 0.20

#Plot
print(evtplot(test_aud_brl, garch_volatility_aud_brl, reference))

##### 3. cad_brl #####
#Detect
garch_volatility_cad_brl <- evtdet.garch_volatility_outlier(test_cad_brl,
                                                            spec = garch11, alpha = 1.5,
                                                            na.action = na.omit)

#Evaluate
evaluate(garch_volatility_cad_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     12     11   
# FALSE    53     173   

round(evaluate(garch_volatility_cad_brl, reference, metric = "F1"), 2)          # 0.27
round(evaluate(garch_volatility_cad_brl, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(garch_volatility_cad_brl, reference, metric = "sensitivity"), 2) # 0.18
round(evaluate(garch_volatility_cad_brl, reference, metric = "specificity"), 2) # 0.94
round(evaluate(garch_volatility_cad_brl, reference, metric = "precision"), 2)   # 0.52
round(evaluate(garch_volatility_cad_brl, reference, metric = "recall"), 2)      # 0.18

#Plot
print(evtplot(test_cad_brl, garch_volatility_cad_brl, reference))

##### 4. chf_brl #####
#Detect
garch_volatility_chf_brl <- evtdet.garch_volatility_outlier(test_chf_brl,
                                                            spec = garch11, alpha = 1.5,
                                                            na.action = na.omit)

#Evaluate
evaluate(garch_volatility_chf_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     13     8 
# FALSE    52     176    

round(evaluate(garch_volatility_chf_brl, reference, metric = "F1"), 2)          # 0.30
round(evaluate(garch_volatility_chf_brl, reference, metric = "accuracy"), 2)    # 0.76
round(evaluate(garch_volatility_chf_brl, reference, metric = "sensitivity"), 2) # 0.20
round(evaluate(garch_volatility_chf_brl, reference, metric = "specificity"), 2) # 0.96
round(evaluate(garch_volatility_chf_brl, reference, metric = "precision"), 2)   # 0.62
round(evaluate(garch_volatility_chf_brl, reference, metric = "recall"), 2)      # 0.20

#Plot
print(evtplot(test_chf_brl, garch_volatility_chf_brl, reference))

##### 5. eur_brl #####
#Detect
garch_volatility_eur_brl <- evtdet.garch_volatility_outlier(test_eur_brl,
                                                            spec = garch11, alpha = 1.5,
                                                            na.action = na.omit)

#Evaluate
evaluate(garch_volatility_eur_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     10     14 
# FALSE    55     170  

round(evaluate(garch_volatility_eur_brl, reference, metric = "F1"), 2)          # 0.22
round(evaluate(garch_volatility_eur_brl, reference, metric = "accuracy"), 2)    # 0.72
round(evaluate(garch_volatility_eur_brl, reference, metric = "sensitivity"), 2) # 0.15
round(evaluate(garch_volatility_eur_brl, reference, metric = "specificity"), 2) # 0.92
round(evaluate(garch_volatility_eur_brl, reference, metric = "precision"), 2)   # 0.42
round(evaluate(garch_volatility_eur_brl, reference, metric = "recall"), 2)      # 0.15

#Plot
print(evtplot(test_eur_brl, garch_volatility_eur_brl, reference))

##### 6. gbp_brl #####
#Detect
garch_volatility_gbp_brl <- evtdet.garch_volatility_outlier(test_gbp_brl,
                                                            spec = garch11, alpha = 1.5,
                                                            na.action = na.omit)

#Evaluate
evaluate(garch_volatility_gbp_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     10     14   
# FALSE    55     170  

round(evaluate(garch_volatility_gbp_brl, reference, metric = "F1"), 2)          # 0.22
round(evaluate(garch_volatility_gbp_brl, reference, metric = "accuracy"), 2)    # 0.72
round(evaluate(garch_volatility_gbp_brl, reference, metric = "sensitivity"), 2) # 0.15
round(evaluate(garch_volatility_gbp_brl, reference, metric = "specificity"), 2) # 0.92
round(evaluate(garch_volatility_gbp_brl, reference, metric = "precision"), 2)   # 0.42
round(evaluate(garch_volatility_gbp_brl, reference, metric = "recall"), 2)      # 0.15

#Plot
print(evtplot(test_gbp_brl, garch_volatility_gbp_brl, reference))

##### 7. sgd_brl #####
#Detect
garch_volatility_sgd_brl <- evtdet.garch_volatility_outlier(test_sgd_brl, 
                                                            spec = garch11, alpha = 1.5,
                                                            na.action = na.omit)

#Evaluate
evaluate(garch_volatility_sgd_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     12     11
# FALSE    53     173    

round(evaluate(garch_volatility_sgd_brl, reference, metric = "F1"), 2)          # 0.27
round(evaluate(garch_volatility_sgd_brl, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(garch_volatility_sgd_brl, reference, metric = "sensitivity"), 2) # 0.18
round(evaluate(garch_volatility_sgd_brl, reference, metric = "specificity"), 2) # 0.94
round(evaluate(garch_volatility_sgd_brl, reference, metric = "precision"), 2)   # 0.52
round(evaluate(garch_volatility_sgd_brl, reference, metric = "recall"), 2)      # 0.18

#Plot
print(evtplot(test_sgd_brl, garch_volatility_sgd_brl, reference))

##### 8. usd_brl #####
#Detect
garch_volatility_usd_brl <- evtdet.garch_volatility_outlier(test_usd_brl,
                                                            spec = garch11, alpha = 1.5,
                                                            na.action = na.omit)

#Evaluate
evaluate(garch_volatility_usd_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     10     9 
# FALSE    55     175     

round(evaluate(garch_volatility_usd_brl, reference, metric = "F1"), 2)          # 0.24
round(evaluate(garch_volatility_usd_brl, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(garch_volatility_usd_brl, reference, metric = "sensitivity"), 2) # 0.15
round(evaluate(garch_volatility_usd_brl, reference, metric = "specificity"), 2) # 0.95
round(evaluate(garch_volatility_usd_brl, reference, metric = "precision"), 2)   # 0.53
round(evaluate(garch_volatility_usd_brl, reference, metric = "recall"), 2)      # 0.15

#Plot
print(evtplot(test_usd_brl, garch_volatility_usd_brl, reference))

##### 9. cny_brl #####
#Detect
garch_volatility_cny_brl <- evtdet.garch_volatility_outlier(test_cny_brl,
                                                            spec = garch11, alpha = 1.5,
                                                            na.action = na.omit)

#Evaluate
evaluate(garch_volatility_cny_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     17     12 
# FALSE    48     172    

round(evaluate(garch_volatility_cny_brl, reference, metric = "F1"), 2)          # 0.36
round(evaluate(garch_volatility_cny_brl, reference, metric = "accuracy"), 2)    # 0.76
round(evaluate(garch_volatility_cny_brl, reference, metric = "sensitivity"), 2) # 0.26
round(evaluate(garch_volatility_cny_brl, reference, metric = "specificity"), 2) # 0.93
round(evaluate(garch_volatility_cny_brl, reference, metric = "precision"), 2)   # 0.59
round(evaluate(garch_volatility_cny_brl, reference, metric = "recall"), 2)      # 0.29

#Plot
print(evtplot(test_cny_brl, garch_volatility_cny_brl, reference))

##### 10. dkk_brl #####
#Detect
garch_volatility_dkk_brl <- evtdet.garch_volatility_outlier(test_dkk_brl,
                                                            spec = garch11, alpha = 1.5,
                                                            na.action = na.omit)

#Evaluate
evaluate(garch_volatility_dkk_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     11     12
# FALSE    54     172  

round(evaluate(garch_volatility_dkk_brl, reference, metric = "F1"), 2)          # 0.25
round(evaluate(garch_volatility_dkk_brl, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(garch_volatility_dkk_brl, reference, metric = "sensitivity"), 2) # 0.17
round(evaluate(garch_volatility_dkk_brl, reference, metric = "specificity"), 2) # 0.93
round(evaluate(garch_volatility_dkk_brl, reference, metric = "precision"), 2)   # 0.48
round(evaluate(garch_volatility_dkk_brl, reference, metric = "recall"), 2)      # 0.17

#Plot
print(evtplot(test_dkk_brl, garch_volatility_dkk_brl, reference))

##### 11. mxn_brl #####
#Detect
garch_volatility_mxn_brl <- evtdet.garch_volatility_outlier(test_mxn_brl,
                                                            spec = garch11, alpha = 1.5,
                                                            na.action = na.omit)

#Evaluate
evaluate(garch_volatility_mxn_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     8      18  
# FALSE    57     166   

round(evaluate(garch_volatility_mxn_brl, reference, metric = "F1"), 2)          # 0.18
round(evaluate(garch_volatility_mxn_brl, reference, metric = "accuracy"), 2)    # 0.70
round(evaluate(garch_volatility_mxn_brl, reference, metric = "sensitivity"), 2) # 0.12
round(evaluate(garch_volatility_mxn_brl, reference, metric = "specificity"), 2) # 0.90
round(evaluate(garch_volatility_mxn_brl, reference, metric = "precision"), 2)   # 0.31
round(evaluate(garch_volatility_mxn_brl, reference, metric = "recall"), 2)      # 0.12

#Plot
print(evtplot(test_mxn_brl, garch_volatility_mxn_brl, reference))

##### 12. nok_brl #####
#Detect
garch_volatility_nok_brl <- evtdet.garch_volatility_outlier(test_nok_brl,
                                                            spec = garch11, alpha = 1.5,
                                                            na.action = na.omit)

#Evaluate
evaluate(garch_volatility_nok_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     5      16    
# FALSE    60     168

round(evaluate(garch_volatility_nok_brl, reference, metric = "F1"), 2)          # 0.12
round(evaluate(garch_volatility_nok_brl, reference, metric = "accuracy"), 2)    # 0.69
round(evaluate(garch_volatility_nok_brl, reference, metric = "sensitivity"), 2) # 0.08
round(evaluate(garch_volatility_nok_brl, reference, metric = "specificity"), 2) # 0.91
round(evaluate(garch_volatility_nok_brl, reference, metric = "precision"), 2)   # 0.24
round(evaluate(garch_volatility_nok_brl, reference, metric = "recall"), 2)      # 0.08

#Plot
print(evtplot(test_nok_brl, garch_volatility_nok_brl, reference))

##### 13. nzd_brl #####
#Detect
garch_volatility_nzd_brl <- evtdet.garch_volatility_outlier(test_nzd_brl,
                                                            spec = garch11, alpha = 1.5,
                                                            na.action = na.omit)

#Evaluate
evaluate(garch_volatility_nzd_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     13     9
# FALSE    52     175 

round(evaluate(garch_volatility_nzd_brl, reference, metric = "F1"), 2)          # 0.30
round(evaluate(garch_volatility_nzd_brl, reference, metric = "accuracy"), 2)    # 0.76
round(evaluate(garch_volatility_nzd_brl, reference, metric = "sensitivity"), 2) # 0.20
round(evaluate(garch_volatility_nzd_brl, reference, metric = "specificity"), 2) # 0.95
round(evaluate(garch_volatility_nzd_brl, reference, metric = "precision"), 2)   # 0.59
round(evaluate(garch_volatility_nzd_brl, reference, metric = "recall"), 2)      # 0.20

#Plot
print(evtplot(test_nzd_brl, garch_volatility_nzd_brl, reference))

##### 14. pln_brl #####
#Detect
garch_volatility_pln_brl <- evtdet.garch_volatility_outlier(test_pln_brl,
                                                            spec = garch11, alpha = 1.5,
                                                            na.action = na.omit)

#Evaluate
evaluate(garch_volatility_pln_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     7      12   
# FALSE    58     172 

round(evaluate(garch_volatility_pln_brl, reference, metric = "F1"), 2)          # 0.17
round(evaluate(garch_volatility_pln_brl, reference, metric = "accuracy"), 2)    # 0.72
round(evaluate(garch_volatility_pln_brl, reference, metric = "sensitivity"), 2) # 0.11
round(evaluate(garch_volatility_pln_brl, reference, metric = "specificity"), 2) # 0.93
round(evaluate(garch_volatility_pln_brl, reference, metric = "precision"), 2)   # 0.37
round(evaluate(garch_volatility_pln_brl, reference, metric = "recall"), 2)      # 0.11

#Plot
print(evtplot(test_pln_brl, garch_volatility_pln_brl, reference))

##### 15. sek_brl #####
#Detect
garch_volatility_sek_brl <- evtdet.garch_volatility_outlier(test_sek_brl,
                                                            spec = garch11, alpha = 1.5,
                                                            na.action = na.omit)

#Evaluate
evaluate(garch_volatility_sek_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     7      10   
# FALSE    58     174

round(evaluate(garch_volatility_sek_brl, reference, metric = "F1"), 2)          # 0.17
round(evaluate(garch_volatility_sek_brl, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(garch_volatility_sek_brl, reference, metric = "sensitivity"), 2) # 0.11
round(evaluate(garch_volatility_sek_brl, reference, metric = "specificity"), 2) # 0.95
round(evaluate(garch_volatility_sek_brl, reference, metric = "precision"), 2)   # 0.41
round(evaluate(garch_volatility_sek_brl, reference, metric = "recall"), 2)      # 0.11

#Plot
print(evtplot(test_sek_brl, garch_volatility_sek_brl, reference))

##### 16. try_brl #####
#Detect
garch_volatility_try_brl <- evtdet.garch_volatility_outlier(test_try_brl,
                                                            spec = garch11, alpha = 1.5,
                                                            na.action = na.omit)

#Evaluate
evaluate(garch_volatility_try_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     5      31   
# FALSE    60     153 

round(evaluate(garch_volatility_try_brl, reference, metric = "F1"), 2)          # 0.10
round(evaluate(garch_volatility_try_brl, reference, metric = "accuracy"), 2)    # 0.63
round(evaluate(garch_volatility_try_brl, reference, metric = "sensitivity"), 2) # 0.08
round(evaluate(garch_volatility_try_brl, reference, metric = "specificity"), 2) # 0.83
round(evaluate(garch_volatility_try_brl, reference, metric = "precision"), 2)   # 0.14
round(evaluate(garch_volatility_try_brl, reference, metric = "recall"), 2)      # 0.08

#Plot
print(evtplot(test_try_brl, garch_volatility_try_brl, reference))

##### 17. zar_brl #####
#Detect
garch_volatility_zar_brl <- evtdet.garch_volatility_outlier(test_zar_brl,
                                                            spec = garch11, alpha = 1.5,
                                                            na.action = na.omit)

#Evaluate
evaluate(garch_volatility_zar_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     5      34 
# FALSE    60     150 

round(evaluate(garch_volatility_zar_brl, reference, metric = "F1"), 2)          # 0.10
round(evaluate(garch_volatility_zar_brl, reference, metric = "accuracy"), 2)    # 0.62
round(evaluate(garch_volatility_zar_brl, reference, metric = "sensitivity"), 2) # 0.08
round(evaluate(garch_volatility_zar_brl, reference, metric = "specificity"), 2) # 0.82
round(evaluate(garch_volatility_zar_brl, reference, metric = "precision"), 2)   # 0.13
round(evaluate(garch_volatility_zar_brl, reference, metric = "recall"), 2)      # 0.08

#Plot
print(evtplot(test_zar_brl, garch_volatility_zar_brl, reference))

##### 18. pen_brl #####
#Detect
garch_volatility_pen_brl <- evtdet.garch_volatility_outlier(test_pen_brl,
                                                            spec = garch11, alpha = 1.5,
                                                            na.action = na.omit)

#Evaluate
evaluate(garch_volatility_pen_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     17     12  
# FALSE    48     172 

round(evaluate(garch_volatility_pen_brl, reference, metric = "F1"), 2)          # 0.36
round(evaluate(garch_volatility_pen_brl, reference, metric = "accuracy"), 2)    # 0.76
round(evaluate(garch_volatility_pen_brl, reference, metric = "sensitivity"), 2) # 0.26
round(evaluate(garch_volatility_pen_brl, reference, metric = "specificity"), 2) # 0.93
round(evaluate(garch_volatility_pen_brl, reference, metric = "precision"), 2)   # 0.59
round(evaluate(garch_volatility_pen_brl, reference, metric = "recall"), 2)      # 0.26

#Plot
print(evtplot(test_pen_brl, garch_volatility_pen_brl, reference))

#######################################
##### Seminal Change Point (1999) #####
#######################################

##### 1. ars_brl #####
#Detect
changepoint_ars_brl <- evtdet.seminalChangePoint2(test_ars_brl, w = 30, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_ars_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     19     10   
# FALSE    46     174    

round(evaluate(changepoint_ars_brl, reference, metric = "F1"), 2)          # 0.40
round(evaluate(changepoint_ars_brl, reference, metric = "accuracy"), 2)    # 0.78
round(evaluate(changepoint_ars_brl, reference, metric = "sensitivity"), 2) # 0.29
round(evaluate(changepoint_ars_brl, reference, metric = "specificity"), 2) # 0.95
round(evaluate(changepoint_ars_brl, reference, metric = "precision"), 2)   # 0.66
round(evaluate(changepoint_ars_brl, reference, metric = "recall"), 2)      # 0.29

#Plot
print(evtplot(test_ars_brl, changepoint_ars_brl, reference))

##### 2. aud_brl #####
#Detect
changepoint_aud_brl <- evtdet.seminalChangePoint2(test_aud_brl, w = 30, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_aud_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     18     28 
# FALSE    47     156  

round(evaluate(changepoint_aud_brl, reference, metric = "F1"), 2)          # 0.32
round(evaluate(changepoint_aud_brl, reference, metric = "accuracy"), 2)    # 0.70
round(evaluate(changepoint_aud_brl, reference, metric = "sensitivity"), 2) # 0.28
round(evaluate(changepoint_aud_brl, reference, metric = "specificity"), 2) # 0.85
round(evaluate(changepoint_aud_brl, reference, metric = "precision"), 2)   # 0.39
round(evaluate(changepoint_aud_brl, reference, metric = "recall"), 2)      # 0.28

#Plot
print(evtplot(test_aud_brl, changepoint_aud_brl, reference))

##### 3. cad_brl #####
#Detect
changepoint_cad_brl <- evtdet.seminalChangePoint2(test_cad_brl, w = 30, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_cad_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     20     22
# FALSE    45     162

round(evaluate(changepoint_cad_brl, reference, metric = "F1"), 2)          # 0.37
round(evaluate(changepoint_cad_brl, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(changepoint_cad_brl, reference, metric = "sensitivity"), 2) # 0.31
round(evaluate(changepoint_cad_brl, reference, metric = "specificity"), 2) # 0.88
round(evaluate(changepoint_cad_brl, reference, metric = "precision"), 2)   # 0.48
round(evaluate(changepoint_cad_brl, reference, metric = "recall"), 2)      # 0.31

#Plot
print(evtplot(test_cad_brl, changepoint_cad_brl, reference))

##### 4. chf_brl #####
#Detect
changepoint_chf_brl <- evtdet.seminalChangePoint2(test_chf_brl, w = 30, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_chf_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     17     26  
# FALSE    48     158  

round(evaluate(changepoint_chf_brl, reference, metric = "F1"), 2)          # 0.31
round(evaluate(changepoint_chf_brl, reference, metric = "accuracy"), 2)    # 0.70
round(evaluate(changepoint_chf_brl, reference, metric = "sensitivity"), 2) # 0.26
round(evaluate(changepoint_chf_brl, reference, metric = "specificity"), 2) # 0.86
round(evaluate(changepoint_chf_brl, reference, metric = "precision"), 2)   # 0.40
round(evaluate(changepoint_chf_brl, reference, metric = "recall"), 2)      # 0.26

#Plot
print(evtplot(test_chf_brl, changepoint_chf_brl, reference))

##### 5. eur_brl #####
#Detect
changepoint_eur_brl <- evtdet.seminalChangePoint2(test_eur_brl, w = 30, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_eur_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     7      25
# FALSE    58     159

round(evaluate(changepoint_eur_brl, reference, metric = "F1"), 2)          # 0.14
round(evaluate(changepoint_eur_brl, reference, metric = "accuracy"), 2)    # 0.67
round(evaluate(changepoint_eur_brl, reference, metric = "sensitivity"), 2) # 0.11
round(evaluate(changepoint_eur_brl, reference, metric = "specificity"), 2) # 0.86
round(evaluate(changepoint_eur_brl, reference, metric = "precision"), 2)   # 0.22
round(evaluate(changepoint_eur_brl, reference, metric = "recall"), 2)      # 0.11

#Plot
print(evtplot(test_eur_brl, changepoint_eur_brl, reference))

##### 6. gbp_brl #####
#Detect
changepoint_gbp_brl <- evtdet.seminalChangePoint2(test_gbp_brl, w = 30, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_gbp_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     7      25  
# FALSE    58     159 

round(evaluate(changepoint_gbp_brl, reference, metric = "F1"), 2)          # 0.14
round(evaluate(changepoint_gbp_brl, reference, metric = "accuracy"), 2)    # 0.67
round(evaluate(changepoint_gbp_brl, reference, metric = "sensitivity"), 2) # 0.11
round(evaluate(changepoint_gbp_brl, reference, metric = "specificity"), 2) # 0.86
round(evaluate(changepoint_gbp_brl, reference, metric = "precision"), 2)   # 0.22
round(evaluate(changepoint_gbp_brl, reference, metric = "recall"), 2)      # 0.11

#Plot
print(evtplot(test_gbp_brl, changepoint_gbp_brl, reference))

##### 7. sgd_brl #####
#Detect
changepoint_sgd_brl <- evtdet.seminalChangePoint2(test_sgd_brl, w = 30, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_sgd_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     10     18 
# FALSE    55     166

round(evaluate(changepoint_sgd_brl, reference, metric = "F1"), 2)          # 0.22
round(evaluate(changepoint_sgd_brl, reference, metric = "accuracy"), 2)    # 0.71
round(evaluate(changepoint_sgd_brl, reference, metric = "sensitivity"), 2) # 0.15
round(evaluate(changepoint_sgd_brl, reference, metric = "specificity"), 2) # 0.90
round(evaluate(changepoint_sgd_brl, reference, metric = "precision"), 2)   # 0.36
round(evaluate(changepoint_sgd_brl, reference, metric = "recall"), 2)      # 0.15

#Plot
print(evtplot(test_sgd_brl, changepoint_sgd_brl, reference))

##### 8. usd_brl #####
#Detect
changepoint_usd_brl <- evtdet.seminalChangePoint2(test_usd_brl, w = 30, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_usd_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     20     18  
# FALSE    45     166 

round(evaluate(changepoint_usd_brl, reference, metric = "F1"), 2)          # 0.39
round(evaluate(changepoint_usd_brl, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(changepoint_usd_brl, reference, metric = "sensitivity"), 2) # 0.31
round(evaluate(changepoint_usd_brl, reference, metric = "specificity"), 2) # 0.90
round(evaluate(changepoint_usd_brl, reference, metric = "precision"), 2)   # 0.53
round(evaluate(changepoint_usd_brl, reference, metric = "recall"), 2)      # 0.31

#Plot
print(evtplot(test_usd_brl, changepoint_usd_brl, reference))

##### 9. cny_brl #####
#Detect
changepoint_cny_brl <- evtdet.seminalChangePoint2(test_cny_brl, w = 30, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_cny_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     17     20   
# FALSE    48     164

round(evaluate(changepoint_cny_brl, reference, metric = "F1"), 2)          # 0.33
round(evaluate(changepoint_cny_brl, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(changepoint_cny_brl, reference, metric = "sensitivity"), 2) # 0.26
round(evaluate(changepoint_cny_brl, reference, metric = "specificity"), 2) # 0.89
round(evaluate(changepoint_cny_brl, reference, metric = "precision"), 2)   # 0.46
round(evaluate(changepoint_cny_brl, reference, metric = "recall"), 2)      # 0.26

#Plot
print(evtplot(test_cny_brl, changepoint_cny_brl, reference))

##### 10. dkk_brl #####
#Detect
changepoint_dkk_brl <- evtdet.seminalChangePoint2(test_dkk_brl, w = 30, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_dkk_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     18     23  
# FALSE    47     161  

round(evaluate(changepoint_dkk_brl, reference, metric = "F1"), 2)          # 0.34
round(evaluate(changepoint_dkk_brl, reference, metric = "accuracy"), 2)    # 0.72
round(evaluate(changepoint_dkk_brl, reference, metric = "sensitivity"), 2) # 0.28
round(evaluate(changepoint_dkk_brl, reference, metric = "specificity"), 2) # 0.88
round(evaluate(changepoint_dkk_brl, reference, metric = "precision"), 2)   # 0.44
round(evaluate(changepoint_dkk_brl, reference, metric = "recall"), 2)      # 0.28

#Plot
print(evtplot(test_dkk_brl, changepoint_dkk_brl, reference))

##### 11. mxn_brl #####
#Detect
changepoint_mxn_brl <- evtdet.seminalChangePoint2(test_mxn_brl, w = 30, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_mxn_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     8      22
# FALSE    57     162

round(evaluate(changepoint_mxn_brl, reference, metric = "F1"), 2)          # 0.17
round(evaluate(changepoint_mxn_brl, reference, metric = "accuracy"), 2)    # 0.68
round(evaluate(changepoint_mxn_brl, reference, metric = "sensitivity"), 2) # 0.12
round(evaluate(changepoint_mxn_brl, reference, metric = "specificity"), 2) # 0.88
round(evaluate(changepoint_mxn_brl, reference, metric = "precision"), 2)   # 0.27
round(evaluate(changepoint_mxn_brl, reference, metric = "recall"), 2)      # 0.12

#Plot
print(evtplot(test_mxn_brl, changepoint_mxn_brl, reference))

##### 12. nok_brl #####
#Detect
changepoint_nok_brl <- evtdet.seminalChangePoint2(test_nok_brl, w = 30, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_nok_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     11     18 
# FALSE    54     166  

round(evaluate(changepoint_nok_brl, reference, metric = "F1"), 2)          # 0.23
round(evaluate(changepoint_nok_brl, reference, metric = "accuracy"), 2)    # 0.71
round(evaluate(changepoint_nok_brl, reference, metric = "sensitivity"), 2) # 0.17
round(evaluate(changepoint_nok_brl, reference, metric = "specificity"), 2) # 0.90
round(evaluate(changepoint_nok_brl, reference, metric = "precision"), 2)   # 0.38
round(evaluate(changepoint_nok_brl, reference, metric = "recall"), 2)      # 0.17

#Plot
print(evtplot(test_nok_brl, changepoint_nok_brl, reference))

##### 13. nzd_brl #####
#Detect
changepoint_nzd_brl <- evtdet.seminalChangePoint2(test_nzd_brl, w = 30, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_nzd_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     13     18 
# FALSE    52     166  

round(evaluate(changepoint_nzd_brl, reference, metric = "F1"), 2)          # 0.27
round(evaluate(changepoint_nzd_brl, reference, metric = "accuracy"), 2)    # 0.72
round(evaluate(changepoint_nzd_brl, reference, metric = "sensitivity"), 2) # 0.20
round(evaluate(changepoint_nzd_brl, reference, metric = "specificity"), 2) # 0.90
round(evaluate(changepoint_nzd_brl, reference, metric = "precision"), 2)   # 0.42
round(evaluate(changepoint_nzd_brl, reference, metric = "recall"), 2)      # 0.20

#Plot
print(evtplot(test_nzd_brl, changepoint_nzd_brl, reference))

##### 14. pln_brl #####
#Detect
changepoint_pln_brl <- evtdet.seminalChangePoint2(test_pln_brl, w = 30, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_pln_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     14     13 
# FALSE    51     171   

round(evaluate(changepoint_pln_brl, reference, metric = "F1"), 2)          # 0.30
round(evaluate(changepoint_pln_brl, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(changepoint_pln_brl, reference, metric = "sensitivity"), 2) # 0.22
round(evaluate(changepoint_pln_brl, reference, metric = "specificity"), 2) # 0.93
round(evaluate(changepoint_pln_brl, reference, metric = "precision"), 2)   # 0.52
round(evaluate(changepoint_pln_brl, reference, metric = "recall"), 2)      # 0.22

#Plot
print(evtplot(test_pln_brl, changepoint_pln_brl, reference))

##### 15. sek_brl #####
#Detect
changepoint_sek_brl <- evtdet.seminalChangePoint2(test_sek_brl, w = 30,  mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_sek_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     15     19  
# FALSE    50     165   

round(evaluate(changepoint_sek_brl, reference, metric = "F1"), 2)          # 0.30
round(evaluate(changepoint_sek_brl, reference, metric = "accuracy"), 2)    # 0.72
round(evaluate(changepoint_sek_brl, reference, metric = "sensitivity"), 2) # 0.23
round(evaluate(changepoint_sek_brl, reference, metric = "specificity"), 2) # 0.90
round(evaluate(changepoint_sek_brl, reference, metric = "precision"), 2)   # 0.44
round(evaluate(changepoint_sek_brl, reference, metric = "recall"), 2)      # 0.23

#Plot
print(evtplot(test_sek_brl, changepoint_sek_brl, reference))

##### 16. try_brl #####
#Detect
changepoint_try_brl <- evtdet.seminalChangePoint2(test_try_brl, w = 30, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_try_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     9      16
# FALSE    56     168 

round(evaluate(changepoint_try_brl, reference, metric = "F1"), 2)          # 0.20
round(evaluate(changepoint_try_brl, reference, metric = "accuracy"), 2)    # 0.71
round(evaluate(changepoint_try_brl, reference, metric = "sensitivity"), 2) # 0.14
round(evaluate(changepoint_try_brl, reference, metric = "specificity"), 2) # 0.91
round(evaluate(changepoint_try_brl, reference, metric = "precision"), 2)   # 0.36
round(evaluate(changepoint_try_brl, reference, metric = "recall"), 2)      # 0.14

#Plot
print(evtplot(test_try_brl, changepoint_try_brl, reference))

##### 17. zar_brl #####
#Detect
changepoint_zar_brl <- evtdet.seminalChangePoint2(test_zar_brl, w = 30, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_zar_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     3      20  
# FALSE    62     164

round(evaluate(changepoint_zar_brl, reference, metric = "F1"), 2)          # 0.07
round(evaluate(changepoint_zar_brl, reference, metric = "accuracy"), 2)    # 0.67
round(evaluate(changepoint_zar_brl, reference, metric = "sensitivity"), 2) # 0.05
round(evaluate(changepoint_zar_brl, reference, metric = "specificity"), 2) # 0.89
round(evaluate(changepoint_zar_brl, reference, metric = "precision"), 2)   # 0.13
round(evaluate(changepoint_zar_brl, reference, metric = "recall"), 2)      # 0.05

#Plot
print(evtplot(test_zar_brl, changepoint_zar_brl, reference))

##### 18. pen_brl #####
#Detect
changepoint_pen_brl <- evtdet.seminalChangePoint2(test_pen_brl, w = 30, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_pen_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     13     14 
# FALSE    52     170  

round(evaluate(changepoint_pen_brl, reference, metric = "F1"), 2)          # 0.28
round(evaluate(changepoint_pen_brl, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(changepoint_pen_brl, reference, metric = "sensitivity"), 2) # 0.20
round(evaluate(changepoint_pen_brl, reference, metric = "specificity"), 2) # 0.92
round(evaluate(changepoint_pen_brl, reference, metric = "precision"), 2)   # 0.48
round(evaluate(changepoint_pen_brl, reference, metric = "recall"), 2)      # 0.20

#Plot
print(evtplot(test_pen_brl, changepoint_pen_brl, reference))

###############################
##### ChangeFinder (2005) #####
###############################

##### 1. ars_brl #####
#Detect
changefinder_ars_brl <- evtdet.changeFinder(test_ars_brl, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_ars_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     5      3  
# FALSE    60     181 

round(evaluate(changefinder_ars_brl, reference, metric = "F1"), 2)          # 0.14
round(evaluate(changefinder_ars_brl, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(changefinder_ars_brl, reference, metric = "sensitivity"), 2) # 0.08
round(evaluate(changefinder_ars_brl, reference, metric = "specificity"), 2) # 0.98
round(evaluate(changefinder_ars_brl, reference, metric = "precision"), 2)   # 0.62
round(evaluate(changefinder_ars_brl, reference, metric = "recall"), 2)      # 0.08

#Plot
print(evtplot(test_ars_brl, changefinder_ars_brl, reference))

##### 2. aud_brl #####
#Detect
changefinder_aud_brl <- evtdet.changeFinder(test_aud_brl, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_aud_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     8      3 
# FALSE    57     181  

round(evaluate(changefinder_aud_brl, reference, metric = "F1"), 2)          # 0.21
round(evaluate(changefinder_aud_brl, reference, metric = "accuracy"), 2)    # 0.76
round(evaluate(changefinder_aud_brl, reference, metric = "sensitivity"), 2) # 0.12
round(evaluate(changefinder_aud_brl, reference, metric = "specificity"), 2) # 0.98
round(evaluate(changefinder_aud_brl, reference, metric = "precision"), 2)   # 0.73
round(evaluate(changefinder_aud_brl, reference, metric = "recall"), 2)      # 0.12

#Plot
print(evtplot(test_aud_brl, changefinder_aud_brl, reference))

##### 3. cad_brl #####
#Detect
changefinder_cad_brl <- evtdet.changeFinder(test_cad_brl, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_cad_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     9      4  
# FALSE    56     180

round(evaluate(changefinder_cad_brl, reference, metric = "F1"), 2)          # 0.23
round(evaluate(changefinder_cad_brl, reference, metric = "accuracy"), 2)    # 0.76
round(evaluate(changefinder_cad_brl, reference, metric = "sensitivity"), 2) # 0.14
round(evaluate(changefinder_cad_brl, reference, metric = "specificity"), 2) # 0.98
round(evaluate(changefinder_cad_brl, reference, metric = "precision"), 2)   # 0.69
round(evaluate(changefinder_cad_brl, reference, metric = "recall"), 2)      # 0.14

#Plot
print(evtplot(test_cad_brl, changefinder_cad_brl, reference))

##### 4. chf_brl #####
#Detect
changefinder_chf_brl <- evtdet.changeFinder(test_chf_brl, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_chf_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     8      5
# FALSE    57     179   

round(evaluate(changefinder_chf_brl, reference, metric = "F1"), 2)          # 0.21
round(evaluate(changefinder_chf_brl, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(changefinder_chf_brl, reference, metric = "sensitivity"), 2) # 0.12
round(evaluate(changefinder_chf_brl, reference, metric = "specificity"), 2) # 0.97
round(evaluate(changefinder_chf_brl, reference, metric = "precision"), 2)   # 0.62
round(evaluate(changefinder_chf_brl, reference, metric = "recall"), 2)      # 0.12

#Plot
print(evtplot(test_chf_brl, changefinder_chf_brl, reference))

##### 5. eur_brl #####
#Detect
changefinder_eur_brl <- evtdet.changeFinder(test_eur_brl, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_eur_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     1      1  
# FALSE    64     183 

round(evaluate(changefinder_eur_brl, reference, metric = "F1"), 2)          # 0.03
round(evaluate(changefinder_eur_brl, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(changefinder_eur_brl, reference, metric = "sensitivity"), 2) # 0.02
round(evaluate(changefinder_eur_brl, reference, metric = "specificity"), 2) # 0.99
round(evaluate(changefinder_eur_brl, reference, metric = "precision"), 2)   # 0.50
round(evaluate(changefinder_eur_brl, reference, metric = "recall"), 2)      # 0.02

#Plot
print(evtplot(test_eur_brl, changefinder_eur_brl, reference))

##### 6. gbp_brl #####
#Detect
changefinder_gbp_brl <- evtdet.changeFinder(test_gbp_brl, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_gbp_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     1      1  
# FALSE    64     183

round(evaluate(changefinder_gbp_brl, reference, metric = "F1"), 2)          # 0.03
round(evaluate(changefinder_gbp_brl, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(changefinder_gbp_brl, reference, metric = "sensitivity"), 2) # 0.02
round(evaluate(changefinder_gbp_brl, reference, metric = "specificity"), 2) # 0.99
round(evaluate(changefinder_gbp_brl, reference, metric = "precision"), 2)   # 0.50
round(evaluate(changefinder_gbp_brl, reference, metric = "recall"), 2)      # 0.02

#Plot
print(evtplot(test_gbp_brl, changefinder_gbp_brl, reference))

##### 7. sgd_brl #####
#Detect
changefinder_sgd_brl <- evtdet.changeFinder(test_sgd_brl, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_sgd_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     8      4  
# FALSE    57     180

round(evaluate(changefinder_sgd_brl, reference, metric = "F1"), 2)          # 0.21
round(evaluate(changefinder_sgd_brl, reference, metric = "accuracy"), 2)    # 0.76
round(evaluate(changefinder_sgd_brl, reference, metric = "sensitivity"), 2) # 0.12
round(evaluate(changefinder_sgd_brl, reference, metric = "specificity"), 2) # 0.98
round(evaluate(changefinder_sgd_brl, reference, metric = "precision"), 2)   # 0.67
round(evaluate(changefinder_sgd_brl, reference, metric = "recall"), 2)      # 0.12

#Plot
print(evtplot(test_sgd_brl, changefinder_sgd_brl, reference))

##### 8. usd_brl #####
#Detect
changefinder_usd_brl <- evtdet.changeFinder(test_usd_brl, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_usd_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     2      4   
# FALSE    63     180 

round(evaluate(changefinder_usd_brl, reference, metric = "F1"), 2)          # 0.06
round(evaluate(changefinder_usd_brl, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(changefinder_usd_brl, reference, metric = "sensitivity"), 2) # 0.03
round(evaluate(changefinder_usd_brl, reference, metric = "specificity"), 2) # 0.98
round(evaluate(changefinder_usd_brl, reference, metric = "precision"), 2)   # 0.33
round(evaluate(changefinder_usd_brl, reference, metric = "recall"), 2)      # 0.03

#Plot
print(evtplot(test_usd_brl, changefinder_usd_brl, reference))

##### 9. cny_brl #####
#Detect
changefinder_cny_brl <- evtdet.changeFinder(test_cny_brl, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_cny_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     6      3 
# FALSE    59     181

round(evaluate(changefinder_cny_brl, reference, metric = "F1"), 2)          # 0.16
round(evaluate(changefinder_cny_brl, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(changefinder_cny_brl, reference, metric = "sensitivity"), 2) # 0.09
round(evaluate(changefinder_cny_brl, reference, metric = "specificity"), 2) # 0.98
round(evaluate(changefinder_cny_brl, reference, metric = "precision"), 2)   # 0.67
round(evaluate(changefinder_cny_brl, reference, metric = "recall"), 2)      # 0.09

#Plot
print(evtplot(test_cny_brl, changefinder_cny_brl, reference))

##### 10. dkk_brl #####
#Detect
changefinder_dkk_brl <- evtdet.changeFinder(test_dkk_brl, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_dkk_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     5      3 
# FALSE    60     181 

round(evaluate(changefinder_dkk_brl, reference, metric = "F1"), 2)          # 0.14
round(evaluate(changefinder_dkk_brl, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(changefinder_dkk_brl, reference, metric = "sensitivity"), 2) # 0.08
round(evaluate(changefinder_dkk_brl, reference, metric = "specificity"), 2) # 0.98
round(evaluate(changefinder_dkk_brl, reference, metric = "precision"), 2)   # 0.62
round(evaluate(changefinder_dkk_brl, reference, metric = "recall"), 2)      # 0.08

#Plot
print(evtplot(test_dkk_brl, changefinder_dkk_brl, reference))

##### 11. mxn_brl #####
#Detect
changefinder_mxn_brl <- evtdet.changeFinder(test_mxn_brl, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_mxn_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     3      3   
# FALSE    62     181  

round(evaluate(changefinder_mxn_brl, reference, metric = "F1"), 2)          # 0.08
round(evaluate(changefinder_mxn_brl, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(changefinder_mxn_brl, reference, metric = "sensitivity"), 2) # 0.05
round(evaluate(changefinder_mxn_brl, reference, metric = "specificity"), 2) # 0.98
round(evaluate(changefinder_mxn_brl, reference, metric = "precision"), 2)   # 0.50
round(evaluate(changefinder_mxn_brl, reference, metric = "recall"), 2)      # 0.05

#Plot
print(evtplot(test_mxn_brl, changefinder_mxn_brl, reference))

##### 12. nok_brl #####
#Detect
changefinder_nok_brl <- evtdet.changeFinder(test_nok_brl, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_nok_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     6      6 
# FALSE    59     178 

round(evaluate(changefinder_nok_brl, reference, metric = "F1"), 2)          # 0.16
round(evaluate(changefinder_nok_brl, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(changefinder_nok_brl, reference, metric = "sensitivity"), 2) # 0.09
round(evaluate(changefinder_nok_brl, reference, metric = "specificity"), 2) # 0.97
round(evaluate(changefinder_nok_brl, reference, metric = "precision"), 2)   # 0.50
round(evaluate(changefinder_nok_brl, reference, metric = "recall"), 2)      # 0.09

#Plot
print(evtplot(test_nok_brl, changefinder_nok_brl, reference))

##### 13. nzd_brl #####
#Detect
changefinder_nzd_brl <- evtdet.changeFinder(test_nzd_brl, mdl = linreg, a.action = na.omit)

#Evaluate
evaluate(changefinder_nzd_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     3      3  
# FALSE    62     181  

round(evaluate(changefinder_nzd_brl, reference, metric = "F1"), 2)          # 0.08
round(evaluate(changefinder_nzd_brl, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(changefinder_nzd_brl, reference, metric = "sensitivity"), 2) # 0.05
round(evaluate(changefinder_nzd_brl, reference, metric = "specificity"), 2) # 0.98
round(evaluate(changefinder_nzd_brl, reference, metric = "precision"), 2)   # 0.50
round(evaluate(changefinder_nzd_brl, reference, metric = "recall"), 2)      # 0.05

#Plot
print(evtplot(test_nzd_brl, changefinder_nzd_brl, reference))

##### 14. pln_brl ##### 
#Detect
changefinder_pln_brl <- evtdet.changeFinder(test_pln_brl, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_pln_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     4      2
# FALSE    61     182  

round(evaluate(changefinder_pln_brl, reference, metric = "F1"), 2)          # 0.11
round(evaluate(changefinder_pln_brl, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(changefinder_pln_brl, reference, metric = "sensitivity"), 2) # 0.06
round(evaluate(changefinder_pln_brl, reference, metric = "specificity"), 2) # 0.99
round(evaluate(changefinder_pln_brl, reference, metric = "precision"), 2)   # 0.67
round(evaluate(changefinder_pln_brl, reference, metric = "recall"), 2)      # 0.06

#Plot
print(evtplot(test_pln_brl, changefinder_pln_brl, reference))

##### 15. sek_brl ##### 
#Detect
changefinder_sek_brl <- evtdet.changeFinder(test_sek_brl, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_sek_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     5      3 
# FALSE    60     181

round(evaluate(changefinder_sek_brl, reference, metric = "F1"), 2)          # 0.14
round(evaluate(changefinder_sek_brl, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(changefinder_sek_brl, reference, metric = "sensitivity"), 2) # 0.08
round(evaluate(changefinder_sek_brl, reference, metric = "specificity"), 2) # 0.98
round(evaluate(changefinder_sek_brl, reference, metric = "precision"), 2)   # 0.62
round(evaluate(changefinder_sek_brl, reference, metric = "recall"), 2)      # 0.08

#Plot
print(evtplot(test_sek_brl, changefinder_sek_brl, reference))

##### 16. try_brl ##### 
#Detect
changefinder_try_brl <- evtdet.changeFinder(test_try_brl, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_try_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     2      4  
# FALSE    63     180 

round(evaluate(changefinder_try_brl, reference, metric = "F1"), 2)          # 0.06
round(evaluate(changefinder_try_brl, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(changefinder_try_brl, reference, metric = "sensitivity"), 2) # 0.03
round(evaluate(changefinder_try_brl, reference, metric = "specificity"), 2) # 0.98
round(evaluate(changefinder_try_brl, reference, metric = "precision"), 2)   # 0.33
round(evaluate(changefinder_try_brl, reference, metric = "recall"), 2)      # 0.03

#Plot
print(evtplot(test_try_brl, changefinder_try_brl, reference))

##### 17. zar_brl ##### 
#Detect
changefinder_zar_brl <- evtdet.changeFinder(test_zar_brl, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_zar_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     4      17   
# FALSE    61     167 

round(evaluate(changefinder_zar_brl, reference, metric = "F1"), 2)          # 0.09
round(evaluate(changefinder_zar_brl, reference, metric = "accuracy"), 2)    # 0.69
round(evaluate(changefinder_zar_brl, reference, metric = "sensitivity"), 2) # 0.06
round(evaluate(changefinder_zar_brl, reference, metric = "specificity"), 2) # 0.91
round(evaluate(changefinder_zar_brl, reference, metric = "precision"), 2)   # 0.19
round(evaluate(changefinder_zar_brl, reference, metric = "recall"), 2)      # 0.06

#Plot
print(evtplot(test_zar_brl, changefinder_zar_brl, reference))

##### 18. pen_brl ##### 
#Detect
changefinder_pen_brl <- evtdet.changeFinder(test_pen_brl, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_pen_brl, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     7      6  
# FALSE    58     178 

round(evaluate(changefinder_pen_brl, reference, metric = "F1"), 2)          # 0.18
round(evaluate(changefinder_pen_brl, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(changefinder_pen_brl, reference, metric = "sensitivity"), 2) # 0.11
round(evaluate(changefinder_pen_brl, reference, metric = "specificity"), 2) # 0.97
round(evaluate(changefinder_pen_brl, reference, metric = "precision"), 2)   # 0.54
round(evaluate(changefinder_pen_brl, reference, metric = "recall"), 2)      # 0.11

#Plot
print(evtplot(test_pen_brl, changefinder_pen_brl, reference))
