############################################################
##### Deteco de Eventos - Desacordos de Expectativas #####
############################################################

################
##### Data #####
################

library(tibble)
library(EventDetectR)
source("https://raw.githubusercontent.com/cefet-rj-dal/harbinger/master/harbinger.R")

attach(df_desagreement)
head(df_desagreement)
str(df_desagreement)

test_d_exch_12 <- subset(df_desagreement, select = c(Data, d_exch_12))
test_d_exch_24 <- subset(df_desagreement, select = c(Data, d_exch_24))
test_d_exch_36 <- subset(df_desagreement, select = c(Data, d_exch_36))
test_d_exch_48 <- subset(df_desagreement, select = c(Data, d_exch_48))
test_d_dlsp_12 <- subset(df_desagreement, select = c(Data, d_dlsp_12))
test_d_dlsp_24 <- subset(df_desagreement, select = c(Data, d_dlsp_24))
test_d_dlsp_36 <- subset(df_desagreement, select = c(Data, d_dlsp_36))
test_d_dlsp_48 <- subset(df_desagreement, select = c(Data, d_dlsp_48))
test_d_ipca_12 <- subset(df_desagreement, select = c(Data, d_ipca_12))
test_d_ipca_24 <- subset(df_desagreement, select = c(Data, d_ipca_24))
test_d_ipca_36 <- subset(df_desagreement, select = c(Data, d_ipca_36))
test_d_ipca_48 <- subset(df_desagreement, select = c(Data, d_ipca_48))
test_d_pib_12 <- subset(df_desagreement, select = c(Data, d_pib_12))
test_d_pib_24 <- subset(df_desagreement, select = c(Data, d_pib_24))
test_d_pib_36 <- subset(df_desagreement, select = c(Data, d_pib_36))
test_d_pib_48 <- subset(df_desagreement, select = c(Data, d_pib_48))
test_d_nfsp_12 <- subset(df_desagreement, select = c(Data, d_nfsp_12))
test_d_nfsp_24 <- subset(df_desagreement, select = c(Data, d_nfsp_24))
test_d_nfsp_36 <- subset(df_desagreement, select = c(Data, d_nfsp_36))
test_d_nfsp_48 <- subset(df_desagreement, select = c(Data, d_nfsp_48))
test_d_selic_12 <- subset(df_desagreement, select = c(Data, d_selic_12))
test_d_selic_24 <- subset(df_desagreement, select = c(Data, d_selic_24))
test_d_selic_36 <- subset(df_desagreement, select = c(Data, d_selic_36))
test_d_selic_48 <- subset(df_desagreement, select = c(Data, d_selic_48))
reference <- subset(df_desagreement, select = c(Data, event))

#####################
##### Anomalize #####
#####################

##### 1. d_exch_12 #####
#Detect
anomalize_d_exch_12 <- evtdet.anomalize(test_d_exch_12, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_d_exch_12, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     13     5  
# FALSE    52     169  

round(evaluate(anomalize_d_exch_12, reference, metric = "F1"), 2)          # 0.31
round(evaluate(anomalize_d_exch_12, reference, metric = "accuracy"), 2)    # 0.76
round(evaluate(anomalize_d_exch_12, reference, metric = "sensitivity"), 2) # 0.20
round(evaluate(anomalize_d_exch_12, reference, metric = "specificity"), 2) # 0.97
round(evaluate(anomalize_d_exch_12, reference, metric = "precision"), 2)   # 0.72
round(evaluate(anomalize_d_exch_12, reference, metric = "recall"), 2)      # 0.20

#Plot
print(evtplot(test_d_exch_12, anomalize_d_exch_12, reference))

##### 2. d_exch_24 #####
#Detect
anomalize_d_exch_24 <- evtdet.anomalize(test_d_exch_24, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_d_exch_24, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     7      4 
# FALSE    58     170  

round(evaluate(anomalize_d_exch_24, reference, metric = "F1"), 2)          # 0.18
round(evaluate(anomalize_d_exch_24, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(anomalize_d_exch_24, reference, metric = "sensitivity"), 2) # 0.11
round(evaluate(anomalize_d_exch_24, reference, metric = "specificity"), 2) # 0.98
round(evaluate(anomalize_d_exch_24, reference, metric = "precision"), 2)   # 0.64
round(evaluate(anomalize_d_exch_24, reference, metric = "recall"), 2)      # 0.11

#Plot
print(evtplot(test_d_exch_24, anomalize_d_exch_24, reference))

##### 3. d_exch_36 #####
#Detect
anomalize_d_exch_36 <- evtdet.anomalize(test_d_exch_36, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_d_exch_36, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     8      12   
# FALSE    57     162  

round(evaluate(anomalize_d_exch_36, reference, metric = "F1"), 2)          # 0.19
round(evaluate(anomalize_d_exch_36, reference, metric = "accuracy"), 2)    # 0.71
round(evaluate(anomalize_d_exch_36, reference, metric = "sensitivity"), 2) # 0.12
round(evaluate(anomalize_d_exch_36, reference, metric = "specificity"), 2) # 0.93
round(evaluate(anomalize_d_exch_36, reference, metric = "precision"), 2)   # 0.40
round(evaluate(anomalize_d_exch_36, reference, metric = "recall"), 2)      # 0.12

#Plot
print(evtplot(test_d_exch_36, anomalize_d_exch_36, reference))

##### 4. d_exch_48 #####
#Detect
anomalize_d_exch_48 <- evtdet.anomalize(test_d_exch_48, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_d_exch_48, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     7      10 
# FALSE    58     164

round(evaluate(anomalize_d_exch_48, reference, metric = "F1"), 2)          # 0.17
round(evaluate(anomalize_d_exch_48, reference, metric = "accuracy"), 2)    # 0.72
round(evaluate(anomalize_d_exch_48, reference, metric = "sensitivity"), 2) # 0.11
round(evaluate(anomalize_d_exch_48, reference, metric = "specificity"), 2) # 0.94
round(evaluate(anomalize_d_exch_48, reference, metric = "precision"), 2)   # 0.41
round(evaluate(anomalize_d_exch_48, reference, metric = "recall"), 2)      # 0.11

#Plot
print(evtplot(test_d_exch_48, anomalize_d_exch_48, reference))

##### 5. d_dlsp_12 #####
#Detect
anomalize_d_dlsp_12 <- evtdet.anomalize(test_d_dlsp_12, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_d_dlsp_12, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     15     14   
# FALSE    50     160  

round(evaluate(anomalize_d_dlsp_12, reference, metric = "F1"), 2)          # 0.32
round(evaluate(anomalize_d_dlsp_12, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(anomalize_d_dlsp_12, reference, metric = "sensitivity"), 2) # 0.23
round(evaluate(anomalize_d_dlsp_12, reference, metric = "specificity"), 2) # 0.92
round(evaluate(anomalize_d_dlsp_12, reference, metric = "precision"), 2)   # 0.52
round(evaluate(anomalize_d_dlsp_12, reference, metric = "recall"), 2)      # 0.23

#Plot
print(evtplot(test_d_dlsp_12, anomalize_d_dlsp_12, reference))

##### 6. d_dlsp_24 #####
#Detect
anomalize_d_dlsp_24 <- evtdet.anomalize(test_d_dlsp_24, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_d_dlsp_24, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     16     5    
# FALSE    49     169   

round(evaluate(anomalize_d_dlsp_24, reference, metric = "F1"), 2)          # 0.37
round(evaluate(anomalize_d_dlsp_24, reference, metric = "accuracy"), 2)    # 0.77
round(evaluate(anomalize_d_dlsp_24, reference, metric = "sensitivity"), 2) # 0.25
round(evaluate(anomalize_d_dlsp_24, reference, metric = "specificity"), 2) # 0.97
round(evaluate(anomalize_d_dlsp_24, reference, metric = "precision"), 2)   # 0.76
round(evaluate(anomalize_d_dlsp_24, reference, metric = "recall"), 2)      # 0.25

#Plot
print(evtplot(test_d_dlsp_24, anomalize_d_dlsp_24, reference))

##### 7. d_dlsp_36 #####
#Detect
anomalize_d_dlsp_36 <- evtdet.anomalize(test_d_dlsp_36, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_d_dlsp_36, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     16     7 
# FALSE    49     167  

round(evaluate(anomalize_d_dlsp_36, reference, metric = "F1"), 2)          # 0.36
round(evaluate(anomalize_d_dlsp_36, reference, metric = "accuracy"), 2)    # 0.77
round(evaluate(anomalize_d_dlsp_36, reference, metric = "sensitivity"), 2) # 0.25
round(evaluate(anomalize_d_dlsp_36, reference, metric = "specificity"), 2) # 0.96
round(evaluate(anomalize_d_dlsp_36, reference, metric = "precision"), 2)   # 0.70
round(evaluate(anomalize_d_dlsp_36, reference, metric = "recall"), 2)      # 0.25

#Plot
print(evtplot(test_d_dlsp_36, anomalize_d_dlsp_36, reference))

##### 8. d_dlsp_48 #####
#Detect
anomalize_d_dlsp_48 <- evtdet.anomalize(test_d_dlsp_48, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_d_dlsp_48, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     14     6
# FALSE    51     168 

round(evaluate(anomalize_d_dlsp_48, reference, metric = "F1"), 2)          # 0.33
round(evaluate(anomalize_d_dlsp_48, reference, metric = "accuracy"), 2)    # 0.76
round(evaluate(anomalize_d_dlsp_48, reference, metric = "sensitivity"), 2) # 0.22
round(evaluate(anomalize_d_dlsp_48, reference, metric = "specificity"), 2) # 0.97
round(evaluate(anomalize_d_dlsp_48, reference, metric = "precision"), 2)   # 0.70
round(evaluate(anomalize_d_dlsp_48, reference, metric = "recall"), 2)      # 0.22

#Plot
print(evtplot(test_d_dlsp_48, anomalize_d_dlsp_48, reference))

##### 9. d_ipca_12 #####
#Detect
anomalize_d_ipca_12 <- evtdet.anomalize(test_d_ipca_12, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_d_ipca_12, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     5      22 
# FALSE    60     152 

round(evaluate(anomalize_d_ipca_12, reference, metric = "F1"), 2)          # 0.11
round(evaluate(anomalize_d_ipca_12, reference, metric = "accuracy"), 2)    # 0.66
round(evaluate(anomalize_d_ipca_12, reference, metric = "sensitivity"), 2) # 0.08
round(evaluate(anomalize_d_ipca_12, reference, metric = "specificity"), 2) # 0.87
round(evaluate(anomalize_d_ipca_12, reference, metric = "precision"), 2)   # 0.19
round(evaluate(anomalize_d_ipca_12, reference, metric = "recall"), 2)      # 0.08

#Plot
print(evtplot(test_d_ipca_12, anomalize_d_ipca_12, reference))

##### 10. d_ipca_24 #####
#Detect
anomalize_d_ipca_24 <- evtdet.anomalize(test_d_ipca_24, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_d_ipca_24, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     8      12  
# FALSE    57     162    

round(evaluate(anomalize_d_ipca_24, reference, metric = "F1"), 2)          # 0.19
round(evaluate(anomalize_d_ipca_24, reference, metric = "accuracy"), 2)    # 0.71
round(evaluate(anomalize_d_ipca_24, reference, metric = "sensitivity"), 2) # 0.12
round(evaluate(anomalize_d_ipca_24, reference, metric = "specificity"), 2) # 0.93
round(evaluate(anomalize_d_ipca_24, reference, metric = "precision"), 2)   # 0.40
round(evaluate(anomalize_d_ipca_24, reference, metric = "recall"), 2)      # 0.12

#Plot
print(evtplot(test_d_ipca_24, anomalize_d_ipca_24, reference))

##### 11. d_ipca_36 #####
#Detect
anomalize_d_ipca_36 <- evtdet.anomalize(test_d_ipca_36, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_d_ipca_36, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     10     19 
# FALSE    55     155 

round(evaluate(anomalize_d_ipca_36, reference, metric = "F1"), 2)          # 0.21
round(evaluate(anomalize_d_ipca_36, reference, metric = "accuracy"), 2)    # 0.69
round(evaluate(anomalize_d_ipca_36, reference, metric = "sensitivity"), 2) # 0.15
round(evaluate(anomalize_d_ipca_36, reference, metric = "specificity"), 2) # 0.89
round(evaluate(anomalize_d_ipca_36, reference, metric = "precision"), 2)   # 0.34
round(evaluate(anomalize_d_ipca_36, reference, metric = "recall"), 2)      # 0.15

#Plot
print(evtplot(test_d_ipca_36, anomalize_d_ipca_36, reference))

##### 12. d_ipca_48 #####
#Detect
anomalize_d_ipca_48 <- evtdet.anomalize(test_d_ipca_48, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_d_ipca_48, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     5      14 
# FALSE    60     160  

round(evaluate(anomalize_d_ipca_48, reference, metric = "F1"), 2)          # 0.12
round(evaluate(anomalize_d_ipca_48, reference, metric = "accuracy"), 2)    # 0.69
round(evaluate(anomalize_d_ipca_48, reference, metric = "sensitivity"), 2) # 0.08
round(evaluate(anomalize_d_ipca_48, reference, metric = "specificity"), 2) # 0.92
round(evaluate(anomalize_d_ipca_48, reference, metric = "precision"), 2)   # 0.26
round(evaluate(anomalize_d_ipca_48, reference, metric = "recall"), 2)      # 0.08

#Plot
print(evtplot(test_d_ipca_48, anomalize_d_ipca_48, reference))

##### 13. d_pib_12 #####
#Detect
anomalize_d_pib_12 <- evtdet.anomalize(test_d_pib_12, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_d_pib_12, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     12     10 
# FALSE    53     164

round(evaluate(anomalize_d_pib_12, reference, metric = "F1"), 2)          # 0.28
round(evaluate(anomalize_d_pib_12, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(anomalize_d_pib_12, reference, metric = "sensitivity"), 2) # 0.18
round(evaluate(anomalize_d_pib_12, reference, metric = "specificity"), 2) # 0.94
round(evaluate(anomalize_d_pib_12, reference, metric = "precision"), 2)   # 0.55
round(evaluate(anomalize_d_pib_12, reference, metric = "recall"), 2)      # 0.18

#Plot
print(evtplot(test_d_pib_12, anomalize_d_pib_12, reference))

##### 14. d_pib_24 #####
#Detect
anomalize_d_pib_24 <- evtdet.anomalize(test_d_pib_24, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_d_pib_24, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     9      5  
# FALSE    56     169    

round(evaluate(anomalize_d_pib_24, reference, metric = "F1"), 2)          # 0.23
round(evaluate(anomalize_d_pib_24, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(anomalize_d_pib_24, reference, metric = "sensitivity"), 2) # 0.14
round(evaluate(anomalize_d_pib_24, reference, metric = "specificity"), 2) # 0.97
round(evaluate(anomalize_d_pib_24, reference, metric = "precision"), 2)   # 0.64
round(evaluate(anomalize_d_pib_24, reference, metric = "recall"), 2)      # 0.14

#Plot
print(evtplot(test_d_pib_24, anomalize_d_pib_24, reference))

##### 15. d_pib_36 #####
#Detect
anomalize_d_pib_36 <- evtdet.anomalize(test_d_pib_36, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_d_pib_36, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     0      13  
# FALSE    65     161 

round(evaluate(anomalize_d_pib_36, reference, metric = "F1"), 2)          # NaN
round(evaluate(anomalize_d_pib_36, reference, metric = "accuracy"), 2)    # 0.67
round(evaluate(anomalize_d_pib_36, reference, metric = "sensitivity"), 2) # 0.00
round(evaluate(anomalize_d_pib_36, reference, metric = "specificity"), 2) # 0.93
round(evaluate(anomalize_d_pib_36, reference, metric = "precision"), 2)   # 0.00
round(evaluate(anomalize_d_pib_36, reference, metric = "recall"), 2)      # 0.00

#Plot
print(evtplot(test_d_pib_36, anomalize_d_pib_36, reference))

##### 16. d_pib_48 #####
#Detect
anomalize_d_pib_48 <- evtdet.anomalize(test_d_pib_48, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_d_pib_48, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     0      5  
# FALSE    65     169 

round(evaluate(anomalize_d_pib_48, reference, metric = "F1"), 2)          # NaN
round(evaluate(anomalize_d_pib_48, reference, metric = "accuracy"), 2)    # 0.71
round(evaluate(anomalize_d_pib_48, reference, metric = "sensitivity"), 2) # 0.00
round(evaluate(anomalize_d_pib_48, reference, metric = "specificity"), 2) # 0.97
round(evaluate(anomalize_d_pib_48, reference, metric = "precision"), 2)   # 0.00
round(evaluate(anomalize_d_pib_48, reference, metric = "recall"), 2)      # 0.00

#Plot
print(evtplot(test_d_pib_48, anomalize_d_pib_48, reference))

##### 17. d_nfsp_12 #####
#Detect
anomalize_d_nfsp_12 <- evtdet.anomalize(test_d_nfsp_12, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_d_nfsp_12, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     11     6
# FALSE    54     168 

round(evaluate(anomalize_d_nfsp_12, reference, metric = "F1"), 2)          # 0.27
round(evaluate(anomalize_d_nfsp_12, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(anomalize_d_nfsp_12, reference, metric = "sensitivity"), 2) # 0.17
round(evaluate(anomalize_d_nfsp_12, reference, metric = "specificity"), 2) # 0.97
round(evaluate(anomalize_d_nfsp_12, reference, metric = "precision"), 2)   # 0.65
round(evaluate(anomalize_d_nfsp_12, reference, metric = "recall"), 2)      # 0.17

#Plot
print(evtplot(test_d_nfsp_12, anomalize_d_nfsp_12, reference))

##### 18. d_nfsp_24 #####
#Detect
anomalize_d_nfsp_24 <- evtdet.anomalize(test_d_nfsp_24, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_d_nfsp_24, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     16     4   
# FALSE    49     170  

round(evaluate(anomalize_d_nfsp_24, reference, metric = "F1"), 2)          # 0.38
round(evaluate(anomalize_d_nfsp_24, reference, metric = "accuracy"), 2)    # 0.78
round(evaluate(anomalize_d_nfsp_24, reference, metric = "sensitivity"), 2) # 0.25
round(evaluate(anomalize_d_nfsp_24, reference, metric = "specificity"), 2) # 0.98
round(evaluate(anomalize_d_nfsp_24, reference, metric = "precision"), 2)   # 0.80
round(evaluate(anomalize_d_nfsp_24, reference, metric = "recall"), 2)      # 0.25

#Plot
print(evtplot(test_d_nfsp_24, anomalize_d_nfsp_24, reference))

##### 19. d_nfsp_36 #####
#Detect
anomalize_d_nfsp_36 <- evtdet.anomalize(test_d_nfsp_36, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_d_nfsp_36, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     18     3   
# FALSE    47     171  

round(evaluate(anomalize_d_nfsp_36, reference, metric = "F1"), 2)          # 0.42
round(evaluate(anomalize_d_nfsp_36, reference, metric = "accuracy"), 2)    # 0.79
round(evaluate(anomalize_d_nfsp_36, reference, metric = "sensitivity"), 2) # 0.28
round(evaluate(anomalize_d_nfsp_36, reference, metric = "specificity"), 2) # 0.98
round(evaluate(anomalize_d_nfsp_36, reference, metric = "precision"), 2)   # 0.86
round(evaluate(anomalize_d_nfsp_36, reference, metric = "recall"), 2)      # 0.28

#Plot
print(evtplot(test_d_nfsp_36, anomalize_d_nfsp_36, reference))

##### 20. d_nfsp_48 #####
#Detect
anomalize_d_nfsp_48 <- evtdet.anomalize(test_d_nfsp_48, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_d_nfsp_48, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     14     2   
# FALSE    51     172 

round(evaluate(anomalize_d_nfsp_48, reference, metric = "F1"), 2)          # 0.35
round(evaluate(anomalize_d_nfsp_48, reference, metric = "accuracy"), 2)    # 0.78
round(evaluate(anomalize_d_nfsp_48, reference, metric = "sensitivity"), 2) # 0.22
round(evaluate(anomalize_d_nfsp_48, reference, metric = "specificity"), 2) # 0.99
round(evaluate(anomalize_d_nfsp_48, reference, metric = "precision"), 2)   # 0.88
round(evaluate(anomalize_d_nfsp_48, reference, metric = "recall"), 2)      # 0.22

#Plot
print(evtplot(test_d_nfsp_48, anomalize_d_nfsp_48, reference))

##### 21. d_selic_12 #####
#Detect
anomalize_d_selic_12 <- evtdet.anomalize(test_d_selic_12, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_d_selic_12, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     4      8 
# FALSE    61     166 

round(evaluate(anomalize_d_selic_12, reference, metric = "F1"), 2)          # 0.10
round(evaluate(anomalize_d_selic_12, reference, metric = "accuracy"), 2)    # 0.71
round(evaluate(anomalize_d_selic_12, reference, metric = "sensitivity"), 2) # 0.06
round(evaluate(anomalize_d_selic_12, reference, metric = "specificity"), 2) # 0.95
round(evaluate(anomalize_d_selic_12, reference, metric = "precision"), 2)   # 0.33
round(evaluate(anomalize_d_selic_12, reference, metric = "recall"), 2)      # 0.06

#Plot
print(evtplot(test_d_selic_12, anomalize_d_selic_12, reference))

##### 22. d_selic_24 #####
#Detect
anomalize_d_selic_24 <- evtdet.anomalize(test_d_selic_24, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_d_selic_24, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     2      8 
# FALSE    63     166  

round(evaluate(anomalize_d_selic_24, reference, metric = "F1"), 2)          # 0.05
round(evaluate(anomalize_d_selic_24, reference, metric = "accuracy"), 2)    # 0.70
round(evaluate(anomalize_d_selic_24, reference, metric = "sensitivity"), 2) # 0.03
round(evaluate(anomalize_d_selic_24, reference, metric = "specificity"), 2) # 0.95
round(evaluate(anomalize_d_selic_24, reference, metric = "precision"), 2)   # 0.20
round(evaluate(anomalize_d_selic_24, reference, metric = "recall"), 2)      # 0.03

#Plot
print(evtplot(test_d_selic_24, anomalize_d_selic_24, reference))

##### 23. d_selic_36 #####
#Detect
anomalize_d_selic_36 <- evtdet.anomalize(test_d_selic_36, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_d_selic_36, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     1      9     
# FALSE    64     165 

round(evaluate(anomalize_d_selic_36, reference, metric = "F1"), 2)          # 0.03
round(evaluate(anomalize_d_selic_36, reference, metric = "accuracy"), 2)    # 0.69
round(evaluate(anomalize_d_selic_36, reference, metric = "sensitivity"), 2) # 0.02
round(evaluate(anomalize_d_selic_36, reference, metric = "specificity"), 2) # 0.95
round(evaluate(anomalize_d_selic_36, reference, metric = "precision"), 2)   # 0.10
round(evaluate(anomalize_d_selic_36, reference, metric = "recall"), 2)      # 0.02

#Plot
print(evtplot(test_d_selic_36, anomalize_d_selic_36, reference))

##### 24. d_selic_48 #####
#Detect
anomalize_d_selic_48 <- evtdet.anomalize(test_d_selic_48, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_d_selic_48, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     3      9         
# FALSE    62     165  

round(evaluate(anomalize_d_selic_48, reference, metric = "F1"), 2)          # 0.08
round(evaluate(anomalize_d_selic_48, reference, metric = "accuracy"), 2)    # 0.70
round(evaluate(anomalize_d_selic_48, reference, metric = "sensitivity"), 2) # 0.05
round(evaluate(anomalize_d_selic_48, reference, metric = "specificity"), 2) # 0.95
round(evaluate(anomalize_d_selic_48, reference, metric = "precision"), 2)   # 0.25
round(evaluate(anomalize_d_selic_48, reference, metric = "recall"), 2)      # 0.05

#Plot
print(evtplot(test_d_selic_48, anomalize_d_selic_48, reference))

###########################################
##### Adaptive Normalization Outliers #####
###########################################

##### 1. d_exch_12 #####
#Detect
an_d_exch_12 <- evtdet.an_outliers(test_d_exch_12, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_d_exch_12, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     12     4    
# FALSE    53     170 

round(evaluate(an_d_exch_12, reference, metric = "F1"), 2)          # 0.30
round(evaluate(an_d_exch_12, reference, metric = "accuracy"), 2)    # 0.76
round(evaluate(an_d_exch_12, reference, metric = "sensitivity"), 2) # 0.18
round(evaluate(an_d_exch_12, reference, metric = "specificity"), 2) # 0.98
round(evaluate(an_d_exch_12, reference, metric = "precision"), 2)   # 0.75
round(evaluate(an_d_exch_12, reference, metric = "recall"), 2)      # 0.18

#Plot
print(evtplot(test_d_exch_12, an_d_exch_12, reference))

##### 2. d_exch_24 #####
#Detect
an_d_exch_24 <- evtdet.an_outliers(test_d_exch_24, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_d_exch_24, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     9      4   
# FALSE    56     170  

round(evaluate(an_d_exch_24, reference, metric = "F1"), 2)          # 0.23
round(evaluate(an_d_exch_24, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(an_d_exch_24, reference, metric = "sensitivity"), 2) # 0.14
round(evaluate(an_d_exch_24, reference, metric = "specificity"), 2) # 0.98
round(evaluate(an_d_exch_24, reference, metric = "precision"), 2)   # 0.69
round(evaluate(an_d_exch_24, reference, metric = "recall"), 2)      # 0.14

#Plot
print(evtplot(test_d_exch_24, an_d_exch_24, reference))

##### 3. d_exch_36 #####
#Detect
an_d_exch_36 <- evtdet.an_outliers(test_d_exch_36, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_d_exch_36, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     6      2  
# FALSE    59     172   

round(evaluate(an_d_exch_36, reference, metric = "F1"), 2)          # 0.16
round(evaluate(an_d_exch_36, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(an_d_exch_36, reference, metric = "sensitivity"), 2) # 0.09
round(evaluate(an_d_exch_36, reference, metric = "specificity"), 2) # 0.99
round(evaluate(an_d_exch_36, reference, metric = "precision"), 2)   # 0.75
round(evaluate(an_d_exch_36, reference, metric = "recall"), 2)      # 0.09

#Plot
print(evtplot(test_d_exch_36, an_d_exch_36, reference))

##### 4. d_exch_48 #####
#Detect
an_d_exch_48 <- evtdet.an_outliers(test_d_exch_48, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_d_exch_48, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     5      0
# FALSE    60     174

round(evaluate(an_d_exch_48, reference, metric = "F1"), 2)          # 0.14
round(evaluate(an_d_exch_48, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(an_d_exch_48, reference, metric = "sensitivity"), 2) # 0.08
round(evaluate(an_d_exch_48, reference, metric = "specificity"), 2) # 1.00
round(evaluate(an_d_exch_48, reference, metric = "precision"), 2)   # 1.00
round(evaluate(an_d_exch_48, reference, metric = "recall"), 2)      # 0.08

#Plot
print(evtplot(test_d_exch_48, an_d_exch_48, reference))

##### 5. d_dlsp_12 #####
#Detect
an_d_dlsp_12 <- evtdet.an_outliers(test_d_dlsp_12, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_d_dlsp_12, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     11     8    
# FALSE    54     166  

round(evaluate(an_d_dlsp_12, reference, metric = "F1"), 2)          # 0.26
round(evaluate(an_d_dlsp_12, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(an_d_dlsp_12, reference, metric = "sensitivity"), 2) # 0.17
round(evaluate(an_d_dlsp_12, reference, metric = "specificity"), 2) # 0.95
round(evaluate(an_d_dlsp_12, reference, metric = "precision"), 2)   # 0.58
round(evaluate(an_d_dlsp_12, reference, metric = "recall"), 2)      # 0.17

#Plot
print(evtplot(test_d_dlsp_12, an_d_dlsp_12, reference))

##### 6. d_dlsp_24 #####
#Detect
an_d_dlsp_24 <- evtdet.an_outliers(test_d_dlsp_24, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_d_dlsp_24, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     18     14
# FALSE    47     160   

round(evaluate(an_d_dlsp_24, reference, metric = "F1"), 2)          # 0.37
round(evaluate(an_d_dlsp_24, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(an_d_dlsp_24, reference, metric = "sensitivity"), 2) # 0.28
round(evaluate(an_d_dlsp_24, reference, metric = "specificity"), 2) # 0.92
round(evaluate(an_d_dlsp_24, reference, metric = "precision"), 2)   # 0.56
round(evaluate(an_d_dlsp_24, reference, metric = "recall"), 2)      # 0.28

#Plot
print(evtplot(test_d_dlsp_24, an_d_dlsp_24, reference))

##### 7. d_dlsp_36 #####
#Detect
an_d_dlsp_36 <- evtdet.an_outliers(test_d_dlsp_36, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_d_dlsp_36, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     27     21 
# FALSE    38     153  

round(evaluate(an_d_dlsp_36, reference, metric = "F1"), 2)          # 0.48
round(evaluate(an_d_dlsp_36, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(an_d_dlsp_36, reference, metric = "sensitivity"), 2) # 0.42
round(evaluate(an_d_dlsp_36, reference, metric = "specificity"), 2) # 0.88
round(evaluate(an_d_dlsp_36, reference, metric = "precision"), 2)   # 0.56
round(evaluate(an_d_dlsp_36, reference, metric = "recall"), 2)      # 0.42

#Plot
print(evtplot(test_d_dlsp_36, an_d_dlsp_36, reference))

##### 8. d_dlsp_48 #####
#Detect
an_d_dlsp_48 <- evtdet.an_outliers(test_d_dlsp_48, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_d_dlsp_48, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     28     20 
# FALSE    37     154

round(evaluate(an_d_dlsp_48, reference, metric = "F1"), 2)          # 0.50
round(evaluate(an_d_dlsp_48, reference, metric = "accuracy"), 2)    # 0.76
round(evaluate(an_d_dlsp_48, reference, metric = "sensitivity"), 2) # 0.43
round(evaluate(an_d_dlsp_48, reference, metric = "specificity"), 2) # 0.89
round(evaluate(an_d_dlsp_48, reference, metric = "precision"), 2)   # 0.58
round(evaluate(an_d_dlsp_48, reference, metric = "recall"), 2)      # 0.43

#Plot
print(evtplot(test_d_dlsp_48, an_d_dlsp_48, reference))

##### 9. d_ipca_12 #####
#Detect
an_d_ipca_12 <- evtdet.an_outliers(test_d_ipca_12, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_d_ipca_12, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     4      30   
# FALSE    61     144 

round(evaluate(an_d_ipca_12, reference, metric = "F1"), 2)          # 0.08
round(evaluate(an_d_ipca_12, reference, metric = "accuracy"), 2)    # 0.62
round(evaluate(an_d_ipca_12, reference, metric = "sensitivity"), 2) # 0.06
round(evaluate(an_d_ipca_12, reference, metric = "specificity"), 2) # 0.83
round(evaluate(an_d_ipca_12, reference, metric = "precision"), 2)   # 0.12
round(evaluate(an_d_ipca_12, reference, metric = "recall"), 2)      # 0.06 

#Plot
print(evtplot(test_d_ipca_12, an_d_ipca_12, reference))

##### 10. d_ipca_24 #####
#Detect
an_d_ipca_24 <- evtdet.an_outliers(test_d_ipca_24, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_d_ipca_24, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     7      26 
# FALSE    58     148 

round(evaluate(an_d_ipca_24, reference, metric = "F1"), 2)          # 0.14
round(evaluate(an_d_ipca_24, reference, metric = "accuracy"), 2)    # 0.65
round(evaluate(an_d_ipca_24, reference, metric = "sensitivity"), 2) # 0.11
round(evaluate(an_d_ipca_24, reference, metric = "specificity"), 2) # 0.85
round(evaluate(an_d_ipca_24, reference, metric = "precision"), 2)   # 0.21
round(evaluate(an_d_ipca_24, reference, metric = "recall"), 2)      # 0.11 

#Plot
print(evtplot(test_d_ipca_24, an_d_ipca_24, reference))

##### 11. d_ipca_36 #####
#Detect
an_d_ipca_36 <- evtdet.an_outliers(test_d_ipca_36, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_d_ipca_36, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     8      21 
# FALSE    57     153

round(evaluate(an_d_ipca_36, reference, metric = "F1"), 2)          # 0.17
round(evaluate(an_d_ipca_36, reference, metric = "accuracy"), 2)    # 0.67
round(evaluate(an_d_ipca_36, reference, metric = "sensitivity"), 2) # 0.12
round(evaluate(an_d_ipca_36, reference, metric = "specificity"), 2) # 0.88
round(evaluate(an_d_ipca_36, reference, metric = "precision"), 2)   # 0.28
round(evaluate(an_d_ipca_36, reference, metric = "recall"), 2)      # 0.12

#Plot
print(evtplot(test_d_ipca_36, an_d_ipca_36, reference))

##### 12. d_ipca_48 #####
#Detect
an_d_ipca_48 <- evtdet.an_outliers(test_d_ipca_48, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_d_ipca_48, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     6      28 
# FALSE    59     146

round(evaluate(an_d_ipca_48, reference, metric = "F1"), 2)          # 0.12
round(evaluate(an_d_ipca_48, reference, metric = "accuracy"), 2)    # 0.64
round(evaluate(an_d_ipca_48, reference, metric = "sensitivity"), 2) # 0.09
round(evaluate(an_d_ipca_48, reference, metric = "specificity"), 2) # 0.84
round(evaluate(an_d_ipca_48, reference, metric = "precision"), 2)   # 0.18
round(evaluate(an_d_ipca_48, reference, metric = "recall"), 2)      # 0.09

#Plot
print(evtplot(test_d_ipca_48, an_d_ipca_48, reference))

##### 13. d_pib_12 #####
#Detect
an_d_pib_12 <- evtdet.an_outliers(test_d_pib_12, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_d_pib_12, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     11     14   
# FALSE    54     160 

round(evaluate(an_d_pib_12, reference, metric = "F1"), 2)          # 0.24
round(evaluate(an_d_pib_12, reference, metric = "accuracy"), 2)    # 0.72
round(evaluate(an_d_pib_12, reference, metric = "sensitivity"), 2) # 0.17
round(evaluate(an_d_pib_12, reference, metric = "specificity"), 2) # 0.92
round(evaluate(an_d_pib_12, reference, metric = "precision"), 2)   # 0.44
round(evaluate(an_d_pib_12, reference, metric = "recall"), 2)      # 0.17

#Plot
print(evtplot(test_d_pib_12, an_d_pib_12, reference))

##### 14. d_pib_24 #####
#Detect
an_d_pib_24 <- evtdet.an_outliers(test_d_pib_24, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_d_pib_24, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     3      2    
# FALSE    62     172  

round(evaluate(an_d_pib_24, reference, metric = "F1"), 2)          # 0.09
round(evaluate(an_d_pib_24, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(an_d_pib_24, reference, metric = "sensitivity"), 2) # 0.05
round(evaluate(an_d_pib_24, reference, metric = "specificity"), 2) # 0.99
round(evaluate(an_d_pib_24, reference, metric = "precision"), 2)   # 0.60
round(evaluate(an_d_pib_24, reference, metric = "recall"), 2)      # 0.05

#Plot
print(evtplot(test_d_pib_24, an_d_pib_24, reference))

##### 15. d_pib_36 #####
#Detect
an_d_pib_36 <- evtdet.an_outliers(test_d_pib_36, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_d_pib_36, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     0      5 
# FALSE    65     169    

round(evaluate(an_d_pib_36, reference, metric = "F1"), 2)          # NaN
round(evaluate(an_d_pib_36, reference, metric = "accuracy"), 2)    # 0.71
round(evaluate(an_d_pib_36, reference, metric = "sensitivity"), 2) # 0.00
round(evaluate(an_d_pib_36, reference, metric = "specificity"), 2) # 0.97
round(evaluate(an_d_pib_36, reference, metric = "precision"), 2)   # 0.00
round(evaluate(an_d_pib_36, reference, metric = "recall"), 2)      # 0.00

#Plot
print(evtplot(test_d_pib_36, an_d_pib_36, reference))

##### 16. d_pib_48 #####
#Detect
an_d_pib_48 <- evtdet.an_outliers(test_d_pib_48, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_d_pib_48, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     0      6 
# FALSE    65     168  

round(evaluate(an_d_pib_48, reference, metric = "F1"), 2)          # NaN
round(evaluate(an_d_pib_48, reference, metric = "accuracy"), 2)    # 0.70
round(evaluate(an_d_pib_48, reference, metric = "sensitivity"), 2) # 0.00
round(evaluate(an_d_pib_48, reference, metric = "specificity"), 2) # 0.97
round(evaluate(an_d_pib_48, reference, metric = "precision"), 2)   # 0.00
round(evaluate(an_d_pib_48, reference, metric = "recall"), 2)      # 0.00

#Plot
print(evtplot(test_d_pib_48, an_d_pib_48, reference))

##### 17. d_nfsp_12 #####
#Detect
an_d_nfsp_12 <- evtdet.an_outliers(test_d_nfsp_12, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_d_nfsp_12, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     16     12 
# FALSE    49     162     

round(evaluate(an_d_nfsp_12, reference, metric = "F1"), 2)          # 0.34
round(evaluate(an_d_nfsp_12, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(an_d_nfsp_12, reference, metric = "sensitivity"), 2) # 0.25
round(evaluate(an_d_nfsp_12, reference, metric = "specificity"), 2) # 0.93
round(evaluate(an_d_nfsp_12, reference, metric = "precision"), 2)   # 0.57
round(evaluate(an_d_nfsp_12, reference, metric = "recall"), 2)      # 0.25

#Plot
print(evtplot(test_d_nfsp_12, an_d_nfsp_12, reference))

##### 18. d_nfsp_24 #####
#Detect
an_d_nfsp_24 <- evtdet.an_outliers(test_d_nfsp_24, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_d_nfsp_24, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     12     4  
# FALSE    53     170    

round(evaluate(an_d_nfsp_24, reference, metric = "F1"), 2)          # 0.30
round(evaluate(an_d_nfsp_24, reference, metric = "accuracy"), 2)    # 0.76
round(evaluate(an_d_nfsp_24, reference, metric = "sensitivity"), 2) # 0.18
round(evaluate(an_d_nfsp_24, reference, metric = "specificity"), 2) # 0.98
round(evaluate(an_d_nfsp_24, reference, metric = "precision"), 2)   # 0.75
round(evaluate(an_d_nfsp_24, reference, metric = "recall"), 2)      # 0.18

#Plot
print(evtplot(test_d_nfsp_24, an_d_nfsp_24, reference))

##### 19. d_nfsp_36 #####
#Detect
an_d_nfsp_36 <- evtdet.an_outliers(test_d_nfsp_36, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_d_nfsp_36, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     13     5   
# FALSE    52     169  

round(evaluate(an_d_nfsp_36, reference, metric = "F1"), 2)          # 0.31
round(evaluate(an_d_nfsp_36, reference, metric = "accuracy"), 2)    # 0.76
round(evaluate(an_d_nfsp_36, reference, metric = "sensitivity"), 2) # 0.20
round(evaluate(an_d_nfsp_36, reference, metric = "specificity"), 2) # 0.97
round(evaluate(an_d_nfsp_36, reference, metric = "precision"), 2)   # 0.72
round(evaluate(an_d_nfsp_36, reference, metric = "recall"), 2)      # 0.20

#Plot
print(evtplot(test_d_nfsp_36, an_d_nfsp_36, reference))

##### 20. d_nfsp_48 #####
#Detect
an_d_nfsp_48 <- evtdet.an_outliers(test_d_nfsp_48, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_d_nfsp_48, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     13     3   
# FALSE    52     171  

round(evaluate(an_d_nfsp_48, reference, metric = "F1"), 2)          # 0.32
round(evaluate(an_d_nfsp_48, reference, metric = "accuracy"), 2)    # 0.77
round(evaluate(an_d_nfsp_48, reference, metric = "sensitivity"), 2) # 0.20
round(evaluate(an_d_nfsp_48, reference, metric = "specificity"), 2) # 0.98
round(evaluate(an_d_nfsp_48, reference, metric = "precision"), 2)   # 0.81
round(evaluate(an_d_nfsp_48, reference, metric = "recall"), 2)      # 0.20

#Plot
print(evtplot(test_d_nfsp_48, an_d_nfsp_48, reference))

##### 21. d_selic_12 #####
#Detect
an_d_selic_12 <- evtdet.an_outliers(test_d_selic_12, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_d_selic_12, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     3      16 
# FALSE    62     158

round(evaluate(an_d_selic_12, reference, metric = "F1"), 2)          # 0.07
round(evaluate(an_d_selic_12, reference, metric = "accuracy"), 2)    # 0.67
round(evaluate(an_d_selic_12, reference, metric = "sensitivity"), 2) # 0.05
round(evaluate(an_d_selic_12, reference, metric = "specificity"), 2) # 0.91
round(evaluate(an_d_selic_12, reference, metric = "precision"), 2)   # 0.16
round(evaluate(an_d_selic_12, reference, metric = "recall"), 2)      # 0.05

#Plot
print(evtplot(test_d_selic_12, an_d_selic_12, reference))

##### 22. d_selic_24 #####
#Detect
an_d_selic_24 <- evtdet.an_outliers(test_d_selic_24, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_d_selic_24, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     1      9    
# FALSE    64     165 

round(evaluate(an_d_selic_24, reference, metric = "F1"), 2)          # 0.03
round(evaluate(an_d_selic_24, reference, metric = "accuracy"), 2)    # 0.69
round(evaluate(an_d_selic_24, reference, metric = "sensitivity"), 2) # 0.02
round(evaluate(an_d_selic_24, reference, metric = "specificity"), 2) # 0.95
round(evaluate(an_d_selic_24, reference, metric = "precision"), 2)   # 0.10
round(evaluate(an_d_selic_24, reference, metric = "recall"), 2)      # 0.02

#Plot
print(evtplot(test_d_selic_24, an_d_selic_24, reference))

##### 23. d_selic_36 #####
#Detect
an_d_selic_36 <- evtdet.an_outliers(test_d_selic_36, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_d_selic_36, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     1      10   
# FALSE    64     164   

round(evaluate(an_d_selic_36, reference, metric = "F1"), 2)          # 0.03
round(evaluate(an_d_selic_36, reference, metric = "accuracy"), 2)    # 0.69
round(evaluate(an_d_selic_36, reference, metric = "sensitivity"), 2) # 0.02
round(evaluate(an_d_selic_36, reference, metric = "specificity"), 2) # 0.94
round(evaluate(an_d_selic_36, reference, metric = "precision"), 2)   # 0.09
round(evaluate(an_d_selic_36, reference, metric = "recall"), 2)      # 0.02

#Plot
print(evtplot(test_d_selic_36, an_d_selic_36, reference))

##### 24. d_selic_48 #####
#Detect
an_d_selic_48 <- evtdet.an_outliers(test_d_selic_48, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_d_selic_48, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     2      13 
# FALSE    63     161 

round(evaluate(an_d_selic_48, reference, metric = "F1"), 2)          # 0.05
round(evaluate(an_d_selic_48, reference, metric = "accuracy"), 2)    # 0.68
round(evaluate(an_d_selic_48, reference, metric = "sensitivity"), 2) # 0.03
round(evaluate(an_d_selic_48, reference, metric = "specificity"), 2) # 0.93
round(evaluate(an_d_selic_48, reference, metric = "precision"), 2)   # 0.13
round(evaluate(an_d_selic_48, reference, metric = "recall"), 2)      # 0.03

#Plot
print(evtplot(test_d_selic_48, an_d_selic_48, reference))

#######################
##### EventDetect #####
#######################

##### 1. d_exch_12 #####
#Detect
eventdetect_d_exch_12 <- evtdet.eventdetect(na.omit(test_d_exch_12), w = 30)

#Error in data.frame(..., check.names = FALSE) : 
#  arguments imply differing number of rows: 0, 1 

#Evaluate
evaluate(eventdetect_d_exch_12, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE    

round(evaluate(eventdetect_d_exch_12, reference, metric = "F1"), 2)          # 
round(evaluate(eventdetect_d_exch_12, reference, metric = "accuracy"), 2)    # 
round(evaluate(eventdetect_d_exch_12, reference, metric = "sensitivity"), 2) # 
round(evaluate(eventdetect_d_exch_12, reference, metric = "specificity"), 2) # 
round(evaluate(eventdetect_d_exch_12, reference, metric = "precision"), 2)   # 
round(evaluate(eventdetect_d_exch_12, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_d_exch_12, eventdetect_d_exch_12, reference))

##### 2. d_exch_24 #####
#Detect
eventdetect_d_exch_24 <- evtdet.eventdetect(na.omit(test_d_exch_24), w = 30)

#Error in data.frame(..., check.names = FALSE) : 
#  arguments imply differing number of rows: 0, 1

#Evaluate
evaluate(eventdetect_d_exch_24, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE     

round(evaluate(eventdetect_d_exch_24, reference, metric = "F1"), 2)          # 
round(evaluate(eventdetect_d_exch_24, reference, metric = "accuracy"), 2)    # 
round(evaluate(eventdetect_d_exch_24, reference, metric = "sensitivity"), 2) # 
round(evaluate(eventdetect_d_exch_24, reference, metric = "specificity"), 2) # 
round(evaluate(eventdetect_d_exch_24, reference, metric = "precision"), 2)   # 
round(evaluate(eventdetect_d_exch_24, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_d_exch_24, eventdetect_d_exch_24, reference))

##### 3. d_exch_36 #####
#Detect
eventdetect_d_exch_36 <- evtdet.eventdetect(na.omit(test_d_exch_36), w = 30)

#Error in data.frame(..., check.names = FALSE) : 
#  arguments imply differing number of rows: 0, 1

#Evaluate
evaluate(eventdetect_d_exch_36, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE    

round(evaluate(eventdetect_d_exch_36, reference, metric = "F1"), 2)          # 
round(evaluate(eventdetect_d_exch_36, reference, metric = "accuracy"), 2)    # 
round(evaluate(eventdetect_d_exch_36, reference, metric = "sensitivity"), 2) # 
round(evaluate(eventdetect_d_exch_36, reference, metric = "specificity"), 2) # 
round(evaluate(eventdetect_d_exch_36, reference, metric = "precision"), 2)   # 
round(evaluate(eventdetect_d_exch_36, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_d_exch_36, eventdetect_d_exch_36, reference))

##### 4. d_exch_48 #####
#Detect
eventdetect_d_exch_48 <- evtdet.eventdetect(na.omit(test_d_exch_48), w = 30)

#Evaluate
evaluate(eventdetect_d_exch_48, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     6      8    
# FALSE    59     166  

round(evaluate(eventdetect_d_exch_48, reference, metric = "F1"), 2)          # 0.15
round(evaluate(eventdetect_d_exch_48, reference, metric = "accuracy"), 2)    # 0.72
round(evaluate(eventdetect_d_exch_48, reference, metric = "sensitivity"), 2) # 0.09
round(evaluate(eventdetect_d_exch_48, reference, metric = "specificity"), 2) # 0.95
round(evaluate(eventdetect_d_exch_48, reference, metric = "precision"), 2)   # 0.43
round(evaluate(eventdetect_d_exch_48, reference, metric = "recall"), 2)      # 0.09

#Plot
print(evtplot(test_d_exch_48, eventdetect_d_exch_48, reference))

##### 5. d_dlsp_12 #####
#Detect
eventdetect_d_dlsp_12 <- evtdet.eventdetect(na.omit(test_d_dlsp_12), w = 30)

#Error in data.frame(..., check.names = FALSE) : 
#  arguments imply differing number of rows: 0, 1

#Evaluate
evaluate(eventdetect_d_dlsp_12, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE   

round(evaluate(eventdetect_d_dlsp_12, reference, metric = "F1"), 2)          # 
round(evaluate(eventdetect_d_dlsp_12, reference, metric = "accuracy"), 2)    # 
round(evaluate(eventdetect_d_dlsp_12, reference, metric = "sensitivity"), 2) # 
round(evaluate(eventdetect_d_dlsp_12, reference, metric = "specificity"), 2) # 
round(evaluate(eventdetect_d_dlsp_12, reference, metric = "precision"), 2)   # 
round(evaluate(eventdetect_d_dlsp_12, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_d_dlsp_12, eventdetect_d_dlsp_12, reference))

##### 6. d_dlsp_24 #####
#Detect
eventdetect_d_dlsp_24 <- evtdet.eventdetect(na.omit(test_d_dlsp_24), w = 30)

#Evaluate
evaluate(eventdetect_d_dlsp_24, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     20     18   
# FALSE    45     156   

round(evaluate(eventdetect_d_dlsp_24, reference, metric = "F1"), 2)          # 0.39
round(evaluate(eventdetect_d_dlsp_24, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(eventdetect_d_dlsp_24, reference, metric = "sensitivity"), 2) # 0.31
round(evaluate(eventdetect_d_dlsp_24, reference, metric = "specificity"), 2) # 0.90
round(evaluate(eventdetect_d_dlsp_24, reference, metric = "precision"), 2)   # 0.53
round(evaluate(eventdetect_d_dlsp_24, reference, metric = "recall"), 2)      # 0.31

#Plot
print(evtplot(test_d_dlsp_24, eventdetect_d_dlsp_24, reference))

##### 7. d_dlsp_36 #####
#Detect
eventdetect_d_dlsp_36 <- evtdet.eventdetect(na.omit(test_d_dlsp_36), w = 30)

#Error in data.frame(..., check.names = FALSE) : 
#  arguments imply differing number of rows: 0, 1

#Evaluate
evaluate(eventdetect_d_dlsp_36, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE    

round(evaluate(eventdetect_d_dlsp_36, reference, metric = "F1"), 2)          # 
round(evaluate(eventdetect_d_dlsp_36, reference, metric = "accuracy"), 2)    # 
round(evaluate(eventdetect_d_dlsp_36, reference, metric = "sensitivity"), 2) # 
round(evaluate(eventdetect_d_dlsp_36, reference, metric = "specificity"), 2) # 
round(evaluate(eventdetect_d_dlsp_36, reference, metric = "precision"), 2)   # 
round(evaluate(eventdetect_d_dlsp_36, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_d_dlsp_36, eventdetect_d_dlsp_36, reference))

##### 8. d_dlsp_48 #####
#Detect
eventdetect_d_dlsp_48 <- evtdet.eventdetect(na.omit(test_d_dlsp_48), w = 30)

#Error in data.frame(..., check.names = FALSE) : 
#  arguments imply differing number of rows: 0, 1

#Evaluate
evaluate(eventdetect_d_dlsp_48, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE      

round(evaluate(eventdetect_d_dlsp_48, reference, metric = "F1"), 2)          # 
round(evaluate(eventdetect_d_dlsp_48, reference, metric = "accuracy"), 2)    # 
round(evaluate(eventdetect_d_dlsp_48, reference, metric = "sensitivity"), 2) # 
round(evaluate(eventdetect_d_dlsp_48, reference, metric = "specificity"), 2) # 
round(evaluate(eventdetect_d_dlsp_48, reference, metric = "precision"), 2)   # 
round(evaluate(eventdetect_d_dlsp_48, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_d_dlsp_48, eventdetect_d_dlsp_48, reference))

##### 9. d_ipca_12 #####
#Detect
eventdetect_d_ipca_12 <- evtdet.eventdetect(na.omit(test_d_ipca_12), w = 30)

#Error in data.frame(..., check.names = FALSE) : 
#  arguments imply differing number of rows: 0, 1

#Evaluate
evaluate(eventdetect_d_ipca_12, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE      
# FALSE      

round(evaluate(eventdetect_d_ipca_12, reference, metric = "F1"), 2)          # 
round(evaluate(eventdetect_d_ipca_12, reference, metric = "accuracy"), 2)    # 
round(evaluate(eventdetect_d_ipca_12, reference, metric = "sensitivity"), 2) # 
round(evaluate(eventdetect_d_ipca_12, reference, metric = "specificity"), 2) # 
round(evaluate(eventdetect_d_ipca_12, reference, metric = "precision"), 2)   # 
round(evaluate(eventdetect_d_ipca_12, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_d_ipca_12, eventdetect_d_ipca_12, reference))

##### 10. d_ipca_24 #####
#Detect
eventdetect_d_ipca_24 <- evtdet.eventdetect(na.omit(test_d_ipca_24), w = 30)

#Error in data.frame(..., check.names = FALSE) : 
#  arguments imply differing number of rows: 0, 1

#Evaluate
evaluate(eventdetect_d_ipca_24, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE       
# FALSE    

round(evaluate(eventdetect_d_ipca_24, reference, metric = "F1"), 2)          # 
round(evaluate(eventdetect_d_ipca_24, reference, metric = "accuracy"), 2)    # 
round(evaluate(eventdetect_d_ipca_24, reference, metric = "sensitivity"), 2) # 
round(evaluate(eventdetect_d_ipca_24, reference, metric = "specificity"), 2) # 
round(evaluate(eventdetect_d_ipca_24, reference, metric = "precision"), 2)   # 
round(evaluate(eventdetect_d_ipca_24, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_d_ipca_24, eventdetect_d_ipca_24, reference))

##### 11. d_ipca_36 #####
#Detect
eventdetect_d_ipca_36 <- evtdet.eventdetect(na.omit(test_d_ipca_36), w = 30)

#Error in data.frame(..., check.names = FALSE) : 
#  arguments imply differing number of rows: 0, 1

#Evaluate
evaluate(eventdetect_d_ipca_36, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE    

round(evaluate(eventdetect_d_ipca_36, reference, metric = "F1"), 2)          # 
round(evaluate(eventdetect_d_ipca_36, reference, metric = "accuracy"), 2)    # 
round(evaluate(eventdetect_d_ipca_36, reference, metric = "sensitivity"), 2) # 
round(evaluate(eventdetect_d_ipca_36, reference, metric = "specificity"), 2) # 
round(evaluate(eventdetect_d_ipca_36, reference, metric = "precision"), 2)   # 
round(evaluate(eventdetect_d_ipca_36, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_d_ipca_36, eventdetect_d_ipca_36, reference))

##### 12. d_ipca_48 #####
#Detect
eventdetect_d_ipca_48 <- evtdet.eventdetect(na.omit(test_d_ipca_48), w = 30)

#Error in data.frame(..., check.names = FALSE) : 
#  arguments imply differing number of rows: 0, 1

#Evaluate
evaluate(eventdetect_d_ipca_48, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE    

round(evaluate(eventdetect_d_ipca_48, reference, metric = "F1"), 2)          # 
round(evaluate(eventdetect_d_ipca_48, reference, metric = "accuracy"), 2)    # 
round(evaluate(eventdetect_d_ipca_48, reference, metric = "sensitivity"), 2) # 
round(evaluate(eventdetect_d_ipca_48, reference, metric = "specificity"), 2) # 
round(evaluate(eventdetect_d_ipca_48, reference, metric = "precision"), 2)   # 
round(evaluate(eventdetect_d_ipca_48, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_d_ipca_48, eventdetect_d_ipca_48, reference))

##### 13. d_pib_12 #####
#Detect
eventdetect_d_pib_12 <- evtdet.eventdetect(na.omit(test_d_pib_12), w = 30)

#Error in data.frame(..., check.names = FALSE) : 
#  arguments imply differing number of rows: 0, 1

#Evaluate
evaluate(eventdetect_d_pib_12, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE       
# FALSE    

round(evaluate(eventdetect_d_pib_12, reference, metric = "F1"), 2)          # 
round(evaluate(eventdetect_d_pib_12, reference, metric = "accuracy"), 2)    # 
round(evaluate(eventdetect_d_pib_12, reference, metric = "sensitivity"), 2) # 
round(evaluate(eventdetect_d_pib_12, reference, metric = "specificity"), 2) # 
round(evaluate(eventdetect_d_pib_12, reference, metric = "precision"), 2)   # 
round(evaluate(eventdetect_d_pib_12, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_d_pib_12, eventdetect_d_pib_12, reference))

##### 14. d_pib_24 #####
#Detect
eventdetect_d_pib_24 <- evtdet.eventdetect(na.omit(test_d_pib_24), w = 30)

#Error in data.frame(..., check.names = FALSE) : 
#  arguments imply differing number of rows: 0, 1

#Evaluate
evaluate(eventdetect_d_pib_24, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE      
# FALSE          

round(evaluate(eventdetect_d_pib_24, reference, metric = "F1"), 2)          # 
round(evaluate(eventdetect_d_pib_24, reference, metric = "accuracy"), 2)    # 
round(evaluate(eventdetect_d_pib_24, reference, metric = "sensitivity"), 2) # 
round(evaluate(eventdetect_d_pib_24, reference, metric = "specificity"), 2) # 
round(evaluate(eventdetect_d_pib_24, reference, metric = "precision"), 2)   # 
round(evaluate(eventdetect_d_pib_24, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_d_pib_24, eventdetect_d_pib_24, reference))

##### 15. d_pib_36 #####
#Detect
eventdetect_d_pib_36 <- evtdet.eventdetect(na.omit(test_d_pib_36), w = 30)

#Evaluate
evaluate(eventdetect_d_pib_36, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     39     99  
# FALSE    26     75       

round(evaluate(eventdetect_d_pib_36, reference, metric = "F1"), 2)          # 0.38
round(evaluate(eventdetect_d_pib_36, reference, metric = "accuracy"), 2)    # 0.48
round(evaluate(eventdetect_d_pib_36, reference, metric = "sensitivity"), 2) # 0.60
round(evaluate(eventdetect_d_pib_36, reference, metric = "specificity"), 2) # 0.43
round(evaluate(eventdetect_d_pib_36, reference, metric = "precision"), 2)   # 0.28
round(evaluate(eventdetect_d_pib_36, reference, metric = "recall"), 2)      # 0.60

#Plot
print(evtplot(test_d_pib_36, eventdetect_d_pib_36, reference))

##### 16. d_pib_48 #####
#Detect
eventdetect_d_pib_48 <- evtdet.eventdetect(na.omit(test_d_pib_48), w = 30)

#Evaluate
evaluate(eventdetect_d_pib_48, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     24     34   
# FALSE    41     140    

round(evaluate(eventdetect_d_pib_48, reference, metric = "F1"), 2)          # 0.39
round(evaluate(eventdetect_d_pib_48, reference, metric = "accuracy"), 2)    # 0.69
round(evaluate(eventdetect_d_pib_48, reference, metric = "sensitivity"), 2) # 0.37
round(evaluate(eventdetect_d_pib_48, reference, metric = "specificity"), 2) # 0.80
round(evaluate(eventdetect_d_pib_48, reference, metric = "precision"), 2)   # 0.41
round(evaluate(eventdetect_d_pib_48, reference, metric = "recall"), 2)      # 0.37

#Plot
print(evtplot(test_d_pib_48, eventdetect_d_pib_48, reference))

##### 17. d_nfsp_12 #####
#Detect
eventdetect_d_nfsp_12 <- evtdet.eventdetect(na.omit(test_d_nfsp_12), w = 30)

#Evaluate
evaluate(eventdetect_d_nfsp_12, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     31     44   
# FALSE    34     130 

round(evaluate(eventdetect_d_nfsp_12, reference, metric = "F1"), 2)          # 0.44
round(evaluate(eventdetect_d_nfsp_12, reference, metric = "accuracy"), 2)    # 0.67
round(evaluate(eventdetect_d_nfsp_12, reference, metric = "sensitivity"), 2) # 0.48
round(evaluate(eventdetect_d_nfsp_12, reference, metric = "specificity"), 2) # 0.75
round(evaluate(eventdetect_d_nfsp_12, reference, metric = "precision"), 2)   # 0.41
round(evaluate(eventdetect_d_nfsp_12, reference, metric = "recall"), 2)      # 0.48

#Plot
print(evtplot(test_d_nfsp_12, eventdetect_d_nfsp_12, reference))

##### 18. d_nfsp_24 #####
#Detect
eventdetect_d_nfsp_24 <- evtdet.eventdetect(na.omit(test_d_nfsp_24), w = 30)

#Evaluate
evaluate(eventdetect_d_nfsp_24, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     25     26
# FALSE    40     148 

round(evaluate(eventdetect_d_nfsp_24, reference, metric = "F1"), 2)          # 0.43
round(evaluate(eventdetect_d_nfsp_24, reference, metric = "accuracy"), 2)    # 0.72
round(evaluate(eventdetect_d_nfsp_24, reference, metric = "sensitivity"), 2) # 0.38
round(evaluate(eventdetect_d_nfsp_24, reference, metric = "specificity"), 2) # 0.85
round(evaluate(eventdetect_d_nfsp_24, reference, metric = "precision"), 2)   # 0.49
round(evaluate(eventdetect_d_nfsp_24, reference, metric = "recall"), 2)      # 0.38

#Plot
print(evtplot(test_d_nfsp_24, eventdetect_d_nfsp_24, reference))

##### 19. d_nfsp_36 #####
#Detect
eventdetect_d_nfsp_36 <- evtdet.eventdetect(na.omit(test_d_nfsp_36), w = 30)

#Evaluate
evaluate(eventdetect_d_nfsp_36, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     0      9 
# FALSE    65     165  

round(evaluate(eventdetect_d_nfsp_36, reference, metric = "F1"), 2)          # NaN
round(evaluate(eventdetect_d_nfsp_36, reference, metric = "accuracy"), 2)    # 0.69
round(evaluate(eventdetect_d_nfsp_36, reference, metric = "sensitivity"), 2) # 0.00
round(evaluate(eventdetect_d_nfsp_36, reference, metric = "specificity"), 2) # 0.95
round(evaluate(eventdetect_d_nfsp_36, reference, metric = "precision"), 2)   # 0.00
round(evaluate(eventdetect_d_nfsp_36, reference, metric = "recall"), 2)      # 0.00

#Plot
print(evtplot(test_d_nfsp_36, eventdetect_d_nfsp_36, reference))

##### 20. d_nfsp_48 #####
#Detect
eventdetect_d_nfsp_48 <- evtdet.eventdetect(na.omit(test_d_nfsp_48), w = 30)

#Error in data.frame(..., check.names = FALSE) : 
#  arguments imply differing number of rows: 0, 1 

#Evaluate
evaluate(eventdetect_d_nfsp_48, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE       

round(evaluate(eventdetect_d_nfsp_48, reference, metric = "F1"), 2)          # 
round(evaluate(eventdetect_d_nfsp_48, reference, metric = "accuracy"), 2)    # 
round(evaluate(eventdetect_d_nfsp_48, reference, metric = "sensitivity"), 2) # 
round(evaluate(eventdetect_d_nfsp_48, reference, metric = "specificity"), 2) # 
round(evaluate(eventdetect_d_nfsp_48, reference, metric = "precision"), 2)   # 
round(evaluate(eventdetect_d_nfsp_48, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_d_nfsp_48, eventdetect_d_nfsp_48, reference))

##### 21. d_selic_12 #####
#Detect
eventdetect_d_selic_12 <- evtdet.eventdetect(na.omit(test_d_selic_12), w = 30)

#Evaluate
evaluate(eventdetect_d_selic_12, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     21     22 
# FALSE    44     152   

round(evaluate(eventdetect_d_selic_12, reference, metric = "F1"), 2)          # 0.39
round(evaluate(eventdetect_d_selic_12, reference, metric = "accuracy"), 2)    # 0.72
round(evaluate(eventdetect_d_selic_12, reference, metric = "sensitivity"), 2) # 0.32
round(evaluate(eventdetect_d_selic_12, reference, metric = "specificity"), 2) # 0.87
round(evaluate(eventdetect_d_selic_12, reference, metric = "precision"), 2)   # 0.49
round(evaluate(eventdetect_d_selic_12, reference, metric = "recall"), 2)      # 0.32

#Plot
print(evtplot(test_d_selic_12, eventdetect_d_selic_12, reference))

##### 22. d_selic_24 #####
#Detect
eventdetect_d_selic_24 <- evtdet.eventdetect(na.omit(test_d_selic_24), w = 30)

#Evaluate
evaluate(eventdetect_d_selic_24, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     16     18   
# FALSE    49     156  

round(evaluate(eventdetect_d_selic_24, reference, metric = "F1"), 2)          # 0.32
round(evaluate(eventdetect_d_selic_24, reference, metric = "accuracy"), 2)    # 0.72
round(evaluate(eventdetect_d_selic_24, reference, metric = "sensitivity"), 2) # 0.25
round(evaluate(eventdetect_d_selic_24, reference, metric = "specificity"), 2) # 0.90
round(evaluate(eventdetect_d_selic_24, reference, metric = "precision"), 2)   # 0.47
round(evaluate(eventdetect_d_selic_24, reference, metric = "recall"), 2)      # 0.25

#Plot
print(evtplot(test_d_selic_24, eventdetect_d_selic_24, reference))

##### 23. d_selic_36 #####
#Detect
eventdetect_d_selic_36 <- evtdet.eventdetect(na.omit(test_d_selic_36), w = 30)

#Evaluate
evaluate(eventdetect_d_selic_36, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     15     15 
# FALSE    50     159  

round(evaluate(eventdetect_d_selic_36, reference, metric = "F1"), 2)          # 0.32
round(evaluate(eventdetect_d_selic_36, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(eventdetect_d_selic_36, reference, metric = "sensitivity"), 2) # 0.23
round(evaluate(eventdetect_d_selic_36, reference, metric = "specificity"), 2) # 0.91
round(evaluate(eventdetect_d_selic_36, reference, metric = "precision"), 2)   # 0.50
round(evaluate(eventdetect_d_selic_36, reference, metric = "recall"), 2)      # 0.23

#Plot
print(evtplot(test_d_selic_36, eventdetect_d_selic_36, reference))

##### 24. d_selic_48 #####
#Detect
eventdetect_d_selic_48 <- evtdet.eventdetect(na.omit(test_d_selic_48), w = 30)

#Evaluate
evaluate(eventdetect_d_selic_48, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     17     19   
# FALSE    48     155       

round(evaluate(eventdetect_d_selic_48, reference, metric = "F1"), 2)          # 0.34
round(evaluate(eventdetect_d_selic_48, reference, metric = "accuracy"), 2)    # 0.72
round(evaluate(eventdetect_d_selic_48, reference, metric = "sensitivity"), 2) # 0.26
round(evaluate(eventdetect_d_selic_48, reference, metric = "specificity"), 2) # 0.89
round(evaluate(eventdetect_d_selic_48, reference, metric = "precision"), 2)   # 0.47
round(evaluate(eventdetect_d_selic_48, reference, metric = "recall"), 2)      # 0.26

#Plot
print(evtplot(test_d_selic_48, eventdetect_d_selic_48, reference))

#######################################
##### Auxiliary Model definitions #####
#######################################

ARIMA <- function(data) forecast::auto.arima(data)
AR <- function(data,p) forecast::Arima(data, order = c(p, 0, 0), seasonal = c(0, 0, 0))
garch <- function(data,spec,...) rugarch::ugarchfit(spec=spec,data=data,solver="hybrid", ...)@fit
ets <- function(data) forecast::ets(ts(data))
linreg <- function(data) {
  #browser()
  data <- as.data.frame(data)
  colnames(data) <- "x"
  data$t <- 1:nrow(data)
  
  #Adjusting a linear regression to the whole window
  lm(x~t, data)
}

#Garch specs
garch11 <- rugarch::ugarchspec(variance.model = list(model = "sGARCH", garchOrder = c(1, 1)), 
                               mean.model = list(armaOrder = c(1, 1), include.mean = TRUE), 
                               distribution.model = "norm")

####################################
##### Garch Volatility Outlier #####
####################################

##### 1. d_exch_12 #####
#Detect
garch_volatility_d_exch_12 <- evtdet.garch_volatility_outlier(test_d_exch_12, spec = garch11, alpha = 1.5,
                                                              na.action = na.omit)

#Evaluate
evaluate(garch_volatility_d_exch_12, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     18     10
# FALSE    47     164  

round(evaluate(garch_volatility_d_exch_12, reference, metric = "F1"), 2)          # 0.39
round(evaluate(garch_volatility_d_exch_12, reference, metric = "accuracy"), 2)    # 0.76
round(evaluate(garch_volatility_d_exch_12, reference, metric = "sensitivity"), 2) # 0.28
round(evaluate(garch_volatility_d_exch_12, reference, metric = "specificity"), 2) # 0.94
round(evaluate(garch_volatility_d_exch_12, reference, metric = "precision"), 2)   # 0.64
round(evaluate(garch_volatility_d_exch_12, reference, metric = "recall"), 2)      # 0.28

#Plot
print(evtplot(test_d_exch_12, garch_volatility_d_exch_12, reference))

##### 2. d_exch_24 #####
#Detect
garch_volatility_d_exch_24 <- evtdet.garch_volatility_outlier(test_d_exch_24, spec = garch11, alpha = 1.5,
                                                              na.action = na.omit)

#Evaluate
evaluate(garch_volatility_d_exch_24, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     13     5
# FALSE    52     169

round(evaluate(garch_volatility_d_exch_24, reference, metric = "F1"), 2)          # 0.31
round(evaluate(garch_volatility_d_exch_24, reference, metric = "accuracy"), 2)    # 0.76
round(evaluate(garch_volatility_d_exch_24, reference, metric = "sensitivity"), 2) # 0.20
round(evaluate(garch_volatility_d_exch_24, reference, metric = "specificity"), 2) # 0.97
round(evaluate(garch_volatility_d_exch_24, reference, metric = "precision"), 2)   # 0.72
round(evaluate(garch_volatility_d_exch_24, reference, metric = "recall"), 2)      # 0.20

#Plot
print(evtplot(test_d_exch_24, garch_volatility_d_exch_24, reference))

##### 3. d_exch_36 #####
#Detect
garch_volatility_d_exch_36 <- evtdet.garch_volatility_outlier(test_d_exch_36, spec = garch11, alpha = 1.5,
                                                              na.action = na.omit)

#Evaluate
evaluate(garch_volatility_d_exch_36, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     19     9   
# FALSE    46     165  

round(evaluate(garch_volatility_d_exch_36, reference, metric = "F1"), 2)          # 0.41
round(evaluate(garch_volatility_d_exch_36, reference, metric = "accuracy"), 2)    # 0.77
round(evaluate(garch_volatility_d_exch_36, reference, metric = "sensitivity"), 2) # 0.29
round(evaluate(garch_volatility_d_exch_36, reference, metric = "specificity"), 2) # 0.95
round(evaluate(garch_volatility_d_exch_36, reference, metric = "precision"), 2)   # 0.68
round(evaluate(garch_volatility_d_exch_36, reference, metric = "recall"), 2)      # 0.29

#Plot
print(evtplot(test_d_exch_36, garch_volatility_d_exch_36, reference))

##### 4. d_exch_48 #####
#Detect
garch_volatility_d_exch_48 <- evtdet.garch_volatility_outlier(test_d_exch_48, spec = garch11, alpha = 1.5,
                                                              na.action = na.omit)

#Evaluate
evaluate(garch_volatility_d_exch_48, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     5      4    
# FALSE    60     170

round(evaluate(garch_volatility_d_exch_48, reference, metric = "F1"), 2)          # 0.14
round(evaluate(garch_volatility_d_exch_48, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(garch_volatility_d_exch_48, reference, metric = "sensitivity"), 2) # 0.08
round(evaluate(garch_volatility_d_exch_48, reference, metric = "specificity"), 2) # 0.98
round(evaluate(garch_volatility_d_exch_48, reference, metric = "precision"), 2)   # 0.56
round(evaluate(garch_volatility_d_exch_48, reference, metric = "recall"), 2)      # 0.08

#Plot
print(evtplot(test_d_exch_48, garch_volatility_d_exch_48, reference))

##### 5. d_dlsp_12 #####
#Detect
garch_volatility_d_dlsp_12 <- evtdet.garch_volatility_outlier(test_d_dlsp_12, spec = garch11, alpha = 1.5,
                                                              na.action = na.omit)

#Evaluate
evaluate(garch_volatility_d_dlsp_12, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     10     18 
# FALSE    55     156  

round(evaluate(garch_volatility_d_dlsp_12, reference, metric = "F1"), 2)          # 0.22
round(evaluate(garch_volatility_d_dlsp_12, reference, metric = "accuracy"), 2)    # 0.69
round(evaluate(garch_volatility_d_dlsp_12, reference, metric = "sensitivity"), 2) # 0.15
round(evaluate(garch_volatility_d_dlsp_12, reference, metric = "specificity"), 2) # 0.90
round(evaluate(garch_volatility_d_dlsp_12, reference, metric = "precision"), 2)   # 0.36
round(evaluate(garch_volatility_d_dlsp_12, reference, metric = "recall"), 2)      # 0.15

#Plot
print(evtplot(test_d_dlsp_12, garch_volatility_d_dlsp_12, reference))

##### 6. d_dlsp_24 #####
#Detect
garch_volatility_d_dlsp_24 <- evtdet.garch_volatility_outlier(test_d_dlsp_24, spec = garch11, alpha = 1.5,
                                                              na.action = na.omit)

#Evaluate
evaluate(garch_volatility_d_dlsp_24, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     20     9  
# FALSE    45     165 

round(evaluate(garch_volatility_d_dlsp_24, reference, metric = "F1"), 2)          # 0.43
round(evaluate(garch_volatility_d_dlsp_24, reference, metric = "accuracy"), 2)    # 0.77
round(evaluate(garch_volatility_d_dlsp_24, reference, metric = "sensitivity"), 2) # 0.31
round(evaluate(garch_volatility_d_dlsp_24, reference, metric = "specificity"), 2) # 0.95
round(evaluate(garch_volatility_d_dlsp_24, reference, metric = "precision"), 2)   # 0.69
round(evaluate(garch_volatility_d_dlsp_24, reference, metric = "recall"), 2)      # 0.31

#Plot
print(evtplot(test_d_dlsp_24, garch_volatility_d_dlsp_24, reference))

##### 7. d_dlsp_36 #####
#Detect
garch_volatility_d_dlsp_36 <- evtdet.garch_volatility_outlier(test_d_dlsp_36, spec = garch11, alpha = 1.5,
                                                              na.action = na.omit)

#Evaluate
evaluate(garch_volatility_d_dlsp_36, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     21     11 
# FALSE    44     163 

round(evaluate(garch_volatility_d_dlsp_36, reference, metric = "F1"), 2)          # 0.43
round(evaluate(garch_volatility_d_dlsp_36, reference, metric = "accuracy"), 2)    # 0.77
round(evaluate(garch_volatility_d_dlsp_36, reference, metric = "sensitivity"), 2) # 0.32
round(evaluate(garch_volatility_d_dlsp_36, reference, metric = "specificity"), 2) # 0.94
round(evaluate(garch_volatility_d_dlsp_36, reference, metric = "precision"), 2)   # 0.66
round(evaluate(garch_volatility_d_dlsp_36, reference, metric = "recall"), 2)      # 0.32

#Plot
print(evtplot(test_d_dlsp_36, garch_volatility_d_dlsp_36, reference))

##### 8. d_dlsp_48 #####
#Detect
garch_volatility_d_dlsp_48 <- evtdet.garch_volatility_outlier(test_d_dlsp_48, spec = garch11, alpha = 1.5,
                                                              na.action = na.omit)

#Evaluate
evaluate(garch_volatility_d_dlsp_48, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     19     11  
# FALSE    46     163   

round(evaluate(garch_volatility_d_dlsp_48, reference, metric = "F1"), 2)          # 0.40
round(evaluate(garch_volatility_d_dlsp_48, reference, metric = "accuracy"), 2)    # 0.76
round(evaluate(garch_volatility_d_dlsp_48, reference, metric = "sensitivity"), 2) # 0.29
round(evaluate(garch_volatility_d_dlsp_48, reference, metric = "specificity"), 2) # 0.94
round(evaluate(garch_volatility_d_dlsp_48, reference, metric = "precision"), 2)   # 0.63
round(evaluate(garch_volatility_d_dlsp_48, reference, metric = "recall"), 2)      # 0.29

#Plot
print(evtplot(test_d_dlsp_48, garch_volatility_d_dlsp_48, reference))

##### 9. d_ipca_12 #####
#Detect
garch_volatility_d_ipca_12 <- evtdet.garch_volatility_outlier(test_d_ipca_12, spec = garch11, alpha = 1.5,
                                                               na.action = na.omit)

#Evaluate
evaluate(garch_volatility_d_ipca_12, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     4      29  
# FALSE    61     145

round(evaluate(garch_volatility_d_ipca_12, reference, metric = "F1"), 2)          # 0.08
round(evaluate(garch_volatility_d_ipca_12, reference, metric = "accuracy"), 2)    # 0.62
round(evaluate(garch_volatility_d_ipca_12, reference, metric = "sensitivity"), 2) # 0.06
round(evaluate(garch_volatility_d_ipca_12, reference, metric = "specificity"), 2) # 0.83
round(evaluate(garch_volatility_d_ipca_12, reference, metric = "precision"), 2)   # 0.12
round(evaluate(garch_volatility_d_ipca_12, reference, metric = "recall"), 2)      # 0.06

#Plot
print(evtplot(test_d_ipca_12, garch_volatility_d_ipca_12, reference))

##### 10. d_ipca_24 #####
#Detect
garch_volatility_d_ipca_24 <- evtdet.garch_volatility_outlier(test_d_ipca_24, spec = garch11, alpha = 1.5,
                                                              na.action = na.omit)

#Evaluate
evaluate(garch_volatility_d_ipca_24, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     12     24 
# FALSE    53     150   

round(evaluate(garch_volatility_d_ipca_24, reference, metric = "F1"), 2)          # 0.24
round(evaluate(garch_volatility_d_ipca_24, reference, metric = "accuracy"), 2)    # 0.68
round(evaluate(garch_volatility_d_ipca_24, reference, metric = "sensitivity"), 2) # 0.18
round(evaluate(garch_volatility_d_ipca_24, reference, metric = "specificity"), 2) # 0.86
round(evaluate(garch_volatility_d_ipca_24, reference, metric = "precision"), 2)   # 0.33
round(evaluate(garch_volatility_d_ipca_24, reference, metric = "recall"), 2)      # 0.18

#Plot
print(evtplot(test_d_ipca_24, garch_volatility_d_ipca_24, reference))

##### 11. d_ipca_36 #####
#Detect
garch_volatility_d_ipca_36 <- evtdet.garch_volatility_outlier(test_d_ipca_36, spec = garch11, alpha = 1.5,
                                                              na.action = na.omit)

#Evaluate
evaluate(garch_volatility_d_ipca_36, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     7      26   
# FALSE    58     148  

round(evaluate(garch_volatility_d_ipca_36, reference, metric = "F1"), 2)          # 0.14
round(evaluate(garch_volatility_d_ipca_36, reference, metric = "accuracy"), 2)    # 0.65
round(evaluate(garch_volatility_d_ipca_36, reference, metric = "sensitivity"), 2) # 0.11
round(evaluate(garch_volatility_d_ipca_36, reference, metric = "specificity"), 2) # 0.85
round(evaluate(garch_volatility_d_ipca_36, reference, metric = "precision"), 2)   # 0.21
round(evaluate(garch_volatility_d_ipca_36, reference, metric = "recall"), 2)      # 0.11

#Plot
print(evtplot(test_d_ipca_36, garch_volatility_d_ipca_36, reference))

##### 12. d_ipca_48 #####
#Detect
garch_volatility_d_ipca_48 <- evtdet.garch_volatility_outlier(test_d_ipca_48, spec = garch11, alpha = 1.5,
                                                              na.action = na.omit)

#Evaluate
evaluate(garch_volatility_d_ipca_48, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     10     22 
# FALSE    55     152  

round(evaluate(garch_volatility_d_ipca_48, reference, metric = "F1"), 2)          # 0.21
round(evaluate(garch_volatility_d_ipca_48, reference, metric = "accuracy"), 2)    # 0.68
round(evaluate(garch_volatility_d_ipca_48, reference, metric = "sensitivity"), 2) # 0.15
round(evaluate(garch_volatility_d_ipca_48, reference, metric = "specificity"), 2) # 0.87
round(evaluate(garch_volatility_d_ipca_48, reference, metric = "precision"), 2)   # 0.31
round(evaluate(garch_volatility_d_ipca_48, reference, metric = "recall"), 2)      # 0.15

#Plot
print(evtplot(test_d_ipca_48, garch_volatility_d_ipca_48, reference))

##### 13. d_pib_12 #####
#Detect
garch_volatility_d_pib_12 <- evtdet.garch_volatility_outlier(test_d_pib_12, spec = garch11, alpha = 1.5,
                                                             na.action = na.omit)

#Evaluate
evaluate(garch_volatility_d_pib_12, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     15     13  
# FALSE    50     161  

round(evaluate(garch_volatility_d_pib_12, reference, metric = "F1"), 2)          # 0.32
round(evaluate(garch_volatility_d_pib_12, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(garch_volatility_d_pib_12, reference, metric = "sensitivity"), 2) # 0.23
round(evaluate(garch_volatility_d_pib_12, reference, metric = "specificity"), 2) # 0.93
round(evaluate(garch_volatility_d_pib_12, reference, metric = "precision"), 2)   # 0.54
round(evaluate(garch_volatility_d_pib_12, reference, metric = "recall"), 2)      # 0.23

#Plot
print(evtplot(test_d_pib_12, garch_volatility_d_pib_12, reference))

##### 14. d_pib_24 #####
#Detect
garch_volatility_d_pib_24 <- evtdet.garch_volatility_outlier(test_d_pib_24, spec = garch11, alpha = 1.5,
                                                             na.action = na.omit)

#Evaluate
evaluate(garch_volatility_d_pib_24, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     10     6  
# FALSE    55     168  

round(evaluate(garch_volatility_d_pib_24, reference, metric = "F1"), 2)          # 0.25
round(evaluate(garch_volatility_d_pib_24, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(garch_volatility_d_pib_24, reference, metric = "sensitivity"), 2) # 0.15
round(evaluate(garch_volatility_d_pib_24, reference, metric = "specificity"), 2) # 0.97
round(evaluate(garch_volatility_d_pib_24, reference, metric = "precision"), 2)   # 0.62
round(evaluate(garch_volatility_d_pib_24, reference, metric = "recall"), 2)      # 0.15

#Plot
print(evtplot(test_d_pib_24, garch_volatility_d_pib_24, reference))

##### 15. d_pib_36 #####
#Detect
garch_volatility_d_pib_36 <- evtdet.garch_volatility_outlier(test_d_pib_36, spec = garch11, alpha = 1.5,
                                                             na.action = na.omit)

#Evaluate
evaluate(garch_volatility_d_pib_36, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     8      10     
# FALSE    57     164 

round(evaluate(garch_volatility_d_pib_36, reference, metric = "F1"), 2)          # 0.19
round(evaluate(garch_volatility_d_pib_36, reference, metric = "accuracy"), 2)    # 0.72
round(evaluate(garch_volatility_d_pib_36, reference, metric = "sensitivity"), 2) # 0.12
round(evaluate(garch_volatility_d_pib_36, reference, metric = "specificity"), 2) # 0.94
round(evaluate(garch_volatility_d_pib_36, reference, metric = "precision"), 2)   # 0.44
round(evaluate(garch_volatility_d_pib_36, reference, metric = "recall"), 2)      # 0.12

#Plot
print(evtplot(test_d_pib_36, garch_volatility_d_pib_36, reference))

##### 16. d_pib_48 #####
#Detect
garch_volatility_d_pib_48 <- evtdet.garch_volatility_outlier(test_d_pib_48, spec = garch11, alpha = 1.5,
                                                             na.action = na.omit)

#  Error in data.frame(..., check.names = FALSE) : 
#    arguments imply differing number of rows: 0, 1 

#Evaluate
evaluate(garch_volatility_d_pib_48, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE     

round(evaluate(garch_volatility_d_pib_48, reference, metric = "F1"), 2)          # 
round(evaluate(garch_volatility_d_pib_48, reference, metric = "accuracy"), 2)    # 
round(evaluate(garch_volatility_d_pib_48, reference, metric = "sensitivity"), 2) # 
round(evaluate(garch_volatility_d_pib_48, reference, metric = "specificity"), 2) # 
round(evaluate(garch_volatility_d_pib_48, reference, metric = "precision"), 2)   # 
round(evaluate(garch_volatility_d_pib_48, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_d_pib_48, garch_volatility_d_pib_48, reference))

##### 17. d_nfsp_12 #####
#Detect
garch_volatility_d_nfsp_12 <- evtdet.garch_volatility_outlier(test_d_nfsp_12, spec = garch11, alpha = 1.5,
                                                              na.action = na.omit)

#Evaluate
evaluate(garch_volatility_d_nfsp_12, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     18     12   
# FALSE    47     162

round(evaluate(garch_volatility_d_nfsp_12, reference, metric = "F1"), 2)          # 0.38
round(evaluate(garch_volatility_d_nfsp_12, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(garch_volatility_d_nfsp_12, reference, metric = "sensitivity"), 2) # 0.28
round(evaluate(garch_volatility_d_nfsp_12, reference, metric = "specificity"), 2) # 0.93
round(evaluate(garch_volatility_d_nfsp_12, reference, metric = "precision"), 2)   # 0.60
round(evaluate(garch_volatility_d_nfsp_12, reference, metric = "recall"), 2)      # 0.28

#Plot
print(evtplot(test_d_nfsp_12, garch_volatility_d_nfsp_12, reference))

##### 18. d_nfsp_24 #####
#Detect
garch_volatility_d_nfsp_24 <- evtdet.garch_volatility_outlier(test_d_nfsp_24, spec = garch11, alpha = 1.5,
                                                              na.action = na.omit)

#Evaluate
evaluate(garch_volatility_d_nfsp_24, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     24     10   
# FALSE    41     164   

round(evaluate(garch_volatility_d_nfsp_24, reference, metric = "F1"), 2)          # 0.48
round(evaluate(garch_volatility_d_nfsp_24, reference, metric = "accuracy"), 2)    # 0.79
round(evaluate(garch_volatility_d_nfsp_24, reference, metric = "sensitivity"), 2) # 0.37
round(evaluate(garch_volatility_d_nfsp_24, reference, metric = "specificity"), 2) # 0.94
round(evaluate(garch_volatility_d_nfsp_24, reference, metric = "precision"), 2)   # 0.71
round(evaluate(garch_volatility_d_nfsp_24, reference, metric = "recall"), 2)      # 0.37

#Plot
print(evtplot(test_d_nfsp_24, garch_volatility_d_nfsp_24, reference))

##### 19. d_nfsp_36 #####
#Detect
garch_volatility_d_nfsp_36 <- evtdet.garch_volatility_outlier(test_d_nfsp_36, spec = garch11, alpha = 1.5,
                                                              na.action = na.omit)

#Evaluate
evaluate(garch_volatility_d_nfsp_36, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     21     13 
# FALSE    44     161

round(evaluate(garch_volatility_d_nfsp_36, reference, metric = "F1"), 2)          # 0.42
round(evaluate(garch_volatility_d_nfsp_36, reference, metric = "accuracy"), 2)    # 0.76
round(evaluate(garch_volatility_d_nfsp_36, reference, metric = "sensitivity"), 2) # 0.32
round(evaluate(garch_volatility_d_nfsp_36, reference, metric = "specificity"), 2) # 0.93
round(evaluate(garch_volatility_d_nfsp_36, reference, metric = "precision"), 2)   # 0.62
round(evaluate(garch_volatility_d_nfsp_36, reference, metric = "recall"), 2)      # 0.32

#Plot
print(evtplot(test_d_nfsp_36, garch_volatility_d_nfsp_36, reference))

##### 20. d_nfsp_48 #####
#Detect
garch_volatility_d_nfsp_48 <- evtdet.garch_volatility_outlier(test_d_nfsp_48, spec = garch11, alpha = 1.5,
                                                              na.action = na.omit)

#Evaluate
evaluate(garch_volatility_d_nfsp_48, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     15     17   
# FALSE    50     157 

round(evaluate(garch_volatility_d_nfsp_48, reference, metric = "F1"), 2)          # 0.31
round(evaluate(garch_volatility_d_nfsp_48, reference, metric = "accuracy"), 2)    # 0.72
round(evaluate(garch_volatility_d_nfsp_48, reference, metric = "sensitivity"), 2) # 0.23
round(evaluate(garch_volatility_d_nfsp_48, reference, metric = "specificity"), 2) # 0.90
round(evaluate(garch_volatility_d_nfsp_48, reference, metric = "precision"), 2)   # 0.47
round(evaluate(garch_volatility_d_nfsp_48, reference, metric = "recall"), 2)      # 0.23

#Plot
print(evtplot(test_d_nfsp_48, garch_volatility_d_nfsp_48, reference))

##### 21. d_selic_12 #####
#Detect
garch_volatility_d_selic_12 <- evtdet.garch_volatility_outlier(test_d_selic_12, spec = garch11, alpha = 1.5,
                                                               na.action = na.omit)

#Evaluate
evaluate(garch_volatility_d_selic_12, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     4      19
# FALSE    61     155  

round(evaluate(garch_volatility_d_selic_12, reference, metric = "F1"), 2)          # 0.09
round(evaluate(garch_volatility_d_selic_12, reference, metric = "accuracy"), 2)    # 0.67
round(evaluate(garch_volatility_d_selic_12, reference, metric = "sensitivity"), 2) # 0.06
round(evaluate(garch_volatility_d_selic_12, reference, metric = "specificity"), 2) # 0.89
round(evaluate(garch_volatility_d_selic_12, reference, metric = "precision"), 2)   # 0.17
round(evaluate(garch_volatility_d_selic_12, reference, metric = "recall"), 2)      # 0.06

#Plot
print(evtplot(test_d_selic_12, garch_volatility_d_selic_12, reference))

##### 22. d_selic_24 #####
#Detect
garch_volatility_d_selic_24 <- evtdet.garch_volatility_outlier(test_d_selic_24, spec = garch11, alpha = 1.5,
                                                               na.action = na.omit)

#Evaluate
evaluate(garch_volatility_d_selic_24, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     5      14   
# FALSE    60     160

round(evaluate(garch_volatility_d_selic_24, reference, metric = "F1"), 2)          # 0.12
round(evaluate(garch_volatility_d_selic_24, reference, metric = "accuracy"), 2)    # 0.69
round(evaluate(garch_volatility_d_selic_24, reference, metric = "sensitivity"), 2) # 0.08
round(evaluate(garch_volatility_d_selic_24, reference, metric = "specificity"), 2) # 0.92
round(evaluate(garch_volatility_d_selic_24, reference, metric = "precision"), 2)   # 0.26
round(evaluate(garch_volatility_d_selic_24, reference, metric = "recall"), 2)      # 0.08

#Plot
print(evtplot(test_d_selic_24, garch_volatility_d_selic_24, reference))

##### 23. d_selic_36 #####
#Detect
garch_volatility_d_selic_36 <- evtdet.garch_volatility_outlier(test_d_selic_36, spec = garch11, alpha = 1.5,
                                                               na.action = na.omit)

#Evaluate
evaluate(garch_volatility_d_selic_36, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     2      11  
# FALSE    63     163 

round(evaluate(garch_volatility_d_selic_36, reference, metric = "F1"), 2)          # 0.05
round(evaluate(garch_volatility_d_selic_36, reference, metric = "accuracy"), 2)    # 0.69
round(evaluate(garch_volatility_d_selic_36, reference, metric = "sensitivity"), 2) # 0.03
round(evaluate(garch_volatility_d_selic_36, reference, metric = "specificity"), 2) # 0.94
round(evaluate(garch_volatility_d_selic_36, reference, metric = "precision"), 2)   # 0.15
round(evaluate(garch_volatility_d_selic_36, reference, metric = "recall"), 2)      # 0.03

#Plot
print(evtplot(test_d_selic_36, garch_volatility_d_selic_36, reference))

##### 24. d_selic_48 #####
#Detect
garch_volatility_d_selic_48 <- evtdet.garch_volatility_outlier(test_d_selic_48, spec = garch11, alpha = 1.5,
                                                               na.action = na.omit)

#Evaluate
evaluate(garch_volatility_d_selic_48, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     2      36   
# FALSE    63     138 

round(evaluate(garch_volatility_d_selic_48, reference, metric = "F1"), 2)          # 0.04
round(evaluate(garch_volatility_d_selic_48, reference, metric = "accuracy"), 2)    # 0.59
round(evaluate(garch_volatility_d_selic_48, reference, metric = "sensitivity"), 2) # 0.03
round(evaluate(garch_volatility_d_selic_48, reference, metric = "specificity"), 2) # 0.79
round(evaluate(garch_volatility_d_selic_48, reference, metric = "precision"), 2)   # 0.05
round(evaluate(garch_volatility_d_selic_48, reference, metric = "recall"), 2)      # 0.03

#Plot
print(evtplot(test_d_selic_48, garch_volatility_d_selic_48, reference))

#######################################
##### Seminal Change Point (1999) #####
#######################################

##### 1. d_exch_12 #####
#Detect
changepoint_d_exch_12 <- evtdet.seminalChangePoint2(test_d_exch_12, w = 30, 
                                                    mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_d_exch_12, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     16     25  
# FALSE    49     149 

round(evaluate(changepoint_d_exch_12, reference, metric = "F1"), 2)          # 0.30
round(evaluate(changepoint_d_exch_12, reference, metric = "accuracy"), 2)    # 0.69
round(evaluate(changepoint_d_exch_12, reference, metric = "sensitivity"), 2) # 0.25
round(evaluate(changepoint_d_exch_12, reference, metric = "specificity"), 2) # 0.86
round(evaluate(changepoint_d_exch_12, reference, metric = "precision"), 2)   # 0.39
round(evaluate(changepoint_d_exch_12, reference, metric = "recall"), 2)      # 0.25

#Plot
print(evtplot(test_d_exch_12, changepoint_d_exch_12, reference))

##### 2. d_exch_24 #####
#Detect
changepoint_d_exch_24 <- evtdet.seminalChangePoint2(test_d_exch_24, w = 30, 
                                                    mdl= linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_d_exch_24, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     18     23 
# FALSE    47     151 

round(evaluate(changepoint_d_exch_24, reference, metric = "F1"), 2)          # 0.34
round(evaluate(changepoint_d_exch_24, reference, metric = "accuracy"), 2)    # 0.71
round(evaluate(changepoint_d_exch_24, reference, metric = "sensitivity"), 2) # 0.28
round(evaluate(changepoint_d_exch_24, reference, metric = "specificity"), 2) # 0.87
round(evaluate(changepoint_d_exch_24, reference, metric = "precision"), 2)   # 0.44
round(evaluate(changepoint_d_exch_24, reference, metric = "recall"), 2)      # 0.28

#Plot
print(evtplot(test_d_exch_24, changepoint_d_exch_24, reference))

##### 3. d_exch_36 #####
#Detect
changepoint_d_exch_36 <- evtdet.seminalChangePoint2(test_d_exch_36, w = 30, 
                                                    mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_d_exch_36, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     17     30 
# FALSE    48     144 

round(evaluate(changepoint_d_exch_36, reference, metric = "F1"), 2)          # 0.30
round(evaluate(changepoint_d_exch_36, reference, metric = "accuracy"), 2)    # 0.67
round(evaluate(changepoint_d_exch_36, reference, metric = "sensitivity"), 2) # 0.26
round(evaluate(changepoint_d_exch_36, reference, metric = "specificity"), 2) # 0.83
round(evaluate(changepoint_d_exch_36, reference, metric = "precision"), 2)   # 0.36
round(evaluate(changepoint_d_exch_36, reference, metric = "recall"), 2)      # 0.26

#Plot
print(evtplot(test_d_exch_36, changepoint_d_exch_36, reference))

##### 4. d_exch_48 #####
#Detect
changepoint_d_exch_48 <- evtdet.seminalChangePoint2(test_d_exch_48, w = 30, 
                                                    mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_d_exch_48, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     18     26 
# FALSE    47     148  

round(evaluate(changepoint_d_exch_48, reference, metric = "F1"), 2)          # 0.33
round(evaluate(changepoint_d_exch_48, reference, metric = "accuracy"), 2)    # 0.69
round(evaluate(changepoint_d_exch_48, reference, metric = "sensitivity"), 2) # 0.28
round(evaluate(changepoint_d_exch_48, reference, metric = "specificity"), 2) # 0.85
round(evaluate(changepoint_d_exch_48, reference, metric = "precision"), 2)   # 0.41
round(evaluate(changepoint_d_exch_48, reference, metric = "recall"), 2)      # 0.28

#Plot
print(evtplot(test_d_exch_48, changepoint_d_exch_48, reference))

##### 5. d_dlsp_12 #####
#Detect
changepoint_d_dlsp_12 <- evtdet.seminalChangePoint2(test_d_dlsp_12, w = 30, 
                                                    mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_d_dlsp_12, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     18     37   
# FALSE    47     137

round(evaluate(changepoint_d_dlsp_12, reference, metric = "F1"), 2)          # 0.30
round(evaluate(changepoint_d_dlsp_12, reference, metric = "accuracy"), 2)    # 0.65
round(evaluate(changepoint_d_dlsp_12, reference, metric = "sensitivity"), 2) # 0.28
round(evaluate(changepoint_d_dlsp_12, reference, metric = "specificity"), 2) # 0.79
round(evaluate(changepoint_d_dlsp_12, reference, metric = "precision"), 2)   # 0.33
round(evaluate(changepoint_d_dlsp_12, reference, metric = "recall"), 2)      # 0.28

#Plot
print(evtplot(test_d_dlsp_12, changepoint_d_dlsp_12, reference))

##### 6. d_dlsp_24 #####
#Detect
changepoint_d_dlsp_24 <- evtdet.seminalChangePoint2(test_d_dlsp_24, w = 30, 
                                                    mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_d_dlsp_24, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     17     21    
# FALSE    48     153  

round(evaluate(changepoint_d_dlsp_24, reference, metric = "F1"), 2)          # 0.33
round(evaluate(changepoint_d_dlsp_24, reference, metric = "accuracy"), 2)    # 0.71
round(evaluate(changepoint_d_dlsp_24, reference, metric = "sensitivity"), 2) # 0.26
round(evaluate(changepoint_d_dlsp_24, reference, metric = "specificity"), 2) # 0.88
round(evaluate(changepoint_d_dlsp_24, reference, metric = "precision"), 2)   # 0.45
round(evaluate(changepoint_d_dlsp_24, reference, metric = "recall"), 2)      # 0.26

#Plot
print(evtplot(test_d_dlsp_24, changepoint_d_dlsp_24, reference))

##### 7. d_dlsp_36 #####
#Detect
changepoint_d_dlsp_36 <- evtdet.seminalChangePoint2(test_d_dlsp_36, w = 30, 
                                                    mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_d_dlsp_36, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     24     18 
# FALSE    41     156  

round(evaluate(changepoint_d_dlsp_36, reference, metric = "F1"), 2)          # 0.45
round(evaluate(changepoint_d_dlsp_36, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(changepoint_d_dlsp_36, reference, metric = "sensitivity"), 2) # 0.37
round(evaluate(changepoint_d_dlsp_36, reference, metric = "specificity"), 2) # 0.90
round(evaluate(changepoint_d_dlsp_36, reference, metric = "precision"), 2)   # 0.57
round(evaluate(changepoint_d_dlsp_36, reference, metric = "recall"), 2)      # 0.37

#Plot
print(evtplot(test_d_dlsp_36, changepoint_d_dlsp_36, reference))

##### 8. d_dlsp_48 #####
#Detect
changepoint_d_dlsp_48 <- evtdet.seminalChangePoint2(test_d_dlsp_48, w = 30, 
                                                    mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_d_dlsp_48, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     16     22   
# FALSE    49     152

round(evaluate(changepoint_d_dlsp_48, reference, metric = "F1"), 2)          # 0.31
round(evaluate(changepoint_d_dlsp_48, reference, metric = "accuracy"), 2)    # 0.70
round(evaluate(changepoint_d_dlsp_48, reference, metric = "sensitivity"), 2) # 0.25
round(evaluate(changepoint_d_dlsp_48, reference, metric = "specificity"), 2) # 0.87
round(evaluate(changepoint_d_dlsp_48, reference, metric = "precision"), 2)   # 0.42
round(evaluate(changepoint_d_dlsp_48, reference, metric = "recall"), 2)      # 0.25

#Plot
print(evtplot(test_d_dlsp_48, changepoint_d_dlsp_48, reference))

##### 9. d_ipca_12 #####
#Detect
changepoint_d_ipca_12 <- evtdet.seminalChangePoint2(test_d_ipca_12, w = 30, 
                                                    mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_d_ipca_12, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     18     23 
# FALSE    47     151 

round(evaluate(changepoint_d_ipca_12, reference, metric = "F1"), 2)          # 0.34
round(evaluate(changepoint_d_ipca_12, reference, metric = "accuracy"), 2)    # 0.71
round(evaluate(changepoint_d_ipca_12, reference, metric = "sensitivity"), 2) # 0.28
round(evaluate(changepoint_d_ipca_12, reference, metric = "specificity"), 2) # 0.87
round(evaluate(changepoint_d_ipca_12, reference, metric = "precision"), 2)   # 0.44
round(evaluate(changepoint_d_ipca_12, reference, metric = "recall"), 2)      # 0.28

#Plot
print(evtplot(test_d_ipca_12, changepoint_d_ipca_12, reference))

##### 10. d_ipca_24 #####
#Detect
changepoint_d_ipca_24 <- evtdet.seminalChangePoint2(test_d_ipca_24, w = 30, 
                                                    mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_d_ipca_24, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     15     30   
# FALSE    50     144   

round(evaluate(changepoint_d_ipca_24, reference, metric = "F1"), 2)          # 0.27
round(evaluate(changepoint_d_ipca_24, reference, metric = "accuracy"), 2)    # 0.67
round(evaluate(changepoint_d_ipca_24, reference, metric = "sensitivity"), 2) # 0.23
round(evaluate(changepoint_d_ipca_24, reference, metric = "specificity"), 2) # 0.83
round(evaluate(changepoint_d_ipca_24, reference, metric = "precision"), 2)   # 0.33
round(evaluate(changepoint_d_ipca_24, reference, metric = "recall"), 2)      # 0.23

#Plot
print(evtplot(test_d_ipca_24, changepoint_d_ipca_24, reference))

##### 11. d_ipca_36 #####
#Detect
changepoint_d_ipca_36 <- evtdet.seminalChangePoint2(test_d_ipca_36, w = 30, 
                                                    mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_d_ipca_36, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     16     17    
# FALSE    49     157 

round(evaluate(changepoint_d_ipca_36, reference, metric = "F1"), 2)          # 0.33
round(evaluate(changepoint_d_ipca_36, reference, metric = "accuracy"), 2)    # 0.72
round(evaluate(changepoint_d_ipca_36, reference, metric = "sensitivity"), 2) # 0.25
round(evaluate(changepoint_d_ipca_36, reference, metric = "specificity"), 2) # 0.90
round(evaluate(changepoint_d_ipca_36, reference, metric = "precision"), 2)   # 0.48
round(evaluate(changepoint_d_ipca_36, reference, metric = "recall"), 2)      # 0.25

#Plot
print(evtplot(test_d_ipca_36, changepoint_d_ipca_36, reference))

##### 12. d_ipca_48 #####
#Detect
changepoint_d_ipca_48 <- evtdet.seminalChangePoint2(test_d_ipca_48, w = 30, 
                                                    mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_d_ipca_48, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     21     25 
# FALSE    44     149 

round(evaluate(changepoint_d_ipca_48, reference, metric = "F1"), 2)          # 0.38
round(evaluate(changepoint_d_ipca_48, reference, metric = "accuracy"), 2)    # 0.71
round(evaluate(changepoint_d_ipca_48, reference, metric = "sensitivity"), 2) # 0.32
round(evaluate(changepoint_d_ipca_48, reference, metric = "specificity"), 2) # 0.86
round(evaluate(changepoint_d_ipca_48, reference, metric = "precision"), 2)   # 0.46
round(evaluate(changepoint_d_ipca_48, reference, metric = "recall"), 2)      # 0.32

#Plot
print(evtplot(test_d_ipca_48, changepoint_d_ipca_48, reference))

##### 13. d_pib_12 #####
#Detect
changepoint_d_pib_12 <- evtdet.seminalChangePoint2(test_d_pib_12, w = 30, 
                                                   mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_d_pib_12, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     21     38
# FALSE    44     136   

round(evaluate(changepoint_d_pib_12, reference, metric = "F1"), 2)          # 0.34
round(evaluate(changepoint_d_pib_12, reference, metric = "accuracy"), 2)    # 0.66
round(evaluate(changepoint_d_pib_12, reference, metric = "sensitivity"), 2) # 0.32
round(evaluate(changepoint_d_pib_12, reference, metric = "specificity"), 2) # 0.78
round(evaluate(changepoint_d_pib_12, reference, metric = "precision"), 2)   # 0.36
round(evaluate(changepoint_d_pib_12, reference, metric = "recall"), 2)      # 0.32

#Plot
print(evtplot(test_d_pib_12, changepoint_d_pib_12, reference))

##### 14. d_pib_24 #####
#Detect
changepoint_d_pib_24 <- evtdet.seminalChangePoint2(test_d_pib_24, w = 30, 
                                                   mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_d_pib_24, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     11     27 
# FALSE    54     147

round(evaluate(changepoint_d_pib_24, reference, metric = "F1"), 2)          # 0.21
round(evaluate(changepoint_d_pib_24, reference, metric = "accuracy"), 2)    # 0.66
round(evaluate(changepoint_d_pib_24, reference, metric = "sensitivity"), 2) # 0.17
round(evaluate(changepoint_d_pib_24, reference, metric = "specificity"), 2) # 0.84
round(evaluate(changepoint_d_pib_24, reference, metric = "precision"), 2)   # 0.29
round(evaluate(changepoint_d_pib_24, reference, metric = "recall"), 2)      # 0.17

#Plot
print(evtplot(test_d_pib_24, changepoint_d_pib_24, reference))

##### 15. d_pib_36 #####
#Detect
changepoint_d_pib_36 <- evtdet.seminalChangePoint2(test_d_pib_36, w = 30,
                                                   mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_d_pib_36, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     15     17   
# FALSE    50     157    

round(evaluate(changepoint_d_pib_36, reference, metric = "F1"), 2)          # 0.31
round(evaluate(changepoint_d_pib_36, reference, metric = "accuracy"), 2)    # 0.72
round(evaluate(changepoint_d_pib_36, reference, metric = "sensitivity"), 2) # 0.23
round(evaluate(changepoint_d_pib_36, reference, metric = "specificity"), 2) # 0.90
round(evaluate(changepoint_d_pib_36, reference, metric = "precision"), 2)   # 0.47
round(evaluate(changepoint_d_pib_36, reference, metric = "recall"), 2)      # 0.23

#Plot
print(evtplot(test_d_pib_36, changepoint_d_pib_36, reference))

##### 16. d_pib_48 #####
#Detect
changepoint_d_pib_48 <- evtdet.seminalChangePoint2(test_d_pib_48, w = 30, 
                                                   mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_d_pib_48, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     7      5 
# FALSE    58     169   

round(evaluate(changepoint_d_pib_48, reference, metric = "F1"), 2)          # 0.18
round(evaluate(changepoint_d_pib_48, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(changepoint_d_pib_48, reference, metric = "sensitivity"), 2) # 0.11
round(evaluate(changepoint_d_pib_48, reference, metric = "specificity"), 2) # 0.97
round(evaluate(changepoint_d_pib_48, reference, metric = "precision"), 2)   # 0.58
round(evaluate(changepoint_d_pib_48, reference, metric = "recall"), 2)      # 0.11

#Plot
print(evtplot(test_d_pib_48, changepoint_d_pib_48, reference))

##### 17. d_nfsp_12 #####
#Detect
changepoint_d_nfsp_12 <- evtdet.seminalChangePoint2(test_d_nfsp_12, w = 30, 
                                                    mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_d_nfsp_12, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     20     32  
# FALSE    45     142   

round(evaluate(changepoint_d_nfsp_12, reference, metric = "F1"), 2)          # 0.34
round(evaluate(changepoint_d_nfsp_12, reference, metric = "accuracy"), 2)    # 0.68
round(evaluate(changepoint_d_nfsp_12, reference, metric = "sensitivity"), 2) # 0.31
round(evaluate(changepoint_d_nfsp_12, reference, metric = "specificity"), 2) # 0.82
round(evaluate(changepoint_d_nfsp_12, reference, metric = "precision"), 2)   # 0.38
round(evaluate(changepoint_d_nfsp_12, reference, metric = "recall"), 2)      # 0.31

#Plot
print(evtplot(test_d_nfsp_12, changepoint_d_nfsp_12, reference))

##### 18. d_nfsp_24 #####
#Detect
changepoint_d_nfsp_24 <- evtdet.seminalChangePoint2(test_d_nfsp_24, w = 30, 
                                                    mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_d_nfsp_24, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     15     27  
# FALSE    50     147

round(evaluate(changepoint_d_nfsp_24, reference, metric = "F1"), 2)          # 0.28
round(evaluate(changepoint_d_nfsp_24, reference, metric = "accuracy"), 2)    # 0.68
round(evaluate(changepoint_d_nfsp_24, reference, metric = "sensitivity"), 2) # 0.23
round(evaluate(changepoint_d_nfsp_24, reference, metric = "specificity"), 2) # 0.84
round(evaluate(changepoint_d_nfsp_24, reference, metric = "precision"), 2)   # 0.36
round(evaluate(changepoint_d_nfsp_24, reference, metric = "recall"), 2)      # 0.23

#Plot
print(evtplot(test_d_nfsp_24, changepoint_d_nfsp_24, reference))

##### 19. d_nfsp_36 #####
#Detect
changepoint_d_nfsp_36 <- evtdet.seminalChangePoint2(test_d_nfsp_36, w = 30, 
                                                    mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_d_nfsp_36, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     19     24
# FALSE    46     150  

round(evaluate(changepoint_d_nfsp_36, reference, metric = "F1"), 2)          # 0.35
round(evaluate(changepoint_d_nfsp_36, reference, metric = "accuracy"), 2)    # 0.71
round(evaluate(changepoint_d_nfsp_36, reference, metric = "sensitivity"), 2) # 0.29
round(evaluate(changepoint_d_nfsp_36, reference, metric = "specificity"), 2) # 0.86
round(evaluate(changepoint_d_nfsp_36, reference, metric = "precision"), 2)   # 0.44
round(evaluate(changepoint_d_nfsp_36, reference, metric = "recall"), 2)      # 0.29

#Plot
print(evtplot(test_d_nfsp_36, changepoint_d_nfsp_36, reference))

##### 20. d_nfsp_48 #####
#Detect
changepoint_d_nfsp_48 <- evtdet.seminalChangePoint2(test_d_nfsp_48, w = 30, 
                                                    mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_d_nfsp_48, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     19     26  
# FALSE    46     148      

round(evaluate(changepoint_d_nfsp_48, reference, metric = "F1"), 2)          # 0.35
round(evaluate(changepoint_d_nfsp_48, reference, metric = "accuracy"), 2)    # 0.70
round(evaluate(changepoint_d_nfsp_48, reference, metric = "sensitivity"), 2) # 0.29
round(evaluate(changepoint_d_nfsp_48, reference, metric = "specificity"), 2) # 0.85
round(evaluate(changepoint_d_nfsp_48, reference, metric = "precision"), 2)   # 0.42
round(evaluate(changepoint_d_nfsp_48, reference, metric = "recall"), 2)      # 0.29

#Plot
print(evtplot(test_d_nfsp_48, changepoint_d_nfsp_48, reference))

##### 21. d_selic_12 #####
#Detect
changepoint_d_selic_12 <- evtdet.seminalChangePoint2(test_d_selic_12, w = 30, 
                                                     mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_d_selic_12, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     19     25  
# FALSE    46     149

round(evaluate(changepoint_d_selic_12, reference, metric = "F1"), 2)          # 0.35
round(evaluate(changepoint_d_selic_12, reference, metric = "accuracy"), 2)    # 0.70
round(evaluate(changepoint_d_selic_12, reference, metric = "sensitivity"), 2) # 0.29
round(evaluate(changepoint_d_selic_12, reference, metric = "specificity"), 2) # 0.86
round(evaluate(changepoint_d_selic_12, reference, metric = "precision"), 2)   # 0.43
round(evaluate(changepoint_d_selic_12, reference, metric = "recall"), 2)      # 0.29

#Plot
print(evtplot(test_d_selic_12, changepoint_d_selic_12, reference))

##### 22. d_selic_24 #####
#Detect
changepoint_d_selic_24 <- evtdet.seminalChangePoint2(test_d_selic_24, w = 30, 
                                                     mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_d_selic_24, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     19     25
# FALSE    46     149 

round(evaluate(changepoint_d_selic_24, reference, metric = "F1"), 2)          # 0.35
round(evaluate(changepoint_d_selic_24, reference, metric = "accuracy"), 2)    # 0.70
round(evaluate(changepoint_d_selic_24, reference, metric = "sensitivity"), 2) # 0.29
round(evaluate(changepoint_d_selic_24, reference, metric = "specificity"), 2) # 0.86
round(evaluate(changepoint_d_selic_24, reference, metric = "precision"), 2)   # 0.43
round(evaluate(changepoint_d_selic_24, reference, metric = "recall"), 2)      # 0.29

#Plot
print(evtplot(test_d_selic_24, changepoint_d_selic_24, reference))

##### 23. d_selic_36 #####
#Detect
changepoint_d_selic_36 <- evtdet.seminalChangePoint2(test_d_selic_36, w = 30, 
                                                     mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_d_selic_36, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     16     22   
# FALSE    49     152  

round(evaluate(changepoint_d_selic_36, reference, metric = "F1"), 2)          # 0.31
round(evaluate(changepoint_d_selic_36, reference, metric = "accuracy"), 2)    # 0.70
round(evaluate(changepoint_d_selic_36, reference, metric = "sensitivity"), 2) # 0.25
round(evaluate(changepoint_d_selic_36, reference, metric = "specificity"), 2) # 0.87
round(evaluate(changepoint_d_selic_36, reference, metric = "precision"), 2)   # 0.42
round(evaluate(changepoint_d_selic_36, reference, metric = "recall"), 2)      # 0.25

#Plot
print(evtplot(test_d_selic_36, changepoint_d_selic_36, reference))

##### 24. d_selic_48 #####
#Detect
changepoint_d_selic_48 <- evtdet.seminalChangePoint2(test_d_selic_48, w = 30, 
                                                     mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_d_selic_48, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     12     20   
# FALSE    53     154 

round(evaluate(changepoint_d_selic_48, reference, metric = "F1"), 2)          # 0.25
round(evaluate(changepoint_d_selic_48, reference, metric = "accuracy"), 2)    # 0.69
round(evaluate(changepoint_d_selic_48, reference, metric = "sensitivity"), 2) # 0.17
round(evaluate(changepoint_d_selic_48, reference, metric = "specificity"), 2) # 0.89
round(evaluate(changepoint_d_selic_48, reference, metric = "precision"), 2)   # 0.38
round(evaluate(changepoint_d_selic_48, reference, metric = "recall"), 2)      # 0.18

#Plot
print(evtplot(test_d_selic_48, changepoint_d_selic_48, reference))

########################
##### ChangeFinder #####
########################

# com "mdl = ARIMA" apareceu a seguinte mensagem de erro: Error in attributes(hx) <- attr_x : 
#                                                         cannot assign 'tsp' to zero-length vector

##### 1. d_exch_12 #####
#Detect
changefinder_d_exch_12 <- evtdet.changeFinder(test_d_exch_12, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_d_exch_12, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     7      4   
# FALSE    58     170 

round(evaluate(changefinder_d_exch_12, reference, metric = "F1"), 2)          # 0.18
round(evaluate(changefinder_d_exch_12, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(changefinder_d_exch_12, reference, metric = "sensitivity"), 2) # 0.11
round(evaluate(changefinder_d_exch_12, reference, metric = "specificity"), 2) # 0.98
round(evaluate(changefinder_d_exch_12, reference, metric = "precision"), 2)   # 0.64
round(evaluate(changefinder_d_exch_12, reference, metric = "recall"), 2)      # 0.11

#Plot
print(evtplot(test_d_exch_12, changefinder_d_exch_12, reference))

##### 2. d_exch_24 #####
#Detect
changefinder_d_exch_24 <- evtdet.changeFinder(test_d_exch_24, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_d_exch_24, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     8      3    
# FALSE    57     171 

round(evaluate(changefinder_d_exch_24, reference, metric = "F1"), 2)          # 0.21
round(evaluate(changefinder_d_exch_24, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(changefinder_d_exch_24, reference, metric = "sensitivity"), 2) # 0.12
round(evaluate(changefinder_d_exch_24, reference, metric = "specificity"), 2) # 0.98
round(evaluate(changefinder_d_exch_24, reference, metric = "precision"), 2)   # 0.73
round(evaluate(changefinder_d_exch_24, reference, metric = "recall"), 2)      # 0.12

#Plot
print(evtplot(test_d_exch_24, changefinder_d_exch_24, reference))

##### 3. d_exch_36 #####
#Detect
changefinder_d_exch_36 <- evtdet.changeFinder(test_d_exch_36, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_d_exch_36, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     8      3  
# FALSE    57     171  

round(evaluate(changefinder_d_exch_36, reference, metric = "F1"), 2)          # 0.21
round(evaluate(changefinder_d_exch_36, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(changefinder_d_exch_36, reference, metric = "sensitivity"), 2) # 0.12
round(evaluate(changefinder_d_exch_36, reference, metric = "specificity"), 2) # 0.98
round(evaluate(changefinder_d_exch_36, reference, metric = "precision"), 2)   # 0.73
round(evaluate(changefinder_d_exch_36, reference, metric = "recall"), 2)      # 0.12

#Plot
print(evtplot(test_d_exch_36, changefinder_d_exch_36, reference))

##### 4. d_exch_48 #####
#Detect
changefinder_d_exch_48 <- evtdet.changeFinder(test_d_exch_48, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_d_exch_48, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     8      2 
# FALSE    57     172    

round(evaluate(changefinder_d_exch_48, reference, metric = "F1"), 2)          # 0.21
round(evaluate(changefinder_d_exch_48, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(changefinder_d_exch_48, reference, metric = "sensitivity"), 2) # 0.12
round(evaluate(changefinder_d_exch_48, reference, metric = "specificity"), 2) # 0.99
round(evaluate(changefinder_d_exch_48, reference, metric = "precision"), 2)   # 0.80
round(evaluate(changefinder_d_exch_48, reference, metric = "recall"), 2)      # 0.12

#Plot
print(evtplot(test_d_exch_48, changefinder_d_exch_48, reference))

##### 5. d_dlsp_12 #####
#Detect
changefinder_d_dlsp_12 <- evtdet.changeFinder(test_d_dlsp_12, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_d_dlsp_12, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     7      11  
# FALSE    58     163  

round(evaluate(changefinder_d_dlsp_12, reference, metric = "F1"), 2)          # 0.17
round(evaluate(changefinder_d_dlsp_12, reference, metric = "accuracy"), 2)    # 0.71
round(evaluate(changefinder_d_dlsp_12, reference, metric = "sensitivity"), 2) # 0.11
round(evaluate(changefinder_d_dlsp_12, reference, metric = "specificity"), 2) # 0.94
round(evaluate(changefinder_d_dlsp_12, reference, metric = "precision"), 2)   # 0.39
round(evaluate(changefinder_d_dlsp_12, reference, metric = "recall"), 2)      # 0.11

#Plot
print(evtplot(test_d_dlsp_12, changefinder_d_dlsp_12, reference))

##### 6. d_dlsp_24 #####
#Detect
changefinder_d_dlsp_24 <- evtdet.changeFinder(test_d_dlsp_24, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_d_dlsp_24, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     14     7   
# FALSE    51     167

round(evaluate(changefinder_d_dlsp_24, reference, metric = "F1"), 2)          # 0.33
round(evaluate(changefinder_d_dlsp_24, reference, metric = "accuracy"), 2)    # 0.76
round(evaluate(changefinder_d_dlsp_24, reference, metric = "sensitivity"), 2) # 0.22
round(evaluate(changefinder_d_dlsp_24, reference, metric = "specificity"), 2) # 0.96
round(evaluate(changefinder_d_dlsp_24, reference, metric = "precision"), 2)   # 0.67
round(evaluate(changefinder_d_dlsp_24, reference, metric = "recall"), 2)      # 0.22

#Plot
print(evtplot(test_d_dlsp_24, changefinder_d_dlsp_24, reference))

##### 7. d_dlsp_36 #####
#Detect
changefinder_d_dlsp_36 <- evtdet.changeFinder(test_d_dlsp_36, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_d_dlsp_36, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     13     5  
# FALSE    52     169 

round(evaluate(changefinder_d_dlsp_36, reference, metric = "F1"), 2)          # 0.31
round(evaluate(changefinder_d_dlsp_36, reference, metric = "accuracy"), 2)    # 0.76
round(evaluate(changefinder_d_dlsp_36, reference, metric = "sensitivity"), 2) # 0.20
round(evaluate(changefinder_d_dlsp_36, reference, metric = "specificity"), 2) # 0.97
round(evaluate(changefinder_d_dlsp_36, reference, metric = "precision"), 2)   # 0.72
round(evaluate(changefinder_d_dlsp_36, reference, metric = "recall"), 2)      # 0.20

#Plot
print(evtplot(test_d_dlsp_36, changefinder_d_dlsp_36, reference))

##### 8. d_dlsp_48 #####
#Detect
changefinder_d_dlsp_48 <- evtdet.changeFinder(test_d_dlsp_48, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_d_dlsp_48, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     12     3 
# FALSE    53     171 

round(evaluate(changefinder_d_dlsp_48, reference, metric = "F1"), 2)          # 0.30
round(evaluate(changefinder_d_dlsp_48, reference, metric = "accuracy"), 2)    # 0.78
round(evaluate(changefinder_d_dlsp_48, reference, metric = "sensitivity"), 2) # 0.18
round(evaluate(changefinder_d_dlsp_48, reference, metric = "specificity"), 2) # 0.98
round(evaluate(changefinder_d_dlsp_48, reference, metric = "precision"), 2)   # 0.80
round(evaluate(changefinder_d_dlsp_48, reference, metric = "recall"), 2)      # 0.18

#Plot
print(evtplot(test_d_dlsp_48, changefinder_d_dlsp_48, reference))

##### 9. d_ipca_12 #####
#Detect
changefinder_d_ipca_12 <- evtdet.changeFinder(test_d_ipca_12, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_d_ipca_12, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     3      8   
# FALSE    62     166  

round(evaluate(changefinder_d_ipca_12, reference, metric = "F1"), 2)          # 0.08
round(evaluate(changefinder_d_ipca_12, reference, metric = "accuracy"), 2)    # 0.71
round(evaluate(changefinder_d_ipca_12, reference, metric = "sensitivity"), 2) # 0.05
round(evaluate(changefinder_d_ipca_12, reference, metric = "specificity"), 2) # 0.95
round(evaluate(changefinder_d_ipca_12, reference, metric = "precision"), 2)   # 0.27
round(evaluate(changefinder_d_ipca_12, reference, metric = "recall"), 2)      # 0.05

#Plot
print(evtplot(test_d_ipca_12, changefinder_d_ipca_12, reference))

##### 10. d_ipca_24 #####
#Detect
changefinder_d_ipca_24 <- evtdet.changeFinder(test_d_ipca_24, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_d_ipca_24, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     6      9 
# FALSE    59     165

round(evaluate(changefinder_d_ipca_24, reference, metric = "F1"), 2)          # 0.15
round(evaluate(changefinder_d_ipca_24, reference, metric = "accuracy"), 2)    # 0.72
round(evaluate(changefinder_d_ipca_24, reference, metric = "sensitivity"), 2) # 0.09
round(evaluate(changefinder_d_ipca_24, reference, metric = "specificity"), 2) # 0.95
round(evaluate(changefinder_d_ipca_24, reference, metric = "precision"), 2)   # 0.40
round(evaluate(changefinder_d_ipca_24, reference, metric = "recall"), 2)      # 0.09

#Plot
print(evtplot(test_d_ipca_24, changefinder_d_ipca_24, reference))

##### 11. d_ipca_36 #####
#Detect
changefinder_d_ipca_36 <- evtdet.changeFinder(test_d_ipca_36, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_d_ipca_36, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     6      9    
# FALSE    59     165  

round(evaluate(changefinder_d_ipca_36, reference, metric = "F1"), 2)          # 0.15
round(evaluate(changefinder_d_ipca_36, reference, metric = "accuracy"), 2)    # 0.72
round(evaluate(changefinder_d_ipca_36, reference, metric = "sensitivity"), 2) # 0.09
round(evaluate(changefinder_d_ipca_36, reference, metric = "specificity"), 2) # 0.95
round(evaluate(changefinder_d_ipca_36, reference, metric = "precision"), 2)   # 0.40
round(evaluate(changefinder_d_ipca_36, reference, metric = "recall"), 2)      # 0.09

#Plot
print(evtplot(test_d_ipca_36, changefinder_d_ipca_36, reference))

##### 12. d_ipca_48 #####
#Detect
changefinder_d_ipca_48 <- evtdet.changeFinder(test_d_ipca_48, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_d_ipca_48, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     5      9   
# FALSE    60     165  

round(evaluate(changefinder_d_ipca_48, reference, metric = "F1"), 2)          # 0.13
round(evaluate(changefinder_d_ipca_48, reference, metric = "accuracy"), 2)    # 0.71
round(evaluate(changefinder_d_ipca_48, reference, metric = "sensitivity"), 2) # 0.08
round(evaluate(changefinder_d_ipca_48, reference, metric = "specificity"), 2) # 0.95
round(evaluate(changefinder_d_ipca_48, reference, metric = "precision"), 2)   # 0.36
round(evaluate(changefinder_d_ipca_48, reference, metric = "recall"), 2)      # 0.08

#Plot
print(evtplot(test_d_ipca_48, changefinder_d_ipca_48, reference))

##### 13. d_pib_12 #####
#Detect
changefinder_d_pib_12 <- evtdet.changeFinder(test_d_pib_12, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_d_pib_12, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     7      8    
# FALSE    58     166   

round(evaluate(changefinder_d_pib_12, reference, metric = "F1"), 2)          # 0.18
round(evaluate(changefinder_d_pib_12, reference, metric = "accuracy"), 2)    # 0.72
round(evaluate(changefinder_d_pib_12, reference, metric = "sensitivity"), 2) # 0.11
round(evaluate(changefinder_d_pib_12, reference, metric = "specificity"), 2) # 0.95
round(evaluate(changefinder_d_pib_12, reference, metric = "precision"), 2)   # 0.47
round(evaluate(changefinder_d_pib_12, reference, metric = "recall"), 2)      # 0.11

#Plot
print(evtplot(test_d_pib_12, changefinder_d_pib_12, reference))

##### 14. d_pib_24 #####
#Detect
changefinder_d_pib_24 <- evtdet.changeFinder(test_d_pib_24, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_d_pib_24, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     4      2  
# FALSE    61     172  

round(evaluate(changefinder_d_pib_24, reference, metric = "F1"), 2)          # 0.11
round(evaluate(changefinder_d_pib_24, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(changefinder_d_pib_24, reference, metric = "sensitivity"), 2) # 0.06
round(evaluate(changefinder_d_pib_24, reference, metric = "specificity"), 2) # 0.99
round(evaluate(changefinder_d_pib_24, reference, metric = "precision"), 2)   # 0.67
round(evaluate(changefinder_d_pib_24, reference, metric = "recall"), 2)      # 0.06

#Plot
print(evtplot(test_d_pib_24, changefinder_d_pib_24, reference))

##### 15. d_pib_36 #####
#Detect
changefinder_d_pib_36 <- evtdet.changeFinder(test_d_pib_36, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_d_pib_36, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     0      10
# FALSE    65     164 

round(evaluate(changefinder_d_pib_36, reference, metric = "F1"), 2)          # NaN
round(evaluate(changefinder_d_pib_36, reference, metric = "accuracy"), 2)    # 0.69
round(evaluate(changefinder_d_pib_36, reference, metric = "sensitivity"), 2) # 0.00
round(evaluate(changefinder_d_pib_36, reference, metric = "specificity"), 2) # 0.94
round(evaluate(changefinder_d_pib_36, reference, metric = "precision"), 2)   # 0.00
round(evaluate(changefinder_d_pib_36, reference, metric = "recall"), 2)      # 0.00

#Plot
print(evtplot(test_d_pib_36, changefinder_d_pib_36, reference))

##### 16. d_pib_48 #####
#Detect
changefinder_d_pib_48 <- evtdet.changeFinder(test_d_pib_48, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_d_pib_48, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     0      10 
# FALSE    65     164    

round(evaluate(changefinder_d_pib_48, reference, metric = "F1"), 2)          # NaN
round(evaluate(changefinder_d_pib_48, reference, metric = "accuracy"), 2)    # 0.69
round(evaluate(changefinder_d_pib_48, reference, metric = "sensitivity"), 2) # 0.00
round(evaluate(changefinder_d_pib_48, reference, metric = "specificity"), 2) # 0.94
round(evaluate(changefinder_d_pib_48, reference, metric = "precision"), 2)   # 0.00
round(evaluate(changefinder_d_pib_48, reference, metric = "recall"), 2)      # 0.00

#Plot
print(evtplot(test_d_pib_48, changefinder_d_pib_48, reference))

##### 17. d_nfsp_12 #####
#Detect
changefinder_d_nfsp_12 <- evtdet.changeFinder(test_d_nfsp_12, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_d_nfsp_12, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     10     3    
# FALSE    55     171  

round(evaluate(changefinder_d_nfsp_12, reference, metric = "F1"), 2)          # 0.26
round(evaluate(changefinder_d_nfsp_12, reference, metric = "accuracy"), 2)    # 0.76
round(evaluate(changefinder_d_nfsp_12, reference, metric = "sensitivity"), 2) # 0.15
round(evaluate(changefinder_d_nfsp_12, reference, metric = "specificity"), 2) # 0.98
round(evaluate(changefinder_d_nfsp_12, reference, metric = "precision"), 2)   # 0.77
round(evaluate(changefinder_d_nfsp_12, reference, metric = "recall"), 2)      # 0.15

#Plot
print(evtplot(test_d_nfsp_12, changefinder_d_nfsp_12, reference))

##### 18. d_nfsp_24 #####
#Detect
changefinder_d_nfsp_24 <- evtdet.changeFinder(test_d_nfsp_24, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_d_nfsp_24, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     11     4 
# FALSE    54     170  

round(evaluate(changefinder_d_nfsp_24, reference, metric = "F1"), 2)          # 0.28
round(evaluate(changefinder_d_nfsp_24, reference, metric = "accuracy"), 2)    # 0.76
round(evaluate(changefinder_d_nfsp_24, reference, metric = "sensitivity"), 2) # 0.17
round(evaluate(changefinder_d_nfsp_24, reference, metric = "specificity"), 2) # 0.98
round(evaluate(changefinder_d_nfsp_24, reference, metric = "precision"), 2)   # 0.73
round(evaluate(changefinder_d_nfsp_24, reference, metric = "recall"), 2)      # 0.17

#Plot
print(evtplot(test_d_nfsp_24, changefinder_d_nfsp_24, reference))

##### 19. d_nfsp_36 #####
#Detect
changefinder_d_nfsp_36 <- evtdet.changeFinder(test_d_nfsp_36, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_d_nfsp_36, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     11     2   
# FALSE    54     172   

round(evaluate(changefinder_d_nfsp_36, reference, metric = "F1"), 2)          # 0.28
round(evaluate(changefinder_d_nfsp_36, reference, metric = "accuracy"), 2)    # 0.77
round(evaluate(changefinder_d_nfsp_36, reference, metric = "sensitivity"), 2) # 0.17
round(evaluate(changefinder_d_nfsp_36, reference, metric = "specificity"), 2) # 0.99
round(evaluate(changefinder_d_nfsp_36, reference, metric = "precision"), 2)   # 0.85
round(evaluate(changefinder_d_nfsp_36, reference, metric = "recall"), 2)      # 0.17

#Plot
print(evtplot(test_d_nfsp_36, changefinder_d_nfsp_36, reference))

##### 20. d_nfsp_48 #####
#Detect
changefinder_d_nfsp_48 <- evtdet.changeFinder(test_d_nfsp_48, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_d_nfsp_48, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     12     1    
# FALSE    53     173   

round(evaluate(changefinder_d_nfsp_48, reference, metric = "F1"), 2)          # 0.31
round(evaluate(changefinder_d_nfsp_48, reference, metric = "accuracy"), 2)    # 0.77
round(evaluate(changefinder_d_nfsp_48, reference, metric = "sensitivity"), 2) # 0.18
round(evaluate(changefinder_d_nfsp_48, reference, metric = "specificity"), 2) # 0.99
round(evaluate(changefinder_d_nfsp_48, reference, metric = "precision"), 2)   # 0.92
round(evaluate(changefinder_d_nfsp_48, reference, metric = "recall"), 2)      # 0.18

#Plot
print(evtplot(test_d_nfsp_48, changefinder_d_nfsp_48, reference))

##### 21. d_selic_12 #####
#Detect
changefinder_d_selic_12 <- evtdet.changeFinder(test_d_selic_12, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_d_selic_12, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     4      11  
# FALSE    61     163  

round(evaluate(changefinder_d_selic_12, reference, metric = "F1"), 2)          # 0.10
round(evaluate(changefinder_d_selic_12, reference, metric = "accuracy"), 2)    # 0.70
round(evaluate(changefinder_d_selic_12, reference, metric = "sensitivity"), 2) # 0.06
round(evaluate(changefinder_d_selic_12, reference, metric = "specificity"), 2) # 0.94
round(evaluate(changefinder_d_selic_12, reference, metric = "precision"), 2)   # 0.27
round(evaluate(changefinder_d_selic_12, reference, metric = "recall"), 2)      # 0.06

#Plot
print(evtplot(test_d_selic_12, changefinder_d_selic_12, reference))

##### 22. d_selic_24 #####
#Detect
changefinder_d_selic_24 <- evtdet.changeFinder(test_d_selic_24, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_d_selic_24, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     2      8 
# FALSE    63     166   

round(evaluate(changefinder_d_selic_24, reference, metric = "F1"), 2)          # 0.05
round(evaluate(changefinder_d_selic_24, reference, metric = "accuracy"), 2)    # 0.70
round(evaluate(changefinder_d_selic_24, reference, metric = "sensitivity"), 2) # 0.03
round(evaluate(changefinder_d_selic_24, reference, metric = "specificity"), 2) # 0.95
round(evaluate(changefinder_d_selic_24, reference, metric = "precision"), 2)   # 0.20
round(evaluate(changefinder_d_selic_24, reference, metric = "recall"), 2)      # 0.03

#Plot
print(evtplot(test_d_selic_24, changefinder_d_selic_24, reference))

##### 23. d_selic_36 #####
#Detect
changefinder_d_selic_36 <- evtdet.changeFinder(test_d_selic_36, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_d_selic_36, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     3      12 
# FALSE    62     162 

round(evaluate(changefinder_d_selic_36, reference, metric = "F1"), 2)          # 0.07
round(evaluate(changefinder_d_selic_36, reference, metric = "accuracy"), 2)    # 0.69
round(evaluate(changefinder_d_selic_36, reference, metric = "sensitivity"), 2) # 0.05
round(evaluate(changefinder_d_selic_36, reference, metric = "specificity"), 2) # 0.93
round(evaluate(changefinder_d_selic_36, reference, metric = "precision"), 2)   # 0.20
round(evaluate(changefinder_d_selic_36, reference, metric = "recall"), 2)      # 0.05

#Plot
print(evtplot(test_d_selic_36, changefinder_d_selic_36, reference))

##### 24. d_selic_48 #####
#Detect
changefinder_d_selic_48 <- evtdet.changeFinder(test_d_selic_48, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_d_selic_48, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     2      9  
# FALSE    63     165  

round(evaluate(changefinder_d_selic_48, reference, metric = "F1"), 2)          # 0.05
round(evaluate(changefinder_d_selic_48, reference, metric = "accuracy"), 2)    # 0.70
round(evaluate(changefinder_d_selic_48, reference, metric = "sensitivity"), 2) # 0.03
round(evaluate(changefinder_d_selic_48, reference, metric = "specificity"), 2) # 0.95
round(evaluate(changefinder_d_selic_48, reference, metric = "precision"), 2)   # 0.18
round(evaluate(changefinder_d_selic_48, reference, metric = "recall"), 2)      # 0.03

#Plot
print(evtplot(test_d_selic_48, changefinder_d_selic_48, reference))
