#################################################################
##### Detec??o de Eventos - D?vida L?quida do Setor P?blico #####
#################################################################

################
##### Data #####
################

library(tibble)
library(EventDetectR)
library(anomalize)
source("https://raw.githubusercontent.com/cefet-rj-dal/harbinger/master/harbinger.R")

attach(df_dlsp)
head(df_dlsp)
str(df_dlsp)

test_dlsp <- subset(df_dlsp, select = c(Data, dlsp))
test_dlsp_gov_central <- subset(df_dlsp, select = c(Data, dlsp_gov_central))
test_dlsp_gov_estadual <- subset(df_dlsp, select = c(Data, dlsp_gov_estadual))
test_dlsp_gov_municipal <- subset(df_dlsp, select = c(Data, dlsp_gov_municipal))
test_dlsp_estatal <- subset(df_dlsp, select = c(Data, dlsp_estatal))
test_dlsp_estatal_federal <- subset(df_dlsp, select = c(Data, dlsp_estatal_federal))
test_dlsp_estatal_estadual <- subset(df_dlsp, select = c(Data, dlsp_estatal_estadual))
test_dlsp_estatal_municipal <- subset(df_dlsp, select = c(Data, dlsp_estatal_municipal))
reference <- subset(df_dlsp, select = c(Data, event))

#####################
##### Anomalize #####
#####################

##### 1. dlsp #####
#Detect
anomalize_dlsp <- evtdet.anomalize(test_dlsp, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_dlsp, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     19     9         
# FALSE    46     164 

round(evaluate(anomalize_dlsp, reference, metric = "F1"), 2)          # 0.41
round(evaluate(anomalize_dlsp, reference, metric = "accuracy"), 2)    # 0.77
round(evaluate(anomalize_dlsp, reference, metric = "sensitivity"), 2) # 0.29
round(evaluate(anomalize_dlsp, reference, metric = "specificity"), 2) # 0.95
round(evaluate(anomalize_dlsp, reference, metric = "precision"), 2)   # 0.68
round(evaluate(anomalize_dlsp, reference, metric = "recall"), 2)      # 0.29

#Plot
print(evtplot(test_dlsp, anomalize_dlsp, reference))

##### 2. dlsp_gov_central #####
#Detect
anomalize_dlsp_gov_central <- evtdet.anomalize(test_dlsp_gov_central, alpha = 0.1,
                                               max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_dlsp_gov_central, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     7      8 
# FALSE    58     165  

round(evaluate(anomalize_dlsp_gov_central, reference, metric = "F1"), 2)          # 0.18
round(evaluate(anomalize_dlsp_gov_central, reference, metric = "accuracy"), 2)    # 0.72
round(evaluate(anomalize_dlsp_gov_central, reference, metric = "sensitivity"), 2) # 0.11
round(evaluate(anomalize_dlsp_gov_central, reference, metric = "specificity"), 2) # 0.95
round(evaluate(anomalize_dlsp_gov_central, reference, metric = "precision"), 2)   # 0.47
round(evaluate(anomalize_dlsp_gov_central, reference, metric = "recall"), 2)      # 0.11

#Plot
print(evtplot(test_dlsp_gov_central, anomalize_dlsp_gov_central, reference))

##### 3. dlsp_gov_estadual #####
#Detect
anomalize_dlsp_gov_estadual <- evtdet.anomalize(test_dlsp_gov_estadual, alpha = 0.1,
                                                max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_dlsp_gov_estadual, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     18     12   
# FALSE    47     161  

round(evaluate(anomalize_dlsp_gov_estadual, reference, metric = "F1"), 2)          # 0.38
round(evaluate(anomalize_dlsp_gov_estadual, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(anomalize_dlsp_gov_estadual, reference, metric = "sensitivity"), 2) # 0.28
round(evaluate(anomalize_dlsp_gov_estadual, reference, metric = "specificity"), 2) # 0.93
round(evaluate(anomalize_dlsp_gov_estadual, reference, metric = "precision"), 2)   # 0.60
round(evaluate(anomalize_dlsp_gov_estadual, reference, metric = "recall"), 2)      # 0.28

#Plot
print(evtplot(test_dlsp_gov_estadual, anomalize_dlsp_gov_estadual, reference))

##### 4. dlsp_gov_municipal #####
#Detect
anomalize_dlsp_gov_municipal <- evtdet.anomalize(test_dlsp_gov_municipal, alpha = 0.1,
                                                 max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_dlsp_gov_municipal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     21     17
# FALSE    44     156

round(evaluate(anomalize_dlsp_gov_municipal, reference, metric = "F1"), 2)          # 0.41
round(evaluate(anomalize_dlsp_gov_municipal, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(anomalize_dlsp_gov_municipal, reference, metric = "sensitivity"), 2) # 0.32
round(evaluate(anomalize_dlsp_gov_municipal, reference, metric = "specificity"), 2) # 0.90
round(evaluate(anomalize_dlsp_gov_municipal, reference, metric = "precision"), 2)   # 0.55
round(evaluate(anomalize_dlsp_gov_municipal, reference, metric = "recall"), 2)      # 0.32

#Plot
print(evtplot(test_dlsp_gov_municipal, anomalize_dlsp_gov_municipal, reference))

##### 5. dlsp_estatal #####
#Detect
anomalize_dlsp_estatal <- evtdet.anomalize(test_dlsp_estatal, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_dlsp_estatal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     2      10  
# FALSE    63     163

round(evaluate(anomalize_dlsp_estatal, reference, metric = "F1"), 2)          # 0.05
round(evaluate(anomalize_dlsp_estatal, reference, metric = "accuracy"), 2)    # 0.69
round(evaluate(anomalize_dlsp_estatal, reference, metric = "sensitivity"), 2) # 0.03
round(evaluate(anomalize_dlsp_estatal, reference, metric = "specificity"), 2) # 0.94
round(evaluate(anomalize_dlsp_estatal, reference, metric = "precision"), 2)   # 0.17
round(evaluate(anomalize_dlsp_estatal, reference, metric = "recall"), 2)      # 0.03

#Plot
print(evtplot(test_dlsp_estatal, anomalize_dlsp_estatal, reference))

##### 6. dlsp_estatal_federal #####
#Detect
anomalize_dlsp_estatal_federal <- evtdet.anomalize(test_dlsp_estatal_federal, alpha = 0.1,
                                                   max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_dlsp_estatal_federal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     5      20   
# FALSE    60     153

round(evaluate(anomalize_dlsp_estatal_federal, reference, metric = "F1"), 2)          # 0.11
round(evaluate(anomalize_dlsp_estatal_federal, reference, metric = "accuracy"), 2)    # 0.66
round(evaluate(anomalize_dlsp_estatal_federal, reference, metric = "sensitivity"), 2) # 0.08
round(evaluate(anomalize_dlsp_estatal_federal, reference, metric = "specificity"), 2) # 0.88
round(evaluate(anomalize_dlsp_estatal_federal, reference, metric = "precision"), 2)   # 0.20
round(evaluate(anomalize_dlsp_estatal_federal, reference, metric = "recall"), 2)      # 0.08

#Plot
print(evtplot(test_dlsp_estatal_federal, anomalize_dlsp_estatal_federal, reference))

##### 7. dlsp_estatal_estadual #####
#Detect
anomalize_dlsp_estatal_estadual <- evtdet.anomalize(test_dlsp_estatal_estadual, alpha = 0.1, max_anoms = 0.2, 
                                                    na.action = na.omit)

#Evaluate
evaluate(anomalize_dlsp_estatal_estadual, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     6      23   
# FALSE    59     150  

round(evaluate(anomalize_dlsp_estatal_estadual, reference, metric = "F1"), 2)          # 0.13
round(evaluate(anomalize_dlsp_estatal_estadual, reference, metric = "accuracy"), 2)    # 0.66
round(evaluate(anomalize_dlsp_estatal_estadual, reference, metric = "sensitivity"), 2) # 0.09
round(evaluate(anomalize_dlsp_estatal_estadual, reference, metric = "specificity"), 2) # 0.87
round(evaluate(anomalize_dlsp_estatal_estadual, reference, metric = "precision"), 2)   # 0.21
round(evaluate(anomalize_dlsp_estatal_estadual, reference, metric = "recall"), 2)      # 0.09

#Plot
print(evtplot(test_dlsp_estatal_estadual, anomalize_dlsp_estatal_estadual, reference))

##### 8. dlsp_estatal_municipal #####
#Detect
anomalize_dlsp_estatal_municipal <- evtdet.anomalize(test_dlsp_estatal_municipal, alpha = 0.1,
                                                     max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_dlsp_estatal_municipal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     5      1 
# FALSE    60     172  

round(evaluate(anomalize_dlsp_estatal_municipal, reference, metric = "F1"), 2)          # 0.14
round(evaluate(anomalize_dlsp_estatal_municipal, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(anomalize_dlsp_estatal_municipal, reference, metric = "sensitivity"), 2) # 0.08
round(evaluate(anomalize_dlsp_estatal_municipal, reference, metric = "specificity"), 2) # 0.99
round(evaluate(anomalize_dlsp_estatal_municipal, reference, metric = "precision"), 2)   # 0.83
round(evaluate(anomalize_dlsp_estatal_municipal, reference, metric = "recall"), 2)      # 0.08

#Plot
print(evtplot(test_dlsp_estatal_municipal, anomalize_dlsp_estatal_municipal, reference))

###########################################
##### Adaptive Normalization Outliers #####
###########################################

##### 1. dlsp #####
#Detect
an_dlsp <- evtdet.an_outliers(test_dlsp, w = 30, alpha = 1.5, na.action = na.omit)

#Error in data.frame(..., check.names = FALSE) : 
#  arguments imply differing number of rows: 0, 1 

#Evaluate
evaluate(an_dlsp, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE    

round(evaluate(an_dlsp, reference, metric = "F1"), 2)          # 
round(evaluate(an_dlsp, reference, metric = "accuracy"), 2)    # 
round(evaluate(an_dlsp, reference, metric = "sensitivity"), 2) # 
round(evaluate(an_dlsp, reference, metric = "specificity"), 2) # 
round(evaluate(an_dlsp, reference, metric = "precision"), 2)   # 
round(evaluate(an_dlsp, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_dlsp, an_dlsp, reference))

##### 2. dlsp_gov_central #####
#Detect
an_dlsp_gov_central <- evtdet.an_outliers(test_dlsp_gov_central, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_dlsp_gov_central, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     3      0    
# FALSE    62     173 

round(evaluate(an_dlsp_gov_central, reference, metric = "F1"), 2)          # 0.09
round(evaluate(an_dlsp_gov_central, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(an_dlsp_gov_central, reference, metric = "sensitivity"), 2) # 0.05
round(evaluate(an_dlsp_gov_central, reference, metric = "specificity"), 2) # 1.00
round(evaluate(an_dlsp_gov_central, reference, metric = "precision"), 2)   # 1.00
round(evaluate(an_dlsp_gov_central, reference, metric = "recall"), 2)      # 0.05

#Plot
print(evtplot(test_dlsp_gov_central, an_dlsp_gov_central, reference))

##### 3. dlsp_gov_estadual #####
#Detect
an_dlsp_gov_estadual <- evtdet.an_outliers(test_dlsp_gov_estadual, w = 30, alpha = 1.5, na.action = na.omit)

#Error in data.frame(..., check.names = FALSE) : 
#  arguments imply differing number of rows: 0, 1 

#Evaluate
evaluate(an_dlsp_gov_estadual, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE    

round(evaluate(an_dlsp_gov_estadual, reference, metric = "F1"), 2)          # 
round(evaluate(an_dlsp_gov_estadual, reference, metric = "accuracy"), 2)    # 
round(evaluate(an_dlsp_gov_estadual, reference, metric = "sensitivity"), 2) # 
round(evaluate(an_dlsp_gov_estadual, reference, metric = "specificity"), 2) # 
round(evaluate(an_dlsp_gov_estadual, reference, metric = "precision"), 2)   # 
round(evaluate(an_dlsp_gov_estadual, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_dlsp_gov_estadual, an_dlsp_gov_estadual, reference))

##### 4. dlsp_gov_municipal #####
#Detect
an_dlsp_gov_municipal <- evtdet.an_outliers(test_dlsp_gov_municipal, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_dlsp_gov_municipal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     22     9  
# FALSE    43     164  

round(evaluate(an_dlsp_gov_municipal, reference, metric = "F1"), 2)          # 0.46
round(evaluate(an_dlsp_gov_municipal, reference, metric = "accuracy"), 2)    # 0.78
round(evaluate(an_dlsp_gov_municipal, reference, metric = "sensitivity"), 2) # 0.34
round(evaluate(an_dlsp_gov_municipal, reference, metric = "specificity"), 2) # 0.95
round(evaluate(an_dlsp_gov_municipal, reference, metric = "precision"), 2)   # 0.71
round(evaluate(an_dlsp_gov_municipal, reference, metric = "recall"), 2)      # 0.34

#Plot
print(evtplot(test_dlsp_gov_municipal, an_dlsp_gov_municipal, reference))

##### 5. dlsp_estatal #####
#Detect
an_dlsp_estatal <- evtdet.an_outliers(test_dlsp_estatal, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_dlsp_estatal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     4      51 
# FALSE    61     122  

round(evaluate(an_dlsp_estatal, reference, metric = "F1"), 2)          # 0.07
round(evaluate(an_dlsp_estatal, reference, metric = "accuracy"), 2)    # 0.53
round(evaluate(an_dlsp_estatal, reference, metric = "sensitivity"), 2) # 0.06
round(evaluate(an_dlsp_estatal, reference, metric = "specificity"), 2) # 0.71
round(evaluate(an_dlsp_estatal, reference, metric = "precision"), 2)   # 0.07
round(evaluate(an_dlsp_estatal, reference, metric = "recall"), 2)      # 0.06

#Plot
print(evtplot(test_dlsp_estatal, an_dlsp_estatal, reference))

##### 6. dlsp_estatal_federal #####
#Detect
an_dlsp_estatal_federal <- evtdet.an_outliers(test_dlsp_estatal_federal, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_dlsp_estatal_federal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     3      20 
# FALSE    62     153 

round(evaluate(an_dlsp_estatal_federal, reference, metric = "F1"), 2)          # 0.07
round(evaluate(an_dlsp_estatal_federal, reference, metric = "accuracy"), 2)    # 0.66
round(evaluate(an_dlsp_estatal_federal, reference, metric = "sensitivity"), 2) # 0.05
round(evaluate(an_dlsp_estatal_federal, reference, metric = "specificity"), 2) # 0.88
round(evaluate(an_dlsp_estatal_federal, reference, metric = "precision"), 2)   # 0.13
round(evaluate(an_dlsp_estatal_federal, reference, metric = "recall"), 2)      # 0.05

#Plot
print(evtplot(test_dlsp_estatal_federal, an_dlsp_estatal_federal, reference))

##### 7. dlsp_estatal_estadual #####
#Detect
an_dlsp_estatal_estadual <- evtdet.an_outliers(test_dlsp_estatal_estadual, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_dlsp_estatal_estadual, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     3      20  
# FALSE    62     153   

round(evaluate(an_dlsp_estatal_estadual, reference, metric = "F1"), 2)          # 0.07
round(evaluate(an_dlsp_estatal_estadual, reference, metric = "accuracy"), 2)    # 0.66
round(evaluate(an_dlsp_estatal_estadual, reference, metric = "sensitivity"), 2) # 0.05
round(evaluate(an_dlsp_estatal_estadual, reference, metric = "specificity"), 2) # 0.88
round(evaluate(an_dlsp_estatal_estadual, reference, metric = "precision"), 2)   # 0.13
round(evaluate(an_dlsp_estatal_estadual, reference, metric = "recall"), 2)      # 0.05

#Plot
print(evtplot(test_dlsp_estatal_estadual, an_dlsp_estatal_estadual, reference))

##### 8. dlsp_estatal_municipal #####
#Detect
an_dlsp_estatal_municipal <- evtdet.an_outliers(test_dlsp_estatal_municipal, w = 30, alpha = 1.5, 
                                                na.action = na.omit)

#Error in data.frame(..., check.names = FALSE) : 
#  arguments imply differing number of rows: 0, 1 

#Evaluate
evaluate(an_dlsp_estatal_municipal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE       

round(evaluate(an_dlsp_estatal_municipal, reference, metric = "F1"), 2)          # 
round(evaluate(an_dlsp_estatal_municipal, reference, metric = "accuracy"), 2)    # 
round(evaluate(an_dlsp_estatal_municipal, reference, metric = "sensitivity"), 2) # 
round(evaluate(an_dlsp_estatal_municipal, reference, metric = "specificity"), 2) # 
round(evaluate(an_dlsp_estatal_municipal, reference, metric = "precision"), 2)   # 
round(evaluate(an_dlsp_estatal_municipal, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_dlsp_estatal_municipal, an_dlsp_estatal_municipal, reference))

#######################
##### EventDetect #####
#######################

##### 1. dlsp #####
#Detect
eventdetect_dlsp <- evtdet.eventdetect(na.omit(test_dlsp), w = 30)

#Evaluate
evaluate(eventdetect_dlsp, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     50     89  
# FALSE    15     84

round(evaluate(eventdetect_dlsp, reference, metric = "F1"), 2)          # 0.49
round(evaluate(eventdetect_dlsp, reference, metric = "accuracy"), 2)    # 0.56
round(evaluate(eventdetect_dlsp, reference, metric = "sensitivity"), 2) # 0.77
round(evaluate(eventdetect_dlsp, reference, metric = "specificity"), 2) # 0.49
round(evaluate(eventdetect_dlsp, reference, metric = "precision"), 2)   # 0.36
round(evaluate(eventdetect_dlsp, reference, metric = "recall"), 2)      # 0.77

#Plot
print(evtplot(test_dlsp, eventdetect_dlsp, reference))

##### 2. dlsp_gov_central #####
#Detect
eventdetect_dlsp_gov_central <- evtdet.eventdetect(na.omit(test_dlsp_gov_central), w = 30)

#Evaluate
evaluate(eventdetect_dlsp_gov_central, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     31     52 
# FALSE    34     121     

round(evaluate(eventdetect_dlsp_gov_central, reference, metric = "F1"), 2)          # 0.42
round(evaluate(eventdetect_dlsp_gov_central, reference, metric = "accuracy"), 2)    # 0.64
round(evaluate(eventdetect_dlsp_gov_central, reference, metric = "sensitivity"), 2) # 0.48
round(evaluate(eventdetect_dlsp_gov_central, reference, metric = "specificity"), 2) # 0.70
round(evaluate(eventdetect_dlsp_gov_central, reference, metric = "precision"), 2)   # 0.37
round(evaluate(eventdetect_dlsp_gov_central, reference, metric = "recall"), 2)      # 0.48

#Plot
print(evtplot(test_dlsp_gov_central, eventdetect_dlsp_gov_central, reference))

##### 3. dlsp_gov_estadual #####
#Detect
eventdetect_dlsp_gov_estadual <- evtdet.eventdetect(na.omit(test_dlsp_gov_estadual), w = 30)

#Evaluate
evaluate(eventdetect_dlsp_gov_estadual, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     60     121
# FALSE    5      52   

round(evaluate(eventdetect_dlsp_gov_estadual, reference, metric = "F1"), 2)          # 0.49
round(evaluate(eventdetect_dlsp_gov_estadual, reference, metric = "accuracy"), 2)    # 0.47
round(evaluate(eventdetect_dlsp_gov_estadual, reference, metric = "sensitivity"), 2) # 0.92
round(evaluate(eventdetect_dlsp_gov_estadual, reference, metric = "specificity"), 2) # 0.30
round(evaluate(eventdetect_dlsp_gov_estadual, reference, metric = "precision"), 2)   # 0.33
round(evaluate(eventdetect_dlsp_gov_estadual, reference, metric = "recall"), 2)      # 0.92

#Plot
print(evtplot(test_dlsp_gov_estadual, eventdetect_dlsp_gov_estadual, reference))

##### 4. dlsp_gov_municipal #####
#Detect
eventdetect_dlsp_gov_municipal <- evtdet.eventdetect(na.omit(test_dlsp_gov_municipal), w = 30)

#Evaluate
evaluate(eventdetect_dlsp_gov_municipal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     39     85    
# FALSE    26     88  

round(evaluate(eventdetect_dlsp_gov_municipal, reference, metric = "F1"), 2)          # 0.41
round(evaluate(eventdetect_dlsp_gov_municipal, reference, metric = "accuracy"), 2)    # 0.53
round(evaluate(eventdetect_dlsp_gov_municipal, reference, metric = "sensitivity"), 2) # 0.60
round(evaluate(eventdetect_dlsp_gov_municipal, reference, metric = "specificity"), 2) # 0.51
round(evaluate(eventdetect_dlsp_gov_municipal, reference, metric = "precision"), 2)   # 0.31
round(evaluate(eventdetect_dlsp_gov_municipal, reference, metric = "recall"), 2)      # 0.60

#Plot
print(evtplot(test_dlsp_gov_municipal, eventdetect_dlsp_gov_municipal, reference))

##### 5. dlsp_estatal #####
#Detect
eventdetect_dlsp_estatal <- evtdet.eventdetect(na.omit(test_dlsp_estatal), w = 30)

#Evaluate
evaluate(eventdetect_dlsp_estatal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     39     99
# FALSE    26     74  

round(evaluate(eventdetect_dlsp_estatal, reference, metric = "F1"), 2)          # 0.38
round(evaluate(eventdetect_dlsp_estatal, reference, metric = "accuracy"), 2)    # 0.47
round(evaluate(eventdetect_dlsp_estatal, reference, metric = "sensitivity"), 2) # 0.60
round(evaluate(eventdetect_dlsp_estatal, reference, metric = "specificity"), 2) # 0.43
round(evaluate(eventdetect_dlsp_estatal, reference, metric = "precision"), 2)   # 0.28
round(evaluate(eventdetect_dlsp_estatal, reference, metric = "recall"), 2)      # 0.60

#Plot
print(evtplot(test_dlsp_estatal, eventdetect_dlsp_estatal, reference))

##### 6. dlsp_estatal_federal #####
#Detect
eventdetect_dlsp_estatal_federal <- evtdet.eventdetect(na.omit(test_dlsp_estatal_federal), w = 30)

#Evaluate
evaluate(eventdetect_dlsp_estatal_federal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     17     59 
# FALSE    48     114 

round(evaluate(eventdetect_dlsp_estatal_federal, reference, metric = "F1"), 2)          # 0.24
round(evaluate(eventdetect_dlsp_estatal_federal, reference, metric = "accuracy"), 2)    # 0.55
round(evaluate(eventdetect_dlsp_estatal_federal, reference, metric = "sensitivity"), 2) # 0.26
round(evaluate(eventdetect_dlsp_estatal_federal, reference, metric = "specificity"), 2) # 0.66
round(evaluate(eventdetect_dlsp_estatal_federal, reference, metric = "precision"), 2)   # 0.22
round(evaluate(eventdetect_dlsp_estatal_federal, reference, metric = "recall"), 2)      # 0.26

#Plot
print(evtplot(test_dlsp_estatal_federal, eventdetect_dlsp_estatal_federal, reference))

##### 7. dlsp_estatal_estadual #####
#Detect
eventdetect_dlsp_estatal_estadual <- evtdet.eventdetect(na.omit(test_dlsp_estatal_estadual), w = 30)

#Evaluate
evaluate(eventdetect_dlsp_estatal_estadual, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     47     94  
# FALSE    18     79  

round(evaluate(eventdetect_dlsp_estatal_estadual, reference, metric = "F1"), 2)          # 0.46
round(evaluate(eventdetect_dlsp_estatal_estadual, reference, metric = "accuracy"), 2)    # 0.53
round(evaluate(eventdetect_dlsp_estatal_estadual, reference, metric = "sensitivity"), 2) # 0.72
round(evaluate(eventdetect_dlsp_estatal_estadual, reference, metric = "specificity"), 2) # 0.46
round(evaluate(eventdetect_dlsp_estatal_estadual, reference, metric = "precision"), 2)   # 0.33
round(evaluate(eventdetect_dlsp_estatal_estadual, reference, metric = "recall"), 2)      # 0.72

#Plot
print(evtplot(test_dlsp_estatal_estadual, eventdetect_dlsp_estatal_estadual, reference))

##### 8. dlsp_estatal_municipal #####
#Detect
eventdetect_dlsp_estatal_municipal <- evtdet.eventdetect(na.omit(test_dlsp_estatal_municipal), w = 30)

#Evaluate
evaluate(eventdetect_dlsp_estatal_municipal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     21     21   
# FALSE    44     152    

round(evaluate(eventdetect_dlsp_estatal_municipal, reference, metric = "F1"), 2)          # 0.39
round(evaluate(eventdetect_dlsp_estatal_municipal, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(eventdetect_dlsp_estatal_municipal, reference, metric = "sensitivity"), 2) # 0.32
round(evaluate(eventdetect_dlsp_estatal_municipal, reference, metric = "specificity"), 2) # 0.88
round(evaluate(eventdetect_dlsp_estatal_municipal, reference, metric = "precision"), 2)   # 0.50
round(evaluate(eventdetect_dlsp_estatal_municipal, reference, metric = "recall"), 2)      # 0.32

#Plot
print(evtplot(test_dlsp_estatal_municipal, eventdetect_dlsp_estatal_municipal, reference))

#######################################
##### Auxiliary Model definitions #####
#######################################

ARIMA <- function(data) forecast::auto.arima(data)
AR <- function(data,p) forecast::Arima(data, order = c(p, 0, 0), seasonal = c(0, 0, 0))
garch <- function(data,spec,...) rugarch::ugarchfit(spec=spec,data=data,solver="hybrid", ...)@fit
ets <- function(data) forecast::ets(ts(data))
linreg <- function(data) {
  #browser()
  data <- as.data.frame(data)
  colnames(data) <- "x"
  data$t <- 1:nrow(data)
  
  #Adjusting a linear regression to the whole window
  lm(x~t, data)
}

#Garch specs
garch11 <- rugarch::ugarchspec(variance.model = list(model = "sGARCH", garchOrder = c(1, 1)), 
                               mean.model = list(armaOrder = c(1, 1), include.mean = TRUE), 
                               distribution.model = "norm")

####################################
##### Garch Volatility Outlier #####
####################################

##### 1. dlsp #####
#Detect
garch_volatility_dlsp <- evtdet.garch_volatility_outlier(test_dlsp, spec = garch11, alpha = 1.5,
                                                         na.action = na.omit)

#Evaluate
evaluate(garch_volatility_dlsp, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     13     13
# FALSE    52     160   

round(evaluate(garch_volatility_dlsp, reference, metric = "F1"), 2)          # 0.29
round(evaluate(garch_volatility_dlsp, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(garch_volatility_dlsp, reference, metric = "sensitivity"), 2) # 0.20
round(evaluate(garch_volatility_dlsp, reference, metric = "specificity"), 2) # 0.92
round(evaluate(garch_volatility_dlsp, reference, metric = "precision"), 2)   # 0.50
round(evaluate(garch_volatility_dlsp, reference, metric = "recall"), 2)      # 0.20

#Plot
print(evtplot(test_dlsp, garch_volatility_dlsp, reference))

##### 2. dlsp_gov_central #####
#Detect
garch_volatility_dlsp_gov_central <- evtdet.garch_volatility_outlier(test_dlsp_gov_central,
                                                                     spec = garch11, alpha = 1.5,
                                                                     na.action = na.omit)

#Evaluate
evaluate(garch_volatility_dlsp_gov_central, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     14     14 
# FALSE    51     159  

round(evaluate(garch_volatility_dlsp_gov_central, reference, metric = "F1"), 2)          # 0.30
round(evaluate(garch_volatility_dlsp_gov_central, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(garch_volatility_dlsp_gov_central, reference, metric = "sensitivity"), 2) # 0.22
round(evaluate(garch_volatility_dlsp_gov_central, reference, metric = "specificity"), 2) # 0.92
round(evaluate(garch_volatility_dlsp_gov_central, reference, metric = "precision"), 2)   # 0.50
round(evaluate(garch_volatility_dlsp_gov_central, reference, metric = "recall"), 2)      # 0.22

#Plot
print(evtplot(test_dlsp_gov_central, garch_volatility_dlsp_gov_central, reference))

##### 3. dlsp_gov_estadual #####
#Detect
garch_volatility_dlsp_gov_estadual <- evtdet.garch_volatility_outlier(test_dlsp_gov_estadual, spec = garch11, 
                                                                      alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(garch_volatility_dlsp_gov_estadual, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     16     10
# FALSE    49     163  

round(evaluate(garch_volatility_dlsp_gov_estadual, reference, metric = "F1"), 2)          # 0.35
round(evaluate(garch_volatility_dlsp_gov_estadual, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(garch_volatility_dlsp_gov_estadual, reference, metric = "sensitivity"), 2) # 0.25
round(evaluate(garch_volatility_dlsp_gov_estadual, reference, metric = "specificity"), 2) # 0.94
round(evaluate(garch_volatility_dlsp_gov_estadual, reference, metric = "precision"), 2)   # 0.62
round(evaluate(garch_volatility_dlsp_gov_estadual, reference, metric = "recall"), 2)      # 0.25

#Plot
print(evtplot(test_dlsp_gov_estadual, garch_volatility_dlsp_gov_estadual, reference))

##### 4. dlsp_gov_municipal #####
#Detect
garch_volatility_dlsp_gov_municipal <- evtdet.garch_volatility_outlier(test_dlsp_gov_municipal,
                                                                       spec = garch11, alpha = 1.5,
                                                                       na.action = na.omit)

#  Error in data.frame(..., check.names = FALSE) : 
#    arguments imply differing number of rows: 0, 1 

#Evaluate
evaluate(garch_volatility_dlsp_gov_municipal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE       

round(evaluate(garch_volatility_dlsp_gov_municipal, reference, metric = "F1"), 2)          # 
round(evaluate(garch_volatility_dlsp_gov_municipal, reference, metric = "accuracy"), 2)    # 
round(evaluate(garch_volatility_dlsp_gov_municipal, reference, metric = "sensitivity"), 2) # 
round(evaluate(garch_volatility_dlsp_gov_municipal, reference, metric = "specificity"), 2) # 
round(evaluate(garch_volatility_dlsp_gov_municipal, reference, metric = "precision"), 2)   # 
round(evaluate(garch_volatility_dlsp_gov_municipal, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_dlsp_gov_municipal, garch_volatility_dlsp_gov_municipal, reference))

##### 5. dlsp_estatal #####
#Detect
garch_volatility_dlsp_estatal <- evtdet.garch_volatility_outlier(test_dlsp_estatal, spec = garch11, alpha = 1.5,
                                                                 na.action = na.omit)

#Evaluate
evaluate(garch_volatility_dlsp_estatal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     6      28 
# FALSE    59     145 

round(evaluate(garch_volatility_dlsp_estatal, reference, metric = "F1"), 2)          # 0.12
round(evaluate(garch_volatility_dlsp_estatal, reference, metric = "accuracy"), 2)    # 0.63
round(evaluate(garch_volatility_dlsp_estatal, reference, metric = "sensitivity"), 2) # 0.09
round(evaluate(garch_volatility_dlsp_estatal, reference, metric = "specificity"), 2) # 0.84
round(evaluate(garch_volatility_dlsp_estatal, reference, metric = "precision"), 2)   # 0.18
round(evaluate(garch_volatility_dlsp_estatal, reference, metric = "recall"), 2)      # 0.09

#Plot
print(evtplot(test_dlsp_estatal, garch_volatility_dlsp_estatal, reference))

##### 6. dlsp_estatal_federal #####
#Detect
garch_volatility_dlsp_estatal_federal <- evtdet.garch_volatility_outlier(test_dlsp_estatal_federal,
                                                                         spec = garch11, alpha = 1.5,
                                                                         na.action = na.omit)

#Evaluate
evaluate(garch_volatility_dlsp_estatal_federal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     6      27
# FALSE    59     146    

round(evaluate(garch_volatility_dlsp_estatal_federal, reference, metric = "F1"), 2)          # 0.12
round(evaluate(garch_volatility_dlsp_estatal_federal, reference, metric = "accuracy"), 2)    # 0.64
round(evaluate(garch_volatility_dlsp_estatal_federal, reference, metric = "sensitivity"), 2) # 0.09
round(evaluate(garch_volatility_dlsp_estatal_federal, reference, metric = "specificity"), 2) # 0.84
round(evaluate(garch_volatility_dlsp_estatal_federal, reference, metric = "precision"), 2)   # 0.18
round(evaluate(garch_volatility_dlsp_estatal_federal, reference, metric = "recall"), 2)      # 0.09

#Plot
print(evtplot(test_dlsp_estatal_federal, garch_volatility_dlsp_estatal_federal, reference))

##### 7. dlsp_estatal_estadual #####
#Detect
garch_volatility_dlsp_estatal_estadual <- evtdet.garch_volatility_outlier(test_dlsp_estatal_estadual, 
                                                                          spec = garch11, alpha = 1.5,
                                                                          na.action = na.omit)

#Evaluate
evaluate(garch_volatility_dlsp_estatal_estadual, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     5      27  
# FALSE    60     146 

round(evaluate(garch_volatility_dlsp_estatal_estadual, reference, metric = "F1"), 2)          # 0.10
round(evaluate(garch_volatility_dlsp_estatal_estadual, reference, metric = "accuracy"), 2)    # 0.63
round(evaluate(garch_volatility_dlsp_estatal_estadual, reference, metric = "sensitivity"), 2) # 0.08
round(evaluate(garch_volatility_dlsp_estatal_estadual, reference, metric = "specificity"), 2) # 0.84
round(evaluate(garch_volatility_dlsp_estatal_estadual, reference, metric = "precision"), 2)   # 0.16
round(evaluate(garch_volatility_dlsp_estatal_estadual, reference, metric = "recall"), 2)      # 0.08

#Plot
print(evtplot(test_dlsp_estatal_estadual, garch_volatility_dlsp_estatal_estadual, reference))

##### 8. dlsp_estatal_municipal #####
#Detect
garch_volatility_dlsp_estatal_municipal <- evtdet.garch_volatility_outlier(test_dlsp_estatal_municipal,
                                                                           spec = garch11, alpha = 1.5,
                                                                           na.action = na.omit)

#Evaluate
evaluate(garch_volatility_dlsp_estatal_municipal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     0      15 
# FALSE    65     158    

round(evaluate(garch_volatility_dlsp_estatal_municipal, reference, metric = "F1"), 2)          # NaN
round(evaluate(garch_volatility_dlsp_estatal_municipal, reference, metric = "accuracy"), 2)    # 0.66
round(evaluate(garch_volatility_dlsp_estatal_municipal, reference, metric = "sensitivity"), 2) # 0.00
round(evaluate(garch_volatility_dlsp_estatal_municipal, reference, metric = "specificity"), 2) # 0.91
round(evaluate(garch_volatility_dlsp_estatal_municipal, reference, metric = "precision"), 2)   # 0.00
round(evaluate(garch_volatility_dlsp_estatal_municipal, reference, metric = "recall"), 2)      # 0.00

#Plot
print(evtplot(test_dlsp_estatal_municipal, garch_volatility_dlsp_estatal_municipal, reference))

#######################################
##### Seminal Change Point (1999) #####
#######################################

##### 1. dlsp #####
#Detect
changepoint_dlsp <- evtdet.seminalChangePoint2(test_dlsp, w = 30, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_dlsp, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     14     16 
# FALSE    51     157   

round(evaluate(changepoint_dlsp, reference, metric = "F1"), 2)          # 0.29
round(evaluate(changepoint_dlsp, reference, metric = "accuracy"), 2)    # 0.72
round(evaluate(changepoint_dlsp, reference, metric = "sensitivity"), 2) # 0.22
round(evaluate(changepoint_dlsp, reference, metric = "specificity"), 2) # 0.91
round(evaluate(changepoint_dlsp, reference, metric = "precision"), 2)   # 0.47
round(evaluate(changepoint_dlsp, reference, metric = "recall"), 2)      # 0.22

#Plot
print(evtplot(test_dlsp, changepoint_dlsp, reference))

##### 2. dlsp_gov_central #####
#Detect
changepoint_dlsp_gov_central <- evtdet.seminalChangePoint2(test_dlsp_gov_central, w = 30,
                                                           mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_dlsp_gov_central, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     17     16   
# FALSE    48     157  

round(evaluate(changepoint_dlsp_gov_central, reference, metric = "F1"), 2)          # 0.35
round(evaluate(changepoint_dlsp_gov_central, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(changepoint_dlsp_gov_central, reference, metric = "sensitivity"), 2) # 0.26
round(evaluate(changepoint_dlsp_gov_central, reference, metric = "specificity"), 2) # 0.91
round(evaluate(changepoint_dlsp_gov_central, reference, metric = "precision"), 2)   # 0.52
round(evaluate(changepoint_dlsp_gov_central, reference, metric = "recall"), 2)      # 0.26

#Plot
print(evtplot(test_dlsp_gov_central, changepoint_dlsp_gov_central, reference))

##### 3. dlsp_gov_estadual #####
#Detect
changepoint_dlsp_gov_estadual <- evtdet.seminalChangePoint2(test_dlsp_gov_estadual, w = 30,
                                                            mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_dlsp_gov_estadual, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     9      19  
# FALSE    56     154   

round(evaluate(changepoint_dlsp_gov_estadual, reference, metric = "F1"), 2)          # 0.19
round(evaluate(changepoint_dlsp_gov_estadual, reference, metric = "accuracy"), 2)    # 0.68
round(evaluate(changepoint_dlsp_gov_estadual, reference, metric = "sensitivity"), 2) # 0.14
round(evaluate(changepoint_dlsp_gov_estadual, reference, metric = "specificity"), 2) # 0.89
round(evaluate(changepoint_dlsp_gov_estadual, reference, metric = "precision"), 2)   # 0.32
round(evaluate(changepoint_dlsp_gov_estadual, reference, metric = "recall"), 2)      # 0.14

#Plot
print(evtplot(test_dlsp_gov_estadual, changepoint_dlsp_gov_estadual, reference))

##### 4. dlsp_gov_municipal #####
#Detect
changepoint_dlsp_gov_municipal <- evtdet.seminalChangePoint2(test_dlsp_gov_municipal, w = 30, 
                                                             mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_dlsp_gov_municipal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     10     20   
# FALSE    55     153 

round(evaluate(changepoint_dlsp_gov_municipal, reference, metric = "F1"), 2)          # 0.21
round(evaluate(changepoint_dlsp_gov_municipal, reference, metric = "accuracy"), 2)    # 0.68
round(evaluate(changepoint_dlsp_gov_municipal, reference, metric = "sensitivity"), 2) # 0.15
round(evaluate(changepoint_dlsp_gov_municipal, reference, metric = "specificity"), 2) # 0.88
round(evaluate(changepoint_dlsp_gov_municipal, reference, metric = "precision"), 2)   # 0.33
round(evaluate(changepoint_dlsp_gov_municipal, reference, metric = "recall"), 2)      # 0.15

#Plot
print(evtplot(test_dlsp_gov_municipal, changepoint_dlsp_gov_municipal, reference))

##### 5. dlsp_estatal #####
#Detect
changepoint_dlsp_estatal <- evtdet.seminalChangePoint2(test_dlsp_estatal, w = 30, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_dlsp_estatal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     8      27
# FALSE    57     146 

round(evaluate(changepoint_dlsp_estatal, reference, metric = "F1"), 2)          # 0.16
round(evaluate(changepoint_dlsp_estatal, reference, metric = "accuracy"), 2)    # 0.65
round(evaluate(changepoint_dlsp_estatal, reference, metric = "sensitivity"), 2) # 0.12
round(evaluate(changepoint_dlsp_estatal, reference, metric = "specificity"), 2) # 0.84
round(evaluate(changepoint_dlsp_estatal, reference, metric = "precision"), 2)   # 0.23
round(evaluate(changepoint_dlsp_estatal, reference, metric = "recall"), 2)      # 0.12

#Plot
print(evtplot(test_dlsp_estatal, changepoint_dlsp_estatal, reference))

##### 6. dlsp_estatal_federal #####
#Detect
changepoint_dlsp_estatal_federal <- evtdet.seminalChangePoint2(test_dlsp_estatal_federal, w = 30,
                                                               mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_dlsp_estatal_federal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     12     27   
# FALSE    53     146  

round(evaluate(changepoint_dlsp_estatal_federal, reference, metric = "F1"), 2)          # 0.23
round(evaluate(changepoint_dlsp_estatal_federal, reference, metric = "accuracy"), 2)    # 0.66
round(evaluate(changepoint_dlsp_estatal_federal, reference, metric = "sensitivity"), 2) # 0.18
round(evaluate(changepoint_dlsp_estatal_federal, reference, metric = "specificity"), 2) # 0.84
round(evaluate(changepoint_dlsp_estatal_federal, reference, metric = "precision"), 2)   # 0.31
round(evaluate(changepoint_dlsp_estatal_federal, reference, metric = "recall"), 2)      # 0.18

#Plot
print(evtplot(test_dlsp_estatal_federal, changepoint_dlsp_estatal_federal, reference))

##### 7. dlsp_estatal_estadual #####
#Detect
changepoint_dlsp_estatal_estadual <- evtdet.seminalChangePoint2(test_dlsp_estatal_estadual, w = 30, 
                                                                mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_dlsp_estatal_estadual, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     12     24 
# FALSE    53     149  

round(evaluate(changepoint_dlsp_estatal_estadual, reference, metric = "F1"), 2)          # 0.24
round(evaluate(changepoint_dlsp_estatal_estadual, reference, metric = "accuracy"), 2)    # 0.68
round(evaluate(changepoint_dlsp_estatal_estadual, reference, metric = "sensitivity"), 2) # 0.18
round(evaluate(changepoint_dlsp_estatal_estadual, reference, metric = "specificity"), 2) # 0.86
round(evaluate(changepoint_dlsp_estatal_estadual, reference, metric = "precision"), 2)   # 0.33
round(evaluate(changepoint_dlsp_estatal_estadual, reference, metric = "recall"), 2)      # 0.18

#Plot
print(evtplot(test_dlsp_estatal_estadual, changepoint_dlsp_estatal_estadual, reference))

##### 8. dlsp_estatal_municipal #####
#Detect
changepoint_dlsp_estatal_municipal <- evtdet.seminalChangePoint2(test_dlsp_estatal_municipal, w = 30,
                                                                 mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_dlsp_estatal_municipal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     15     26 
# FALSE    50     147

round(evaluate(changepoint_dlsp_estatal_municipal, reference, metric = "F1"), 2)          # 0.28
round(evaluate(changepoint_dlsp_estatal_municipal, reference, metric = "accuracy"), 2)    # 0.68
round(evaluate(changepoint_dlsp_estatal_municipal, reference, metric = "sensitivity"), 2) # 0.23
round(evaluate(changepoint_dlsp_estatal_municipal, reference, metric = "specificity"), 2) # 0.85
round(evaluate(changepoint_dlsp_estatal_municipal, reference, metric = "precision"), 2)   # 0.37
round(evaluate(changepoint_dlsp_estatal_municipal, reference, metric = "recall"), 2)      # 0.23

#Plot
print(evtplot(test_dlsp_estatal_municipal, changepoint_dlsp_estatal_municipal, reference))

###############################
##### ChangeFinder (2005) #####
###############################

##### 1. dlsp #####
#Detect
changefinder_dlsp <- evtdet.changeFinder(test_dlsp, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_dlsp, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     1      1 
# FALSE    64     172

round(evaluate(changefinder_dlsp, reference, metric = "F1"), 2)          # 0.03
round(evaluate(changefinder_dlsp, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(changefinder_dlsp, reference, metric = "sensitivity"), 2) # 0.02
round(evaluate(changefinder_dlsp, reference, metric = "specificity"), 2) # 0.99
round(evaluate(changefinder_dlsp, reference, metric = "precision"), 2)   # 0.50
round(evaluate(changefinder_dlsp, reference, metric = "recall"), 2)      # 0.02

#Plot
print(evtplot(test_dlsp, changefinder_dlsp, reference))

##### 2. dlsp_gov_central #####
#Detect
changefinder_dlsp_gov_central <- evtdet.changeFinder(test_dlsp_gov_central, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_dlsp_gov_central, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     1      1 
# FALSE    64     172  

round(evaluate(changefinder_dlsp_gov_central, reference, metric = "F1"), 2)          # 0.03
round(evaluate(changefinder_dlsp_gov_central, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(changefinder_dlsp_gov_central, reference, metric = "sensitivity"), 2) # 0.02
round(evaluate(changefinder_dlsp_gov_central, reference, metric = "specificity"), 2) # 0.99
round(evaluate(changefinder_dlsp_gov_central, reference, metric = "precision"), 2)   # 0.50
round(evaluate(changefinder_dlsp_gov_central, reference, metric = "recall"), 2)      # 0.02

#Plot
print(evtplot(test_dlsp_gov_central, changefinder_dlsp_gov_central, reference))

##### 3. dlsp_gov_estadual #####
#Detect
changefinder_dlsp_gov_estadual <- evtdet.changeFinder(test_dlsp_gov_estadual, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_dlsp_gov_estadual, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     0      1 
# FALSE    65     172 

round(evaluate(changefinder_dlsp_gov_estadual, reference, metric = "F1"), 2)          # NaN
round(evaluate(changefinder_dlsp_gov_estadual, reference, metric = "accuracy"), 2)    # 0.72
round(evaluate(changefinder_dlsp_gov_estadual, reference, metric = "sensitivity"), 2) # 0.00
round(evaluate(changefinder_dlsp_gov_estadual, reference, metric = "specificity"), 2) # 0.99
round(evaluate(changefinder_dlsp_gov_estadual, reference, metric = "precision"), 2)   # 0.00
round(evaluate(changefinder_dlsp_gov_estadual, reference, metric = "recall"), 2)      # 0.00

#Plot
print(evtplot(test_dlsp_gov_estadual, changefinder_dlsp_gov_estadual, reference))

##### 4. dlsp_gov_municipal #####
#Detect
changefinder_dlsp_gov_municipal <- evtdet.changeFinder(test_dlsp_gov_municipal, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_dlsp_gov_municipal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     8      1  
# FALSE    57     172  

round(evaluate(changefinder_dlsp_gov_municipal, reference, metric = "F1"), 2)          # 0.22
round(evaluate(changefinder_dlsp_gov_municipal, reference, metric = "accuracy"), 2)    # 0.76
round(evaluate(changefinder_dlsp_gov_municipal, reference, metric = "sensitivity"), 2) # 0.12
round(evaluate(changefinder_dlsp_gov_municipal, reference, metric = "specificity"), 2) # 0.99
round(evaluate(changefinder_dlsp_gov_municipal, reference, metric = "precision"), 2)   # 0.89
round(evaluate(changefinder_dlsp_gov_municipal, reference, metric = "recall"), 2)      # 0.12

#Plot
print(evtplot(test_dlsp_gov_municipal, changefinder_dlsp_gov_municipal, reference))

##### 5. dlsp_estatal #####
#Detect
changefinder_dlsp_estatal <- evtdet.changeFinder(test_dlsp_estatal, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_dlsp_estatal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     4      11
# FALSE    61     162 

round(evaluate(changefinder_dlsp_estatal, reference, metric = "F1"), 2)          # 0.10
round(evaluate(changefinder_dlsp_estatal, reference, metric = "accuracy"), 2)    # 0.70
round(evaluate(changefinder_dlsp_estatal, reference, metric = "sensitivity"), 2) # 0.06
round(evaluate(changefinder_dlsp_estatal, reference, metric = "specificity"), 2) # 0.94
round(evaluate(changefinder_dlsp_estatal, reference, metric = "precision"), 2)   # 0.27
round(evaluate(changefinder_dlsp_estatal, reference, metric = "recall"), 2)      # 0.06

#Plot
print(evtplot(test_dlsp_estatal, changefinder_dlsp_estatal, reference))

##### 6. dlsp_estatal_federal #####
#Detect
changefinder_dlsp_estatal_federal <- evtdet.changeFinder(test_dlsp_estatal_federal, mdl = linreg, 
                                                         na.action = na.omit)

#Evaluate
evaluate(changefinder_dlsp_estatal_federal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     0      2   
# FALSE    65     171 

round(evaluate(changefinder_dlsp_estatal_federal, reference, metric = "F1"), 2)          # NaN
round(evaluate(changefinder_dlsp_estatal_federal, reference, metric = "accuracy"), 2)    # 0.72
round(evaluate(changefinder_dlsp_estatal_federal, reference, metric = "sensitivity"), 2) # 0.00
round(evaluate(changefinder_dlsp_estatal_federal, reference, metric = "specificity"), 2) # 0.99
round(evaluate(changefinder_dlsp_estatal_federal, reference, metric = "precision"), 2)   # 0.00
round(evaluate(changefinder_dlsp_estatal_federal, reference, metric = "recall"), 2)      # 0.00

#Plot
print(evtplot(test_dlsp_estatal_federal, changefinder_dlsp_estatal_federal, reference))

##### 7. dlsp_estatal_estadual #####
#Detect
changefinder_dlsp_estatal_estadual <- evtdet.changeFinder(test_dlsp_estatal_estadual, mdl = linreg, 
                                                          na.action = na.omit)

#Evaluate
evaluate(changefinder_dlsp_estatal_estadual, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     3      5  
# FALSE    62     168

round(evaluate(changefinder_dlsp_estatal_estadual, reference, metric = "F1"), 2)          # 0.08
round(evaluate(changefinder_dlsp_estatal_estadual, reference, metric = "accuracy"), 2)    # 0.72
round(evaluate(changefinder_dlsp_estatal_estadual, reference, metric = "sensitivity"), 2) # 0.05
round(evaluate(changefinder_dlsp_estatal_estadual, reference, metric = "specificity"), 2) # 0.97
round(evaluate(changefinder_dlsp_estatal_estadual, reference, metric = "precision"), 2)   # 0.38
round(evaluate(changefinder_dlsp_estatal_estadual, reference, metric = "recall"), 2)      # 0.05

#Plot
print(evtplot(test_dlsp_estatal_estadual, changefinder_dlsp_estatal_estadual, reference))

##### 8. dlsp_estatal_municipal #####
#Detect
changefinder_dlsp_estatal_municipal <- evtdet.changeFinder(test_dlsp_estatal_municipal, mdl = linreg, 
                                                           na.action = na.omit)

#Evaluate
evaluate(changefinder_dlsp_estatal_municipal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     1      1    
# FALSE    64     172

round(evaluate(changefinder_dlsp_estatal_municipal, reference, metric = "F1"), 2)          # 0.03
round(evaluate(changefinder_dlsp_estatal_municipal, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(changefinder_dlsp_estatal_municipal, reference, metric = "sensitivity"), 2) # 0.02
round(evaluate(changefinder_dlsp_estatal_municipal, reference, metric = "specificity"), 2) # 0.99
round(evaluate(changefinder_dlsp_estatal_municipal, reference, metric = "precision"), 2)   # 0.50
round(evaluate(changefinder_dlsp_estatal_municipal, reference, metric = "recall"), 2)      # 0.02

#Plot
print(evtplot(test_dlsp_estatal_municipal, changefinder_dlsp_estatal_municipal, reference))

