##########################################
##### Deteco de Eventos - Inflao #####
##########################################

################
##### Data #####
################

library(tibble)
library(EventDetectR)
source("https://raw.githubusercontent.com/cefet-rj-dal/harbinger/master/harbinger.R")

attach(df_inflation)
head(df_inflation)
str(df_inflation)

test_ipca <- subset(df_inflation, select = c(Data, ipca))
test_ipca_comida_bebida <- subset(df_inflation, select = c(Data, ipca_comida_bebida))
test_ipca_habitat <- subset(df_inflation, select = c(Data, ipca_habitat))
test_ipca_artigos_casa <- subset(df_inflation, select = c(Data, ipca_artigos_casa))
test_ipca_roupa <- subset(df_inflation, select = c(Data, ipca_roupa))
test_ipca_cumunicacao <- subset(df_inflation, select = c(Data, ipca_cumunicacao))
test_ipca_saude <- subset(df_inflation, select = c(Data, ipca_saude))
test_ipca_desp_pessoal <- subset(df_inflation, select = c(Data, ipca_desp_pessoal))
test_ipca_educacao <- subset(df_inflation, select = c(Data, ipca_educacao))
test_ipca_comercializavel <- subset(df_inflation, select = c(Data, ipca_comercializavel))
test_ipca_nao_comercializavel <- subset(df_inflation, select = c(Data, ipca_nao_comercializavel))
test_ipca_monitorado <- subset(df_inflation, select = c(Data, ipca_monitorado))
test_ipca_nao_duravel <- subset(df_inflation, select = c(Data, ipca_nao_duravel))
test_ipca_semi_duravel <- subset(df_inflation, select = c(Data, ipca_semi_duravel))
test_ipca_duravel <- subset(df_inflation, select = c(Data, ipca_duravel))
test_ipca_servico <- subset(df_inflation, select = c(Data, ipca_servico))
test_ipca_livre <- subset(df_inflation, select = c(Data, ipca_livre))
test_ipca_industrial <- subset(df_inflation, select = c(Data, ipca_industrial))
test_ipca_comida_casa <- subset(df_inflation, select = c(Data, ipca_comida_casa))
test_ipca_transporte <- subset(df_inflation, select = c(Data, ipca_transporte))
reference <- subset(df_inflation, select = c(Data, event))

#####################
##### Anomalize #####
#####################

##### 1. ipca #####
#Detect
anomalize_ipca <- evtdet.anomalize(test_ipca, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_ipca, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     6      7        
# FALSE    59     177  

round(evaluate(anomalize_ipca, reference, metric = "F1"), 2)          # 0.15
round(evaluate(anomalize_ipca, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(anomalize_ipca, reference, metric = "sensitivity"), 2) # 0.09
round(evaluate(anomalize_ipca, reference, metric = "specificity"), 2) # 0.96
round(evaluate(anomalize_ipca, reference, metric = "precision"), 2)   # 0.46
round(evaluate(anomalize_ipca, reference, metric = "recall"), 2)      # 0.09

#Plot
print(evtplot(test_ipca, anomalize_ipca, reference))

##### 2. ipca_comida_bebida #####
#Detect
anomalize_ipca_comida_bebida <- evtdet.anomalize(test_ipca_comida_bebida, alpha = 0.1, 
                                                 max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_ipca_comida_bebida, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     3      5      
# FALSE    62     179  

round(evaluate(anomalize_ipca_comida_bebida, reference, metric = "F1"), 2)          # 0.08
round(evaluate(anomalize_ipca_comida_bebida, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(anomalize_ipca_comida_bebida, reference, metric = "sensitivity"), 2) # 0.05
round(evaluate(anomalize_ipca_comida_bebida, reference, metric = "specificity"), 2) # 0.97
round(evaluate(anomalize_ipca_comida_bebida, reference, metric = "precision"), 2)   # 0.38
round(evaluate(anomalize_ipca_comida_bebida, reference, metric = "recall"), 2)      # 0.05

#Plot
print(evtplot(test_ipca_comida_bebida, anomalize_ipca_comida_bebida, reference))

##### 3. ipca_habitat #####
#Detect
anomalize_ipca_habitat <- evtdet.anomalize(test_ipca_habitat, alpha = 0.1, 
                                           max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_ipca_habitat, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     13     21    
# FALSE    52     163  

round(evaluate(anomalize_ipca_habitat, reference, metric = "F1"), 2)          # 0.26
round(evaluate(anomalize_ipca_habitat, reference, metric = "accuracy"), 2)    # 0.71
round(evaluate(anomalize_ipca_habitat, reference, metric = "sensitivity"), 2) # 0.20
round(evaluate(anomalize_ipca_habitat, reference, metric = "specificity"), 2) # 0.89
round(evaluate(anomalize_ipca_habitat, reference, metric = "precision"), 2)   # 0.38
round(evaluate(anomalize_ipca_habitat, reference, metric = "recall"), 2)      # 0.20

#Plot
print(evtplot(test_ipca_habitat, anomalize_ipca_habitat, reference))

##### 4. ipca_artigos_casa #####
#Detect
anomalize_ipca_artigos_casa <- evtdet.anomalize(test_ipca_artigos_casa, alpha = 0.1, 
                                                max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_ipca_artigos_casa, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     6      4
# FALSE    59     180  

round(evaluate(anomalize_ipca_artigos_casa, reference, metric = "F1"), 2)          # 0.16
round(evaluate(anomalize_ipca_artigos_casa, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(anomalize_ipca_artigos_casa, reference, metric = "sensitivity"), 2) # 0.09
round(evaluate(anomalize_ipca_artigos_casa, reference, metric = "specificity"), 2) # 0.98
round(evaluate(anomalize_ipca_artigos_casa, reference, metric = "precision"), 2)   # 0.60
round(evaluate(anomalize_ipca_artigos_casa, reference, metric = "recall"), 2)      # 0.09

#Plot
print(evtplot(test_ipca_artigos_casa, anomalize_ipca_artigos_casa, reference))

##### 5. ipca_roupa #####
#Detect
anomalize_ipca_roupa <- evtdet.anomalize(test_ipca_roupa, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_ipca_roupa, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     4      16  
# FALSE    61     168  

round(evaluate(anomalize_ipca_roupa, reference, metric = "F1"), 2)          # 0.09
round(evaluate(anomalize_ipca_roupa, reference, metric = "accuracy"), 2)    # 0.69
round(evaluate(anomalize_ipca_roupa, reference, metric = "sensitivity"), 2) # 0.06
round(evaluate(anomalize_ipca_roupa, reference, metric = "specificity"), 2) # 0.91
round(evaluate(anomalize_ipca_roupa, reference, metric = "precision"), 2)   # 0.20
round(evaluate(anomalize_ipca_roupa, reference, metric = "recall"), 2)      # 0.06

#Plot
print(evtplot(test_ipca_roupa, anomalize_ipca_roupa, reference))

##### 6. ipca_cumunicacao #####
#Detect
anomalize_ipca_cumunicacao <- evtdet.anomalize(test_ipca_cumunicacao, alpha = 0.1, 
                                               max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_ipca_cumunicacao, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     9      26
# FALSE    56     158 

round(evaluate(anomalize_ipca_cumunicacao, reference, metric = "F1"), 2)          # 0.18
round(evaluate(anomalize_ipca_cumunicacao, reference, metric = "accuracy"), 2)    # 0.67
round(evaluate(anomalize_ipca_cumunicacao, reference, metric = "sensitivity"), 2) # 0.14
round(evaluate(anomalize_ipca_cumunicacao, reference, metric = "specificity"), 2) # 0.86
round(evaluate(anomalize_ipca_cumunicacao, reference, metric = "precision"), 2)   # 0.26
round(evaluate(anomalize_ipca_cumunicacao, reference, metric = "recall"), 2)      # 0.14

#Plot
print(evtplot(test_ipca_cumunicacao, anomalize_ipca_cumunicacao, reference))

##### 7. ipca_saude #####
#Detect
anomalize_ipca_saude <- evtdet.anomalize(test_ipca_saude, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_ipca_saude, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     7      22 
# FALSE    58     162

round(evaluate(anomalize_ipca_saude, reference, metric = "F1"), 2)          # 0.15
round(evaluate(anomalize_ipca_saude, reference, metric = "accuracy"), 2)    # 0.68
round(evaluate(anomalize_ipca_saude, reference, metric = "sensitivity"), 2) # 0.11
round(evaluate(anomalize_ipca_saude, reference, metric = "specificity"), 2) # 0.88
round(evaluate(anomalize_ipca_saude, reference, metric = "precision"), 2)   # 0.24
round(evaluate(anomalize_ipca_saude, reference, metric = "recall"), 2)      # 0.11

#Plot
print(evtplot(test_ipca_saude, anomalize_ipca_saude, reference))

##### 8. ipca_desp_pessoal #####
#Detect
anomalize_ipca_desp_pessoal <- evtdet.anomalize(test_ipca_desp_pessoal, alpha = 0.1, 
                                                max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_ipca_desp_pessoal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     2      15   
# FALSE    63     169

round(evaluate(anomalize_ipca_desp_pessoal, reference, metric = "F1"), 2)          # 0.05
round(evaluate(anomalize_ipca_desp_pessoal, reference, metric = "accuracy"), 2)    # 0.69
round(evaluate(anomalize_ipca_desp_pessoal, reference, metric = "sensitivity"), 2) # 0.03
round(evaluate(anomalize_ipca_desp_pessoal, reference, metric = "specificity"), 2) # 0.92
round(evaluate(anomalize_ipca_desp_pessoal, reference, metric = "precision"), 2)   # 0.12
round(evaluate(anomalize_ipca_desp_pessoal, reference, metric = "recall"), 2)      # 0.03

#Plot
print(evtplot(test_ipca_desp_pessoal, anomalize_ipca_desp_pessoal, reference))

##### 9. ipca_educacao #####
#Detect
anomalize_ipca_educacao <- evtdet.anomalize(test_ipca_educacao, alpha = 0.1, 
                                            max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_ipca_educacao, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     13     26
# FALSE    52     158 

round(evaluate(anomalize_ipca_educacao, reference, metric = "F1"), 2)          # 0.25
round(evaluate(anomalize_ipca_educacao, reference, metric = "accuracy"), 2)    # 0.69
round(evaluate(anomalize_ipca_educacao, reference, metric = "sensitivity"), 2) # 0.20
round(evaluate(anomalize_ipca_educacao, reference, metric = "specificity"), 2) # 0.89
round(evaluate(anomalize_ipca_educacao, reference, metric = "precision"), 2)   # 0.33
round(evaluate(anomalize_ipca_educacao, reference, metric = "recall"), 2)      # 0.20

#Plot
print(evtplot(test_ipca_educacao, anomalize_ipca_educacao, reference))

##### 10. ipca_comercializavel #####
#Detect
anomalize_ipca_comercializavel <- evtdet.anomalize(test_ipca_comercializavel, alpha = 0.1, 
                                                   max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_ipca_comercializavel, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     4      7  
# FALSE    61     177 

round(evaluate(anomalize_ipca_comercializavel, reference, metric = "F1"), 2)          # 0.11
round(evaluate(anomalize_ipca_comercializavel, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(anomalize_ipca_comercializavel, reference, metric = "sensitivity"), 2) # 0.06
round(evaluate(anomalize_ipca_comercializavel, reference, metric = "specificity"), 2) # 0.96
round(evaluate(anomalize_ipca_comercializavel, reference, metric = "precision"), 2)   # 0.36
round(evaluate(anomalize_ipca_comercializavel, reference, metric = "recall"), 2)      # 0.06

#Plot
print(evtplot(test_ipca_comercializavel, anomalize_ipca_comercializavel, reference))

##### 11. ipca_nao_comercializavel #####
#Detect
anomalize_ipca_nao_comercializavel <- evtdet.anomalize(test_ipca_nao_comercializavel, alpha = 0.1, 
                                                       max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_ipca_nao_comercializavel, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     1      4       
# FALSE    64     180  

round(evaluate(anomalize_ipca_nao_comercializavel, reference, metric = "F1"), 2)          # 0.03
round(evaluate(anomalize_ipca_nao_comercializavel, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(anomalize_ipca_nao_comercializavel, reference, metric = "sensitivity"), 2) # 0.02
round(evaluate(anomalize_ipca_nao_comercializavel, reference, metric = "specificity"), 2) # 0.98
round(evaluate(anomalize_ipca_nao_comercializavel, reference, metric = "precision"), 2)   # 0.20
round(evaluate(anomalize_ipca_nao_comercializavel, reference, metric = "recall"), 2)      # 0.02

#Plot
print(evtplot(test_ipca_nao_comercializavel, anomalize_ipca_nao_comercializavel, reference))

##### 12. ipca_monitorado #####
#Detect
anomalize_ipca_monitorado <- evtdet.anomalize(test_ipca_monitorado, alpha = 0.1,
                                              max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_ipca_monitorado, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     9      15      
# FALSE    56     169 

round(evaluate(anomalize_ipca_monitorado, reference, metric = "F1"), 2)          # 0.20
round(evaluate(anomalize_ipca_monitorado, reference, metric = "accuracy"), 2)    # 0.71
round(evaluate(anomalize_ipca_monitorado, reference, metric = "sensitivity"), 2) # 0.14
round(evaluate(anomalize_ipca_monitorado, reference, metric = "specificity"), 2) # 0.92
round(evaluate(anomalize_ipca_monitorado, reference, metric = "precision"), 2)   # 0.38
round(evaluate(anomalize_ipca_monitorado, reference, metric = "recall"), 2)      # 0.14

#Plot
print(evtplot(test_ipca_monitorado, anomalize_ipca_monitorado, reference))

##### 13. ipca_nao_duravel #####
#Detect
anomalize_ipca_nao_duravel <- evtdet.anomalize(test_ipca_nao_duravel, alpha = 0.1,
                                               max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_ipca_nao_duravel, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     5      5    
# FALSE    60     179  

round(evaluate(anomalize_ipca_nao_duravel, reference, metric = "F1"), 2)          # 0.13
round(evaluate(anomalize_ipca_nao_duravel, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(anomalize_ipca_nao_duravel, reference, metric = "sensitivity"), 2) # 0.08
round(evaluate(anomalize_ipca_nao_duravel, reference, metric = "specificity"), 2) # 0.97
round(evaluate(anomalize_ipca_nao_duravel, reference, metric = "precision"), 2)   # 0.50
round(evaluate(anomalize_ipca_nao_duravel, reference, metric = "recall"), 2)      # 0.08

#Plot
print(evtplot(test_ipca_nao_duravel, anomalize_ipca_nao_duravel, reference))

##### 14. ipca_semi_duravel #####
#Detect
anomalize_ipca_semi_duravel <- evtdet.anomalize(test_ipca_semi_duravel, alpha = 0.1,
                                                max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_ipca_semi_duravel, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     7      13   
# FALSE    58     171  

round(evaluate(anomalize_ipca_semi_duravel, reference, metric = "F1"), 2)          # 0.16
round(evaluate(anomalize_ipca_semi_duravel, reference, metric = "accuracy"), 2)    # 0.71
round(evaluate(anomalize_ipca_semi_duravel, reference, metric = "sensitivity"), 2) # 0.11
round(evaluate(anomalize_ipca_semi_duravel, reference, metric = "specificity"), 2) # 0.93
round(evaluate(anomalize_ipca_semi_duravel, reference, metric = "precision"), 2)   # 0.35
round(evaluate(anomalize_ipca_semi_duravel, reference, metric = "recall"), 2)      # 0.11

#Plot
print(evtplot(test_ipca_semi_duravel, anomalize_ipca_semi_duravel, reference))

##### 15. ipca_duravel #####
#Detect
anomalize_ipca_duravel <- evtdet.anomalize(test_ipca_duravel, alpha = 0.1,
                                           max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_ipca_duravel, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     4      3   
# FALSE    61     181    

round(evaluate(anomalize_ipca_duravel, reference, metric = "F1"), 2)          # 0.11
round(evaluate(anomalize_ipca_duravel, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(anomalize_ipca_duravel, reference, metric = "sensitivity"), 2) # 0.06
round(evaluate(anomalize_ipca_duravel, reference, metric = "specificity"), 2) # 0.98
round(evaluate(anomalize_ipca_duravel, reference, metric = "precision"), 2)   # 0.57
round(evaluate(anomalize_ipca_duravel, reference, metric = "recall"), 2)      # 0.06

#Plot
print(evtplot(test_ipca_duravel, anomalize_ipca_duravel, reference))

##### 16. ipca_servico #####
#Detect
anomalize_ipca_servico <- evtdet.anomalize(test_ipca_servico, alpha = 0.1,
                                           max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_ipca_servico, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     3      6  
# FALSE    62     178  

round(evaluate(anomalize_ipca_servico, reference, metric = "F1"), 2)          # 0.08
round(evaluate(anomalize_ipca_servico, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(anomalize_ipca_servico, reference, metric = "sensitivity"), 2) # 0.05
round(evaluate(anomalize_ipca_servico, reference, metric = "specificity"), 2) # 0.97
round(evaluate(anomalize_ipca_servico, reference, metric = "precision"), 2)   # 0.33
round(evaluate(anomalize_ipca_servico, reference, metric = "recall"), 2)      # 0.05

#Plot
print(evtplot(test_ipca_servico, anomalize_ipca_servico, reference))

##### 17. ipca_livre #####
#Detect
anomalize_ipca_livre <- evtdet.anomalize(test_ipca_livre, alpha = 0.1,
                                         max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_ipca_livre, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     3      6    
# FALSE    62     178   

round(evaluate(anomalize_ipca_livre, reference, metric = "F1"), 2)          # 0.08
round(evaluate(anomalize_ipca_livre, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(anomalize_ipca_livre, reference, metric = "sensitivity"), 2) # 0.05
round(evaluate(anomalize_ipca_livre, reference, metric = "specificity"), 2) # 0.97
round(evaluate(anomalize_ipca_livre, reference, metric = "precision"), 2)   # 0.33
round(evaluate(anomalize_ipca_livre, reference, metric = "recall"), 2)      # 0.05

#Plot
print(evtplot(test_ipca_livre, anomalize_ipca_livre, reference))

##### 18. ipca_industrial #####
#Detect
anomalize_ipca_industrial <- evtdet.anomalize(test_ipca_industrial, alpha = 0.1,
                                              max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_ipca_industrial, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     5      10
# FALSE    60     174  

round(evaluate(anomalize_ipca_industrial, reference, metric = "F1"), 2)          # 0.12
round(evaluate(anomalize_ipca_industrial, reference, metric = "accuracy"), 2)    # 0.72
round(evaluate(anomalize_ipca_industrial, reference, metric = "sensitivity"), 2) # 0.08
round(evaluate(anomalize_ipca_industrial, reference, metric = "specificity"), 2) # 0.95
round(evaluate(anomalize_ipca_industrial, reference, metric = "precision"), 2)   # 0.33
round(evaluate(anomalize_ipca_industrial, reference, metric = "recall"), 2)      # 0.08

#Plot
print(evtplot(test_ipca_industrial, anomalize_ipca_industrial, reference))

##### 19. ipca_comida_casa #####
#Detect
anomalize_ipca_comida_casa <- evtdet.anomalize(test_ipca_comida_casa, alpha = 0.1,
                                               max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_ipca_comida_casa, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     2      5
# FALSE    63     179   

round(evaluate(anomalize_ipca_comida_casa, reference, metric = "F1"), 2)          # 0.06
round(evaluate(anomalize_ipca_comida_casa, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(anomalize_ipca_comida_casa, reference, metric = "sensitivity"), 2) # 0.03
round(evaluate(anomalize_ipca_comida_casa, reference, metric = "specificity"), 2) # 0.97
round(evaluate(anomalize_ipca_comida_casa, reference, metric = "precision"), 2)   # 0.29
round(evaluate(anomalize_ipca_comida_casa, reference, metric = "recall"), 2)      # 0.03

#Plot
print(evtplot(test_ipca_comida_casa, anomalize_ipca_comida_casa, reference))

##### 20. ipca_transporte #####
#Detect
anomalize_ipca_transporte <- evtdet.anomalize(test_ipca_transporte, alpha = 0.1,
                                              max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_ipca_transporte, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     4      16   
# FALSE    61     168     

round(evaluate(anomalize_ipca_transporte, reference, metric = "F1"), 2)          # 0.09
round(evaluate(anomalize_ipca_transporte, reference, metric = "accuracy"), 2)    # 0.69
round(evaluate(anomalize_ipca_transporte, reference, metric = "sensitivity"), 2) # 0.06
round(evaluate(anomalize_ipca_transporte, reference, metric = "specificity"), 2) # 0.91
round(evaluate(anomalize_ipca_transporte, reference, metric = "precision"), 2)   # 0.20
round(evaluate(anomalize_ipca_transporte, reference, metric = "recall"), 2)      # 0.06

#Plot
print(evtplot(test_ipca_transporte, anomalize_ipca_transporte, reference))

###########################################
##### Adaptive Normalization Outliers #####
###########################################

##### 1. ipca #####
#Detect
an_ipca <- evtdet.an_outliers(test_ipca, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_ipca, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     5      6  
# FALSE    60     178  

round(evaluate(an_ipca, reference, metric = "F1"), 2)          # 0.13
round(evaluate(an_ipca, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(an_ipca, reference, metric = "sensitivity"), 2) # 0.08
round(evaluate(an_ipca, reference, metric = "specificity"), 2) # 0.97
round(evaluate(an_ipca, reference, metric = "precision"), 2)   # 0.45
round(evaluate(an_ipca, reference, metric = "recall"), 2)      # 0.08

#Plot
print(evtplot(test_ipca, an_ipca, reference))

##### 2. ipca_comida_bebida #####
#Detect
an_ipca_comida_bebida <- evtdet.an_outliers(test_ipca_comida_bebida, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_ipca_comida_bebida, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     4      5 
# FALSE    61     179 

round(evaluate(an_ipca_comida_bebida, reference, metric = "F1"), 2)          # 0.11
round(evaluate(an_ipca_comida_bebida, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(an_ipca_comida_bebida, reference, metric = "sensitivity"), 2) # 0.06
round(evaluate(an_ipca_comida_bebida, reference, metric = "specificity"), 2) # 0.97
round(evaluate(an_ipca_comida_bebida, reference, metric = "precision"), 2)   # 0.44
round(evaluate(an_ipca_comida_bebida, reference, metric = "recall"), 2)      # 0.06

#Plot
print(evtplot(test_ipca_comida_bebida, an_ipca_comida_bebida, reference))

##### 3. ipca_habitat #####
#Detect
an_ipca_habitat <- evtdet.an_outliers(test_ipca_habitat, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_ipca_habitat, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     14     21 
# FALSE    51     163  

round(evaluate(an_ipca_habitat, reference, metric = "F1"), 2)          # 0.28
round(evaluate(an_ipca_habitat, reference, metric = "accuracy"), 2)    # 0.71
round(evaluate(an_ipca_habitat, reference, metric = "sensitivity"), 2) # 0.22
round(evaluate(an_ipca_habitat, reference, metric = "specificity"), 2) # 0.89
round(evaluate(an_ipca_habitat, reference, metric = "precision"), 2)   # 0.40
round(evaluate(an_ipca_habitat, reference, metric = "recall"), 2)      # 0.22

#Plot
print(evtplot(test_ipca_habitat, an_ipca_habitat, reference))

##### 4. ipca_artigos_casa #####
#Detect
an_ipca_artigos_casa <- evtdet.an_outliers(test_ipca_artigos_casa, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_ipca_artigos_casa, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     5      4    
# FALSE    60     180  

round(evaluate(an_ipca_artigos_casa, reference, metric = "F1"), 2)          # 0.14
round(evaluate(an_ipca_artigos_casa, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(an_ipca_artigos_casa, reference, metric = "sensitivity"), 2) # 0.08
round(evaluate(an_ipca_artigos_casa, reference, metric = "specificity"), 2) # 0.98
round(evaluate(an_ipca_artigos_casa, reference, metric = "precision"), 2)   # 0.56
round(evaluate(an_ipca_artigos_casa, reference, metric = "recall"), 2)      # 0.08

#Plot
print(evtplot(test_ipca_artigos_casa, an_ipca_artigos_casa, reference))

##### 5. ipca_roupa #####
#Detect
an_ipca_roupa <- evtdet.an_outliers(test_ipca_roupa, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_ipca_roupa, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     4      8    
# FALSE    61     176  

round(evaluate(an_ipca_roupa, reference, metric = "F1"), 2)          # 0.10
round(evaluate(an_ipca_roupa, reference, metric = "accuracy"), 2)    # 0.72
round(evaluate(an_ipca_roupa, reference, metric = "sensitivity"), 2) # 0.06
round(evaluate(an_ipca_roupa, reference, metric = "specificity"), 2) # 0.96
round(evaluate(an_ipca_roupa, reference, metric = "precision"), 2)   # 0.33
round(evaluate(an_ipca_roupa, reference, metric = "recall"), 2)      # 0.06

#Plot
print(evtplot(test_ipca_roupa, an_ipca_roupa, reference))

##### 6. ipca_cumunicacao #####
#Detect
an_ipca_cumunicacao <- evtdet.an_outliers(test_ipca_cumunicacao, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_ipca_cumunicacao, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     12     52  
# FALSE    53     132 

round(evaluate(an_ipca_cumunicacao, reference, metric = "F1"), 2)          # 0.19
round(evaluate(an_ipca_cumunicacao, reference, metric = "accuracy"), 2)    # 0.58
round(evaluate(an_ipca_cumunicacao, reference, metric = "sensitivity"), 2) # 0.18
round(evaluate(an_ipca_cumunicacao, reference, metric = "specificity"), 2) # 0.72
round(evaluate(an_ipca_cumunicacao, reference, metric = "precision"), 2)   # 0.19
round(evaluate(an_ipca_cumunicacao, reference, metric = "recall"), 2)      # 0.18

#Plot
print(evtplot(test_ipca_cumunicacao, an_ipca_cumunicacao, reference))

##### 7. ipca_saude #####
#Detect
an_ipca_saude <- evtdet.an_outliers(test_ipca_saude, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_ipca_saude, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     5      20 
# FALSE    60     164    

round(evaluate(an_ipca_saude, reference, metric = "F1"), 2)          # 0.11
round(evaluate(an_ipca_saude, reference, metric = "accuracy"), 2)    # 0.68
round(evaluate(an_ipca_saude, reference, metric = "sensitivity"), 2) # 0.08
round(evaluate(an_ipca_saude, reference, metric = "specificity"), 2) # 0.89
round(evaluate(an_ipca_saude, reference, metric = "precision"), 2)   # 0.20
round(evaluate(an_ipca_saude, reference, metric = "recall"), 2)      # 0.08

#Plot
print(evtplot(test_ipca_saude, an_ipca_saude, reference))

##### 8. ipca_desp_pessoal #####
#Detect
an_ipca_desp_pessoal <- evtdet.an_outliers(test_ipca_desp_pessoal, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_ipca_desp_pessoal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     4      15   
# FALSE    61     169  

round(evaluate(an_ipca_desp_pessoal, reference, metric = "F1"), 2)          # 0.10
round(evaluate(an_ipca_desp_pessoal, reference, metric = "accuracy"), 2)    # 0.69
round(evaluate(an_ipca_desp_pessoal, reference, metric = "sensitivity"), 2) # 0.06
round(evaluate(an_ipca_desp_pessoal, reference, metric = "specificity"), 2) # 0.92
round(evaluate(an_ipca_desp_pessoal, reference, metric = "precision"), 2)   # 0.21
round(evaluate(an_ipca_desp_pessoal, reference, metric = "recall"), 2)      # 0.06

#Plot
print(evtplot(test_ipca_desp_pessoal, an_ipca_desp_pessoal, reference))

##### 9. ipca_educacao #####
#Detect
an_ipca_educacao <- evtdet.an_outliers(test_ipca_educacao, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_ipca_educacao, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     9      18 
# FALSE    56     166  

round(evaluate(an_ipca_educacao, reference, metric = "F1"), 2)          # 0.20
round(evaluate(an_ipca_educacao, reference, metric = "accuracy"), 2)    # 0.70
round(evaluate(an_ipca_educacao, reference, metric = "sensitivity"), 2) # 0.14
round(evaluate(an_ipca_educacao, reference, metric = "specificity"), 2) # 0.90
round(evaluate(an_ipca_educacao, reference, metric = "precision"), 2)   # 0.33
round(evaluate(an_ipca_educacao, reference, metric = "recall"), 2)      # 0.14

#Plot
print(evtplot(test_ipca_educacao, an_ipca_educacao, reference))

##### 10. ipca_comercializavel #####
#Detect
an_ipca_comercializavel <- evtdet.an_outliers(test_ipca_comercializavel, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_ipca_comercializavel, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     5      7 
# FALSE    60     177  

round(evaluate(an_ipca_comercializavel, reference, metric = "F1"), 2)          # 0.13
round(evaluate(an_ipca_comercializavel, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(an_ipca_comercializavel, reference, metric = "sensitivity"), 2) # 0.08
round(evaluate(an_ipca_comercializavel, reference, metric = "specificity"), 2) # 0.96
round(evaluate(an_ipca_comercializavel, reference, metric = "precision"), 2)   # 0.42
round(evaluate(an_ipca_comercializavel, reference, metric = "recall"), 2)      # 0.08

#Plot
print(evtplot(test_ipca_comercializavel, an_ipca_comercializavel, reference))

##### 11. ipca_nao_comercializavel #####
#Detect
an_ipca_nao_comercializavel <- evtdet.an_outliers(test_ipca_nao_comercializavel, w = 30, alpha = 1.5, 
                                                  na.action = na.omit)

#Evaluate
evaluate(an_ipca_nao_comercializavel, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     1      4      
# FALSE    64     180  

round(evaluate(an_ipca_nao_comercializavel, reference, metric = "F1"), 2)          # 0.03
round(evaluate(an_ipca_nao_comercializavel, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(an_ipca_nao_comercializavel, reference, metric = "sensitivity"), 2) # 0.02
round(evaluate(an_ipca_nao_comercializavel, reference, metric = "specificity"), 2) # 0.98
round(evaluate(an_ipca_nao_comercializavel, reference, metric = "precision"), 2)   # 0.20
round(evaluate(an_ipca_nao_comercializavel, reference, metric = "recall"), 2)      # 0.02

#Plot
print(evtplot(test_ipca_nao_comercializavel, an_ipca_nao_comercializavel, reference))

##### 12. ipca_monitorado #####
#Detect
an_ipca_monitorado <- evtdet.an_outliers(test_ipca_monitorado, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_ipca_monitorado, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     9      18  
# FALSE    56     166   

round(evaluate(an_ipca_monitorado, reference, metric = "F1"), 2)          # 0.20
round(evaluate(an_ipca_monitorado, reference, metric = "accuracy"), 2)    # 0.70
round(evaluate(an_ipca_monitorado, reference, metric = "sensitivity"), 2) # 0.14
round(evaluate(an_ipca_monitorado, reference, metric = "specificity"), 2) # 0.90
round(evaluate(an_ipca_monitorado, reference, metric = "precision"), 2)   # 0.33
round(evaluate(an_ipca_monitorado, reference, metric = "recall"), 2)      # 0.14

#Plot
print(evtplot(test_ipca_monitorado, an_ipca_monitorado, reference))

##### 13. ipca_nao_duravel #####
#Detect
an_ipca_nao_duravel <- evtdet.an_outliers(test_ipca_nao_duravel, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_ipca_nao_duravel, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     5      5  
# FALSE    60     179    

round(evaluate(an_ipca_nao_duravel, reference, metric = "F1"), 2)          # 0.13
round(evaluate(an_ipca_nao_duravel, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(an_ipca_nao_duravel, reference, metric = "sensitivity"), 2) # 0.08
round(evaluate(an_ipca_nao_duravel, reference, metric = "specificity"), 2) # 0.97
round(evaluate(an_ipca_nao_duravel, reference, metric = "precision"), 2)   # 0.50
round(evaluate(an_ipca_nao_duravel, reference, metric = "recall"), 2)      # 0.08

#Plot
print(evtplot(test_ipca_nao_duravel, an_ipca_nao_duravel, reference))

##### 14. ipca_semi_duravel #####
#Detect
an_ipca_semi_duravel <- evtdet.an_outliers(test_ipca_semi_duravel, w = 30, alpha = 1.5, na.action = na.omit)

#Error in data.frame(..., check.names = FALSE) : 
#  arguments imply differing number of rows: 0, 1 

#Evaluate
evaluate(an_ipca_semi_duravel, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE    

round(evaluate(an_ipca_semi_duravel, reference, metric = "F1"), 2)          # 
round(evaluate(an_ipca_semi_duravel, reference, metric = "accuracy"), 2)    # 
round(evaluate(an_ipca_semi_duravel, reference, metric = "sensitivity"), 2) # 
round(evaluate(an_ipca_semi_duravel, reference, metric = "specificity"), 2) # 
round(evaluate(an_ipca_semi_duravel, reference, metric = "precision"), 2)   # 
round(evaluate(an_ipca_semi_duravel, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_ipca_semi_duravel, an_ipca_semi_duravel, reference))

##### 15. ipca_duravel #####
#Detect
an_ipca_duravel <- evtdet.an_outliers(test_ipca_duravel, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_ipca_duravel, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     1      2
# FALSE    64     182 

round(evaluate(an_ipca_duravel, reference, metric = "F1"), 2)          # 0.03
round(evaluate(an_ipca_duravel, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(an_ipca_duravel, reference, metric = "sensitivity"), 2) # 0.02
round(evaluate(an_ipca_duravel, reference, metric = "specificity"), 2) # 0.99
round(evaluate(an_ipca_duravel, reference, metric = "precision"), 2)   # 0.33
round(evaluate(an_ipca_duravel, reference, metric = "recall"), 2)      # 0.02

#Plot
print(evtplot(test_ipca_duravel, an_ipca_duravel, reference))

##### 16. ipca_servico #####
#Detect
an_ipca_servico <- evtdet.an_outliers(test_ipca_servico, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_ipca_servico, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     7      12  
# FALSE    58     172 

round(evaluate(an_ipca_servico, reference, metric = "F1"), 2)          # 0.17
round(evaluate(an_ipca_servico, reference, metric = "accuracy"), 2)    # 0.72
round(evaluate(an_ipca_servico, reference, metric = "sensitivity"), 2) # 0.11
round(evaluate(an_ipca_servico, reference, metric = "specificity"), 2) # 0.93
round(evaluate(an_ipca_servico, reference, metric = "precision"), 2)   # 0.37
round(evaluate(an_ipca_servico, reference, metric = "recall"), 2)      # 0.11

#Plot
print(evtplot(test_ipca_servico, an_ipca_servico, reference))

##### 17. ipca_livre #####
#Detect
an_ipca_livre <- evtdet.an_outliers(test_ipca_livre, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_ipca_livre, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     3      3 
# FALSE    62     181

round(evaluate(an_ipca_livre, reference, metric = "F1"), 2)          # 0.08
round(evaluate(an_ipca_livre, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(an_ipca_livre, reference, metric = "sensitivity"), 2) # 0.05
round(evaluate(an_ipca_livre, reference, metric = "specificity"), 2) # 0.98
round(evaluate(an_ipca_livre, reference, metric = "precision"), 2)   # 0.50
round(evaluate(an_ipca_livre, reference, metric = "recall"), 2)      # 0.05

#Plot
print(evtplot(test_ipca_livre, an_ipca_livre, reference))

##### 18. ipca_industrial #####
#Detect
an_ipca_industrial <- evtdet.an_outliers(test_ipca_industrial, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_ipca_industrial, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     4      7   
# FALSE    61     177

round(evaluate(an_ipca_industrial, reference, metric = "F1"), 2)          # 0.11
round(evaluate(an_ipca_industrial, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(an_ipca_industrial, reference, metric = "sensitivity"), 2) # 0.06
round(evaluate(an_ipca_industrial, reference, metric = "specificity"), 2) # 0.96
round(evaluate(an_ipca_industrial, reference, metric = "precision"), 2)   # 0.36
round(evaluate(an_ipca_industrial, reference, metric = "recall"), 2)      # 0.06

#Plot
print(evtplot(test_ipca_industrial, an_ipca_industrial, reference))

##### 19. ipca_comida_casa #####
#Detect
an_ipca_comida_casa <- evtdet.an_outliers(test_ipca_comida_casa, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_ipca_comida_casa, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     3      3   
# FALSE    62     181  

round(evaluate(an_ipca_comida_casa, reference, metric = "F1"), 2)          # 0.08
round(evaluate(an_ipca_comida_casa, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(an_ipca_comida_casa, reference, metric = "sensitivity"), 2) # 0.05
round(evaluate(an_ipca_comida_casa, reference, metric = "specificity"), 2) # 0.98
round(evaluate(an_ipca_comida_casa, reference, metric = "precision"), 2)   # 0.50
round(evaluate(an_ipca_comida_casa, reference, metric = "recall"), 2)      # 0.05

#Plot
print(evtplot(test_ipca_comida_casa, an_ipca_comida_casa, reference))

##### 20. ipca_transporte #####
#Detect
an_ipca_transporte <- evtdet.an_outliers(test_ipca_transporte, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_ipca_transporte, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     4      8
# FALSE    61     176  

round(evaluate(an_ipca_transporte, reference, metric = "F1"), 2)          # 0.10
round(evaluate(an_ipca_transporte, reference, metric = "accuracy"), 2)    # 0.72
round(evaluate(an_ipca_transporte, reference, metric = "sensitivity"), 2) # 0.06
round(evaluate(an_ipca_transporte, reference, metric = "specificity"), 2) # 0.96
round(evaluate(an_ipca_transporte, reference, metric = "precision"), 2)   # 0.33
round(evaluate(an_ipca_transporte, reference, metric = "recall"), 2)      # 0.06

#Plot
print(evtplot(test_ipca_transporte, an_ipca_transporte, reference))

#######################
##### EventDetect #####
#######################

##### 1. ipca #####
#Detect
eventdetect_ipca <- evtdet.eventdetect(na.omit(test_ipca), w = 30)

#Evaluate
evaluate(eventdetect_ipca, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     14     13     
# FALSE    51     171 

round(evaluate(eventdetect_ipca, reference, metric = "F1"), 2)          # 0.30
round(evaluate(eventdetect_ipca, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(eventdetect_ipca, reference, metric = "sensitivity"), 2) # 0.22
round(evaluate(eventdetect_ipca, reference, metric = "specificity"), 2) # 0.93
round(evaluate(eventdetect_ipca, reference, metric = "precision"), 2)   # 0.52
round(evaluate(eventdetect_ipca, reference, metric = "recall"), 2)      # 0.22

#Plot
print(evtplot(test_ipca, eventdetect_ipca, reference))

##### 2. ipca_comida_bebida #####
#Detect
eventdetect_ipca_comida_bebida <- evtdet.eventdetect(na.omit(test_ipca_comida_bebida), w = 30)

#Error in data.frame(..., check.names = FALSE) : 
#  arguments imply differing number of rows: 0, 1

#Evaluate
evaluate(eventdetect_ipca_comida_bebida, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE        
# FALSE       

round(evaluate(eventdetect_ipca_comida_bebida, reference, metric = "F1"), 2)          # 
round(evaluate(eventdetect_ipca_comida_bebida, reference, metric = "accuracy"), 2)    # 
round(evaluate(eventdetect_ipca_comida_bebida, reference, metric = "sensitivity"), 2) # 
round(evaluate(eventdetect_ipca_comida_bebida, reference, metric = "specificity"), 2) # 
round(evaluate(eventdetect_ipca_comida_bebida, reference, metric = "precision"), 2)   # 
round(evaluate(eventdetect_ipca_comida_bebida, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_ipca_comida_bebida, eventdetect_ipca_comida_bebida, reference))

##### 3. ipca_habitat #####
#Detect
eventdetect_ipca_habitat <- evtdet.eventdetect(na.omit(test_ipca_habitat), w = 30)

#Error in data.frame(..., check.names = FALSE) : 
#  arguments imply differing number of rows: 0, 1

#Evaluate
evaluate(eventdetect_ipca_habitat, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE       

round(evaluate(eventdetect_ipca_habitat, reference, metric = "F1"), 2)          # 
round(evaluate(eventdetect_ipca_habitat, reference, metric = "accuracy"), 2)    # 
round(evaluate(eventdetect_ipca_habitat, reference, metric = "sensitivity"), 2) # 
round(evaluate(eventdetect_ipca_habitat, reference, metric = "specificity"), 2) # 
round(evaluate(eventdetect_ipca_habitat, reference, metric = "precision"), 2)   # 
round(evaluate(eventdetect_ipca_habitat, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_ipca_habitat, eventdetect_ipca_habitat, reference))

##### 4. ipca_artigos_casa #####
#Detect
eventdetect_ipca_artigos_casa <- evtdet.eventdetect(na.omit(test_ipca_artigos_casa), w = 30)

#Error in data.frame(..., check.names = FALSE) : 
#  arguments imply differing number of rows: 0, 1

#Evaluate
evaluate(eventdetect_ipca_artigos_casa, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE     

round(evaluate(eventdetect_ipca_artigos_casa, reference, metric = "F1"), 2)          # 
round(evaluate(eventdetect_ipca_artigos_casa, reference, metric = "accuracy"), 2)    # 
round(evaluate(eventdetect_ipca_artigos_casa, reference, metric = "sensitivity"), 2) # 
round(evaluate(eventdetect_ipca_artigos_casa, reference, metric = "specificity"), 2) # 
round(evaluate(eventdetect_ipca_artigos_casa, reference, metric = "precision"), 2)   # 
round(evaluate(eventdetect_ipca_artigos_casa, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_ipca_artigos_casa, eventdetect_ipca_artigos_casa, reference))

##### 5. ipca_roupa #####
#Detect
eventdetect_ipca_roupa <- evtdet.eventdetect(na.omit(test_ipca_roupa), w = 30)

#Error in data.frame(..., check.names = FALSE) : 
#  arguments imply differing number of rows: 0, 1

#Evaluate
evaluate(eventdetect_ipca_roupa, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE    

round(evaluate(eventdetect_ipca_roupa, reference, metric = "F1"), 2)          # 
round(evaluate(eventdetect_ipca_roupa, reference, metric = "accuracy"), 2)    # 
round(evaluate(eventdetect_ipca_roupa, reference, metric = "sensitivity"), 2) # 
round(evaluate(eventdetect_ipca_roupa, reference, metric = "specificity"), 2) # 
round(evaluate(eventdetect_ipca_roupa, reference, metric = "precision"), 2)   # 
round(evaluate(eventdetect_ipca_roupa, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_ipca_roupa, eventdetect_ipca_roupa, reference))

##### 6. ipca_cumunicacao #####
#Detect
eventdetect_ipca_cumunicacao <- evtdet.eventdetect(na.omit(test_ipca_cumunicacao), w = 30)

#Error in data.frame(..., check.names = FALSE) : 
#  arguments imply differing number of rows: 0, 1

#Evaluate
evaluate(eventdetect_ipca_cumunicacao, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE      
# FALSE    

round(evaluate(eventdetect_ipca_cumunicacao, reference, metric = "F1"), 2)          # 
round(evaluate(eventdetect_ipca_cumunicacao, reference, metric = "accuracy"), 2)    # 
round(evaluate(eventdetect_ipca_cumunicacao, reference, metric = "sensitivity"), 2) # 
round(evaluate(eventdetect_ipca_cumunicacao, reference, metric = "specificity"), 2) # 
round(evaluate(eventdetect_ipca_cumunicacao, reference, metric = "precision"), 2)   # 
round(evaluate(eventdetect_ipca_cumunicacao, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_ipca_cumunicacao, eventdetect_ipca_cumunicacao, reference))

##### 7. ipca_saude #####
#Detect
eventdetect_ipca_saude <- evtdet.eventdetect(na.omit(test_ipca_saude), w = 30)

#Error in data.frame(..., check.names = FALSE) : 
#  arguments imply differing number of rows: 0, 1

#Evaluate
evaluate(eventdetect_ipca_saude, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE      

round(evaluate(eventdetect_ipca_saude, reference, metric = "F1"), 2)          # 
round(evaluate(eventdetect_ipca_saude, reference, metric = "accuracy"), 2)    # 
round(evaluate(eventdetect_ipca_saude, reference, metric = "sensitivity"), 2) # 
round(evaluate(eventdetect_ipca_saude, reference, metric = "specificity"), 2) # 
round(evaluate(eventdetect_ipca_saude, reference, metric = "precision"), 2)   # 
round(evaluate(eventdetect_ipca_saude, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_ipca_saude, eventdetect_ipca_saude, reference))

##### 8. ipca_desp_pessoal #####
#Detect
eventdetect_ipca_desp_pessoal <- evtdet.eventdetect(na.omit(test_ipca_desp_pessoal), w = 30)

#  Error in data.frame(..., check.names = FALSE) : 
#    imply differing number of rows: 0, 1

#Evaluate
evaluate(eventdetect_ipca_desp_pessoal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE        
# FALSE        

round(evaluate(eventdetect_ipca_desp_pessoal, reference, metric = "F1"), 2)          # 
round(evaluate(eventdetect_ipca_desp_pessoal, reference, metric = "accuracy"), 2)    # 
round(evaluate(eventdetect_ipca_desp_pessoal, reference, metric = "sensitivity"), 2) # 
round(evaluate(eventdetect_ipca_desp_pessoal, reference, metric = "specificity"), 2) # 
round(evaluate(eventdetect_ipca_desp_pessoal, reference, metric = "precision"), 2)   # 
round(evaluate(eventdetect_ipca_desp_pessoal, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_ipca_desp_pessoal, eventdetect_ipca_desp_pessoal, reference))

##### 9. ipca_educacao #####
#Detect
eventdetect_ipca_educacao <- evtdet.eventdetect(na.omit(test_ipca_educacao), w = 30)

#Error in data.frame(..., check.names = FALSE) : 
#  arguments imply differing number of rows: 0, 1

#Evaluate
evaluate(eventdetect_ipca_educacao, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE       
# FALSE    

round(evaluate(eventdetect_ipca_educacao, reference, metric = "F1"), 2)          # 
round(evaluate(eventdetect_ipca_educacao, reference, metric = "accuracy"), 2)    # 
round(evaluate(eventdetect_ipca_educacao, reference, metric = "sensitivity"), 2) # 
round(evaluate(eventdetect_ipca_educacao, reference, metric = "specificity"), 2) # 
round(evaluate(eventdetect_ipca_educacao, reference, metric = "precision"), 2)   # 
round(evaluate(eventdetect_ipca_educacao, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_ipca_educacao, eventdetect_ipca_educacao, reference))

##### 10. ipca_comercializavel #####
#Detect
eventdetect_ipca_comercializavel <- evtdet.eventdetect(na.omit(test_ipca_comercializavel), w = 30)

#Evaluate
evaluate(eventdetect_ipca_comercializavel, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     19     23 
# FALSE    46     161  

round(evaluate(eventdetect_ipca_comercializavel, reference, metric = "F1"), 2)          # 0.36
round(evaluate(eventdetect_ipca_comercializavel, reference, metric = "accuracy"), 2)    # 0.72
round(evaluate(eventdetect_ipca_comercializavel, reference, metric = "sensitivity"), 2) # 0.29
round(evaluate(eventdetect_ipca_comercializavel, reference, metric = "specificity"), 2) # 0.88
round(evaluate(eventdetect_ipca_comercializavel, reference, metric = "precision"), 2)   # 0.45
round(evaluate(eventdetect_ipca_comercializavel, reference, metric = "recall"), 2)      # 0.29

#Plot
print(evtplot(test_ipca_comercializavel, eventdetect_ipca_comercializavel, reference))

##### 11. ipca_nao_comercializavel #####
#Detect
eventdetect_ipca_nao_comercializavel <- evtdet.eventdetect(na.omit(test_ipca_nao_comercializavel), w = 30)

#Error in data.frame(..., check.names = FALSE) : 
#  arguments imply differing number of rows: 0, 1

#Evaluate
evaluate(eventdetect_ipca_nao_comercializavel, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE    

round(evaluate(eventdetect_ipca_nao_comercializavel, reference, metric = "F1"), 2)          # 
round(evaluate(eventdetect_ipca_nao_comercializavel, reference, metric = "accuracy"), 2)    # 
round(evaluate(eventdetect_ipca_nao_comercializavel, reference, metric = "sensitivity"), 2) # 
round(evaluate(eventdetect_ipca_nao_comercializavel, reference, metric = "specificity"), 2) # 
round(evaluate(eventdetect_ipca_nao_comercializavel, reference, metric = "precision"), 2)   # 
round(evaluate(eventdetect_ipca_nao_comercializavel, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_ipca_nao_comercializavel, eventdetect_ipca_nao_comercializavel, reference))

##### 12. ipca_monitorado #####
#Detect
eventdetect_ipca_monitorado <- evtdet.eventdetect(na.omit(test_ipca_monitorado), w = 30)

#Error in data.frame(..., check.names = FALSE) : 
#  arguments imply differing number of rows: 0, 1

#Evaluate
evaluate(eventdetect_ipca_monitorado, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE        
# FALSE      

round(evaluate(eventdetect_ipca_monitorado, reference, metric = "F1"), 2)          # 
round(evaluate(eventdetect_ipca_monitorado, reference, metric = "accuracy"), 2)    # 
round(evaluate(eventdetect_ipca_monitorado, reference, metric = "sensitivity"), 2) # 
round(evaluate(eventdetect_ipca_monitorado, reference, metric = "specificity"), 2) # 
round(evaluate(eventdetect_ipca_monitorado, reference, metric = "precision"), 2)   # 
round(evaluate(eventdetect_ipca_monitorado, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_ipca_monitorado, eventdetect_ipca_monitorado, reference))

##### 13. ipca_nao_duravel #####
#Detect
eventdetect_ipca_nao_duravel <- evtdet.eventdetect(na.omit(test_ipca_nao_duravel), w = 30)

#Error in data.frame(..., check.names = FALSE) : 
#  arguments imply differing number of rows: 0, 1

#Evaluate
evaluate(eventdetect_ipca_nao_duravel, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE      

round(evaluate(eventdetect_ipca_nao_duravel, reference, metric = "F1"), 2)          # 
round(evaluate(eventdetect_ipca_nao_duravel, reference, metric = "accuracy"), 2)    # 
round(evaluate(eventdetect_ipca_nao_duravel, reference, metric = "sensitivity"), 2) # 
round(evaluate(eventdetect_ipca_nao_duravel, reference, metric = "specificity"), 2) # 
round(evaluate(eventdetect_ipca_nao_duravel, reference, metric = "precision"), 2)   # 
round(evaluate(eventdetect_ipca_nao_duravel, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_ipca_nao_duravel, eventdetect_ipca_nao_duravel, reference))

##### 14. ipca_semi_duravel #####
#Detect
eventdetect_ipca_semi_duravel <- evtdet.eventdetect(na.omit(test_ipca_semi_duravel), w = 30)

#Error in data.frame(..., check.names = FALSE) : 
#  arguments imply differing number of rows: 0, 1

#Evaluate
evaluate(eventdetect_ipca_semi_duravel, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE    

round(evaluate(eventdetect_ipca_semi_duravel, reference, metric = "F1"), 2)          # 
round(evaluate(eventdetect_ipca_semi_duravel, reference, metric = "accuracy"), 2)    # 
round(evaluate(eventdetect_ipca_semi_duravel, reference, metric = "sensitivity"), 2) # 
round(evaluate(eventdetect_ipca_semi_duravel, reference, metric = "specificity"), 2) # 
round(evaluate(eventdetect_ipca_semi_duravel, reference, metric = "precision"), 2)   # 
round(evaluate(eventdetect_ipca_semi_duravel, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_ipca_semi_duravel, eventdetect_ipca_semi_duravel, reference))

##### 15. ipca_duravel #####
#Detect
eventdetect_ipca_duravel <- evtdet.eventdetect(na.omit(test_ipca_duravel), w = 30)

#Error in data.frame(..., check.names = FALSE) : 
#  arguments imply differing number of rows: 0, 1

#Evaluate
evaluate(eventdetect_ipca_duravel, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE    

round(evaluate(eventdetect_ipca_duravel, reference, metric = "F1"), 2)          # 
round(evaluate(eventdetect_ipca_duravel, reference, metric = "accuracy"), 2)    # 
round(evaluate(eventdetect_ipca_duravel, reference, metric = "sensitivity"), 2) # 
round(evaluate(eventdetect_ipca_duravel, reference, metric = "specificity"), 2) # 
round(evaluate(eventdetect_ipca_duravel, reference, metric = "precision"), 2)   # 
round(evaluate(eventdetect_ipca_duravel, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_ipca_duravel, eventdetect_ipca_duravel, reference))

##### 16. ipca_servico #####
#Detect
eventdetect_ipca_servico <- evtdet.eventdetect(na.omit(test_ipca_servico), w = 30)

#Error in data.frame(..., check.names = FALSE) : 
#  arguments imply differing number of rows: 0, 1

#Evaluate
evaluate(eventdetect_ipca_servico, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE    

round(evaluate(eventdetect_ipca_servico, reference, metric = "F1"), 2)          # 
round(evaluate(eventdetect_ipca_servico, reference, metric = "accuracy"), 2)    # 
round(evaluate(eventdetect_ipca_servico, reference, metric = "sensitivity"), 2) # 
round(evaluate(eventdetect_ipca_servico, reference, metric = "specificity"), 2) # 
round(evaluate(eventdetect_ipca_servico, reference, metric = "precision"), 2)   # 
round(evaluate(eventdetect_ipca_servico, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_ipca_servico, eventdetect_ipca_servico, reference))

##### 17. ipca_livre #####
#Detect
eventdetect_ipca_livre <- evtdet.eventdetect(na.omit(test_ipca_livre), w = 30)

#Error in data.frame(..., check.names = FALSE) : 
#  arguments imply differing number of rows: 0, 1 

#Evaluate
evaluate(eventdetect_ipca_livre, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE     

round(evaluate(eventdetect_ipca_livre, reference, metric = "F1"), 2)          # 
round(evaluate(eventdetect_ipca_livre, reference, metric = "accuracy"), 2)    # 
round(evaluate(eventdetect_ipca_livre, reference, metric = "sensitivity"), 2) # 
round(evaluate(eventdetect_ipca_livre, reference, metric = "specificity"), 2) # 
round(evaluate(eventdetect_ipca_livre, reference, metric = "precision"), 2)   # 
round(evaluate(eventdetect_ipca_livre, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_ipca_livre, eventdetect_ipca_livre, reference))

##### 18. ipca_industrial #####
#Detect
eventdetect_ipca_industrial <- evtdet.eventdetect(na.omit(test_ipca_industrial), w = 30)

#Error in data.frame(..., check.names = FALSE) : 
#  arguments imply differing number of rows: 0, 1 

#Evaluate
evaluate(eventdetect_ipca_industrial, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE      
# FALSE      

round(evaluate(eventdetect_ipca_industrial, reference, metric = "F1"), 2)          # 
round(evaluate(eventdetect_ipca_industrial, reference, metric = "accuracy"), 2)    # 
round(evaluate(eventdetect_ipca_industrial, reference, metric = "sensitivity"), 2) # 
round(evaluate(eventdetect_ipca_industrial, reference, metric = "specificity"), 2) # 
round(evaluate(eventdetect_ipca_industrial, reference, metric = "precision"), 2)   # 
round(evaluate(eventdetect_ipca_industrial, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_ipca_industrial, eventdetect_ipca_industrial, reference))

##### 19. ipca_comida_casa #####
#Detect
eventdetect_ipca_comida_casa <- evtdet.eventdetect(na.omit(test_ipca_comida_casa), w = 30)

#Error in data.frame(..., check.names = FALSE) : 
#  arguments imply differing number of rows: 0, 1 

#Evaluate
evaluate(eventdetect_ipca_comida_casa, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE      

round(evaluate(eventdetect_ipca_comida_casa, reference, metric = "F1"), 2)          # 
round(evaluate(eventdetect_ipca_comida_casa, reference, metric = "accuracy"), 2)    # 
round(evaluate(eventdetect_ipca_comida_casa, reference, metric = "sensitivity"), 2) # 
round(evaluate(eventdetect_ipca_comida_casa, reference, metric = "specificity"), 2) # 
round(evaluate(eventdetect_ipca_comida_casa, reference, metric = "precision"), 2)   # 
round(evaluate(eventdetect_ipca_comida_casa, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_ipca_comida_casa, eventdetect_ipca_comida_casa, reference))

##### 20. ipca_transporte #####
#Detect
eventdetect_ipca_transporte <- evtdet.eventdetect(na.omit(test_ipca_transporte), w = 30)

#Error in data.frame(..., check.names = FALSE) : 
#  arguments imply differing number of rows: 0, 1 

#Evaluate
evaluate(eventdetect_iipca_transporte, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE      

round(evaluate(eventdetect_ipca_transporte, reference, metric = "F1"), 2)          # 
round(evaluate(eventdetect_ipca_transporte, reference, metric = "accuracy"), 2)    # 
round(evaluate(eventdetect_ipca_transporte, reference, metric = "sensitivity"), 2) # 
round(evaluate(eventdetect_ipca_transporte, reference, metric = "specificity"), 2) # 
round(evaluate(eventdetect_ipca_transporte, reference, metric = "precision"), 2)   # 
round(evaluate(eventdetect_ipca_transporte, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_ipca_transporte, eventdetect_ipca_transporte, reference))

#######################################
##### Auxiliary Model definitions #####
#######################################

ARIMA <- function(data) forecast::auto.arima(data)
AR <- function(data,p) forecast::Arima(data, order = c(p, 0, 0), seasonal = c(0, 0, 0))
garch <- function(data,spec,...) rugarch::ugarchfit(spec=spec,data=data,solver="hybrid", ...)@fit
ets <- function(data) forecast::ets(ts(data))
linreg <- function(data) {
  #browser()
  data <- as.data.frame(data)
  colnames(data) <- "x"
  data$t <- 1:nrow(data)
  
  #Adjusting a linear regression to the whole window
  lm(x~t, data)
}

#Garch specs
garch11 <- rugarch::ugarchspec(variance.model = list(model = "sGARCH", garchOrder = c(1, 1)), 
                               mean.model = list(armaOrder = c(1, 1), include.mean = TRUE), 
                               distribution.model = "norm")

####################################
##### Garch Volatility Outlier #####
####################################

##### 1. ipca #####
#Detect
garch_volatility_ipca <- evtdet.garch_volatility_outlier(test_ipca, spec = garch11, alpha = 1.5,
                                                         na.action = na.omit)

#Evaluate
evaluate(garch_volatility_ipca, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     14     16
# FALSE    51     168  

round(evaluate(garch_volatility_ipca, reference, metric = "F1"), 2)          # 0.29
round(evaluate(garch_volatility_ipca, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(garch_volatility_ipca, reference, metric = "sensitivity"), 2) # 0.22
round(evaluate(garch_volatility_ipca, reference, metric = "specificity"), 2) # 0.91
round(evaluate(garch_volatility_ipca, reference, metric = "precision"), 2)   # 0.47
round(evaluate(garch_volatility_ipca, reference, metric = "recall"), 2)      # 0.22

#Plot
print(evtplot(test_ipca, garch_volatility_ipca, reference))

##### 2. ipca_comida_bebida #####
#Detect
garch_volatility_ipca_comida_bebida <- evtdet.garch_volatility_outlier(test_ipca_comida_bebida, 
                                                                       spec = garch11, alpha = 1.5,
                                                                       na.action = na.omit)

#Evaluate
evaluate(garch_volatility_ipca_comida_bebida, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     7      14
# FALSE    58     170

round(evaluate(garch_volatility_ipca_comida_bebida, reference, metric = "F1"), 2)          # 0.16
round(evaluate(garch_volatility_ipca_comida_bebida, reference, metric = "accuracy"), 2)    # 0.71
round(evaluate(garch_volatility_ipca_comida_bebida, reference, metric = "sensitivity"), 2) # 0.11
round(evaluate(garch_volatility_ipca_comida_bebida, reference, metric = "specificity"), 2) # 0.92
round(evaluate(garch_volatility_ipca_comida_bebida, reference, metric = "precision"), 2)   # 0.33
round(evaluate(garch_volatility_ipca_comida_bebida, reference, metric = "recall"), 2)      # 0.11

#Plot
print(evtplot(test_ipca_comida_bebida, garch_volatility_ipca_comida_bebida, reference))

##### 3. ipca_habitat #####
#Detect
garch_volatility_ipca_habitat <- evtdet.garch_volatility_outlier(test_ipca_habitat, spec = garch11, alpha = 1.5,
                                                                 na.action = na.omit)

#Evaluate
evaluate(garch_volatility_ipca_habitat, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     7      10     
# FALSE    58     174  

round(evaluate(garch_volatility_ipca_habitat, reference, metric = "F1"), 2)          # 0.17
round(evaluate(garch_volatility_ipca_habitat, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(garch_volatility_ipca_habitat, reference, metric = "sensitivity"), 2) # 0.11
round(evaluate(garch_volatility_ipca_habitat, reference, metric = "specificity"), 2) # 0.95
round(evaluate(garch_volatility_ipca_habitat, reference, metric = "precision"), 2)   # 0.41
round(evaluate(garch_volatility_ipca_habitat, reference, metric = "recall"), 2)      # 0.11

#Plot
print(evtplot(test_ipca_habitat, garch_volatility_ipca_habitat, reference))

##### 4. ipca_artigos_casa #####
#Detect
garch_volatility_ipca_artigos_casa <- evtdet.garch_volatility_outlier(test_ipca_artigos_casa, 
                                                                      spec = garch11, alpha = 1.5,
                                                                      na.action = na.omit)

#Evaluate
evaluate(garch_volatility_ipca_artigos_casa, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     8      8  
# FALSE    57     176   

round(evaluate(garch_volatility_ipca_artigos_casa, reference, metric = "F1"), 2)          # 0.20
round(evaluate(garch_volatility_ipca_artigos_casa, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(garch_volatility_ipca_artigos_casa, reference, metric = "sensitivity"), 2) # 0.12
round(evaluate(garch_volatility_ipca_artigos_casa, reference, metric = "specificity"), 2) # 0.96
round(evaluate(garch_volatility_ipca_artigos_casa, reference, metric = "precision"), 2)   # 0.50
round(evaluate(garch_volatility_ipca_artigos_casa, reference, metric = "recall"), 2)      # 0.12

#Plot
print(evtplot(test_ipca_artigos_casa, garch_volatility_ipca_artigos_casa, reference))

##### 5. ipca_roupa #####
#Detect
garch_volatility_ipca_roupa <- evtdet.garch_volatility_outlier(test_ipca_roupa, spec = garch11, alpha = 1.5,
                                                               na.action = na.omit)

#Evaluate
evaluate(garch_volatility_ipca_roupa, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     8      17
# FALSE    57     167

round(evaluate(garch_volatility_ipca_roupa, reference, metric = "F1"), 2)          # 0.18
round(evaluate(garch_volatility_ipca_roupa, reference, metric = "accuracy"), 2)    # 0.70
round(evaluate(garch_volatility_ipca_roupa, reference, metric = "sensitivity"), 2) # 0.12
round(evaluate(garch_volatility_ipca_roupa, reference, metric = "specificity"), 2) # 0.91
round(evaluate(garch_volatility_ipca_roupa, reference, metric = "precision"), 2)   # 0.32
round(evaluate(garch_volatility_ipca_roupa, reference, metric = "recall"), 2)      # 0.12

#Plot
print(evtplot(test_ipca_roupa, garch_volatility_ipca_roupa, reference))

##### 6. ipca_cumunicacao #####
#Detect
garch_volatility_ipca_cumunicacao <- evtdet.garch_volatility_outlier(test_ipca_cumunicacao, 
                                                                     spec = garch11, alpha = 1.5,
                                                                     na.action = na.omit)

#Evaluate
evaluate(garch_volatility_ipca_cumunicacao, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     5      38
# FALSE    60     146   

round(evaluate(garch_volatility_ipca_cumunicacao, reference, metric = "F1"), 2)          # 0.09
round(evaluate(garch_volatility_ipca_cumunicacao, reference, metric = "accuracy"), 2)    # 0.61
round(evaluate(garch_volatility_ipca_cumunicacao, reference, metric = "sensitivity"), 2) # 0.08
round(evaluate(garch_volatility_ipca_cumunicacao, reference, metric = "specificity"), 2) # 0.79
round(evaluate(garch_volatility_ipca_cumunicacao, reference, metric = "precision"), 2)   # 0.12
round(evaluate(garch_volatility_ipca_cumunicacao, reference, metric = "recall"), 2)      # 0.08

#Plot
print(evtplot(test_ipca_cumunicacao, garch_volatility_ipca_cumunicacao, reference))

##### 7. ipca_saude #####
#Detect
garch_volatility_ipca_saude <- evtdet.garch_volatility_outlier(test_ipca_saude, spec = garch11, alpha = 1.5,
                                                               na.action = na.omit)

#Evaluate
evaluate(garch_volatility_ipca_saude, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     0      9 
# FALSE    65     175  

round(evaluate(garch_volatility_ipca_saude, reference, metric = "F1"), 2)          # NaN
round(evaluate(garch_volatility_ipca_saude, reference, metric = "accuracy"), 2)    # 0.70
round(evaluate(garch_volatility_ipca_saude, reference, metric = "sensitivity"), 2) # 0.00
round(evaluate(garch_volatility_ipca_saude, reference, metric = "specificity"), 2) # 0.95
round(evaluate(garch_volatility_ipca_saude, reference, metric = "precision"), 2)   # 0.00
round(evaluate(garch_volatility_ipca_saude, reference, metric = "recall"), 2)      # 0.00

#Plot
print(evtplot(test_ipca_saude, garch_volatility_ipca_saude, reference))

##### 8. ipca_desp_pessoal #####
#Detect
garch_volatility_ipca_desp_pessoal <- evtdet.garch_volatility_outlier(test_ipca_desp_pessoal, 
                                                                      spec = garch11, alpha = 1.5,
                                                                      na.action = na.omit)

# Error in data.frame(..., check.names = FALSE) : 
#   arguments imply differing number of rows: 0, 1 

#Evaluate
evaluate(garch_volatility_ipca_desp_pessoal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE       

round(evaluate(garch_volatility_ipca_desp_pessoal, reference, metric = "F1"), 2)          # 
round(evaluate(garch_volatility_ipca_desp_pessoal, reference, metric = "accuracy"), 2)    # 
round(evaluate(garch_volatility_ipca_desp_pessoal, reference, metric = "sensitivity"), 2) # 
round(evaluate(garch_volatility_ipca_desp_pessoal, reference, metric = "specificity"), 2) # 
round(evaluate(garch_volatility_ipca_desp_pessoal, reference, metric = "precision"), 2)   # 
round(evaluate(garch_volatility_ipca_desp_pessoal, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_ipca_desp_pessoal, garch_volatility_ipca_desp_pessoal, reference))

##### 9. ipca_educacao #####
#Detect
garch_volatility_ipca_educacao <- evtdet.garch_volatility_outlier(test_ipca_educacao, 
                                                                  spec = garch11, alpha = 1.5,
                                                                  na.action = na.omit)

# Error in data.frame(..., check.names = FALSE) : 
#   arguments imply differing number of rows: 0, 1 

#Evaluate
evaluate(garch_volatility_ipca_educacao, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE      

round(evaluate(garch_volatility_ipca_educacao, reference, metric = "F1"), 2)          # 
round(evaluate(garch_volatility_ipca_educacao, reference, metric = "accuracy"), 2)    # 
round(evaluate(garch_volatility_ipca_educacao, reference, metric = "sensitivity"), 2) # 
round(evaluate(garch_volatility_ipca_educacao, reference, metric = "specificity"), 2) # 
round(evaluate(garch_volatility_ipca_educacao, reference, metric = "precision"), 2)   # 
round(evaluate(garch_volatility_ipca_educacao, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_ipca_educacao, garch_volatility_ipca_educacao, reference))

##### 10. ipca_comercializavel #####
#Detect
garch_volatility_ipca_comercializavel <- evtdet.garch_volatility_outlier(test_ipca_comercializavel, 
                                                                         spec = garch11, alpha = 1.5,
                                                                         na.action = na.omit)

#Evaluate
evaluate(garch_volatility_ipca_comercializavel, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     5      15 
# FALSE    60     169  

round(evaluate(garch_volatility_ipca_comercializavel, reference, metric = "F1"), 2)          # 0.12
round(evaluate(garch_volatility_ipca_comercializavel, reference, metric = "accuracy"), 2)    # 0.70
round(evaluate(garch_volatility_ipca_comercializavel, reference, metric = "sensitivity"), 2) # 0.08
round(evaluate(garch_volatility_ipca_comercializavel, reference, metric = "specificity"), 2) # 0.92
round(evaluate(garch_volatility_ipca_comercializavel, reference, metric = "precision"), 2)   # 0.25
round(evaluate(garch_volatility_ipca_comercializavel, reference, metric = "recall"), 2)      # 0.08

#Plot
print(evtplot(test_ipca_comercializavel, garch_volatility_ipca_comercializavel, reference))

##### 11. ipca_nao_comercializavel #####
#Detect
garch_volatility_ipca_nao_comercializavel <- evtdet.garch_volatility_outlier(test_ipca_nao_comercializavel,
                                                                             spec = garch11, alpha = 1.5,
                                                                             na.action = na.omit)

# Error in data.frame(..., check.names = FALSE) : 
#   arguments imply differing number of rows: 0, 1 

#Evaluate
evaluate(garch_volatility_ipca_nao_comercializavel, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE     

round(evaluate(garch_volatility_ipca_nao_comercializavel, reference, metric = "F1"), 2)          # 
round(evaluate(garch_volatility_ipca_nao_comercializavel, reference, metric = "accuracy"), 2)    # 
round(evaluate(garch_volatility_ipca_nao_comercializavel, reference, metric = "sensitivity"), 2) # 
round(evaluate(garch_volatility_ipca_nao_comercializavel, reference, metric = "specificity"), 2) # 
round(evaluate(garch_volatility_ipca_nao_comercializavel, reference, metric = "precision"), 2)   # 
round(evaluate(garch_volatility_ipca_nao_comercializavel, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_ipca_nao_comercializavel, garch_volatility_ipca_nao_comercializavel, reference))

##### 12. ipca_monitorado #####
#Detect
garch_volatility_ipca_monitorado <- evtdet.garch_volatility_outlier(test_ipca_monitorado,
                                                                    spec = garch11, alpha = 1.5,
                                                                    na.action = na.omit)

#Evaluate
evaluate(garch_volatility_ipca_monitorado, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     9      13   
# FALSE    56     171   

round(evaluate(garch_volatility_ipca_monitorado, reference, metric = "F1"), 2)          # 0.21
round(evaluate(garch_volatility_ipca_monitorado, reference, metric = "accuracy"), 2)    # 0.72
round(evaluate(garch_volatility_ipca_monitorado, reference, metric = "sensitivity"), 2) # 0.14
round(evaluate(garch_volatility_ipca_monitorado, reference, metric = "specificity"), 2) # 0.93
round(evaluate(garch_volatility_ipca_monitorado, reference, metric = "precision"), 2)   # 0.41
round(evaluate(garch_volatility_ipca_monitorado, reference, metric = "recall"), 2)      # 0.14

#Plot
print(evtplot(test_ipca_monitorado, garch_volatility_ipca_monitorado, reference))

##### 13. ipca_nao_duravel #####
#Detect
garch_volatility_ipca_nao_duravel <- evtdet.garch_volatility_outlier(test_ipca_nao_duravel,
                                                                     spec = garch11, alpha = 1.5,
                                                                     na.action = na.omit)

#Evaluate
evaluate(garch_volatility_ipca_nao_duravel, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     6      15 
# FALSE    59     169 

round(evaluate(garch_volatility_ipca_nao_duravel, reference, metric = "F1"), 2)          # 0.14
round(evaluate(garch_volatility_ipca_nao_duravel, reference, metric = "accuracy"), 2)    # 0.70
round(evaluate(garch_volatility_ipca_nao_duravel, reference, metric = "sensitivity"), 2) # 0.09
round(evaluate(garch_volatility_ipca_nao_duravel, reference, metric = "specificity"), 2) # 0.92
round(evaluate(garch_volatility_ipca_nao_duravel, reference, metric = "precision"), 2)   # 0.29
round(evaluate(garch_volatility_ipca_nao_duravel, reference, metric = "recall"), 2)      # 0.09

#Plot
print(evtplot(test_ipca_nao_duravel, garch_volatility_ipca_nao_duravel, reference))

##### 14. ipca_semi_duravel #####
#Detect
garch_volatility_ipca_semi_duravel <- evtdet.garch_volatility_outlier(test_ipca_semi_duravel,
                                                                      spec = garch11, alpha = 1.5,
                                                                      na.action = na.omit)

# Error in data.frame(..., check.names = FALSE) : 
#   arguments imply differing number of rows: 0, 1 

#Evaluate
evaluate(garch_volatility_ipca_semi_duravel, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE    

round(evaluate(garch_volatility_ipca_semi_duravel, reference, metric = "F1"), 2)          # 
round(evaluate(garch_volatility_ipca_semi_duravel, reference, metric = "accuracy"), 2)    # 
round(evaluate(garch_volatility_ipca_semi_duravel, reference, metric = "sensitivity"), 2) # 
round(evaluate(garch_volatility_ipca_semi_duravel, reference, metric = "specificity"), 2) # 
round(evaluate(garch_volatility_ipca_semi_duravel, reference, metric = "precision"), 2)   # 
round(evaluate(garch_volatility_ipca_semi_duravel, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_ipca_semi_duravel, garch_volatility_ipca_semi_duravel, reference))

##### 15. ipca_duravel #####
#Detect
garch_volatility_ipca_duravel <- evtdet.garch_volatility_outlier(test_ipca_duravel,
                                                                 spec = garch11, alpha = 1.5,
                                                                 na.action = na.omit)

# Error in data.frame(..., check.names = FALSE) : 
#   arguments imply differing number of rows: 0, 1 

#Evaluate
evaluate(garch_volatility_ipca_duravel, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE    

round(evaluate(garch_volatility_ipca_duravel, reference, metric = "F1"), 2)          # 
round(evaluate(garch_volatility_ipca_duravel, reference, metric = "accuracy"), 2)    # 
round(evaluate(garch_volatility_ipca_duravel, reference, metric = "sensitivity"), 2) # 
round(evaluate(garch_volatility_ipca_duravel, reference, metric = "specificity"), 2) # 
round(evaluate(garch_volatility_ipca_duravel, reference, metric = "precision"), 2)   # 
round(evaluate(garch_volatility_ipca_duravel, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_ipca_duravel, garch_volatility_ipca_duravel, reference))

##### 16. ipca_servico #####
#Detect
garch_volatility_ipca_servico <- evtdet.garch_volatility_outlier(test_ipca_servico,
                                                                 spec = garch11, alpha = 1.5,
                                                                 na.action = na.omit)

# Error in data.frame(..., check.names = FALSE) : 
#   arguments imply differing number of rows: 0, 1 

#Evaluate
evaluate(garch_volatility_ipca_servico, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE    

round(evaluate(garch_volatility_ipca_servico, reference, metric = "F1"), 2)          # 
round(evaluate(garch_volatility_ipca_servico, reference, metric = "accuracy"), 2)    # 
round(evaluate(garch_volatility_ipca_servico, reference, metric = "sensitivity"), 2) # 
round(evaluate(garch_volatility_ipca_servico, reference, metric = "specificity"), 2) # 
round(evaluate(garch_volatility_ipca_servico, reference, metric = "precision"), 2)   # 
round(evaluate(garch_volatility_ipca_servico, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_ipca_servico, garch_volatility_ipca_servico, reference))

##### 17. ipca_livre #####
#Detect
garch_volatility_ipca_livre <- evtdet.garch_volatility_outlier(test_ipca_livre,
                                                               spec = garch11, alpha = 1.5,
                                                               na.action = na.omit)

#Evaluate
evaluate(garch_volatility_ipca_livre, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     3      15
# FALSE    62     169 

round(evaluate(garch_volatility_ipca_livre, reference, metric = "F1"), 2)          # 0.07
round(evaluate(garch_volatility_ipca_livre, reference, metric = "accuracy"), 2)    # 0.69
round(evaluate(garch_volatility_ipca_livre, reference, metric = "sensitivity"), 2) # 0.05
round(evaluate(garch_volatility_ipca_livre, reference, metric = "specificity"), 2) # 0.92
round(evaluate(garch_volatility_ipca_livre, reference, metric = "precision"), 2)   # 0.17
round(evaluate(garch_volatility_ipca_livre, reference, metric = "recall"), 2)      # 0.05

#Plot
print(evtplot(test_ipca_livre, garch_volatility_ipca_livre, reference))

##### 18. ipca_industrial #####
#Detect
garch_volatility_ipca_industrial <- evtdet.garch_volatility_outlier(test_ipca_industrial,
                                                                    spec = garch11, alpha = 1.5,
                                                                    na.action = na.omit)

#Evaluate
evaluate(garch_volatility_ipca_industrial, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     5      20 
# FALSE    60     164 

round(evaluate(garch_volatility_ipca_industrial, reference, metric = "F1"), 2)          # 0.11
round(evaluate(garch_volatility_ipca_industrial, reference, metric = "accuracy"), 2)    # 0.68
round(evaluate(garch_volatility_ipca_industrial, reference, metric = "sensitivity"), 2) # 0.08
round(evaluate(garch_volatility_ipca_industrial, reference, metric = "specificity"), 2) # 0.89
round(evaluate(garch_volatility_ipca_industrial, reference, metric = "precision"), 2)   # 0.20
round(evaluate(garch_volatility_ipca_industrial, reference, metric = "recall"), 2)      # 0.08

#Plot
print(evtplot(test_ipca_industrial, garch_volatility_ipca_industrial, reference))

##### 19. ipca_comida_casa #####
#Detect
garch_volatility_ipca_comida_casa <- evtdet.garch_volatility_outlier(test_ipca_comida_casa,
                                                                     spec = garch11, alpha = 1.5,
                                                                     na.action = na.omit)

# Error in data.frame(..., check.names = FALSE) : 
#   arguments imply differing number of rows: 0, 1 

#Evaluate
evaluate(garch_volatility_ipca_comida_casa, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE    

round(evaluate(garch_volatility_ipca_comida_casa, reference, metric = "F1"), 2)          # 
round(evaluate(garch_volatility_ipca_comida_casa, reference, metric = "accuracy"), 2)    # 
round(evaluate(garch_volatility_ipca_comida_casa, reference, metric = "sensitivity"), 2) # 
round(evaluate(garch_volatility_ipca_comida_casa, reference, metric = "specificity"), 2) # 
round(evaluate(garch_volatility_ipca_comida_casa, reference, metric = "precision"), 2)   # 
round(evaluate(garch_volatility_ipca_comida_casa, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_ipca_comida_casa, garch_volatility_ipca_comida_casa, reference))

##### 20. ipca_transporte #####
#Detect
garch_volatility_ipca_transporte <- evtdet.garch_volatility_outlier(test_ipca_transporte,
                                                                    spec = garch11, alpha = 1.5,
                                                                    na.action = na.omit)

#Evaluate
evaluate(garch_volatility_ipca_transporte, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     8      17   
# FALSE    57     167

round(evaluate(garch_volatility_ipca_transporte, reference, metric = "F1"), 2)          # 0.18
round(evaluate(garch_volatility_ipca_transporte, reference, metric = "accuracy"), 2)    # 0.70
round(evaluate(garch_volatility_ipca_transporte, reference, metric = "sensitivity"), 2) # 0.12
round(evaluate(garch_volatility_ipca_transporte, reference, metric = "specificity"), 2) # 0.91
round(evaluate(garch_volatility_ipca_transporte, reference, metric = "precision"), 2)   # 0.32
round(evaluate(garch_volatility_ipca_transporte, reference, metric = "recall"), 2)      # 0.12

#Plot
print(evtplot(test_ipca_transporte, garch_volatility_ipca_transporte, reference))

#######################################
##### Seminal Change Point (1999) #####
#######################################

##### 1. ipca #####
#Detect
changepoint_ipca <- evtdet.seminalChangePoint2(test_ipca, w = 30, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_ipca, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     16     34  
# FALSE    49     150    

round(evaluate(changepoint_ipca, reference, metric = "F1"), 2)          # 0.28
round(evaluate(changepoint_ipca, reference, metric = "accuracy"), 2)    # 0.67
round(evaluate(changepoint_ipca, reference, metric = "sensitivity"), 2) # 0.25
round(evaluate(changepoint_ipca, reference, metric = "specificity"), 2) # 0.82
round(evaluate(changepoint_ipca, reference, metric = "precision"), 2)   # 0.32
round(evaluate(changepoint_ipca, reference, metric = "recall"), 2)      # 0.25

#Plot
print(evtplot(test_ipca, changepoint_ipca, reference))

##### 2. ipca_comida_bebida #####
#Detect
changepoint_ipca_comida_bebida <- evtdet.seminalChangePoint2(test_ipca_comida_bebida, w = 30, 
                                                             mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_ipca_comida_bebida, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     5      45   
# FALSE    60     139  

round(evaluate(changepoint_ipca_comida_bebida, reference, metric = "F1"), 2)          # 0.09
round(evaluate(changepoint_ipca_comida_bebida, reference, metric = "accuracy"), 2)    # 0.58
round(evaluate(changepoint_ipca_comida_bebida, reference, metric = "sensitivity"), 2) # 0.08
round(evaluate(changepoint_ipca_comida_bebida, reference, metric = "specificity"), 2) # 0.76
round(evaluate(changepoint_ipca_comida_bebida, reference, metric = "precision"), 2)   # 0.10
round(evaluate(changepoint_ipca_comida_bebida, reference, metric = "recall"), 2)      # 0.08

#Plot
print(evtplot(test_ipca_comida_bebida, changepoint_ipca_comida_bebida, reference))

##### 3. ipca_habitat #####
#Detect
changepoint_ipca_habitat <- evtdet.seminalChangePoint2(test_ipca_habitat, w = 30, 
                                                       mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_ipca_habitat, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     11     31  
# FALSE    54     153 

round(evaluate(changepoint_ipca_habitat, reference, metric = "F1"), 2)          # 0.21
round(evaluate(changepoint_ipca_habitat, reference, metric = "accuracy"), 2)    # 0.66
round(evaluate(changepoint_ipca_habitat, reference, metric = "sensitivity"), 2) # 0.17
round(evaluate(changepoint_ipca_habitat, reference, metric = "specificity"), 2) # 0.83
round(evaluate(changepoint_ipca_habitat, reference, metric = "precision"), 2)   # 0.26
round(evaluate(changepoint_ipca_habitat, reference, metric = "recall"), 2)      # 0.17

#Plot
print(evtplot(test_ipca_habitat, changepoint_ipca_habitat, reference))

##### 4. ipca_artigos_casa #####
#Detect
changepoint_ipca_artigos_casa <- evtdet.seminalChangePoint2(test_ipca_artigos_casa, w = 30, 
                                                            mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_ipca_artigos_casa, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     14     20 
# FALSE    51     164

round(evaluate(changepoint_ipca_artigos_casa, reference, metric = "F1"), 2)          # 0.28
round(evaluate(changepoint_ipca_artigos_casa, reference, metric = "accuracy"), 2)    # 0.71
round(evaluate(changepoint_ipca_artigos_casa, reference, metric = "sensitivity"), 2) # 0.22
round(evaluate(changepoint_ipca_artigos_casa, reference, metric = "specificity"), 2) # 0.89
round(evaluate(changepoint_ipca_artigos_casa, reference, metric = "precision"), 2)   # 0.41
round(evaluate(changepoint_ipca_artigos_casa, reference, metric = "recall"), 2)      # 0.22

#Plot
print(evtplot(test_ipca_artigos_casa, changepoint_ipca_artigos_casa, reference))

##### 5. ipca_roupa #####
#Detect
changepoint_ipca_roupa <- evtdet.seminalChangePoint2(test_ipca_roupa, w = 30, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_ipca_roupa, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     15     40
# FALSE    50     144  

round(evaluate(changepoint_ipca_roupa, reference, metric = "F1"), 2)          # 0.25
round(evaluate(changepoint_ipca_roupa, reference, metric = "accuracy"), 2)    # 0.64
round(evaluate(changepoint_ipca_roupa, reference, metric = "sensitivity"), 2) # 0.23
round(evaluate(changepoint_ipca_roupa, reference, metric = "specificity"), 2) # 0.78
round(evaluate(changepoint_ipca_roupa, reference, metric = "precision"), 2)   # 0.27
round(evaluate(changepoint_ipca_roupa, reference, metric = "recall"), 2)      # 0.23

#Plot
print(evtplot(test_ipca_roupa, changepoint_ipca_roupa, reference))

##### 6. ipca_cumunicacao #####
#Detect
changepoint_ipca_cumunicacao <- evtdet.seminalChangePoint2(test_ipca_cumunicacao, w = 30, 
                                                           mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_ipca_cumunicacao, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     13     32 
# FALSE    52     152  

round(evaluate(changepoint_ipca_cumunicacao, reference, metric = "F1"), 2)          # 0.24
round(evaluate(changepoint_ipca_cumunicacao, reference, metric = "accuracy"), 2)    # 0.66
round(evaluate(changepoint_ipca_cumunicacao, reference, metric = "sensitivity"), 2) # 0.20
round(evaluate(changepoint_ipca_cumunicacao, reference, metric = "specificity"), 2) # 0.83
round(evaluate(changepoint_ipca_cumunicacao, reference, metric = "precision"), 2)   # 0.29
round(evaluate(changepoint_ipca_cumunicacao, reference, metric = "recall"), 2)      # 0.20

#Plot
print(evtplot(test_ipca_cumunicacao, changepoint_ipca_cumunicacao, reference))

##### 7. ipca_saude #####
#Detect
changepoint_ipca_saude <- evtdet.seminalChangePoint2(test_ipca_saude, w = 30, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_ipca_saude, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     16     43  
# FALSE    49     141

round(evaluate(changepoint_ipca_saude, reference, metric = "F1"), 2)          # 0.26
round(evaluate(changepoint_ipca_saude, reference, metric = "accuracy"), 2)    # 0.63
round(evaluate(changepoint_ipca_saude, reference, metric = "sensitivity"), 2) # 0.25
round(evaluate(changepoint_ipca_saude, reference, metric = "specificity"), 2) # 0.77
round(evaluate(changepoint_ipca_saude, reference, metric = "precision"), 2)   # 0.27
round(evaluate(changepoint_ipca_saude, reference, metric = "recall"), 2)      # 0.25

#Plot
print(evtplot(test_ipca_saude, changepoint_ipca_saude, reference))

##### 8. ipca_desp_pessoal #####
#Detect
changepoint_ipca_desp_pessoal <- evtdet.seminalChangePoint2(test_ipca_desp_pessoal, w = 30, 
                                                            mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_ipca_desp_pessoal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     22     39 
# FALSE    43     145  

round(evaluate(changepoint_ipca_desp_pessoal, reference, metric = "F1"), 2)          # 0.35
round(evaluate(changepoint_ipca_desp_pessoal, reference, metric = "accuracy"), 2)    # 0.67
round(evaluate(changepoint_ipca_desp_pessoal, reference, metric = "sensitivity"), 2) # 0.34
round(evaluate(changepoint_ipca_desp_pessoal, reference, metric = "specificity"), 2) # 0.79
round(evaluate(changepoint_ipca_desp_pessoal, reference, metric = "precision"), 2)   # 0.36
round(evaluate(changepoint_ipca_desp_pessoal, reference, metric = "recall"), 2)      # 0.34

#Plot
print(evtplot(test_ipca_desp_pessoal, changepoint_ipca_desp_pessoal, reference))

##### 9. ipca_educacao #####
#Detect
changepoint_ipca_educacao <- evtdet.seminalChangePoint2(test_ipca_educacao, w = 30, 
                                                        mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_ipca_educacao, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     18     29  
# FALSE    47     155  

round(evaluate(changepoint_ipca_educacao, reference, metric = "F1"), 2)          # 0.32
round(evaluate(changepoint_ipca_educacao, reference, metric = "accuracy"), 2)    # 0.69
round(evaluate(changepoint_ipca_educacao, reference, metric = "sensitivity"), 2) # 0.28
round(evaluate(changepoint_ipca_educacao, reference, metric = "specificity"), 2) # 0.84
round(evaluate(changepoint_ipca_educacao, reference, metric = "precision"), 2)   # 0.38
round(evaluate(changepoint_ipca_educacao, reference, metric = "recall"), 2)      # 0.28

#Plot
print(evtplot(test_ipca_educacao, changepoint_ipca_educacao, reference))

##### 10. ipca_comercializavel #####
#Detect
changepoint_ipca_comercializavel <- evtdet.seminalChangePoint2(test_ipca_comercializavel, w = 30, 
                                                               mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_ipca_comercializavel, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     10     44 
# FALSE    55     140 

round(evaluate(changepoint_ipca_comercializavel, reference, metric = "F1"), 2)          # 0.17
round(evaluate(changepoint_ipca_comercializavel, reference, metric = "accuracy"), 2)    # 0.60
round(evaluate(changepoint_ipca_comercializavel, reference, metric = "sensitivity"), 2) # 0.15
round(evaluate(changepoint_ipca_comercializavel, reference, metric = "specificity"), 2) # 0.76
round(evaluate(changepoint_ipca_comercializavel, reference, metric = "precision"), 2)   # 0.19
round(evaluate(changepoint_ipca_comercializavel, reference, metric = "recall"), 2)      # 0.15

#Plot
print(evtplot(test_ipca_comercializavel, changepoint_ipca_comercializavel, reference))

##### 11. ipca_nao_comercializavel #####
#Detect
changepoint_ipca_nao_comercializavel <- evtdet.seminalChangePoint2(test_ipca_nao_comercializavel, w = 30, 
                                                                   mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_ipca_nao_comercializavel, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     16     44  
# FALSE    49     140 

round(evaluate(changepoint_ipca_nao_comercializavel, reference, metric = "F1"), 2)          # 0.26
round(evaluate(changepoint_ipca_nao_comercializavel, reference, metric = "accuracy"), 2)    # 0.63
round(evaluate(changepoint_ipca_nao_comercializavel, reference, metric = "sensitivity"), 2) # 0.25
round(evaluate(changepoint_ipca_nao_comercializavel, reference, metric = "specificity"), 2) # 0.76
round(evaluate(changepoint_ipca_nao_comercializavel, reference, metric = "precision"), 2)   # 0.27
round(evaluate(changepoint_ipca_nao_comercializavel, reference, metric = "recall"), 2)      # 0.25

#Plot
print(evtplot(test_ipca_nao_comercializavel, changepoint_ipca_nao_comercializavel, reference))

##### 12. ipca_monitorado #####
#Detect
changepoint_ipca_monitorado <- evtdet.seminalChangePoint2(test_ipca_monitorado, w = 30,
                                                          mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_ipca_monitorado, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     14     42
# FALSE    51     142 

round(evaluate(changepoint_ipca_monitorado, reference, metric = "F1"), 2)          # 0.23
round(evaluate(changepoint_ipca_monitorado, reference, metric = "accuracy"), 2)    # 0.63
round(evaluate(changepoint_ipca_monitorado, reference, metric = "sensitivity"), 2) # 0.22
round(evaluate(changepoint_ipca_monitorado, reference, metric = "specificity"), 2) # 0.77
round(evaluate(changepoint_ipca_monitorado, reference, metric = "precision"), 2)   # 0.25
round(evaluate(changepoint_ipca_monitorado, reference, metric = "recall"), 2)      # 0.22

#Plot
print(evtplot(test_ipca_monitorado, changepoint_ipca_monitorado, reference))

##### 13. ipca_nao_duravel #####
#Detect
changepoint_ipca_nao_duravel <- evtdet.seminalChangePoint2(test_ipca_nao_duravel, w = 30,
                                                           mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_ipca_nao_duravel, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     4      41 
# FALSE    61     143  

round(evaluate(changepoint_ipca_nao_duravel, reference, metric = "F1"), 2)          # 0.07
round(evaluate(changepoint_ipca_nao_duravel, reference, metric = "accuracy"), 2)    # 0.59
round(evaluate(changepoint_ipca_nao_duravel, reference, metric = "sensitivity"), 2) # 0.06
round(evaluate(changepoint_ipca_nao_duravel, reference, metric = "specificity"), 2) # 0.78
round(evaluate(changepoint_ipca_nao_duravel, reference, metric = "precision"), 2)   # 0.09
round(evaluate(changepoint_ipca_nao_duravel, reference, metric = "recall"), 2)      # 0.06

#Plot
print(evtplot(test_ipca_nao_duravel, changepoint_ipca_nao_duravel, reference))

##### 14. ipca_semi_duravel #####
#Detect
changepoint_ipca_semi_duravel <- evtdet.seminalChangePoint2(test_ipca_semi_duravel, w = 30,
                                                            mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_ipca_semi_duravel, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     8      39
# FALSE    57     145   

round(evaluate(changepoint_ipca_semi_duravel, reference, metric = "F1"), 2)          # 0.14
round(evaluate(changepoint_ipca_semi_duravel, reference, metric = "accuracy"), 2)    # 0.61
round(evaluate(changepoint_ipca_semi_duravel, reference, metric = "sensitivity"), 2) # 0.12
round(evaluate(changepoint_ipca_semi_duravel, reference, metric = "specificity"), 2) # 0.79
round(evaluate(changepoint_ipca_semi_duravel, reference, metric = "precision"), 2)   # 0.17
round(evaluate(changepoint_ipca_semi_duravel, reference, metric = "recall"), 2)      # 0.12

#Plot
print(evtplot(test_ipca_semi_duravel, changepoint_ipca_semi_duravel, reference))

##### 15. ipca_duravel #####
#Detect
changepoint_ipca_duravel <- evtdet.seminalChangePoint2(test_ipca_duravel, w = 30,
                                                       mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_ipca_duravel, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     25     32   
# FALSE    40     152 

round(evaluate(changepoint_ipca_duravel, reference, metric = "F1"), 2)          # 0.41
round(evaluate(changepoint_ipca_duravel, reference, metric = "accuracy"), 2)    # 0.71
round(evaluate(changepoint_ipca_duravel, reference, metric = "sensitivity"), 2) # 0.38
round(evaluate(changepoint_ipca_duravel, reference, metric = "specificity"), 2) # 0.83
round(evaluate(changepoint_ipca_duravel, reference, metric = "precision"), 2)   # 0.44
round(evaluate(changepoint_ipca_duravel, reference, metric = "recall"), 2)      # 0.38

#Plot
print(evtplot(test_ipca_duravel, changepoint_ipca_duravel, reference))

##### 16. ipca_servico #####
#Detect
changepoint_ipca_servico <- evtdet.seminalChangePoint2(test_ipca_servico, w = 30,
                                                       mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_ipca_servico, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     18     44  
# FALSE    47     140

round(evaluate(changepoint_ipca_servico, reference, metric = "F1"), 2)          # 0.28
round(evaluate(changepoint_ipca_servico, reference, metric = "accuracy"), 2)    # 0.63
round(evaluate(changepoint_ipca_servico, reference, metric = "sensitivity"), 2) # 0.28
round(evaluate(changepoint_ipca_servico, reference, metric = "specificity"), 2) # 0.76
round(evaluate(changepoint_ipca_servico, reference, metric = "precision"), 2)   # 0.29
round(evaluate(changepoint_ipca_servico, reference, metric = "recall"), 2)      # 0.28

#Plot
print(evtplot(test_ipca_servico, changepoint_ipca_servico, reference))

##### 17. ipca_livre #####
#Detect
changepoint_ipca_livre <- evtdet.seminalChangePoint2(test_ipca_livre, w = 30,
                                                     mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_ipca_livre, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     7      42 
# FALSE    58     142  

round(evaluate(changepoint_ipca_livre, reference, metric = "F1"), 2)          # 0.12
round(evaluate(changepoint_ipca_livre, reference, metric = "accuracy"), 2)    # 0.60
round(evaluate(changepoint_ipca_livre, reference, metric = "sensitivity"), 2) # 0.11
round(evaluate(changepoint_ipca_livre, reference, metric = "specificity"), 2) # 0.77
round(evaluate(changepoint_ipca_livre, reference, metric = "precision"), 2)   # 0.14
round(evaluate(changepoint_ipca_livre, reference, metric = "recall"), 2)      # 0.11

#Plot
print(evtplot(test_ipca_livre, changepoint_ipca_livre, reference))

##### 18. ipca_industrial #####
#Detect
changepoint_ipca_industrial <- evtdet.seminalChangePoint2(test_ipca_industrial, w = 30,
                                                          mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_ipca_industrial, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     13     34  
# FALSE    52     150  

round(evaluate(changepoint_ipca_industrial, reference, metric = "F1"), 2)          # 0.23
round(evaluate(changepoint_ipca_industrial, reference, metric = "accuracy"), 2)    # 0.65
round(evaluate(changepoint_ipca_industrial, reference, metric = "sensitivity"), 2) # 0.20
round(evaluate(changepoint_ipca_industrial, reference, metric = "specificity"), 2) # 0.82
round(evaluate(changepoint_ipca_industrial, reference, metric = "precision"), 2)   # 0.28
round(evaluate(changepoint_ipca_industrial, reference, metric = "recall"), 2)      # 0.20

#Plot
print(evtplot(test_ipca_industrial, changepoint_ipca_industrial, reference))

##### 19. ipca_comida_casa #####
#Detect
changepoint_ipca_comida_casa <- evtdet.seminalChangePoint2(test_ipca_comida_casa, w = 30,
                                                           mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_ipca_comida_casa, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     5      47   
# FALSE    60     137  

round(evaluate(changepoint_ipca_comida_casa, reference, metric = "F1"), 2)          # 0.09
round(evaluate(changepoint_ipca_comida_casa, reference, metric = "accuracy"), 2)    # 0.57
round(evaluate(changepoint_ipca_comida_casa, reference, metric = "sensitivity"), 2) # 0.08
round(evaluate(changepoint_ipca_comida_casa, reference, metric = "specificity"), 2) # 0.74
round(evaluate(changepoint_ipca_comida_casa, reference, metric = "precision"), 2)   # 0.10
round(evaluate(changepoint_ipca_comida_casa, reference, metric = "recall"), 2)      # 0.08

#Plot
print(evtplot(test_ipca_comida_casa, changepoint_ipca_comida_casa, reference))

##### 20. ipca_transporte #####
#Detect
changepoint_ipca_transporte <- evtdet.seminalChangePoint2(test_ipca_transporte, w = 30,
                                                          mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_ipca_transporte, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     15     40
# FALSE    50     144 

round(evaluate(changepoint_ipca_transporte, reference, metric = "F1"), 2)          # 0.25
round(evaluate(changepoint_ipca_transporte, reference, metric = "accuracy"), 2)    # 0.64
round(evaluate(changepoint_ipca_transporte, reference, metric = "sensitivity"), 2) # 0.23
round(evaluate(changepoint_ipca_transporte, reference, metric = "specificity"), 2) # 0.78
round(evaluate(changepoint_ipca_transporte, reference, metric = "precision"), 2)   # 0.27
round(evaluate(changepoint_ipca_transporte, reference, metric = "recall"), 2)      # 0.23

#Plot
print(evtplot(test_ipca_transporte, changepoint_ipca_transporte, reference))

###############################
##### ChangeFinder (2005) #####
###############################

##### 1. ipca #####
#Detect
changefinder_ipca <- evtdet.changeFinder(test_ipca, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_ipca, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     9      9  
# FALSE    56     175

round(evaluate(changefinder_ipca, reference, metric = "F1"), 2)          # 0.22
round(evaluate(changefinder_ipca, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(changefinder_ipca, reference, metric = "sensitivity"), 2) # 0.14
round(evaluate(changefinder_ipca, reference, metric = "specificity"), 2) # 0.95
round(evaluate(changefinder_ipca, reference, metric = "precision"), 2)   # 0.50
round(evaluate(changefinder_ipca, reference, metric = "recall"), 2)      # 0.14

#Plot
print(evtplot(test_ipca, changefinder_ipca, reference))

##### 2. ipca_comida_bebida #####
#Detect
changefinder_ipca_comida_bebida <- evtdet.changeFinder(test_ipca_comida_bebida, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_ipca_comida_bebida, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     5      3
# FALSE    60     181

round(evaluate(changefinder_ipca_comida_bebida, reference, metric = "F1"), 2)          # 0.14
round(evaluate(changefinder_ipca_comida_bebida, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(changefinder_ipca_comida_bebida, reference, metric = "sensitivity"), 2) # 0.08
round(evaluate(changefinder_ipca_comida_bebida, reference, metric = "specificity"), 2) # 0.98
round(evaluate(changefinder_ipca_comida_bebida, reference, metric = "precision"), 2)   # 0.62
round(evaluate(changefinder_ipca_comida_bebida, reference, metric = "recall"), 2)      # 0.08

#Plot
print(evtplot(test_ipca_comida_bebida, changefinder_ipca_comida_bebida, reference))

##### 3. ipca_habitat #####
#Detect
changefinder_ipca_habitat <- evtdet.changeFinder(test_ipca_habitat, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_ipca_habitat, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     11     19  
# FALSE    54     165 

round(evaluate(changefinder_ipca_habitat, reference, metric = "F1"), 2)          # 0.23
round(evaluate(changefinder_ipca_habitat, reference, metric = "accuracy"), 2)    # 0.71
round(evaluate(changefinder_ipca_habitat, reference, metric = "sensitivity"), 2) # 0.17
round(evaluate(changefinder_ipca_habitat, reference, metric = "specificity"), 2) # 0.90
round(evaluate(changefinder_ipca_habitat, reference, metric = "precision"), 2)   # 0.37
round(evaluate(changefinder_ipca_habitat, reference, metric = "recall"), 2)      # 0.17

#Plot
print(evtplot(test_ipca_habitat, changefinder_ipca_habitat, reference))

##### 4. ipca_artigos_casa #####
#Detect
changefinder_ipca_artigos_casa <- evtdet.changeFinder(test_ipca_artigos_casa, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_ipca_artigos_casa, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     7      4  
# FALSE    58     180  

round(evaluate(changefinder_ipca_artigos_casa, reference, metric = "F1"), 2)          # 0.18
round(evaluate(changefinder_ipca_artigos_casa, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(changefinder_ipca_artigos_casa, reference, metric = "sensitivity"), 2) # 0.11
round(evaluate(changefinder_ipca_artigos_casa, reference, metric = "specificity"), 2) # 0.98
round(evaluate(changefinder_ipca_artigos_casa, reference, metric = "precision"), 2)   # 0.64
round(evaluate(changefinder_ipca_artigos_casa, reference, metric = "recall"), 2)      # 0.11

#Plot
print(evtplot(test_ipca_artigos_casa, changefinder_ipca_artigos_casa, reference))

##### 5. ipca_roupa #####
#Detect
changefinder_ipca_roupa <- evtdet.changeFinder(test_ipca_roupa, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_ipca_roupa, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     5      7 
# FALSE    60     177  

round(evaluate(changefinder_ipca_roupa, reference, metric = "F1"), 2)          # 0.13
round(evaluate(changefinder_ipca_roupa, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(changefinder_ipca_roupa, reference, metric = "sensitivity"), 2) # 0.08
round(evaluate(changefinder_ipca_roupa, reference, metric = "specificity"), 2) # 0.96
round(evaluate(changefinder_ipca_roupa, reference, metric = "precision"), 2)   # 0.42
round(evaluate(changefinder_ipca_roupa, reference, metric = "recall"), 2)      # 0.08

#Plot
print(evtplot(test_ipca_roupa, changefinder_ipca_roupa, reference))

##### 6. ipca_cumunicacao #####
#Detect
changefinder_ipca_cumunicacao <- evtdet.changeFinder(test_ipca_cumunicacao, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_ipca_cumunicacao, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     3      12   
# FALSE    62     172  

round(evaluate(changefinder_ipca_cumunicacao, reference, metric = "F1"), 2)          # 0.07
round(evaluate(changefinder_ipca_cumunicacao, reference, metric = "accuracy"), 2)    # 0.70
round(evaluate(changefinder_ipca_cumunicacao, reference, metric = "sensitivity"), 2) # 0.05
round(evaluate(changefinder_ipca_cumunicacao, reference, metric = "specificity"), 2) # 0.93
round(evaluate(changefinder_ipca_cumunicacao, reference, metric = "precision"), 2)   # 0.20
round(evaluate(changefinder_ipca_cumunicacao, reference, metric = "recall"), 2)      # 0.05

#Plot
print(evtplot(test_ipca_cumunicacao, changefinder_ipca_cumunicacao, reference))

##### 7. ipca_saude #####
#Detect
changefinder_ipca_saude <- evtdet.changeFinder(test_ipca_saude, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_ipca_saude, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     7      19 
# FALSE    58     165 

round(evaluate(changefinder_ipca_saude, reference, metric = "F1"), 2)          # 0.15
round(evaluate(changefinder_ipca_saude, reference, metric = "accuracy"), 2)    # 0.69
round(evaluate(changefinder_ipca_saude, reference, metric = "sensitivity"), 2) # 0.11
round(evaluate(changefinder_ipca_saude, reference, metric = "specificity"), 2) # 0.90
round(evaluate(changefinder_ipca_saude, reference, metric = "precision"), 2)   # 0.27
round(evaluate(changefinder_ipca_saude, reference, metric = "recall"), 2)      # 0.11

#Plot
print(evtplot(test_ipca_saude, changefinder_ipca_saude, reference))

##### 8. ipca_desp_pessoal #####
#Detect
changefinder_ipca_desp_pessoal <- evtdet.changeFinder(test_ipca_desp_pessoal, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_ipca_desp_pessoal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     2      14   
# FALSE    63     170 

round(evaluate(changefinder_ipca_desp_pessoal, reference, metric = "F1"), 2)          # 0.05
round(evaluate(changefinder_ipca_desp_pessoal, reference, metric = "accuracy"), 2)    # 0.69
round(evaluate(changefinder_ipca_desp_pessoal, reference, metric = "sensitivity"), 2) # 0.03
round(evaluate(changefinder_ipca_desp_pessoal, reference, metric = "specificity"), 2) # 0.92
round(evaluate(changefinder_ipca_desp_pessoal, reference, metric = "precision"), 2)   # 0.12
round(evaluate(changefinder_ipca_desp_pessoal, reference, metric = "recall"), 2)      # 0.03

#Plot
print(evtplot(test_ipca_desp_pessoal, changefinder_ipca_desp_pessoal, reference))

##### 9. ipca_educacao #####
#Detect
changefinder_ipca_educacao <- evtdet.changeFinder(test_ipca_educacao, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_ipca_educacao, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     8      18
# FALSE    57     166  

round(evaluate(changefinder_ipca_educacao, reference, metric = "F1"), 2)          # 0.18
round(evaluate(changefinder_ipca_educacao, reference, metric = "accuracy"), 2)    # 0.70
round(evaluate(changefinder_ipca_educacao, reference, metric = "sensitivity"), 2) # 0.12
round(evaluate(changefinder_ipca_educacao, reference, metric = "specificity"), 2) # 0.90
round(evaluate(changefinder_ipca_educacao, reference, metric = "precision"), 2)   # 0.31
round(evaluate(changefinder_ipca_educacao, reference, metric = "recall"), 2)      # 0.12

#Plot
print(evtplot(test_ipca_educacao, changefinder_ipca_educacao, reference))

##### 10. ipca_comercializavel #####
#Detect
changefinder_ipca_comercializavel <- evtdet.changeFinder(test_ipca_comercializavel, mdl = linreg, 
                                                         na.action = na.omit)

#Evaluate
evaluate(changefinder_ipca_comercializavel, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     6      7 
# FALSE    59     177  

round(evaluate(changefinder_ipca_comercializavel, reference, metric = "F1"), 2)          # 0.15
round(evaluate(changefinder_ipca_comercializavel, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(changefinder_ipca_comercializavel, reference, metric = "sensitivity"), 2) # 0.09
round(evaluate(changefinder_ipca_comercializavel, reference, metric = "specificity"), 2) # 0.96
round(evaluate(changefinder_ipca_comercializavel, reference, metric = "precision"), 2)   # 0.46
round(evaluate(changefinder_ipca_comercializavel, reference, metric = "recall"), 2)      # 0.09

#Plot
print(evtplot(test_ipca_comercializavel, changefinder_ipca_comercializavel, reference))

##### 11. ipca_nao_comercializavel #####
#Detect
changefinder_ipca_nao_comercializavel <- evtdet.changeFinder(test_ipca_nao_comercializavel, mdl = linreg, 
                                                             na.action = na.omit)

#Evaluate
evaluate(changefinder_ipca_nao_comercializavel, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     2      12  
# FALSE    63     172 

round(evaluate(changefinder_ipca_nao_comercializavel, reference, metric = "F1"), 2)          # 0.05
round(evaluate(changefinder_ipca_nao_comercializavel, reference, metric = "accuracy"), 2)    # 0.70
round(evaluate(changefinder_ipca_nao_comercializavel, reference, metric = "sensitivity"), 2) # 0.03
round(evaluate(changefinder_ipca_nao_comercializavel, reference, metric = "specificity"), 2) # 0.93
round(evaluate(changefinder_ipca_nao_comercializavel, reference, metric = "precision"), 2)   # 0.14
round(evaluate(changefinder_ipca_nao_comercializavel, reference, metric = "recall"), 2)      # 0.03

#Plot
print(evtplot(test_ipca_nao_comercializavel, changefinder_ipca_nao_comercializavel, reference))

##### 12. ipca_monitorado #####
#Detect
changefinder_ipca_monitorado <- evtdet.changeFinder(test_ipca_monitorado, mdl = linreg,
                                                    na.action = na.omit)

#Evaluate
evaluate(changefinder_ipca_monitorado, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     9      14
# FALSE    56     170

round(evaluate(changefinder_ipca_monitorado, reference, metric = "F1"), 2)          # 0.20
round(evaluate(changefinder_ipca_monitorado, reference, metric = "accuracy"), 2)    # 0.72
round(evaluate(changefinder_ipca_monitorado, reference, metric = "sensitivity"), 2) # 0.14
round(evaluate(changefinder_ipca_monitorado, reference, metric = "specificity"), 2) # 0.92
round(evaluate(changefinder_ipca_monitorado, reference, metric = "precision"), 2)   # 0.39
round(evaluate(changefinder_ipca_monitorado, reference, metric = "recall"), 2)      # 0.14

#Plot
print(evtplot(test_ipca_monitorado, changefinder_ipca_monitorado, reference))

##### 13. ipca_nao_duravel #####
#Detect
changefinder_ipca_nao_duravel <- evtdet.changeFinder(test_ipca_nao_duravel, mdl = linreg,
                                                     a.action = na.omit)

#Evaluate
evaluate(changefinder_ipca_nao_duravel, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     6      7    
# FALSE    59     177  

round(evaluate(changefinder_ipca_nao_duravel, reference, metric = "F1"), 2)          # 0.15
round(evaluate(changefinder_ipca_nao_duravel, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(changefinder_ipca_nao_duravel, reference, metric = "sensitivity"), 2) # 0.09
round(evaluate(changefinder_ipca_nao_duravel, reference, metric = "specificity"), 2) # 0.96
round(evaluate(changefinder_ipca_nao_duravel, reference, metric = "precision"), 2)   # 0.46
round(evaluate(changefinder_ipca_nao_duravel, reference, metric = "recall"), 2)      # 0.09

#Plot
print(evtplot(test_ipca_nao_duravel, changefinder_ipca_nao_duravel, reference))

##### 14. ipca_semi_duravel ##### 
#Detect
changefinder_ipca_semi_duravel <- evtdet.changeFinder(test_ipca_semi_duravel, mdl = linreg,
                                                      na.action = na.omit)

#Evaluate
evaluate(changefinder_ipca_semi_duravel, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     1      3  
# FALSE    64     181 

round(evaluate(changefinder_ipca_semi_duravel, reference, metric = "F1"), 2)          # 0.03
round(evaluate(changefinder_ipca_semi_duravel, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(changefinder_ipca_semi_duravel, reference, metric = "sensitivity"), 2) # 0.02
round(evaluate(changefinder_ipca_semi_duravel, reference, metric = "specificity"), 2) # 0.98
round(evaluate(changefinder_ipca_semi_duravel, reference, metric = "precision"), 2)   # 0.25
round(evaluate(changefinder_ipca_semi_duravel, reference, metric = "recall"), 2)      # 0.02

#Plot
print(evtplot(test_ipca_semi_duravel, changefinder_ipca_semi_duravel, reference))

##### 15. ipca_duravel ##### 
#Detect
changefinder_ipca_duravel <- evtdet.changeFinder(test_ipca_duravel, mdl = linreg,
                                                 na.action = na.omit)

#Evaluate
evaluate(changefinder_ipca_duravel, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     6      7   
# FALSE    59     177   

round(evaluate(changefinder_ipca_duravel, reference, metric = "F1"), 2)          # 0.15
round(evaluate(changefinder_ipca_duravel, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(changefinder_ipca_duravel, reference, metric = "sensitivity"), 2) # 0.09
round(evaluate(changefinder_ipca_duravel, reference, metric = "specificity"), 2) # 0.96
round(evaluate(changefinder_ipca_duravel, reference, metric = "precision"), 2)   # 0.46
round(evaluate(changefinder_ipca_duravel, reference, metric = "recall"), 2)      # 0.09

#Plot
print(evtplot(test_ipca_duravel, changefinder_ipca_duravel, reference))

##### 16. ipca_servico ##### 
#Detect
changefinder_ipca_servico <- evtdet.changeFinder(test_ipca_servico, mdl = linreg,
                                                 na.action = na.omit)

#Evaluate
evaluate(changefinder_ipca_servico, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     4      15   
# FALSE    61     169

round(evaluate(changefinder_ipca_servico, reference, metric = "F1"), 2)          # 0.10
round(evaluate(changefinder_ipca_servico, reference, metric = "accuracy"), 2)    # 0.69
round(evaluate(changefinder_ipca_servico, reference, metric = "sensitivity"), 2) # 0.06
round(evaluate(changefinder_ipca_servico, reference, metric = "specificity"), 2) # 0.92
round(evaluate(changefinder_ipca_servico, reference, metric = "precision"), 2)   # 0.21
round(evaluate(changefinder_ipca_servico, reference, metric = "recall"), 2)      # 0.06

#Plot
print(evtplot(test_ipca_servico, changefinder_ipca_servico, reference))

##### 17. ipca_livre ##### 
#Detect
changefinder_ipca_livre <- evtdet.changeFinder(test_ipca_livre, mdl = linreg,
                                               na.action = na.omit)

#Evaluate
evaluate(changefinder_ipca_livre, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     2      4    
# FALSE    63     180  

round(evaluate(changefinder_ipca_livre, reference, metric = "F1"), 2)          # 0.06
round(evaluate(changefinder_ipca_livre, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(changefinder_ipca_livre, reference, metric = "sensitivity"), 2) # 0.03
round(evaluate(changefinder_ipca_livre, reference, metric = "specificity"), 2) # 0.98
round(evaluate(changefinder_ipca_livre, reference, metric = "precision"), 2)   # 0.33
round(evaluate(changefinder_ipca_livre, reference, metric = "recall"), 2)      # 0.03

#Plot
print(evtplot(test_ipca_livre, changefinder_ipca_livre, reference))

##### 18. ipca_industrial ##### 
#Detect
changefinder_ipca_industrial <- evtdet.changeFinder(test_ipca_industrial, mdl = linreg,
                                                    na.action = na.omit)

#Evaluate
evaluate(changefinder_ipca_industrial, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     8      8    
# FALSE    57     176  

round(evaluate(changefinder_ipca_industrial, reference, metric = "F1"), 2)          # 0.20
round(evaluate(changefinder_ipca_industrial, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(changefinder_ipca_industrial, reference, metric = "sensitivity"), 2) # 0.12
round(evaluate(changefinder_ipca_industrial, reference, metric = "specificity"), 2) # 0.96
round(evaluate(changefinder_ipca_industrial, reference, metric = "precision"), 2)   # 0.50
round(evaluate(changefinder_ipca_industrial, reference, metric = "recall"), 2)      # 0.12

#Plot
print(evtplot(test_ipca_industrial, changefinder_ipca_industrial, reference))

##### 19. ipca_industrial ##### 
#Detect
changefinder_ipca_comida_casa <- evtdet.changeFinder(test_ipca_comida_casa, mdl = linreg,
                                                     na.action = na.omit)

#Evaluate
evaluate(changefinder_ipca_comida_casa, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     5      6      
# FALSE    60     178  

round(evaluate(changefinder_ipca_comida_casa, reference, metric = "F1"), 2)          # 0.13
round(evaluate(changefinder_ipca_comida_casa, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(changefinder_ipca_comida_casa, reference, metric = "sensitivity"), 2) # 0.08
round(evaluate(changefinder_ipca_comida_casa, reference, metric = "specificity"), 2) # 0.97
round(evaluate(changefinder_ipca_comida_casa, reference, metric = "precision"), 2)   # 0.45
round(evaluate(changefinder_ipca_comida_casa, reference, metric = "recall"), 2)      # 0.08

#Plot
print(evtplot(test_ipca_comida_casa, changefinder_ipca_comida_casa, reference))

##### 20. ipca_transporte ##### 
#Detect
changefinder_ipca_transporte <- evtdet.changeFinder(test_ipca_transporte, mdl = linreg,
                                                    na.action = na.omit)

#Evaluate
evaluate(changefinder_ipca_transporte, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     5      7   
# FALSE    60     177

round(evaluate(changefinder_ipca_transporte, reference, metric = "F1"), 2)          # 0.13
round(evaluate(changefinder_ipca_transporte, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(changefinder_ipca_transporte, reference, metric = "sensitivity"), 2) # 0.08
round(evaluate(changefinder_ipca_transporte, reference, metric = "specificity"), 2) # 0.96
round(evaluate(changefinder_ipca_transporte, reference, metric = "precision"), 2)   # 0.42
round(evaluate(changefinder_ipca_transporte, reference, metric = "recall"), 2)      # 0.08

#Plot
print(evtplot(test_ipca_transporte, changefinder_ipca_transporte, reference))
