###############################################
##### Deteco de Eventos - Taxa de Juros #####
###############################################

################
##### Data #####
################

library(tibble)
library(EventDetectR)
source("https://raw.githubusercontent.com/cefet-rj-dal/harbinger/master/harbinger.R")

attach(df_interest)
head(df_interest)
str(df_interest)

test_selic <- subset(df_interest, select = c(Data, selic))
test_cdi <- subset(df_interest, select = c(Data, cdi))
test_ltn1m <- subset(df_interest, select = c(Data, ltn1m))
test_ltn3m <- subset(df_interest, select = c(Data, ltn3m))
test_ltn6m <- subset(df_interest, select = c(Data, ltn6m))
test_ltn12m <- subset(df_interest, select = c(Data, ltn12m))
test_spread <- subset(df_interest, select = c(Data, spread))
reference <- subset(df_interest, select = c(Data, event))

#####################
##### Anomalize #####
#####################

##### 1. selic #####
#Detect
anomalize_selic <- evtdet.anomalize(test_selic, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_selic, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     0      6     
# FALSE    65     178  

round(evaluate(anomalize_selic, reference, metric = "F1"), 2)          # NaN
round(evaluate(anomalize_selic, reference, metric = "accuracy"), 2)    # 0.71
round(evaluate(anomalize_selic, reference, metric = "sensitivity"), 2) # 0.00
round(evaluate(anomalize_selic, reference, metric = "specificity"), 2) # 0.97
round(evaluate(anomalize_selic, reference, metric = "precision"), 2)   # 0.00
round(evaluate(anomalize_selic, reference, metric = "recall"), 2)      # 0.00

#Plot
print(evtplot(test_selic, anomalize_selic, reference))

##### 2. cdi #####
#Detect
anomalize_cdi <- evtdet.anomalize(test_cdi, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_cdi, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     0      6     
# FALSE    65     178  

round(evaluate(anomalize_cdi, reference, metric = "F1"), 2)          # NaN
round(evaluate(anomalize_cdi, reference, metric = "accuracy"), 2)    # 0.71
round(evaluate(anomalize_cdi, reference, metric = "sensitivity"), 2) # 0.00
round(evaluate(anomalize_cdi, reference, metric = "specificity"), 2) # 0.97
round(evaluate(anomalize_cdi, reference, metric = "precision"), 2)   # 0.00
round(evaluate(anomalize_cdi, reference, metric = "recall"), 2)      # 0.00

#Plot
print(evtplot(test_cdi, anomalize_cdi, reference))

##### 3. ltn1m #####
#Detect
anomalize_ltn1m <- evtdet.anomalize(test_ltn1m, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_ltn1m, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     1      7 
# FALSE    64     177  

round(evaluate(anomalize_ltn1m, reference, metric = "F1"), 2)          # 0.03
round(evaluate(anomalize_ltn1m, reference, metric = "accuracy"), 2)    # 0.71
round(evaluate(anomalize_ltn1m, reference, metric = "sensitivity"), 2) # 0.02
round(evaluate(anomalize_ltn1m, reference, metric = "specificity"), 2) # 0.96
round(evaluate(anomalize_ltn1m, reference, metric = "precision"), 2)   # 0.12
round(evaluate(anomalize_ltn1m, reference, metric = "recall"), 2)      # 0.02

#Plot
print(evtplot(test_ltn1m, anomalize_ltn1m, reference))

##### 4. ltn3m #####
#Detect
anomalize_ltn3m <- evtdet.anomalize(test_ltn3m, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_ltn3m, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     1      7  
# FALSE    64     177   

round(evaluate(anomalize_ltn3m, reference, metric = "F1"), 2)          # 0.03
round(evaluate(anomalize_ltn3m, reference, metric = "accuracy"), 2)    # 0.71
round(evaluate(anomalize_ltn3m, reference, metric = "sensitivity"), 2) # 0.02
round(evaluate(anomalize_ltn3m, reference, metric = "specificity"), 2) # 0.96
round(evaluate(anomalize_ltn3m, reference, metric = "precision"), 2)   # 0.12
round(evaluate(anomalize_ltn3m, reference, metric = "recall"), 2)      # 0.02

#Plot
print(evtplot(test_ltn3m, anomalize_ltn3m, reference))

##### 5. ltn6m #####
#Detect
anomalize_ltn6m <- evtdet.anomalize(test_ltn6m, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_ltn6m, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     2      7  
# FALSE    63     177

round(evaluate(anomalize_ltn6m, reference, metric = "F1"), 2)          # 0.05
round(evaluate(anomalize_ltn6m, reference, metric = "accuracy"), 2)    # 0.72
round(evaluate(anomalize_ltn6m, reference, metric = "sensitivity"), 2) # 0.03
round(evaluate(anomalize_ltn6m, reference, metric = "specificity"), 2) # 0.96
round(evaluate(anomalize_ltn6m, reference, metric = "precision"), 2)   # 0.22
round(evaluate(anomalize_ltn6m, reference, metric = "recall"), 2)      # 0.03

#Plot
print(evtplot(test_ltn6m, anomalize_ltn6m, reference))

##### 6. ltn12m #####
#Detect
anomalize_ltn12m <- evtdet.anomalize(test_ltn12m, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_ltn12m, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     5      9 
# FALSE    60     175 

round(evaluate(anomalize_ltn12m, reference, metric = "F1"), 2)          # 0.13
round(evaluate(anomalize_ltn12m, reference, metric = "accuracy"), 2)    # 0.72
round(evaluate(anomalize_ltn12m, reference, metric = "sensitivity"), 2) # 0.08
round(evaluate(anomalize_ltn12m, reference, metric = "specificity"), 2) # 0.95
round(evaluate(anomalize_ltn12m, reference, metric = "precision"), 2)   # 0.36
round(evaluate(anomalize_ltn12m, reference, metric = "recall"), 2)      # 0.08

#Plot
print(evtplot(test_ltn12m, anomalize_ltn12m, reference))

##### 7. spread #####
#Detect
anomalize_spread <- evtdet.anomalize(test_spread, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_spread, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     3      9    
# FALSE    62     175  

round(evaluate(anomalize_spread, reference, metric = "F1"), 2)          # 0.08
round(evaluate(anomalize_spread, reference, metric = "accuracy"), 2)    # 0.71
round(evaluate(anomalize_spread, reference, metric = "sensitivity"), 2) # 0.05
round(evaluate(anomalize_spread, reference, metric = "specificity"), 2) # 0.95
round(evaluate(anomalize_spread, reference, metric = "precision"), 2)   # 0.25
round(evaluate(anomalize_spread, reference, metric = "recall"), 2)      # 0.05

#Plot
print(evtplot(test_spread, anomalize_spread, reference))

###########################################
##### Adaptive Normalization Outliers #####
###########################################

##### 1. selic #####
#Detect
an_selic <- evtdet.an_outliers(test_selic, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_selic, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     0      1  
# FALSE    65     183  

round(evaluate(an_selic, reference, metric = "F1"), 2)          # NaN
round(evaluate(an_selic, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(an_selic, reference, metric = "sensitivity"), 2) # 0.00
round(evaluate(an_selic, reference, metric = "specificity"), 2) # 0.99
round(evaluate(an_selic, reference, metric = "precision"), 2)   # 0.98
round(evaluate(an_selic, reference, metric = "recall"), 2)      # 0.00

#Plot
print(evtplot(test_selic, an_selic, reference))

##### 2. cdi #####
#Detect
an_cdi <- evtdet.an_outliers(test_cdi, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_cdi, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     0      1    
# FALSE    65     183  

round(evaluate(an_cdi, reference, metric = "F1"), 2)          # NaN
round(evaluate(an_cdi, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(an_cdi, reference, metric = "sensitivity"), 2) # 0.00
round(evaluate(an_cdi, reference, metric = "specificity"), 2) # 0.99
round(evaluate(an_cdi, reference, metric = "precision"), 2)   # 0.00
round(evaluate(an_cdi, reference, metric = "recall"), 2)      # 0.00

#Plot
print(evtplot(test_cdi, an_cdi, reference))

##### 3. ltn1m #####
#Detect
an_ltn1m <- evtdet.an_outliers(test_ltn1m, w = 30, alpha = 1.5, na.action = na.omit)

#Error in data.frame(..., check.names = FALSE) : 
#  arguments imply differing number of rows: 0, 1

#Evaluate
evaluate(an_ltn1m, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE      

round(evaluate(an_ltn1m, reference, metric = "F1"), 2)          # 
round(evaluate(an_ltn1m, reference, metric = "accuracy"), 2)    # 
round(evaluate(an_ltn1m, reference, metric = "sensitivity"), 2) # 
round(evaluate(an_ltn1m, reference, metric = "specificity"), 2) # 
round(evaluate(an_ltn1m, reference, metric = "precision"), 2)   # 
round(evaluate(an_ltn1m, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_ltn1m, an_ltn1m, reference))

##### 4. ltn3m #####
#Detect
an_ltn3m <- evtdet.an_outliers(test_ltn3m, w = 30, alpha = 1.5, na.action = na.omit)

#Error in data.frame(..., check.names = FALSE) : 
#  arguments imply differing number of rows: 0, 1

#Evaluate
evaluate(an_ltn3m, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE      

round(evaluate(an_ltn3m, reference, metric = "F1"), 2)          # 
round(evaluate(an_ltn3m, reference, metric = "accuracy"), 2)    # 
round(evaluate(an_ltn3m, reference, metric = "sensitivity"), 2) # 
round(evaluate(an_ltn3m, reference, metric = "specificity"), 2) # 
round(evaluate(an_ltn3m, reference, metric = "precision"), 2)   # 
round(evaluate(an_ltn3m, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_ltn3m, an_ltn3m, reference))

##### 5. ltn6m #####
#Detect
an_ltn6m <- evtdet.an_outliers(test_ltn6m, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_ltn6m, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     0      1 
# FALSE    65     183  

round(evaluate(an_ltn6m, reference, metric = "F1"), 2)          # NaN
round(evaluate(an_ltn6m, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(an_ltn6m, reference, metric = "sensitivity"), 2) # 0.00
round(evaluate(an_ltn6m, reference, metric = "specificity"), 2) # 0.99
round(evaluate(an_ltn6m, reference, metric = "precision"), 2)   # 0.00
round(evaluate(an_ltn6m, reference, metric = "recall"), 2)      # 0.00

#Plot
print(evtplot(test_ltn6m, an_ltn6m, reference))

##### 6. ltn12m #####
#Detect
an_ltn12m <- evtdet.an_outliers(test_ltn12m, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_ltn12m, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     2      5 
# FALSE    63     179

round(evaluate(an_ltn12m, reference, metric = "F1"), 2)          # 0.06
round(evaluate(an_ltn12m, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(an_ltn12m, reference, metric = "sensitivity"), 2) # 0.03
round(evaluate(an_ltn12m, reference, metric = "specificity"), 2) # 0.97
round(evaluate(an_ltn12m, reference, metric = "precision"), 2)   # 0.29
round(evaluate(an_ltn12m, reference, metric = "recall"), 2)      # 0.03

#Plot
print(evtplot(test_ltn12m, an_ltn12m, reference))

##### 7. spread #####
#Detect
an_spread <- evtdet.an_outliers(test_spread, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_spread, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     3      9 
# FALSE    62     175  

round(evaluate(an_spread, reference, metric = "F1"), 2)          # 0.08
round(evaluate(an_spread, reference, metric = "accuracy"), 2)    # 0.71
round(evaluate(an_spread, reference, metric = "sensitivity"), 2) # 0.05
round(evaluate(an_spread, reference, metric = "specificity"), 2) # 0.95
round(evaluate(an_spread, reference, metric = "precision"), 2)   # 0.25
round(evaluate(an_spread, reference, metric = "recall"), 2)      # 0.05

#Plot
print(evtplot(test_spread, an_spread, reference))

#######################
##### EventDetect #####
#######################

##### 1. selic #####
#Detect
eventdetect_selic <- evtdet.eventdetect(na.omit(test_selic), w = 30)

#Evaluate
evaluate(eventdetect_selic, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     60     140 
# FALSE    5      44   

round(evaluate(eventdetect_selic, reference, metric = "F1"), 2)          # 0.45
round(evaluate(eventdetect_selic, reference, metric = "accuracy"), 2)    # 0.42
round(evaluate(eventdetect_selic, reference, metric = "sensitivity"), 2) # 0.92
round(evaluate(eventdetect_selic, reference, metric = "specificity"), 2) # 0.24
round(evaluate(eventdetect_selic, reference, metric = "precision"), 2)   # 0.30
round(evaluate(eventdetect_selic, reference, metric = "recall"), 2)      # 0.92

#Plot
print(evtplot(test_selic, eventdetect_selic, reference))

##### 2. cdi #####
#Detect
eventdetect_cdi <- evtdet.eventdetect(na.omit(test_cdi), w = 30)

#Evaluate
evaluate(eventdetect_cdi, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     60     140  
# FALSE    5      44  

round(evaluate(eventdetect_cdi, reference, metric = "F1"), 2)          # 0.45
round(evaluate(eventdetect_cdi, reference, metric = "accuracy"), 2)    # 0.42
round(evaluate(eventdetect_cdi, reference, metric = "sensitivity"), 2) # 0.92
round(evaluate(eventdetect_cdi, reference, metric = "specificity"), 2) # 0.24
round(evaluate(eventdetect_cdi, reference, metric = "precision"), 2)   # 0.30
round(evaluate(eventdetect_cdi, reference, metric = "recall"), 2)      # 0.92

#Plot
print(evtplot(test_cdi, eventdetect_cdi, reference))

##### 3. ltn1m #####
#Detect
eventdetect_ltn1m <- evtdet.eventdetect(na.omit(test_ltn1m), w = 30)

#Evaluate
evaluate(eventdetect_ltn1m, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     60     140 
# FALSE    5      44    

round(evaluate(eventdetect_ltn1m, reference, metric = "F1"), 2)          # 0.45
round(evaluate(eventdetect_ltn1m, reference, metric = "accuracy"), 2)    # 0.42
round(evaluate(eventdetect_ltn1m, reference, metric = "sensitivity"), 2) # 0.92
round(evaluate(eventdetect_ltn1m, reference, metric = "specificity"), 2) # 0.24
round(evaluate(eventdetect_ltn1m, reference, metric = "precision"), 2)   # 0.30
round(evaluate(eventdetect_ltn1m, reference, metric = "recall"), 2)      # 0.92

#Plot
print(evtplot(test_ltn1m, eventdetect_ltn1m, reference))

##### 4. ltn3m #####
#Detect
eventdetect_ltn3m <- evtdet.eventdetect(na.omit(test_ltn3m), w = 30)

#Evaluate
evaluate(eventdetect_ltn3m, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     60     128
# FALSE    5      56   

round(evaluate(eventdetect_ltn3m, reference, metric = "F1"), 2)          # 0.47
round(evaluate(eventdetect_ltn3m, reference, metric = "accuracy"), 2)    # 0.47
round(evaluate(eventdetect_ltn3m, reference, metric = "sensitivity"), 2) # 0.92
round(evaluate(eventdetect_ltn3m, reference, metric = "specificity"), 2) # 0.30
round(evaluate(eventdetect_ltn3m, reference, metric = "precision"), 2)   # 0.32
round(evaluate(eventdetect_ltn3m, reference, metric = "recall"), 2)      # 0.92

#Plot
print(evtplot(test_ltn3m, eventdetect_ltn3m, reference))

##### 5. ltn6m #####
#Detect
eventdetect_ltn6m <- evtdet.eventdetect(na.omit(test_ltn6m), w = 30)

#Evaluate
evaluate(eventdetect_ltn6m, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     60     113
# FALSE    5      71   

round(evaluate(eventdetect_ltn6m, reference, metric = "F1"), 2)          # 0.50
round(evaluate(eventdetect_ltn6m, reference, metric = "accuracy"), 2)    # 0.53
round(evaluate(eventdetect_ltn6m, reference, metric = "sensitivity"), 2) # 0.92
round(evaluate(eventdetect_ltn6m, reference, metric = "specificity"), 2) # 0.39
round(evaluate(eventdetect_ltn6m, reference, metric = "precision"), 2)   # 0.35
round(evaluate(eventdetect_ltn6m, reference, metric = "recall"), 2)      # 0.92

#Plot
print(evtplot(test_ltn6m, eventdetect_ltn6m, reference))

##### 6. ltn12m #####
#Detect
eventdetect_ltn12m <- evtdet.eventdetect(na.omit(test_ltn12m), w = 30)

#Evaluate
evaluate(eventdetect_ltn12m, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     37     83 
# FALSE    28     101

round(evaluate(eventdetect_ltn12m, reference, metric = "F1"), 2)          # 0.40
round(evaluate(eventdetect_ltn12m, reference, metric = "accuracy"), 2)    # 0.55
round(evaluate(eventdetect_ltn12m, reference, metric = "sensitivity"), 2) # 0.57
round(evaluate(eventdetect_ltn12m, reference, metric = "specificity"), 2) # 0.55
round(evaluate(eventdetect_ltn12m, reference, metric = "precision"), 2)   # 0.31
round(evaluate(eventdetect_ltn12m, reference, metric = "recall"), 2)      # 0.57

#Plot
print(evtplot(test_ltn12m, eventdetect_ltn12m, reference))

##### 7. spread #####
#Detect
eventdetect_spread <- evtdet.eventdetect(na.omit(test_spread), w = 30)

#Evaluate
evaluate(eventdetect_spread, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     21     33 
# FALSE    44     151

round(evaluate(eventdetect_spread, reference, metric = "F1"), 2)          # 0.35
round(evaluate(eventdetect_spread, reference, metric = "accuracy"), 2)    # 0.69
round(evaluate(eventdetect_spread, reference, metric = "sensitivity"), 2) # 0.32
round(evaluate(eventdetect_spread, reference, metric = "specificity"), 2) # 0.82
round(evaluate(eventdetect_spread, reference, metric = "precision"), 2)   # 0.39
round(evaluate(eventdetect_spread, reference, metric = "recall"), 2)      # 0.32

#Plot
print(evtplot(test_spread, eventdetect_spread, reference))

#######################################
##### Auxiliary Model definitions #####
#######################################

ARIMA <- function(data) forecast::auto.arima(data)
AR <- function(data,p) forecast::Arima(data, order = c(p, 0, 0), seasonal = c(0, 0, 0))
garch <- function(data,spec,...) rugarch::ugarchfit(spec=spec,data=data,solver="hybrid", ...)@fit
ets <- function(data) forecast::ets(ts(data))
linreg <- function(data) {
  #browser()
  data <- as.data.frame(data)
  colnames(data) <- "x"
  data$t <- 1:nrow(data)
  
  #Adjusting a linear regression to the whole window
  lm(x~t, data)
}

#Garch specs
garch11 <- rugarch::ugarchspec(variance.model = list(model = "sGARCH", garchOrder = c(1, 1)), 
                               mean.model = list(armaOrder = c(1, 1), include.mean = TRUE), 
                               distribution.model = "norm")

####################################
##### Garch Volatility Outlier #####
####################################

##### 1. selic #####
#Detect
garch_volatility_selic <- evtdet.garch_volatility_outlier(test_selic, spec = garch11, alpha = 1.5,
                                                          na.action = na.omit)

#  Error in data.frame(..., check.names = FALSE) : 
#    arguments imply differing number of rows: 0, 1 

#Evaluate
evaluate(garch_volatility_selic, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE    

round(evaluate(garch_volatility_selic, reference, metric = "F1"), 2)          # 
round(evaluate(garch_volatility_selic, reference, metric = "accuracy"), 2)    # 
round(evaluate(garch_volatility_selic, reference, metric = "sensitivity"), 2) # 
round(evaluate(garch_volatility_selic, reference, metric = "specificity"), 2) # 
round(evaluate(garch_volatility_selic, reference, metric = "precision"), 2)   # 
round(evaluate(garch_volatility_selic, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_selic, garch_volatility_selic, reference))

##### 2. cdi #####
#Detect
garch_volatility_cdi <- evtdet.garch_volatility_outlier(test_cdi, spec = garch11, alpha = 1.5,
                                                        na.action = na.omit)

#  Error in data.frame(..., check.names = FALSE) : 
#    arguments imply differing number of rows: 0, 1 

#Evaluate
evaluate(garch_volatility_cdi, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE    

round(evaluate(garch_volatility_cdi, reference, metric = "F1"), 2)          # 
round(evaluate(garch_volatility_cdi, reference, metric = "accuracy"), 2)    # 
round(evaluate(garch_volatility_cdi, reference, metric = "sensitivity"), 2) # 
round(evaluate(garch_volatility_cdi, reference, metric = "specificity"), 2) # 
round(evaluate(garch_volatility_cdi, reference, metric = "precision"), 2)   # 
round(evaluate(garch_volatility_cdi, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_cdi, garch_volatility_cdi, reference))

##### 3. ltn1m #####
#Detect
garch_volatility_ltn1m <- evtdet.garch_volatility_outlier(test_ltn1m, spec = garch11, alpha = 1.5, 
                                                          na.action = na.omit)

#Evaluate
evaluate(garch_volatility_ltn1m, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     6      26 
# FALSE    59     158 

round(evaluate(garch_volatility_ltn1m, reference, metric = "F1"), 2)          # 0.12
round(evaluate(garch_volatility_ltn1m, reference, metric = "accuracy"), 2)    # 0.66
round(evaluate(garch_volatility_ltn1m, reference, metric = "sensitivity"), 2) # 0.09
round(evaluate(garch_volatility_ltn1m, reference, metric = "specificity"), 2) # 0.86
round(evaluate(garch_volatility_ltn1m, reference, metric = "precision"), 2)   # 0.19
round(evaluate(garch_volatility_ltn1m, reference, metric = "recall"), 2)      # 0.09

#Plot
print(evtplot(test_ltn1m, garch_volatility_ltn1m, reference))

##### 4. ltn3m #####
#Detect
garch_volatility_ltn3m <- evtdet.garch_volatility_outlier(test_ltn3m, spec = garch11, alpha = 1.5, 
                                                          na.action = na.omit)

#Evaluate
evaluate(garch_volatility_ltn3m, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     6      35
# FALSE    59     149 

round(evaluate(garch_volatility_ltn3m, reference, metric = "F1"), 2)          # 0.11
round(evaluate(garch_volatility_ltn3m, reference, metric = "accuracy"), 2)    # 0.62
round(evaluate(garch_volatility_ltn3m, reference, metric = "sensitivity"), 2) # 0.09
round(evaluate(garch_volatility_ltn3m, reference, metric = "specificity"), 2) # 0.81
round(evaluate(garch_volatility_ltn3m, reference, metric = "precision"), 2)   # 0.15
round(evaluate(garch_volatility_ltn3m, reference, metric = "recall"), 2)      # 0.09

#Plot
print(evtplot(test_ltn3m, garch_volatility_ltn3m, reference))

##### 5. ltn6m #####
#Detect
garch_volatility_ltn6m <- evtdet.garch_volatility_outlier(test_ltn6m, spec = garch11, alpha = 1.5, 
                                                          na.action = na.omit)

#Evaluate
evaluate(garch_volatility_ltn6m, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     8      41 
# FALSE    57     143  

round(evaluate(garch_volatility_ltn6m, reference, metric = "F1"), 2)          # 0.14
round(evaluate(garch_volatility_ltn6m, reference, metric = "accuracy"), 2)    # 0.61
round(evaluate(garch_volatility_ltn6m, reference, metric = "sensitivity"), 2) # 0.12
round(evaluate(garch_volatility_ltn6m, reference, metric = "specificity"), 2) # 0.78
round(evaluate(garch_volatility_ltn6m, reference, metric = "precision"), 2)   # 0.16
round(evaluate(garch_volatility_ltn6m, reference, metric = "recall"), 2)      # 0.12

#Plot
print(evtplot(test_ltn6m, garch_volatility_ltn6m, reference))

##### 6. ltn12m #####
#Detect
garch_volatility_ltn12m <- evtdet.garch_volatility_outlier(test_ltn12m, spec = garch11, alpha = 1.5,
                                                           na.action = na.omit)

#Evaluate
evaluate(garch_volatility_ltn12m, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     8      44 
# FALSE    57     140 

round(evaluate(garch_volatility_ltn12m, reference, metric = "F1"), 2)          # 0.14
round(evaluate(garch_volatility_ltn12m, reference, metric = "accuracy"), 2)    # 0.59
round(evaluate(garch_volatility_ltn12m, reference, metric = "sensitivity"), 2) # 0.12
round(evaluate(garch_volatility_ltn12m, reference, metric = "specificity"), 2) # 0.76
round(evaluate(garch_volatility_ltn12m, reference, metric = "precision"), 2)   # 0.15
round(evaluate(garch_volatility_ltn12m, reference, metric = "recall"), 2)      # 0.12

#Plot
print(evtplot(test_ltn12m, garch_volatility_ltn12m, reference))

##### 7. spread #####
#Detect
garch_volatility_spread <- evtdet.garch_volatility_outlier(test_spread, spec = garch11, alpha = 1.5,
                                                           na.action = na.omit)

#Evaluate
evaluate(garch_volatility_spread, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     7      36  
# FALSE    58     148 

round(evaluate(garch_volatility_spread, reference, metric = "F1"), 2)          # 0.13
round(evaluate(garch_volatility_spread, reference, metric = "accuracy"), 2)    # 0.62
round(evaluate(garch_volatility_spread, reference, metric = "sensitivity"), 2) # 0.11
round(evaluate(garch_volatility_spread, reference, metric = "specificity"), 2) # 0.80
round(evaluate(garch_volatility_spread, reference, metric = "precision"), 2)   # 0.16
round(evaluate(garch_volatility_spread, reference, metric = "recall"), 2)      # 0.11

#Plot
print(evtplot(test_spread, garch_volatility_spread, reference))

#######################################
##### Seminal Change Point (1999) #####
#######################################

##### 1. selic #####
#Detect
changepoint_selic <- evtdet.seminalChangePoint2(test_selic, w = 30, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_selic, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     4      14     
# FALSE    61     170     

round(evaluate(changepoint_selic, reference, metric = "F1"), 2)          # 0.10
round(evaluate(changepoint_selic, reference, metric = "accuracy"), 2)    # 0.70
round(evaluate(changepoint_selic, reference, metric = "sensitivity"), 2) # 0.06
round(evaluate(changepoint_selic, reference, metric = "specificity"), 2) # 0.92
round(evaluate(changepoint_selic, reference, metric = "precision"), 2)   # 0.22
round(evaluate(changepoint_selic, reference, metric = "recall"), 2)      # 0.06

#Plot
print(evtplot(test_selic, changepoint_selic, reference))

##### 2. cdi #####
#Detect
changepoint_cdi <- evtdet.seminalChangePoint2(test_cdi, w = 30, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_cdi, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     3      16 
# FALSE    62     168 

round(evaluate(changepoint_cdi, reference, metric = "F1"), 2)          # 0.07
round(evaluate(changepoint_cdi, reference, metric = "accuracy"), 2)    # 0.69
round(evaluate(changepoint_cdi, reference, metric = "sensitivity"), 2) # 0.05
round(evaluate(changepoint_cdi, reference, metric = "specificity"), 2) # 0.91
round(evaluate(changepoint_cdi, reference, metric = "precision"), 2)   # 0.16
round(evaluate(changepoint_cdi, reference, metric = "recall"), 2)      # 0.05

#Plot
print(evtplot(test_cdi, changepoint_cdi, reference))

##### 3. ltn1m #####
#Detect
changepoint_ltn1m <- evtdet.seminalChangePoint2(test_ltn1m, w = 30, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_ltn1m, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     6      7  
# FALSE    59     177  

round(evaluate(changepoint_ltn1m, reference, metric = "F1"), 2)          # 0.15
round(evaluate(changepoint_ltn1m, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(changepoint_ltn1m, reference, metric = "sensitivity"), 2) # 0.09
round(evaluate(changepoint_ltn1m, reference, metric = "specificity"), 2) # 0.96
round(evaluate(changepoint_ltn1m, reference, metric = "precision"), 2)   # 0.46
round(evaluate(changepoint_ltn1m, reference, metric = "recall"), 2)      # 0.09

#Plot
print(evtplot(test_ltn1m, changepoint_ltn1m, reference))

##### 4. ltn3m #####
#Detect
changepoint_ltn3m <- evtdet.seminalChangePoint2(test_ltn3m, w = 30, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_ltn3m, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     1      6    
# FALSE    64     178

round(evaluate(changepoint_ltn3m, reference, metric = "F1"), 2)          # 0.03
round(evaluate(changepoint_ltn3m, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(changepoint_ltn3m, reference, metric = "sensitivity"), 2) # 0.02
round(evaluate(changepoint_ltn3m, reference, metric = "specificity"), 2) # 0.97
round(evaluate(changepoint_ltn3m, reference, metric = "precision"), 2)   # 0.14
round(evaluate(changepoint_ltn3m, reference, metric = "recall"), 2)      # 0.02

#Plot
print(evtplot(test_ltn3m, changepoint_ltn3m, reference))

##### 5. ltn6m #####
#Detect
changepoint_ltn6m <- evtdet.seminalChangePoint2(test_ltn6m, w = 30, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_ltn6m, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     7      5    
# FALSE    58     179  

round(evaluate(changepoint_ltn6m, reference, metric = "F1"), 2)          # 0.18
round(evaluate(changepoint_ltn6m, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(changepoint_ltn6m, reference, metric = "sensitivity"), 2) # 0.11
round(evaluate(changepoint_ltn6m, reference, metric = "specificity"), 2) # 0.97
round(evaluate(changepoint_ltn6m, reference, metric = "precision"), 2)   # 0.58
round(evaluate(changepoint_ltn6m, reference, metric = "recall"), 2)      # 0.11

#Plot
print(evtplot(test_ltn6m, changepoint_ltn6m, reference))

##### 6. ltn12m #####
#Detect
changepoint_ltn12m <- evtdet.seminalChangePoint2(test_ltn12m, w = 30, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_ltn12m, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     9      9   
# FALSE    56     175   

round(evaluate(changepoint_ltn12m, reference, metric = "F1"), 2)          # 0.22
round(evaluate(changepoint_ltn12m, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(changepoint_ltn12m, reference, metric = "sensitivity"), 2) # 0.14
round(evaluate(changepoint_ltn12m, reference, metric = "specificity"), 2) # 0.95
round(evaluate(changepoint_ltn12m, reference, metric = "precision"), 2)   # 0.50
round(evaluate(changepoint_ltn12m, reference, metric = "recall"), 2)      # 0.14

#Plot
print(evtplot(test_ltn12m, changepoint_ltn12m, reference))

##### 7. spread #####
#Detect
changepoint_spread <- evtdet.seminalChangePoint2(test_spread, w = 30, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_spread, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     16     6    
# FALSE    49     178 

round(evaluate(changepoint_spread, reference, metric = "F1"), 2)          # 0.37
round(evaluate(changepoint_spread, reference, metric = "accuracy"), 2)    # 0.78
round(evaluate(changepoint_spread, reference, metric = "sensitivity"), 2) # 0.25
round(evaluate(changepoint_spread, reference, metric = "specificity"), 2) # 0.97
round(evaluate(changepoint_spread, reference, metric = "precision"), 2)   # 0.73
round(evaluate(changepoint_spread, reference, metric = "recall"), 2)      # 0.25

#Plot
print(evtplot(test_spread, changepoint_spread, reference))

###############################
##### ChangeFinder (2005) #####
###############################

##### 1. selic #####
#Detect
changefinder_selic <- evtdet.changeFinder(test_selic, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_selic, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     3      3
# FALSE    62     181 

round(evaluate(changefinder_selic, reference, metric = "F1"), 2)          # 0.08
round(evaluate(changefinder_selic, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(changefinder_selic, reference, metric = "sensitivity"), 2) # 0.05
round(evaluate(changefinder_selic, reference, metric = "specificity"), 2) # 0.98
round(evaluate(changefinder_selic, reference, metric = "precision"), 2)   # 0.50
round(evaluate(changefinder_selic, reference, metric = "recall"), 2)      # 0.05

#Plot
print(evtplot(test_selic, changefinder_selic, reference))

##### 2. cdi #####
#Detect
changefinder_cdi <- evtdet.changeFinder(test_cdi, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_cdi, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     3      3   
# FALSE    62     181  

round(evaluate(changefinder_cdi, reference, metric = "F1"), 2)          # 0.08
round(evaluate(changefinder_cdi, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(changefinder_cdi, reference, metric = "sensitivity"), 2) # 0.05
round(evaluate(changefinder_cdi, reference, metric = "specificity"), 2) # 0.98
round(evaluate(changefinder_cdi, reference, metric = "precision"), 2)   # 0.50
round(evaluate(changefinder_cdi, reference, metric = "recall"), 2)      # 0.05

#Plot
print(evtplot(test_cdi, changefinder_cdi, reference))

##### 3. ltn1m #####
#Detect
changefinder_ltn1m <- evtdet.changeFinder(test_ltn1m, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_ltn1m, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     2      6   
# FALSE    63     178   

round(evaluate(changefinder_ltn1m, reference, metric = "F1"), 2)          # 0.05
round(evaluate(changefinder_ltn1m, reference, metric = "accuracy"), 2)    # 0.72
round(evaluate(changefinder_ltn1m, reference, metric = "sensitivity"), 2) # 0.03
round(evaluate(changefinder_ltn1m, reference, metric = "specificity"), 2) # 0.97
round(evaluate(changefinder_ltn1m, reference, metric = "precision"), 2)   # 0.25
round(evaluate(changefinder_ltn1m, reference, metric = "recall"), 2)      # 0.03

#Plot
print(evtplot(test_ltn1m, changefinder_ltn1m, reference))

##### 4. ltn3m #####
#Detect
changefinder_ltn3m <- evtdet.changeFinder(test_ltn3m, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_ltn3m, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     2      4 
# FALSE    63     180

round(evaluate(changefinder_ltn3m, reference, metric = "F1"), 2)          # 0.06
round(evaluate(changefinder_ltn3m, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(changefinder_ltn3m, reference, metric = "sensitivity"), 2) # 0.03
round(evaluate(changefinder_ltn3m, reference, metric = "specificity"), 2) # 0.98
round(evaluate(changefinder_ltn3m, reference, metric = "precision"), 2)   # 0.33
round(evaluate(changefinder_ltn3m, reference, metric = "recall"), 2)      # 0.03

#Plot
print(evtplot(test_ltn3m, changefinder_ltn3m, reference))

##### 5. ltn6m #####
#Detect
changefinder_ltn6m <- evtdet.changeFinder(test_ltn6m, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_ltn6m, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     3      3   
# FALSE    62     181

round(evaluate(changefinder_ltn6m, reference, metric = "F1"), 2)          # 0.08
round(evaluate(changefinder_ltn6m, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(changefinder_ltn6m, reference, metric = "sensitivity"), 2) # 0.05
round(evaluate(changefinder_ltn6m, reference, metric = "specificity"), 2) # 0.98
round(evaluate(changefinder_ltn6m, reference, metric = "precision"), 2)   # 0.50
round(evaluate(changefinder_ltn6m, reference, metric = "recall"), 2)      # 0.05

#Plot
print(evtplot(test_ltn6m, changefinder_ltn6m, reference))

##### 6. ltn12m #####
#Detect
changefinder_ltn12m <- evtdet.changeFinder(test_ltn12m, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_ltn12m, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     5      5   
# FALSE    60     179 

round(evaluate(changefinder_ltn12m, reference, metric = "F1"), 2)          # 0.13
round(evaluate(changefinder_ltn12m, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(changefinder_ltn12m, reference, metric = "sensitivity"), 2) # 0.08
round(evaluate(changefinder_ltn12m, reference, metric = "specificity"), 2) # 0.97
round(evaluate(changefinder_ltn12m, reference, metric = "precision"), 2)   # 0.50
round(evaluate(changefinder_ltn12m, reference, metric = "recall"), 2)      # 0.08

#Plot
print(evtplot(test_ltn12m, changefinder_ltn12m, reference))

##### 7. spread #####
#Detect
changefinder_spread <- evtdet.changeFinder(test_spread, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_spread, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     4      11
# FALSE    61     173

round(evaluate(changefinder_spread, reference, metric = "F1"), 2)          # 0.10
round(evaluate(changefinder_spread, reference, metric = "accuracy"), 2)    # 0.71
round(evaluate(changefinder_spread, reference, metric = "sensitivity"), 2) # 0.06
round(evaluate(changefinder_spread, reference, metric = "specificity"), 2) # 0.94
round(evaluate(changefinder_spread, reference, metric = "precision"), 2)   # 0.27
round(evaluate(changefinder_spread, reference, metric = "recall"), 2)      # 0.06

#Plot
print(evtplot(test_spread, changefinder_spread, reference))
