####################################################################################################
##### Deteco de Eventos - Necessidade de Financiamento do Setor Pblico (Resultado Primrio) #####
####################################################################################################

################
##### Data #####
################

library(tibble)
library(EventDetectR)
source("https://raw.githubusercontent.com/cefet-rj-dal/harbinger/master/harbinger.R")

attach(df_nfsp)
head(df_nfsp)
str(df_nfsp)

test_nfsp_consolidado <- subset(df_nfsp, select = c(Data, nfsp_consolidado))
test_nfsp_gov_federal <- subset(df_nfsp, select = c(Data, nfsp_gov_federal))
test_nfsp_gov_estadual <- subset(df_nfsp, select = c(Data, nfsp_gov_estadual))
test_nfsp_gov_municipal <- subset(df_nfsp, select = c(Data, nfsp_gov_municipal))
test_nfsp_estatal <- subset(df_nfsp, select = c(Data, nfsp_estatal))
test_nfsp_estatal_federal <- subset(df_nfsp, select = c(Data, nfsp_estatal_federal))
test_nfsp_estatal_estadual <- subset(df_nfsp, select = c(Data, nfsp_estatal_estadual))
test_nfsp_estatl_municipal <- subset(df_nfsp, select = c(Data, nfsp_estatl_municipal))
reference <- subset(df_nfsp, select = c(Data, event))

#####################
##### Anomalize #####
#####################

##### 1. nfsp_consolidado #####
#Detect
anomalize_nfsp_consolidado <- evtdet.anomalize(test_nfsp_consolidado, alpha = 0.1, max_anoms = 0.2, 
                                               na.action = na.omit)

#Evaluate
evaluate(anomalize_nfsp_consolidado, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     13     14     
# FALSE    52     170  

round(evaluate(anomalize_nfsp_consolidado, reference, metric = "F1"), 2)          # 0.28
round(evaluate(anomalize_nfsp_consolidado, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(anomalize_nfsp_consolidado, reference, metric = "sensitivity"), 2) # 0.20
round(evaluate(anomalize_nfsp_consolidado, reference, metric = "specificity"), 2) # 0.92
round(evaluate(anomalize_nfsp_consolidado, reference, metric = "precision"), 2)   # 0.48
round(evaluate(anomalize_nfsp_consolidado, reference, metric = "recall"), 2)      # 0.20

#Plot
print(evtplot(test_nfsp_consolidado, anomalize_nfsp_consolidado, reference))

##### 2. nfsp_gov_federal #####
#Detect
anomalize_nfsp_gov_federal <- evtdet.anomalize(test_nfsp_gov_federal, alpha = 0.1, max_anoms = 0.2, 
                                               na.action = na.omit)

#Evaluate
evaluate(anomalize_nfsp_gov_federal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     15     14   
# FALSE    50     170

round(evaluate(anomalize_nfsp_gov_federal, reference, metric = "F1"), 2)          # 0.32
round(evaluate(anomalize_nfsp_gov_federal, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(anomalize_nfsp_gov_federal, reference, metric = "sensitivity"), 2) # 0.23
round(evaluate(anomalize_nfsp_gov_federal, reference, metric = "specificity"), 2) # 0.92
round(evaluate(anomalize_nfsp_gov_federal, reference, metric = "precision"), 2)   # 0.52
round(evaluate(anomalize_nfsp_gov_federal, reference, metric = "recall"), 2)      # 0.23

#Plot
print(evtplot(test_nfsp_gov_federal, anomalize_nfsp_gov_federal, reference))

##### 3. nfsp_gov_estadual #####
#Detect
anomalize_nfsp_gov_estadual <- evtdet.anomalize(test_nfsp_gov_estadual, alpha = 0.1, max_anoms = 0.2, 
                                                na.action = na.omit)

#Evaluate
evaluate(anomalize_nfsp_gov_estadual, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     8      3 
# FALSE    57     181  

round(evaluate(anomalize_nfsp_gov_estadual, reference, metric = "F1"), 2)          # 0.21
round(evaluate(anomalize_nfsp_gov_estadual, reference, metric = "accuracy"), 2)    # 0.76
round(evaluate(anomalize_nfsp_gov_estadual, reference, metric = "sensitivity"), 2) # 0.12
round(evaluate(anomalize_nfsp_gov_estadual, reference, metric = "specificity"), 2) # 0.98
round(evaluate(anomalize_nfsp_gov_estadual, reference, metric = "precision"), 2)   # 0.73
round(evaluate(anomalize_nfsp_gov_estadual, reference, metric = "recall"), 2)      # 0.12

#Plot
print(evtplot(test_nfsp_gov_estadual, anomalize_nfsp_gov_estadual, reference))

##### 4. nfsp_gov_municipal #####
#Detect
anomalize_nfsp_gov_municipal <- evtdet.anomalize(test_nfsp_gov_municipal, alpha = 0.1, max_anoms = 0.2, 
                                                 na.action = na.omit)

#Evaluate
evaluate(anomalize_nfsp_gov_municipal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     9      11   
# FALSE    56     173    

round(evaluate(anomalize_nfsp_gov_municipal, reference, metric = "F1"), 2)          # 0.21
round(evaluate(anomalize_nfsp_gov_municipal, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(anomalize_nfsp_gov_municipal, reference, metric = "sensitivity"), 2) # 0.14
round(evaluate(anomalize_nfsp_gov_municipal, reference, metric = "specificity"), 2) # 0.94
round(evaluate(anomalize_nfsp_gov_municipal, reference, metric = "precision"), 2)   # 0.45
round(evaluate(anomalize_nfsp_gov_municipal, reference, metric = "recall"), 2)      # 0.14

#Plot
print(evtplot(test_nfsp_gov_municipal, anomalize_nfsp_gov_municipal, reference))

##### 5. nfsp_estatal #####
#Detect
anomalize_nfsp_estatal <- evtdet.anomalize(test_nfsp_estatal, alpha = 0.1, max_anoms = 0.2, 
                                           na.action = na.omit)

#Evaluate
evaluate(anomalize_nfsp_estatal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     4      18  
# FALSE    61     166  

round(evaluate(anomalize_nfsp_estatal, reference, metric = "F1"), 2)          # 0.09
round(evaluate(anomalize_nfsp_estatal, reference, metric = "accuracy"), 2)    # 0.68
round(evaluate(anomalize_nfsp_estatal, reference, metric = "sensitivity"), 2) # 0.06
round(evaluate(anomalize_nfsp_estatal, reference, metric = "specificity"), 2) # 0.90
round(evaluate(anomalize_nfsp_estatal, reference, metric = "precision"), 2)   # 0.18
round(evaluate(anomalize_nfsp_estatal, reference, metric = "recall"), 2)      # 0.06

#Plot
print(evtplot(test_nfsp_estatal, anomalize_nfsp_estatal, reference))

##### 6. nfsp_estatal_federal #####
#Detect
anomalize_nfsp_estatal_federal <- evtdet.anomalize(test_nfsp_estatal_federal, alpha = 0.1, max_anoms = 0.2, 
                                                   na.action = na.omit)

#Evaluate
evaluate(anomalize_nfsp_estatal_federal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     6      30     
# FALSE    59     154

round(evaluate(anomalize_nfsp_estatal_federal, reference, metric = "F1"), 2)          # 0.12
round(evaluate(anomalize_nfsp_estatal_federal, reference, metric = "accuracy"), 2)    # 0.64
round(evaluate(anomalize_nfsp_estatal_federal, reference, metric = "sensitivity"), 2) # 0.09
round(evaluate(anomalize_nfsp_estatal_federal, reference, metric = "specificity"), 2) # 0.84
round(evaluate(anomalize_nfsp_estatal_federal, reference, metric = "precision"), 2)   # 0.17
round(evaluate(anomalize_nfsp_estatal_federal, reference, metric = "recall"), 2)      # 0.09

#Plot
print(evtplot(test_nfsp_estatal_federal, anomalize_nfsp_estatal_federal, reference))

##### 7. nfsp_estatal_estadual #####
#Detect
anomalize_nfsp_estatal_estadual <- evtdet.anomalize(test_nfsp_estatal_estadual, alpha = 0.1, max_anoms = 0.2, 
                                                    na.action = na.omit)

#Evaluate
evaluate(anomalize_nfsp_estatal_estadual, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     0      10 
# FALSE    65     174  

round(evaluate(anomalize_nfsp_estatal_estadual, reference, metric = "F1"), 2)          # NaN
round(evaluate(anomalize_nfsp_estatal_estadual, reference, metric = "accuracy"), 2)    # 0.70
round(evaluate(anomalize_nfsp_estatal_estadual, reference, metric = "sensitivity"), 2) # 0.00
round(evaluate(anomalize_nfsp_estatal_estadual, reference, metric = "specificity"), 2) # 0.94
round(evaluate(anomalize_nfsp_estatal_estadual, reference, metric = "precision"), 2)   # 0.00
round(evaluate(anomalize_nfsp_estatal_estadual, reference, metric = "recall"), 2)      # 0.00

#Plot
print(evtplot(test_nfsp_estatal_estadual, anomalize_nfsp_estatal_estadual, reference))

##### 8. nfsp_estatl_municipal #####
#Detect
anomalize_nfsp_estatl_municipal <- evtdet.anomalize(test_nfsp_estatl_municipal, alpha = 0.1, max_anoms = 0.2, 
                                                    na.action = na.omit)

#Evaluate
evaluate(anomalize_nfsp_estatl_municipal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     5      12   
# FALSE    60     172  

round(evaluate(anomalize_nfsp_estatl_municipal, reference, metric = "F1"), 2)          # 0.12
round(evaluate(anomalize_nfsp_estatl_municipal, reference, metric = "accuracy"), 2)    # 0.71
round(evaluate(anomalize_nfsp_estatl_municipal, reference, metric = "sensitivity"), 2) # 0.08
round(evaluate(anomalize_nfsp_estatl_municipal, reference, metric = "specificity"), 2) # 0.93
round(evaluate(anomalize_nfsp_estatl_municipal, reference, metric = "precision"), 2)   # 0.29
round(evaluate(anomalize_nfsp_estatl_municipal, reference, metric = "recall"), 2)      # 0.08

#Plot
print(evtplot(test_nfsp_estatl_municipal, anomalize_nfsp_estatl_municipal, reference))

###########################################
##### Adaptive Normalization Outliers #####
###########################################

##### 1. nfsp_consolidado #####
#Detect
an_nfsp_consolidado <- evtdet.an_outliers(test_nfsp_consolidado, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_nfsp_consolidado, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     15     15          
# FALSE    50     169  

round(evaluate(an_nfsp_consolidado, reference, metric = "F1"), 2)          # 0.32
round(evaluate(an_nfsp_consolidado, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(an_nfsp_consolidado, reference, metric = "sensitivity"), 2) # 0.23
round(evaluate(an_nfsp_consolidado, reference, metric = "specificity"), 2) # 0.92
round(evaluate(an_nfsp_consolidado, reference, metric = "precision"), 2)   # 0.50
round(evaluate(an_nfsp_consolidado, reference, metric = "recall"), 2)      # 0.23

#Plot
print(evtplot(test_nfsp_consolidado, an_nfsp_consolidado, reference))

##### 2. nfsp_gov_federal #####
#Detect
an_nfsp_gov_federal <- evtdet.an_outliers(test_nfsp_gov_federal, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_nfsp_gov_federal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     13     14       
# FALSE    52     170  

round(evaluate(an_nfsp_gov_federal, reference, metric = "F1"), 2)          # 0.28
round(evaluate(an_nfsp_gov_federal, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(an_nfsp_gov_federal, reference, metric = "sensitivity"), 2) # 0.20
round(evaluate(an_nfsp_gov_federal, reference, metric = "specificity"), 2) # 0.92
round(evaluate(an_nfsp_gov_federal, reference, metric = "precision"), 2)   # 0.48
round(evaluate(an_nfsp_gov_federal, reference, metric = "recall"), 2)      # 0.20

#Plot
print(evtplot(test_nfsp_gov_federal, an_nfsp_gov_federal, reference))

##### 3. nfsp_gov_estadual #####
#Detect
an_nfsp_gov_estadual <- evtdet.an_outliers(test_nfsp_gov_estadual, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_nfsp_gov_estadual, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     12     17 
# FALSE    53     167        

round(evaluate(an_nfsp_gov_estadual, reference, metric = "F1"), 2)          # 0.26
round(evaluate(an_nfsp_gov_estadual, reference, metric = "accuracy"), 2)    # 0.72
round(evaluate(an_nfsp_gov_estadual, reference, metric = "sensitivity"), 2) # 0.18
round(evaluate(an_nfsp_gov_estadual, reference, metric = "specificity"), 2) # 0.91
round(evaluate(an_nfsp_gov_estadual, reference, metric = "precision"), 2)   # 0.41
round(evaluate(an_nfsp_gov_estadual, reference, metric = "recall"), 2)      # 0.18

#Plot
print(evtplot(test_nfsp_gov_estadual, an_nfsp_gov_estadual, reference))

##### 4. nfsp_gov_municipal #####
#Detect
an_nfsp_gov_municipal <- evtdet.an_outliers(test_nfsp_gov_municipal, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_nfsp_gov_municipal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     11     13  
# FALSE    54     171

round(evaluate(an_nfsp_gov_municipal, reference, metric = "F1"), 2)          # 0.25
round(evaluate(an_nfsp_gov_municipal, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(an_nfsp_gov_municipal, reference, metric = "sensitivity"), 2) # 0.17
round(evaluate(an_nfsp_gov_municipal, reference, metric = "specificity"), 2) # 0.93
round(evaluate(an_nfsp_gov_municipal, reference, metric = "precision"), 2)   # 0.46
round(evaluate(an_nfsp_gov_municipal, reference, metric = "recall"), 2)      # 0.17

#Plot
print(evtplot(test_nfsp_gov_municipal, an_nfsp_gov_municipal, reference))

##### 5. nfsp_estatal #####
#Detect
an_nfsp_estatal <- evtdet.an_outliers(test_nfsp_estatal, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_nfsp_estatal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     5      21   
# FALSE    60     163   

round(evaluate(an_nfsp_estatal, reference, metric = "F1"), 2)          # 0.11
round(evaluate(an_nfsp_estatal, reference, metric = "accuracy"), 2)    # 0.67
round(evaluate(an_nfsp_estatal, reference, metric = "sensitivity"), 2) # 0.08
round(evaluate(an_nfsp_estatal, reference, metric = "specificity"), 2) # 0.89
round(evaluate(an_nfsp_estatal, reference, metric = "precision"), 2)   # 0.19
round(evaluate(an_nfsp_estatal, reference, metric = "recall"), 2)      # 0.08

#Plot
print(evtplot(test_nfsp_estatal, an_nfsp_estatal, reference))

##### 6. nfsp_estatal_federal #####
#Detect
an_nfsp_estatal_federal <- evtdet.an_outliers(test_nfsp_estatal_federal, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_nfsp_estatal_federal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     4      28    
# FALSE    61     156  

round(evaluate(an_nfsp_estatal_federal, reference, metric = "F1"), 2)          # 0.08
round(evaluate(an_nfsp_estatal_federal, reference, metric = "accuracy"), 2)    # 0.64 
round(evaluate(an_nfsp_estatal_federal, reference, metric = "sensitivity"), 2) # 0.06
round(evaluate(an_nfsp_estatal_federal, reference, metric = "specificity"), 2) # 0.85
round(evaluate(an_nfsp_estatal_federal, reference, metric = "precision"), 2)   # 0.12
round(evaluate(an_nfsp_estatal_federal, reference, metric = "recall"), 2)      # 0.06

#Plot
print(evtplot(test_nfsp_estatal_federal, an_nfsp_estatal_federal, reference))

##### 7. nfsp_estatal_estadual #####
#Detect
an_nfsp_estatal_estadual <- evtdet.an_outliers(test_nfsp_estatal_estadual, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_nfsp_estatal_estadual, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     0      13   
# FALSE    65     171 

round(evaluate(an_nfsp_estatal_estadual, reference, metric = "F1"), 2)          # NaN
round(evaluate(an_nfsp_estatal_estadual, reference, metric = "accuracy"), 2)    # 0.69
round(evaluate(an_nfsp_estatal_estadual, reference, metric = "sensitivity"), 2) # 0.00
round(evaluate(an_nfsp_estatal_estadual, reference, metric = "specificity"), 2) # 0.93
round(evaluate(an_nfsp_estatal_estadual, reference, metric = "precision"), 2)   # 0.00
round(evaluate(an_nfsp_estatal_estadual, reference, metric = "recall"), 2)      # 0.00

#Plot
print(evtplot(test_nfsp_estatal_estadual, an_nfsp_estatal_estadual, reference))

##### 8. nfsp_estatl_municipal #####
#Detect
an_nfsp_estatl_municipal <- evtdet.an_outliers(test_nfsp_estatl_municipal, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_nfsp_estatl_municipal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     7      20   
# FALSE    58     164  

round(evaluate(an_nfsp_estatl_municipal, reference, metric = "F1"), 2)          # 0.15
round(evaluate(an_nfsp_estatl_municipal, reference, metric = "accuracy"), 2)    # 0.69
round(evaluate(an_nfsp_estatl_municipal, reference, metric = "sensitivity"), 2) # 0.11
round(evaluate(an_nfsp_estatl_municipal, reference, metric = "specificity"), 2) # 0.89
round(evaluate(an_nfsp_estatl_municipal, reference, metric = "precision"), 2)   # 0.26
round(evaluate(an_nfsp_estatl_municipal, reference, metric = "recall"), 2)      # 0.11

#Plot
print(evtplot(test_nfsp_estatl_municipal, an_nfsp_estatl_municipal, reference))

#######################
##### EventDetect #####
#######################

##### 1. nfsp_consolidado #####
#Detect
eventdetect_nfsp_consolidado <- evtdet.eventdetect(na.omit(test_nfsp_consolidado), w = 30)

#Error in data.frame(..., check.names = FALSE) : 
#  arguments imply differing number of rows: 0, 1 

#Evaluate
evaluate(eventdetect_nfsp_consolidado, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE    

round(evaluate(eventdetect_nfsp_consolidado, reference, metric = "F1"), 2)          # 
round(evaluate(eventdetect_nfsp_consolidado, reference, metric = "accuracy"), 2)    # 
round(evaluate(eventdetect_nfsp_consolidado, reference, metric = "sensitivity"), 2) # 
round(evaluate(eventdetect_nfsp_consolidado, reference, metric = "specificity"), 2) # 
round(evaluate(eventdetect_nfsp_consolidado, reference, metric = "precision"), 2)   # 
round(evaluate(eventdetect_nfsp_consolidado, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_nfsp_consolidado, eventdetect_nfsp_consolidado, reference))

##### 2. nfsp_gov_federal #####
#Detect
eventdetect_nfsp_gov_federal <- evtdet.eventdetect(na.omit(test_nfsp_gov_federal), w = 30)

#Error in data.frame(..., check.names = FALSE) : 
#  arguments imply differing number of rows: 0, 1 

#Evaluate
evaluate(eventdetect_nfsp_gov_federal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE    

round(evaluate(eventdetect_nfsp_gov_federal, reference, metric = "F1"), 2)          # 
round(evaluate(eventdetect_nfsp_gov_federal, reference, metric = "accuracy"), 2)    # 
round(evaluate(eventdetect_nfsp_gov_federal, reference, metric = "sensitivity"), 2) # 
round(evaluate(eventdetect_nfsp_gov_federal, reference, metric = "specificity"), 2) # 
round(evaluate(eventdetect_nfsp_gov_federal, reference, metric = "precision"), 2)   # 
round(evaluate(eventdetect_nfsp_gov_federal, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_nfsp_gov_federal, eventdetect_nfsp_gov_federal, reference))

##### 3. nfsp_gov_estadual #####
#Detect
eventdetect_nfsp_gov_estadual <- evtdet.eventdetect(na.omit(test_nfsp_gov_estadual), w = 30)

#Error in data.frame(..., check.names = FALSE) : 
#  arguments imply differing number of rows: 0, 1 

#Evaluate
evaluate(eventdetect_nfsp_gov_estadual, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE        

round(evaluate(eventdetect_nfsp_gov_estadual, reference, metric = "F1"), 2)          # 
round(evaluate(eventdetect_nfsp_gov_estadual, reference, metric = "accuracy"), 2)    # 
round(evaluate(eventdetect_nfsp_gov_estadual, reference, metric = "sensitivity"), 2) # 
round(evaluate(eventdetect_nfsp_gov_estadual, reference, metric = "specificity"), 2) # 
round(evaluate(eventdetect_nfsp_gov_estadual, reference, metric = "precision"), 2)   # 
round(evaluate(eventdetect_nfsp_gov_estadual, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_nfsp_gov_estadual, eventdetect_nfsp_gov_estadual, reference))

##### 4. nfsp_gov_municipal #####
#Detect
eventdetect_nfsp_gov_municipal <- evtdet.eventdetect(na.omit(test_nfsp_gov_municipal), w = 30)

#Evaluate
evaluate(eventdetect_nfsp_gov_municipal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     21     29    
# FALSE    44     155       

round(evaluate(eventdetect_nfsp_gov_municipal, reference, metric = "F1"), 2)          # 0.37
round(evaluate(eventdetect_nfsp_gov_municipal, reference, metric = "accuracy"), 2)    # 0.71
round(evaluate(eventdetect_nfsp_gov_municipal, reference, metric = "sensitivity"), 2) # 0.32
round(evaluate(eventdetect_nfsp_gov_municipal, reference, metric = "specificity"), 2) # 0.84
round(evaluate(eventdetect_nfsp_gov_municipal, reference, metric = "precision"), 2)   # 0.42
round(evaluate(eventdetect_nfsp_gov_municipal, reference, metric = "recall"), 2)      # 0.32

#Plot
print(evtplot(test_nfsp_gov_municipal, eventdetect_nfsp_gov_municipal, reference))

##### 5. nfsp_estatal #####
#Detect
eventdetect_nfsp_estatal <- evtdet.eventdetect(na.omit(test_nfsp_estatal), w = 30)

#  Error in data.frame(..., check.names = FALSE) : 
#    arguments imply differing number of rows: 0, 1 

#Evaluate
evaluate(eventdetect_nfsp_estatal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE    

round(evaluate(eventdetect_nfsp_estatal, reference, metric = "F1"), 2)          # 
round(evaluate(eventdetect_nfsp_estatal, reference, metric = "accuracy"), 2)    # 
round(evaluate(eventdetect_nfsp_estatal, reference, metric = "sensitivity"), 2) # 
round(evaluate(eventdetect_nfsp_estatal, reference, metric = "specificity"), 2) # 
round(evaluate(eventdetect_nfsp_estatal, reference, metric = "precision"), 2)   # 
round(evaluate(eventdetect_nfsp_estatal, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_nfsp_estatal, eventdetect_nfsp_estatal, reference))

##### 6. nfsp_estatal_federal #####
#Detect
eventdetect_nfsp_estatal_federal <- evtdet.eventdetect(na.omit(test_nfsp_estatal_federal), w = 30)

#  Error in data.frame(..., check.names = FALSE) : 
#    arguments imply differing number of rows: 0, 1 

#Evaluate
evaluate(eventdetect_nfsp_estatal_federal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE      
# FALSE    

round(evaluate(eventdetect_nfsp_estatal_federal, reference, metric = "F1"), 2)          # 
round(evaluate(eventdetect_nfsp_estatal_federal, reference, metric = "accuracy"), 2)    # 
round(evaluate(eventdetect_nfsp_estatal_federal, reference, metric = "sensitivity"), 2) # 
round(evaluate(eventdetect_nfsp_estatal_federal, reference, metric = "specificity"), 2) # 
round(evaluate(eventdetect_nfsp_estatal_federal, reference, metric = "precision"), 2)   # 
round(evaluate(eventdetect_nfsp_estatal_federal, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_nfsp_estatal_federal, eventdetect_nfsp_estatal_federal, reference))

##### 7. nfsp_estatal_estadual #####
#Detect
eventdetect_nfsp_estatal_estadual <- evtdet.eventdetect(na.omit(test_nfsp_estatal_estadual), w = 30)

#  Error in data.frame(..., check.names = FALSE) : 
#    arguments imply differing number of rows: 0, 1

#Evaluate
evaluate(eventdetect_nfsp_estatal_estadual, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE    

round(evaluate(eventdetect_nfsp_estatal_estadual, reference, metric = "F1"), 2)          # 
round(evaluate(eventdetect_nfsp_estatal_estadual, reference, metric = "accuracy"), 2)    # 
round(evaluate(eventdetect_nfsp_estatal_estadual, reference, metric = "sensitivity"), 2) # 
round(evaluate(eventdetect_nfsp_estatal_estadual, reference, metric = "specificity"), 2) # 
round(evaluate(eventdetect_nfsp_estatal_estadual, reference, metric = "precision"), 2)   # 
round(evaluate(eventdetect_nfsp_estatal_estadual, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_nfsp_estatal_estadual, eventdetect_nfsp_estatal_estadual, reference))

##### 8. nfsp_estatl_municipal #####
#Detect
eventdetect_nfsp_estatl_municipal <- evtdet.eventdetect(na.omit(test_nfsp_estatl_municipal), w = 30)

#  Error in data.frame(..., check.names = FALSE) : 
#    imply differing number of rows: 0, 1

#Evaluate
evaluate(eventdetect_nfsp_estatl_municipal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE        
# FALSE        

round(evaluate(eventdetect_nfsp_estatl_municipal, reference, metric = "F1"), 2)          # 
round(evaluate(eventdetect_nfsp_estatl_municipal, reference, metric = "accuracy"), 2)    # 
round(evaluate(eventdetect_nfsp_estatl_municipal, reference, metric = "sensitivity"), 2) # 
round(evaluate(eventdetect_nfsp_estatl_municipal, reference, metric = "specificity"), 2) # 
round(evaluate(eventdetect_nfsp_estatl_municipal, reference, metric = "precision"), 2)   # 
round(evaluate(eventdetect_nfsp_estatl_municipal, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_nfsp_estatl_municipal, eventdetect_nfsp_estatl_municipal, reference))

#######################################
##### Auxiliary Model definitions #####
#######################################

ARIMA <- function(data) forecast::auto.arima(data)
AR <- function(data,p) forecast::Arima(data, order = c(p, 0, 0), seasonal = c(0, 0, 0))
garch <- function(data,spec,...) rugarch::ugarchfit(spec=spec,data=data,solver="hybrid", ...)@fit
ets <- function(data) forecast::ets(ts(data))
linreg <- function(data) {
  #browser()
  data <- as.data.frame(data)
  colnames(data) <- "x"
  data$t <- 1:nrow(data)
  
  #Adjusting a linear regression to the whole window
  lm(x~t, data)
}

#Garch specs
garch11 <- rugarch::ugarchspec(variance.model = list(model = "sGARCH", garchOrder = c(1, 1)), 
                               mean.model = list(armaOrder = c(1, 1), include.mean = TRUE), 
                               distribution.model = "norm")

####################################
##### Garch Volatility Outlier #####
####################################

##### 1. nfsp_consolidado #####
#Detect
garch_volatility_nfsp_consolidado <- evtdet.garch_volatility_outlier(test_nfsp_consolidado, spec = garch11, 
                                                                     alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(garch_volatility_nfsp_consolidado, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     16     13   
# FALSE    49     171 

round(evaluate(garch_volatility_nfsp_consolidado, reference, metric = "F1"), 2)          # 0.34
round(evaluate(garch_volatility_nfsp_consolidado, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(garch_volatility_nfsp_consolidado, reference, metric = "sensitivity"), 2) # 0.25
round(evaluate(garch_volatility_nfsp_consolidado, reference, metric = "specificity"), 2) # 0.93
round(evaluate(garch_volatility_nfsp_consolidado, reference, metric = "precision"), 2)   # 0.55
round(evaluate(garch_volatility_nfsp_consolidado, reference, metric = "recall"), 2)      # 0.25

#Plot
print(evtplot(test_nfsp_consolidado, garch_volatility_nfsp_consolidado, reference))

##### 2. nfsp_gov_federal #####
#Detect
garch_volatility_nfsp_gov_federal <- evtdet.garch_volatility_outlier(test_nfsp_gov_federal, spec = garch11, 
                                                                     alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(garch_volatility_nfsp_gov_federal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     13     13  
# FALSE    52     171  

round(evaluate(garch_volatility_nfsp_gov_federal, reference, metric = "F1"), 2)          # 0.29
round(evaluate(garch_volatility_nfsp_gov_federal, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(garch_volatility_nfsp_gov_federal, reference, metric = "sensitivity"), 2) # 0.20
round(evaluate(garch_volatility_nfsp_gov_federal, reference, metric = "specificity"), 2) # 0.93
round(evaluate(garch_volatility_nfsp_gov_federal, reference, metric = "precision"), 2)   # 0.50
round(evaluate(garch_volatility_nfsp_gov_federal, reference, metric = "recall"), 2)      # 0.20

#Plot
print(evtplot(test_nfsp_gov_federal, garch_volatility_nfsp_gov_federal, reference))

##### 3. nfsp_gov_estadual #####
#Detect
garch_volatility_nfsp_gov_estadual <- evtdet.garch_volatility_outlier(test_nfsp_gov_estadual, spec = garch11, 
                                                                      alpha = 1.5, na.action = na.omit)

#Error in data.frame(..., check.names = FALSE) : 
#  arguments imply differing number of rows: 0, 1 

#Evaluate
evaluate(garch_volatility_nfsp_gov_estadual, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE         
# FALSE     

round(evaluate(garch_volatility_nfsp_gov_estadual, reference, metric = "F1"), 2)          # 
round(evaluate(garch_volatility_nfsp_gov_estadual, reference, metric = "accuracy"), 2)    # 
round(evaluate(garch_volatility_nfsp_gov_estadual, reference, metric = "sensitivity"), 2) # 
round(evaluate(garch_volatility_nfsp_gov_estadual, reference, metric = "specificity"), 2) # 
round(evaluate(garch_volatility_nfsp_gov_estadual, reference, metric = "precision"), 2)   # 
round(evaluate(garch_volatility_nfsp_gov_estadual, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_nfsp_gov_estadual, garch_volatility_nfsp_gov_estadual, reference))

##### 4. nfsp_gov_municipal #####
#Detect
garch_volatility_nfsp_gov_municipal <- evtdet.garch_volatility_outlier(test_nfsp_gov_municipal, spec = garch11, 
                                                                       alpha = 1.5, na.action = na.omit)

#Error in data.frame(..., check.names = FALSE) : 
#  arguments imply differing number of rows: 0, 1 

#Evaluate
evaluate(garch_volatility_nfsp_gov_municipal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     
# FALSE    

round(evaluate(garch_volatility_nfsp_gov_municipal, reference, metric = "F1"), 2)          # 
round(evaluate(garch_volatility_nfsp_gov_municipal, reference, metric = "accuracy"), 2)    # 
round(evaluate(garch_volatility_nfsp_gov_municipal, reference, metric = "sensitivity"), 2) # 
round(evaluate(garch_volatility_nfsp_gov_municipal, reference, metric = "specificity"), 2) # 
round(evaluate(garch_volatility_nfsp_gov_municipal, reference, metric = "precision"), 2)   # 
round(evaluate(garch_volatility_nfsp_gov_municipal, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_nfsp_gov_municipal, garch_volatility_nfsp_gov_municipal, reference))

##### 5. nfsp_estatal #####
#Detect
garch_volatility_nfsp_estatal <- evtdet.garch_volatility_outlier(test_nfsp_estatal, spec = garch11, 
                                                                 alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(garch_volatility_nfsp_estatal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     6      21     
# FALSE    59     163  

round(evaluate(garch_volatility_nfsp_estatal, reference, metric = "F1"), 2)          # 0.13
round(evaluate(garch_volatility_nfsp_estatal, reference, metric = "accuracy"), 2)    # 0.68
round(evaluate(garch_volatility_nfsp_estatal, reference, metric = "sensitivity"), 2) # 0.09
round(evaluate(garch_volatility_nfsp_estatal, reference, metric = "specificity"), 2) # 0.89
round(evaluate(garch_volatility_nfsp_estatal, reference, metric = "precision"), 2)   # 0.22
round(evaluate(garch_volatility_nfsp_estatal, reference, metric = "recall"), 2)      # 0.09

#Plot
print(evtplot(test_nfsp_estatal, garch_volatility_nfsp_estatal, reference))

##### 6. nfsp_estatal_federal #####
#Detect
garch_volatility_nfsp_estatal_federal <- evtdet.garch_volatility_outlier(test_nfsp_estatal_federal, spec = garch11, 
                                                                         alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(garch_volatility_nfsp_estatal_federal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     9      24   
# FALSE    56     160  

round(evaluate(garch_volatility_nfsp_estatal_federal, reference, metric = "F1"), 2)          # 0.18
round(evaluate(garch_volatility_nfsp_estatal_federal, reference, metric = "accuracy"), 2)    # 0.68
round(evaluate(garch_volatility_nfsp_estatal_federal, reference, metric = "sensitivity"), 2) # 0.14
round(evaluate(garch_volatility_nfsp_estatal_federal, reference, metric = "specificity"), 2) # 0.87
round(evaluate(garch_volatility_nfsp_estatal_federal, reference, metric = "precision"), 2)   # 0.27
round(evaluate(garch_volatility_nfsp_estatal_federal, reference, metric = "recall"), 2)      # 0.14

#Plot
print(evtplot(test_nfsp_estatal_federal, garch_volatility_nfsp_estatal_federal, reference))

##### 7. nfsp_estatal_estadual #####
#Detect
garch_volatility_nfsp_estatal_estadual <- evtdet.garch_volatility_outlier(test_nfsp_estatal_estadual, spec = garch11, 
                                                                          alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(garch_volatility_nfsp_estatal_estadual, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     1      12   
# FALSE    64     172  

round(evaluate(garch_volatility_nfsp_estatal_estadual, reference, metric = "F1"), 2)          # 0.03
round(evaluate(garch_volatility_nfsp_estatal_estadual, reference, metric = "accuracy"), 2)    # 0.69
round(evaluate(garch_volatility_nfsp_estatal_estadual, reference, metric = "sensitivity"), 2) # 0.02
round(evaluate(garch_volatility_nfsp_estatal_estadual, reference, metric = "specificity"), 2) # 0.93
round(evaluate(garch_volatility_nfsp_estatal_estadual, reference, metric = "precision"), 2)   # 0.08
round(evaluate(garch_volatility_nfsp_estatal_estadual, reference, metric = "recall"), 2)      # 0.02

#Plot
print(evtplot(test_nfsp_estatal_estadual, garch_volatility_nfsp_estatal_estadual, reference))

##### 8. nfsp_estatl_municipal #####
#Detect
garch_volatility_nfsp_estatl_municipal <- evtdet.garch_volatility_outlier(test_nfsp_estatl_municipal, spec = garch11,
                                                                          alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(garch_volatility_nfsp_estatl_municipal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     5      25
# FALSE    60     159    

round(evaluate(garch_volatility_nfsp_estatl_municipal, reference, metric = "F1"), 2)          # 0.11
round(evaluate(garch_volatility_nfsp_estatl_municipal, reference, metric = "accuracy"), 2)    # 0.66
round(evaluate(garch_volatility_nfsp_estatl_municipal, reference, metric = "sensitivity"), 2) # 0.08
round(evaluate(garch_volatility_nfsp_estatl_municipal, reference, metric = "specificity"), 2) # 0.86
round(evaluate(garch_volatility_nfsp_estatl_municipal, reference, metric = "precision"), 2)   # 0.17
round(evaluate(garch_volatility_nfsp_estatl_municipal, reference, metric = "recall"), 2)      # 0.08

#Plot
print(evtplot(test_nfsp_estatl_municipal, garch_volatility_nfsp_estatl_municipal, reference))

#######################################
##### Seminal Change Point (1999) #####
#######################################

##### 1. nfsp_consolidado #####
#Detect
changepoint_nfsp_consolidado <- evtdet.seminalChangePoint2(test_nfsp_consolidado, w = 30, mdl = linreg, 
                                                           na.action = na.omit)

#Evaluate
evaluate(changepoint_nfsp_consolidado, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     18     29    
# FALSE    47     155    

round(evaluate(changepoint_nfsp_consolidado, reference, metric = "F1"), 2)          # 0.32
round(evaluate(changepoint_nfsp_consolidado, reference, metric = "accuracy"), 2)    # 0.69
round(evaluate(changepoint_nfsp_consolidado, reference, metric = "sensitivity"), 2) # 0.28
round(evaluate(changepoint_nfsp_consolidado, reference, metric = "specificity"), 2) # 0.84
round(evaluate(changepoint_nfsp_consolidado, reference, metric = "precision"), 2)   # 0.38
round(evaluate(changepoint_nfsp_consolidado, reference, metric = "recall"), 2)      # 0.28

#Plot
print(evtplot(test_nfsp_consolidado, changepoint_nfsp_consolidado, reference))

##### 2. nfsp_gov_federal #####
#Detect
changepoint_nfsp_gov_federal <- evtdet.seminalChangePoint2(test_nfsp_gov_federal, w = 30, mdl = linreg, 
                                                           na.action = na.omit)

#Evaluate
evaluate(changepoint_nfsp_gov_federal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     19     33  
# FALSE    46     151 

round(evaluate(changepoint_nfsp_gov_federal, reference, metric = "F1"), 2)          # 0.32
round(evaluate(changepoint_nfsp_gov_federal, reference, metric = "accuracy"), 2)    # 0.68
round(evaluate(changepoint_nfsp_gov_federal, reference, metric = "sensitivity"), 2) # 0.29
round(evaluate(changepoint_nfsp_gov_federal, reference, metric = "specificity"), 2) # 0.82
round(evaluate(changepoint_nfsp_gov_federal, reference, metric = "precision"), 2)   # 0.37
round(evaluate(changepoint_nfsp_gov_federal, reference, metric = "recall"), 2)      # 0.29

#Plot
print(evtplot(test_nfsp_gov_federal, changepoint_nfsp_gov_federal, reference))

##### 3. nfsp_gov_estadual #####
#Detect
changepoint_nfsp_gov_estadual <- evtdet.seminalChangePoint2(test_nfsp_gov_estadual, w = 30, mdl = linreg, 
                                                       na.action = na.omit)

#Evaluate
evaluate(changepoint_nfsp_gov_estadual, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     17     32   
# FALSE    48     152  

round(evaluate(changepoint_nfsp_gov_estadual, reference, metric = "F1"), 2)          # 0.30
round(evaluate(changepoint_nfsp_gov_estadual, reference, metric = "accuracy"), 2)    # 0.68
round(evaluate(changepoint_nfsp_gov_estadual, reference, metric = "sensitivity"), 2) # 0.26
round(evaluate(changepoint_nfsp_gov_estadual, reference, metric = "specificity"), 2) # 0.83
round(evaluate(changepoint_nfsp_gov_estadual, reference, metric = "precision"), 2)   # 0.35
round(evaluate(changepoint_nfsp_gov_estadual, reference, metric = "recall"), 2)      # 0.26

#Plot
print(evtplot(test_nfsp_gov_estadual, changepoint_nfsp_gov_estadual, reference))

##### 4. nfsp_gov_municipal #####
#Detect
changepoint_nfsp_gov_municipal <- evtdet.seminalChangePoint2(test_nfsp_gov_municipal, w = 30, mdl = linreg, 
                                                             na.action = na.omit)

#Evaluate
evaluate(changepoint_nfsp_gov_municipal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     13     20
# FALSE    52     164  

round(evaluate(changepoint_nfsp_gov_municipal, reference, metric = "F1"), 2)          # 0.27
round(evaluate(changepoint_nfsp_gov_municipal, reference, metric = "accuracy"), 2)    # 0.71
round(evaluate(changepoint_nfsp_gov_municipal, reference, metric = "sensitivity"), 2) # 0.20
round(evaluate(changepoint_nfsp_gov_municipal, reference, metric = "specificity"), 2) # 0.89
round(evaluate(changepoint_nfsp_gov_municipal, reference, metric = "precision"), 2)   # 0.39
round(evaluate(changepoint_nfsp_gov_municipal, reference, metric = "recall"), 2)      # 0.20

#Plot
print(evtplot(test_nfsp_gov_municipal, changepoint_nfsp_gov_municipal, reference))

##### 5. nfsp_estatal #####
#Detect
changepoint_nfsp_estatal <- evtdet.seminalChangePoint2(test_nfsp_estatal, w = 30, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_nfsp_estatal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     18     43   
# FALSE    47     141   

round(evaluate(changepoint_nfsp_estatal, reference, metric = "F1"), 2)          # 0.29
round(evaluate(changepoint_nfsp_estatal, reference, metric = "accuracy"), 2)    # 0.64
round(evaluate(changepoint_nfsp_estatal, reference, metric = "sensitivity"), 2) # 0.28
round(evaluate(changepoint_nfsp_estatal, reference, metric = "specificity"), 2) # 0.77
round(evaluate(changepoint_nfsp_estatal, reference, metric = "precision"), 2)   # 0.30
round(evaluate(changepoint_nfsp_estatal, reference, metric = "recall"), 2)      # 0.28

#Plot
print(evtplot(test_nfsp_estatal, changepoint_nfsp_estatal, reference))

##### 6. nfsp_estatal_federal #####
#Detect
changepoint_nfsp_estatal_federal <- evtdet.seminalChangePoint2(test_nfsp_estatal_federal, w = 30, mdl = linreg,
                                                               na.action = na.omit)

#Evaluate
evaluate(changepoint_nfsp_estatal_federal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     19     40     
# FALSE    46     144 

round(evaluate(changepoint_nfsp_estatal_federal, reference, metric = "F1"), 2)          # 0.31
round(evaluate(changepoint_nfsp_estatal_federal, reference, metric = "accuracy"), 2)    # 0.65
round(evaluate(changepoint_nfsp_estatal_federal, reference, metric = "sensitivity"), 2) # 0.29
round(evaluate(changepoint_nfsp_estatal_federal, reference, metric = "specificity"), 2) # 0.78
round(evaluate(changepoint_nfsp_estatal_federal, reference, metric = "precision"), 2)   # 0.32
round(evaluate(changepoint_nfsp_estatal_federal, reference, metric = "recall"), 2)      # 0.29

#Plot
print(evtplot(test_nfsp_estatal_federal, changepoint_nfsp_estatal_federal, reference))

##### 7. nfsp_estatal_estadual #####
#Detect
changepoint_nfsp_estatal_estadual <- evtdet.seminalChangePoint2(test_nfsp_estatal_estadual, w = 30, mdl = linreg, 
                                                                na.action = na.omit)

#Evaluate
evaluate(changepoint_nfsp_estatal_estadual, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     10     32
# FALSE    55     152  

round(evaluate(changepoint_nfsp_estatal_estadual, reference, metric = "F1"), 2)          # 0.19
round(evaluate(changepoint_nfsp_estatal_estadual, reference, metric = "accuracy"), 2)    # 0.65
round(evaluate(changepoint_nfsp_estatal_estadual, reference, metric = "sensitivity"), 2) # 0.15
round(evaluate(changepoint_nfsp_estatal_estadual, reference, metric = "specificity"), 2) # 0.83
round(evaluate(changepoint_nfsp_estatal_estadual, reference, metric = "precision"), 2)   # 0.24
round(evaluate(changepoint_nfsp_estatal_estadual, reference, metric = "recall"), 2)      # 0.15

#Plot
print(evtplot(test_nfsp_estatal_estadual, changepoint_nfsp_estatal_estadual, reference))

##### 8. nfsp_estatl_municipal #####
#Detect
changepoint_nfsp_estatl_municipal <- evtdet.seminalChangePoint2(test_nfsp_estatl_municipal, w = 30, mdl = linreg,
                                                                na.action = na.omit)

#Evaluate
evaluate(changepoint_nfsp_estatl_municipal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     15     28   
# FALSE    50     156  

round(evaluate(changepoint_nfsp_estatl_municipal, reference, metric = "F1"), 2)          # 0.28
round(evaluate(changepoint_nfsp_estatl_municipal, reference, metric = "accuracy"), 2)    # 0.69
round(evaluate(changepoint_nfsp_estatl_municipal, reference, metric = "sensitivity"), 2) # 0.23
round(evaluate(changepoint_nfsp_estatl_municipal, reference, metric = "specificity"), 2) # 0.85
round(evaluate(changepoint_nfsp_estatl_municipal, reference, metric = "precision"), 2)   # 0.35
round(evaluate(changepoint_nfsp_estatl_municipal, reference, metric = "recall"), 2)      # 0.23

#Plot
print(evtplot(test_nfsp_estatl_municipal, changepoint_nfsp_estatl_municipal, reference))

###############################
##### ChangeFinder (2005) #####
###############################

##### 1. nfsp_consolidado #####
#Detect
changefinder_nfsp_consolidado <- evtdet.changeFinder(test_nfsp_consolidado, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_nfsp_consolidado, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     9      9    
# FALSE    56     175

round(evaluate(changefinder_nfsp_consolidado, reference, metric = "F1"), 2)          # 0.22
round(evaluate(changefinder_nfsp_consolidado, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(changefinder_nfsp_consolidado, reference, metric = "sensitivity"), 2) # 0.14
round(evaluate(changefinder_nfsp_consolidado, reference, metric = "specificity"), 2) # 0.95
round(evaluate(changefinder_nfsp_consolidado, reference, metric = "precision"), 2)   # 0.50
round(evaluate(changefinder_nfsp_consolidado, reference, metric = "recall"), 2)      # 0.14

#Plot
print(evtplot(test_nfsp_consolidado, changefinder_nfsp_consolidado, reference))

##### 2. nfsp_gov_federal #####
#Detect
changefinder_nfsp_gov_federal <- evtdet.changeFinder(test_nfsp_gov_federal, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_nfsp_gov_federal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     10     14  
# FALSE    55     170  

round(evaluate(changefinder_nfsp_gov_federal, reference, metric = "F1"), 2)          # 0.22
round(evaluate(changefinder_nfsp_gov_federal, reference, metric = "accuracy"), 2)    # 0.72
round(evaluate(changefinder_nfsp_gov_federal, reference, metric = "sensitivity"), 2) # 0.15
round(evaluate(changefinder_nfsp_gov_federal, reference, metric = "specificity"), 2) # 0.92
round(evaluate(changefinder_nfsp_gov_federal, reference, metric = "precision"), 2)   # 0.42
round(evaluate(changefinder_nfsp_gov_federal, reference, metric = "recall"), 2)      # 0.15

#Plot
print(evtplot(test_nfsp_gov_federal, changefinder_nfsp_gov_federal, reference))

##### 3. nfsp_gov_estadual #####
#Detect
changefinder_nfsp_gov_estadual <- evtdet.changeFinder(test_nfsp_gov_estadual, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_nfsp_gov_estadual, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     10     8    
# FALSE    55     176  

round(evaluate(changefinder_nfsp_gov_estadual, reference, metric = "F1"), 2)          # 0.24
round(evaluate(changefinder_nfsp_gov_estadual, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(changefinder_nfsp_gov_estadual, reference, metric = "sensitivity"), 2) # 0.15
round(evaluate(changefinder_nfsp_gov_estadual, reference, metric = "specificity"), 2) # 0.96
round(evaluate(changefinder_nfsp_gov_estadual, reference, metric = "precision"), 2)   # 0.56
round(evaluate(changefinder_nfsp_gov_estadual, reference, metric = "recall"), 2)      # 0.15

#Plot
print(evtplot(test_nfsp_gov_estadual, changefinder_nfsp_gov_estadual, reference))

##### 4. nfsp_gov_municipal #####
#Detect
changefinder_nfsp_gov_municipal <- evtdet.changeFinder(test_nfsp_gov_municipal, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_nfsp_gov_municipal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     9      8 
# FALSE    56     176

round(evaluate(changefinder_nfsp_gov_municipal, reference, metric = "F1"), 2)          # 0.22
round(evaluate(changefinder_nfsp_gov_municipal, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(changefinder_nfsp_gov_municipal, reference, metric = "sensitivity"), 2) # 0.14
round(evaluate(changefinder_nfsp_gov_municipal, reference, metric = "specificity"), 2) # 0.96
round(evaluate(changefinder_nfsp_gov_municipal, reference, metric = "precision"), 2)   # 0.53
round(evaluate(changefinder_nfsp_gov_municipal, reference, metric = "recall"), 2)      # 0.14

#Plot
print(evtplot(test_nfsp_gov_municipal, changefinder_nfsp_gov_municipal, reference))

##### 5. nfsp_estatal #####
#Detect
changefinder_nfsp_estatal <- evtdet.changeFinder(test_nfsp_estatal, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_nfsp_estatal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     5      20 
# FALSE    60     164  

round(evaluate(changefinder_nfsp_estatal, reference, metric = "F1"), 2)          # 0.11
round(evaluate(changefinder_nfsp_estatal, reference, metric = "accuracy"), 2)    # 0.68
round(evaluate(changefinder_nfsp_estatal, reference, metric = "sensitivity"), 2) # 0.08
round(evaluate(changefinder_nfsp_estatal, reference, metric = "specificity"), 2) # 0.89
round(evaluate(changefinder_nfsp_estatal, reference, metric = "precision"), 2)   # 0.20
round(evaluate(changefinder_nfsp_estatal, reference, metric = "recall"), 2)      # 0.08

#Plot
print(evtplot(test_nfsp_estatal, changefinder_nfsp_estatal, reference))

##### 6. nfsp_estatal_federal #####
#Detect
changefinder_nfsp_estatal_federal <- evtdet.changeFinder(test_nfsp_estatal_federal, mdl = linreg, 
                                                         na.action = na.omit)

#Evaluate
evaluate(changefinder_nfsp_estatal_federal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     4      25   
# FALSE    61     159  

round(evaluate(changefinder_nfsp_estatal_federal, reference, metric = "F1"), 2)          # 0.09
round(evaluate(changefinder_nfsp_estatal_federal, reference, metric = "accuracy"), 2)    # 0.65
round(evaluate(changefinder_nfsp_estatal_federal, reference, metric = "sensitivity"), 2) # 0.06
round(evaluate(changefinder_nfsp_estatal_federal, reference, metric = "specificity"), 2) # 0.86
round(evaluate(changefinder_nfsp_estatal_federal, reference, metric = "precision"), 2)   # 0.14
round(evaluate(changefinder_nfsp_estatal_federal, reference, metric = "recall"), 2)      # 0.06

#Plot
print(evtplot(test_nfsp_estatal_federal, changefinder_nfsp_estatal_federal, reference))

##### 7. nfsp_estatal_estadual #####
#Detect
changefinder_nfsp_estatal_estadual <- evtdet.changeFinder(test_nfsp_estatal_estadual, mdl = linreg, 
                                                          na.action = na.omit)

#Evaluate
evaluate(changefinder_nfsp_estatal_estadual, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     1      17   
# FALSE    64     167  

round(evaluate(changefinder_nfsp_estatal_estadual, reference, metric = "F1"), 2)          # 0.02
round(evaluate(changefinder_nfsp_estatal_estadual, reference, metric = "accuracy"), 2)    # 0.67
round(evaluate(changefinder_nfsp_estatal_estadual, reference, metric = "sensitivity"), 2) # 0.02
round(evaluate(changefinder_nfsp_estatal_estadual, reference, metric = "specificity"), 2) # 0.91
round(evaluate(changefinder_nfsp_estatal_estadual, reference, metric = "precision"), 2)   # 0.06
round(evaluate(changefinder_nfsp_estatal_estadual, reference, metric = "recall"), 2)      # 0.02

#Plot
print(evtplot(test_nfsp_estatal_estadual, changefinder_nfsp_estatal_estadual, reference))

##### 8. nfsp_estatl_municipal #####
#Detect
changefinder_nfsp_estatl_municipal <- evtdet.changeFinder(test_nfsp_estatl_municipal, mdl = linreg, 
                                                          na.action = na.omit)

#Evaluate
evaluate(changefinder_nfsp_estatl_municipal, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     3      11    
# FALSE    62     173 

round(evaluate(changefinder_nfsp_estatl_municipal, reference, metric = "F1"), 2)          # 0.08
round(evaluate(changefinder_nfsp_estatl_municipal, reference, metric = "accuracy"), 2)    # 0.71
round(evaluate(changefinder_nfsp_estatl_municipal, reference, metric = "sensitivity"), 2) # 0.05
round(evaluate(changefinder_nfsp_estatl_municipal, reference, metric = "specificity"), 2) # 0.94
round(evaluate(changefinder_nfsp_estatl_municipal, reference, metric = "precision"), 2)   # 0.21
round(evaluate(changefinder_nfsp_estatl_municipal, reference, metric = "recall"), 2)      # 0.05

#Plot
print(evtplot(test_nfsp_estatl_municipal, changefinder_nfsp_estatl_municipal, reference))
