##################################################
##### Deteco de Eventos - ndices de Aes #####
##################################################

################
##### Data #####
################

library(tibble)
library(EventDetectR)
source("https://raw.githubusercontent.com/cefet-rj-dal/harbinger/master/harbinger.R")

attach(df_stocks)
head(df_stocks)
str(df_stocks)

test_ibovespa <- subset(df_stocks, select = c(Data, ibovespa))
test_ibrx100 <- subset(df_stocks, select = c(Data, ibrx100))
test_ibrx50 <- subset(df_stocks, selec = c(Data, ibrx50))
test_ibra <- subset(df_stocks, select = c(Data, ibra))
test_midlarge <- subset(df_stocks, select = c(Data, midlarge))
test_smallcap <- subset(df_stocks, select = c(Data, smallcap))
test_igc <- subset(df_stocks, select = c(Data, igc))
test_itag <- subset(df_stocks, select = c(Data, itag))
test_igct <- subset(df_stocks, select = c(Data, igct))
test_ifnc <- subset(df_stocks, select = c(Data, ifnc))
test_ieex <- subset(df_stocks, select = c(Data, ieex))
reference <- subset(df_stocks, select = c(Data, event))

#####################
##### Anomalize #####
#####################

##### 1. ibovespa #####
#Detect
anomalize_ibovespa <- evtdet.anomalize(test_ibovespa, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_ibovespa, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     15     8   
# FALSE    51     187 

round(evaluate(anomalize_ibovespa, reference, metric = "F1"), 2)          # 0.34
round(evaluate(anomalize_ibovespa, reference, metric = "accuracy"), 2)    # 0.77
round(evaluate(anomalize_ibovespa, reference, metric = "sensitivity"), 2) # 0.23
round(evaluate(anomalize_ibovespa, reference, metric = "specificity"), 2) # 0.96
round(evaluate(anomalize_ibovespa, reference, metric = "precision"), 2)   # 0.65
round(evaluate(anomalize_ibovespa, reference, metric = "recall"), 2)      # 0.23

#Plot
print(evtplot(test_ibovespa, anomalize_ibovespa, reference))

##### 2. ibrx100 #####
#Detect
anomalize_ibrx100 <- evtdet.anomalize(test_ibrx100, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_ibrx100, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     21     12   
# FALSE    45     183  

round(evaluate(anomalize_ibrx100, reference, metric = "F1"), 2)          # 0.42
round(evaluate(anomalize_ibrx100, reference, metric = "accuracy"), 2)    # 0.78
round(evaluate(anomalize_ibrx100, reference, metric = "sensitivity"), 2) # 0.32
round(evaluate(anomalize_ibrx100, reference, metric = "specificity"), 2) # 0.94
round(evaluate(anomalize_ibrx100, reference, metric = "precision"), 2)   # 0.64
round(evaluate(anomalize_ibrx100, reference, metric = "recall"), 2)      # 0.32

#Plot
print(evtplot(test_ibrx100, anomalize_ibrx100, reference))

##### 3. ibrx50 #####
#Detect
anomalize_ibrx50 <- evtdet.anomalize(test_ibrx50, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_ibrx50, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     19     16  
# FALSE    47     179  

round(evaluate(anomalize_ibrx50, reference, metric = "F1"), 2)          # 0.38
round(evaluate(anomalize_ibrx50, reference, metric = "accuracy"), 2)    # 0.76
round(evaluate(anomalize_ibrx50, reference, metric = "sensitivity"), 2) # 0.29
round(evaluate(anomalize_ibrx50, reference, metric = "specificity"), 2) # 0.92
round(evaluate(anomalize_ibrx50, reference, metric = "precision"), 2)   # 0.54
round(evaluate(anomalize_ibrx50, reference, metric = "recall"), 2)      # 0.29

#Plot
print(evtplot(test_ibrx50, anomalize_ibrx50, reference))

##### 4. ibra #####
#Detect
anomalize_ibra <- evtdet.anomalize(test_ibra, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_ibra, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     11     2    
# FALSE    54     182  

round(evaluate(anomalize_ibra, reference, metric = "F1"), 2)          # 0.28
round(evaluate(anomalize_ibra, reference, metric = "accuracy"), 2)    # 0.78
round(evaluate(anomalize_ibra, reference, metric = "sensitivity"), 2) # 0.17
round(evaluate(anomalize_ibra, reference, metric = "specificity"), 2) # 0.99
round(evaluate(anomalize_ibra, reference, metric = "precision"), 2)   # 0.85
round(evaluate(anomalize_ibra, reference, metric = "recall"), 2)      # 0.17

#Plot
print(evtplot(test_ibra, anomalize_ibra, reference))

##### 5. midlarge #####
#Detect
anomalize_midlarge <- evtdet.anomalize(test_midlarge, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_midlarge, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     13     4  
# FALSE    52     180 

round(evaluate(anomalize_midlarge, reference, metric = "F1"), 2)          # 0.32
round(evaluate(anomalize_midlarge, reference, metric = "accuracy"), 2)    # 0.78
round(evaluate(anomalize_midlarge, reference, metric = "sensitivity"), 2) # 0.20
round(evaluate(anomalize_midlarge, reference, metric = "specificity"), 2) # 0.98
round(evaluate(anomalize_midlarge, reference, metric = "precision"), 2)   # 0.76
round(evaluate(anomalize_midlarge, reference, metric = "recall"), 2)      # 0.20

#Plot
print(evtplot(test_midlarge, anomalize_midlarge, reference))

##### 6. smallcap #####
#Detect
anomalize_smallcap <- evtdet.anomalize(test_smallcap, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_smallcap, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     11     2 
# FALSE    54     182  

round(evaluate(anomalize_smallcap, reference, metric = "F1"), 2)          # 0.28
round(evaluate(anomalize_smallcap, reference, metric = "accuracy"), 2)    # 0.78
round(evaluate(anomalize_smallcap, reference, metric = "sensitivity"), 2) # 0.17
round(evaluate(anomalize_smallcap, reference, metric = "specificity"), 2) # 0.99
round(evaluate(anomalize_smallcap, reference, metric = "precision"), 2)   # 0.85
round(evaluate(anomalize_smallcap, reference, metric = "recall"), 2)      # 0.17

#Plot
print(evtplot(test_smallcap, anomalize_smallcap, reference))

##### 7. igc #####
#Detect
anomalize_igc <- evtdet.anomalize(test_igc, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_igc, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     19     11 
# FALSE    46     173  

round(evaluate(anomalize_igc, reference, metric = "F1"), 2)          # 0.40
round(evaluate(anomalize_igc, reference, metric = "accuracy"), 2)    # 0.77
round(evaluate(anomalize_igc, reference, metric = "sensitivity"), 2) # 0.29
round(evaluate(anomalize_igc, reference, metric = "specificity"), 2) # 0.94
round(evaluate(anomalize_igc, reference, metric = "precision"), 2)   # 0.63
round(evaluate(anomalize_igc, reference, metric = "recall"), 2)      # 0.29

#Plot
print(evtplot(test_igc, anomalize_igc, reference))

##### 8. itag #####
#Detect
anomalize_itag <- evtdet.anomalize(test_itag, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_itag, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     19     8    
# FALSE    46     176  

round(evaluate(anomalize_itag, reference, metric = "F1"), 2)          # 0.41
round(evaluate(anomalize_itag, reference, metric = "accuracy"), 2)    # 0.78
round(evaluate(anomalize_itag, reference, metric = "sensitivity"), 2) # 0.29
round(evaluate(anomalize_itag, reference, metric = "specificity"), 2) # 0.96
round(evaluate(anomalize_itag, reference, metric = "precision"), 2)   # 0.70
round(evaluate(anomalize_itag, reference, metric = "recall"), 2)      # 0.29

#Plot
print(evtplot(test_itag, anomalize_itag, reference))

##### 9. igct #####
#Detect
anomalize_igct <- evtdet.anomalize(test_igct, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_igct, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     14     5   
# FALSE    51     179  

round(evaluate(anomalize_igct, reference, metric = "F1"), 2)          # 0.33
round(evaluate(anomalize_igct, reference, metric = "accuracy"), 2)    # 0.78
round(evaluate(anomalize_igct, reference, metric = "sensitivity"), 2) # 0.22
round(evaluate(anomalize_igct, reference, metric = "specificity"), 2) # 0.97
round(evaluate(anomalize_igct, reference, metric = "precision"), 2)   # 0.74
round(evaluate(anomalize_igct, reference, metric = "recall"), 2)      # 0.22

#Plot
print(evtplot(test_igct, anomalize_igct, reference))

##### 10. ifnc #####
#Detect
anomalize_ifnc <- evtdet.anomalize(test_ifnc, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_ifnc, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     19     18 
# FALSE    46     166  

round(evaluate(anomalize_ifnc, reference, metric = "F1"), 2)          # 0.37
round(evaluate(anomalize_ifnc, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(anomalize_ifnc, reference, metric = "sensitivity"), 2) # 0.29
round(evaluate(anomalize_ifnc, reference, metric = "specificity"), 2) # 0.90
round(evaluate(anomalize_ifnc, reference, metric = "precision"), 2)   # 0.51
round(evaluate(anomalize_ifnc, reference, metric = "recall"), 2)      # 0.29

#Plot
print(evtplot(test_ifnc, anomalize_ifnc, reference))

##### 11. ieex #####
#Detect
anomalize_ieex <- evtdet.anomalize(test_ieex, alpha = 0.1, max_anoms = 0.2, na.action = na.omit)

#Evaluate
evaluate(anomalize_ieex, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     21     24  
# FALSE    45     171  

round(evaluate(anomalize_ieex, reference, metric = "F1"), 2)          # 0.38
round(evaluate(anomalize_ieex, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(anomalize_ieex, reference, metric = "sensitivity"), 2) # 0.32
round(evaluate(anomalize_ieex, reference, metric = "specificity"), 2) # 0.88
round(evaluate(anomalize_ieex, reference, metric = "precision"), 2)   # 0.47
round(evaluate(anomalize_ieex, reference, metric = "recall"), 2)      # 0.32

#Plot
print(evtplot(test_ieex, anomalize_ieex, reference))

###########################################
##### Adaptive Normalization Outliers #####
###########################################

##### 1. ibovespa #####
#Detect
an_ibovespa <- evtdet.an_outliers(test_ibovespa, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_ibovespa, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     1      0  
# FALSE    65     195

round(evaluate(an_ibovespa, reference, metric = "F1"), 2)          # 0.03
round(evaluate(an_ibovespa, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(an_ibovespa, reference, metric = "sensitivity"), 2) # 0.02
round(evaluate(an_ibovespa, reference, metric = "specificity"), 2) # 1.00
round(evaluate(an_ibovespa, reference, metric = "precision"), 2)   # 1.00
round(evaluate(an_ibovespa, reference, metric = "recall"), 2)      # 0.02

#Plot
print(evtplot(test_ibovespa, an_ibovespa, reference))

##### 2. ibrx100 #####
#Detect
an_ibrx100 <- evtdet.an_outliers(test_ibrx100, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_ibrx100, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     2      0      
# FALSE    64     195  

round(evaluate(an_ibrx100, reference, metric = "F1"), 2)          # 0.06
round(evaluate(an_ibrx100, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(an_ibrx100, reference, metric = "sensitivity"), 2) # 0.03
round(evaluate(an_ibrx100, reference, metric = "specificity"), 2) # 1.00
round(evaluate(an_ibrx100, reference, metric = "precision"), 2)   # 1.00
round(evaluate(an_ibrx100, reference, metric = "recall"), 2)      # 0.03

#Plot
print(evtplot(test_ibrx100, an_ibrx100, reference))

##### 3. ibrx50 #####
#Detect
an_ibrx50 <- evtdet.an_outliers(test_ibrx50, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_ibrx50, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     1      0    
# FALSE    65     195  

round(evaluate(an_ibrx50, reference, metric = "F1"), 2)          # 0.03
round(evaluate(an_ibrx50, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(an_ibrx50, reference, metric = "sensitivity"), 2) # 0.02
round(evaluate(an_ibrx50, reference, metric = "specificity"), 2) # 1.00
round(evaluate(an_ibrx50, reference, metric = "precision"), 2)   # 1.00
round(evaluate(an_ibrx50, reference, metric = "recall"), 2)      # 0.02

#Plot
print(evtplot(test_ibrx50, an_ibrx50, reference))

##### 4. ibra #####
#Detect
an_ibra <- evtdet.an_outliers(test_ibra, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_ibra, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     1      0    
# FALSE    64     184 

round(evaluate(an_ibra, reference, metric = "F1"), 2)          # 0.03
round(evaluate(an_ibra, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(an_ibra, reference, metric = "sensitivity"), 2) # 0.02
round(evaluate(an_ibra, reference, metric = "specificity"), 2) # 1.00
round(evaluate(an_ibra, reference, metric = "precision"), 2)   # 1.00
round(evaluate(an_ibra, reference, metric = "recall"), 2)      # 0.02

#Plot
print(evtplot(test_ibra, an_ibra, reference))

##### 5. midlarge #####
#Detect
an_midlarge <- evtdet.an_outliers(test_midlarge, w = 30, alpha = 1.5, na.action = na.omit)

#Error in data.frame(..., check.names = FALSE) : 
#  arguments imply differing number of rows: 0, 1 

#Evaluate
evaluate(an_midlarge, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE      
# FALSE     

round(evaluate(an_midlarge, reference, metric = "F1"), 2)          # 
round(evaluate(an_midlarge, reference, metric = "accuracy"), 2)    # 
round(evaluate(an_midlarge, reference, metric = "sensitivity"), 2) # 
round(evaluate(an_midlarge, reference, metric = "specificity"), 2) # 
round(evaluate(an_midlarge, reference, metric = "precision"), 2)   # 
round(evaluate(an_midlarge, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_midlarge, an_midlarge, reference))

##### 6. smallcap #####
#Detect
an_smallcap <- evtdet.an_outliers(test_smallcap, w = 30, alpha = 1.5, na.action = na.omit)

#Error in data.frame(..., check.names = FALSE) : 
#  arguments imply differing number of rows: 0, 1 

#Evaluate
evaluate(an_smallcap, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE      
# FALSE    

round(evaluate(an_smallcap, reference, metric = "F1"), 2)          # 
round(evaluate(an_smallcap, reference, metric = "accuracy"), 2)    # 
round(evaluate(an_smallcap, reference, metric = "sensitivity"), 2) # 
round(evaluate(an_smallcap, reference, metric = "specificity"), 2) # 
round(evaluate(an_smallcap, reference, metric = "precision"), 2)   # 
round(evaluate(an_smallcap, reference, metric = "recall"), 2)      # 

#Plot
print(evtplot(test_smallcap, an_smallcap, reference))

##### 7. igc #####
#Detect
an_igc <- evtdet.an_outliers(test_igc, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_igc, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     7      1    
# FALSE    58     183  

round(evaluate(an_igc, reference, metric = "F1"), 2)          # 0.19
round(evaluate(an_igc, reference, metric = "accuracy"), 2)    # 0.76
round(evaluate(an_igc, reference, metric = "sensitivity"), 2) # 0.11
round(evaluate(an_igc, reference, metric = "specificity"), 2) # 0.99
round(evaluate(an_igc, reference, metric = "precision"), 2)   # 0.88
round(evaluate(an_igc, reference, metric = "recall"), 2)      # 0.11

#Plot
print(evtplot(test_igc, an_igc, reference))

##### 8. itag #####
#Detect
an_itag <- evtdet.an_outliers(test_itag, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_itag, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     9      1    
# FALSE    56     183

round(evaluate(an_itag, reference, metric = "F1"), 2)          # 0.24
round(evaluate(an_itag, reference, metric = "accuracy"), 2)    # 0.77
round(evaluate(an_itag, reference, metric = "sensitivity"), 2) # 0.14
round(evaluate(an_itag, reference, metric = "specificity"), 2) # 0.99
round(evaluate(an_itag, reference, metric = "precision"), 2)   # 0.90
round(evaluate(an_itag, reference, metric = "recall"), 2)      # 0.14

#Plot
print(evtplot(test_itag, an_itag, reference))

##### 9. igct #####
#Detect
an_igct <- evtdet.an_outliers(test_igct, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_igct, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     1      0 
# FALSE    64     184 

round(evaluate(an_igct, reference, metric = "F1"), 2)          # 0.03
round(evaluate(an_igct, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(an_igct, reference, metric = "sensitivity"), 2) # 0.02
round(evaluate(an_igct, reference, metric = "specificity"), 2) # 1.00
round(evaluate(an_igct, reference, metric = "precision"), 2)   # 1.00
round(evaluate(an_igct, reference, metric = "recall"), 2)      # 0.02

#Plot
print(evtplot(test_igct, an_igct, reference))

##### 10. ifnc #####
#Detect
an_ifnc <- evtdet.an_outliers(test_ifnc, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_ifnc, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     14     24   
# FALSE    51     160  

round(evaluate(an_ifnc, reference, metric = "F1"), 2)          # 0.27
round(evaluate(an_ifnc, reference, metric = "accuracy"), 2)    # 0.70
round(evaluate(an_ifnc, reference, metric = "sensitivity"), 2) # 0.22
round(evaluate(an_ifnc, reference, metric = "specificity"), 2) # 0.87
round(evaluate(an_ifnc, reference, metric = "precision"), 2)   # 0.37
round(evaluate(an_ifnc, reference, metric = "recall"), 2)      # 0.22

#Plot
print(evtplot(test_ifnc, an_ifnc, reference))

##### 11. ieex #####
#Detect
an_ieex <- evtdet.an_outliers(test_ieex, w = 30, alpha = 1.5, na.action = na.omit)

#Evaluate
evaluate(an_ieex, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     11     27   
# FALSE    55     168  

round(evaluate(an_ieex, reference, metric = "F1"), 2)          # 0.21
round(evaluate(an_ieex, reference, metric = "accuracy"), 2)    # 0.69
round(evaluate(an_ieex, reference, metric = "sensitivity"), 2) # 0.17
round(evaluate(an_ieex, reference, metric = "specificity"), 2) # 0.86
round(evaluate(an_ieex, reference, metric = "precision"), 2)   # 0.29
round(evaluate(an_ieex, reference, metric = "recall"), 2)      # 0.17

#Plot
print(evtplot(test_ieex, an_ieex, reference))

#######################
##### EventDetect #####
#######################

##### 1. ibovespa #####
#Detect
eventdetect_ibovespa <- evtdet.eventdetect(na.omit(test_ibovespa), w = 30)

#Evaluate
evaluate(eventdetect_ibovespa, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     47     131
# FALSE    19     64   

round(evaluate(eventdetect_ibovespa, reference, metric = "F1"), 2)          # 0.39
round(evaluate(eventdetect_ibovespa, reference, metric = "accuracy"), 2)    # 0.43
round(evaluate(eventdetect_ibovespa, reference, metric = "sensitivity"), 2) # 0.71
round(evaluate(eventdetect_ibovespa, reference, metric = "specificity"), 2) # 0.33
round(evaluate(eventdetect_ibovespa, reference, metric = "precision"), 2)   # 0.26
round(evaluate(eventdetect_ibovespa, reference, metric = "recall"), 2)      # 0.71

#Plot
print(evtplot(test_ibovespa, eventdetect_ibovespa, reference))

##### 2. ibrx100 #####
#Detect
eventdetect_ibrx100 <- evtdet.eventdetect(na.omit(test_ibrx100), w = 30)

#Evaluate
evaluate(eventdetect_ibrx100, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     51     143 
# FALSE    15     52  

round(evaluate(eventdetect_ibrx100, reference, metric = "F1"), 2)          # 0.39
round(evaluate(eventdetect_ibrx100, reference, metric = "accuracy"), 2)    # 0.39
round(evaluate(eventdetect_ibrx100, reference, metric = "sensitivity"), 2) # 0.77
round(evaluate(eventdetect_ibrx100, reference, metric = "specificity"), 2) # 0.27
round(evaluate(eventdetect_ibrx100, reference, metric = "precision"), 2)   # 0.26
round(evaluate(eventdetect_ibrx100, reference, metric = "recall"), 2)      # 0.77

#Plot
print(evtplot(test_ibrx100, eventdetect_ibrx100, reference))

##### 3. ibrx50 #####
#Detect
eventdetect_ibrx50 <- evtdet.eventdetect(na.omit(test_ibrx50), w = 30)

#Evaluate
evaluate(eventdetect_ibrx50, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     57     129  
# FALSE    9      66   

round(evaluate(eventdetect_ibrx50, reference, metric = "F1"), 2)          # 0.45
round(evaluate(eventdetect_ibrx50, reference, metric = "accuracy"), 2)    # 0.47
round(evaluate(eventdetect_ibrx50, reference, metric = "sensitivity"), 2) # 0.86
round(evaluate(eventdetect_ibrx50, reference, metric = "specificity"), 2) # 0.34
round(evaluate(eventdetect_ibrx50, reference, metric = "precision"), 2)   # 0.31
round(evaluate(eventdetect_ibrx50, reference, metric = "recall"), 2)      # 0.86

#Plot
print(evtplot(test_ibrx50, eventdetect_ibrx50, reference))

##### 4. ibra #####
#Detect
eventdetect_ibra <- evtdet.eventdetect(na.omit(test_ibra), w = 30)

#Evaluate
evaluate(eventdetect_ibra, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     18     17     
# FALSE    47     167 

round(evaluate(eventdetect_ibra, reference, metric = "F1"), 2)          # 0.36
round(evaluate(eventdetect_ibra, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(eventdetect_ibra, reference, metric = "sensitivity"), 2) # 0.28
round(evaluate(eventdetect_ibra, reference, metric = "specificity"), 2) # 0.91
round(evaluate(eventdetect_ibra, reference, metric = "precision"), 2)   # 0.51
round(evaluate(eventdetect_ibra, reference, metric = "recall"), 2)      # 0.28

#Plot
print(evtplot(test_ibra, eventdetect_ibra, reference))

##### 5. midlarge #####
#Detect
eventdetect_midlarge <- evtdet.eventdetect(na.omit(test_midlarge), w = 30)

#Evaluate
evaluate(eventdetect_midlarge, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     49     66   
# FALSE    16     118

round(evaluate(eventdetect_midlarge, reference, metric = "F1"), 2)          # 0.54
round(evaluate(eventdetect_midlarge, reference, metric = "accuracy"), 2)    # 0.67
round(evaluate(eventdetect_midlarge, reference, metric = "sensitivity"), 2) # 0.75
round(evaluate(eventdetect_midlarge, reference, metric = "specificity"), 2) # 0.64
round(evaluate(eventdetect_midlarge, reference, metric = "precision"), 2)   # 0.43
round(evaluate(eventdetect_midlarge, reference, metric = "recall"), 2)      # 0.75

#Plot
print(evtplot(test_midlarge, eventdetect_midlarge, reference))

##### 6. smallcap #####
#Detect
eventdetect_smallcap <- evtdet.eventdetect(na.omit(test_smallcap), w = 30)

#Evaluate
evaluate(eventdetect_smallcap, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     17     13 
# FALSE    48     171

round(evaluate(eventdetect_smallcap, reference, metric = "F1"), 2)          # 0.36
round(evaluate(eventdetect_smallcap, reference, metric = "accuracy"), 2)    # 0.76
round(evaluate(eventdetect_smallcap, reference, metric = "sensitivity"), 2) # 0.26
round(evaluate(eventdetect_smallcap, reference, metric = "specificity"), 2) # 0.93
round(evaluate(eventdetect_smallcap, reference, metric = "precision"), 2)   # 0.57
round(evaluate(eventdetect_smallcap, reference, metric = "recall"), 2)      # 0.26

#Plot
print(evtplot(test_smallcap, eventdetect_smallcap, reference))

##### 7. igc #####
#Detect
eventdetect_igc <- evtdet.eventdetect(na.omit(test_igc), w = 30)

#Evaluate
evaluate(eventdetect_igc, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     60     126  
# FALSE    5      58 

round(evaluate(eventdetect_igc, reference, metric = "F1"), 2)          # 0.48
round(evaluate(eventdetect_igc, reference, metric = "accuracy"), 2)    # 0.47
round(evaluate(eventdetect_igc, reference, metric = "sensitivity"), 2) # 0.92
round(evaluate(eventdetect_igc, reference, metric = "specificity"), 2) # 0.32
round(evaluate(eventdetect_igc, reference, metric = "precision"), 2)   # 0.32
round(evaluate(eventdetect_igc, reference, metric = "recall"), 2)      # 0.92

#Plot
print(evtplot(test_igc, eventdetect_igc, reference))

##### 8. itag #####
#Detect
eventdetect_itag <- evtdet.eventdetect(na.omit(test_itag), w = 30)

#Evaluate
evaluate(eventdetect_itag, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     13     20   
# FALSE    52     164  

round(evaluate(eventdetect_itag, reference, metric = "F1"), 2)          # 0.27
round(evaluate(eventdetect_itag, reference, metric = "accuracy"), 2)    # 0.71
round(evaluate(eventdetect_itag, reference, metric = "sensitivity"), 2) # 0.20
round(evaluate(eventdetect_itag, reference, metric = "specificity"), 2) # 0.89
round(evaluate(eventdetect_itag, reference, metric = "precision"), 2)   # 0.39
round(evaluate(eventdetect_itag, reference, metric = "recall"), 2)      # 0.20

#Plot
print(evtplot(test_itag, eventdetect_itag, reference))

##### 9. igct #####
#Detect
eventdetect_igct <- evtdet.eventdetect(na.omit(test_igct), w = 30)

#Evaluate
evaluate(eventdetect_igct, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     21     24  
# FALSE    44     160 

round(evaluate(eventdetect_igct, reference, metric = "F1"), 2)          # 0.38
round(evaluate(eventdetect_igct, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(eventdetect_igct, reference, metric = "sensitivity"), 2) # 0.32
round(evaluate(eventdetect_igct, reference, metric = "specificity"), 2) # 0.87
round(evaluate(eventdetect_igct, reference, metric = "precision"), 2)   # 0.47
round(evaluate(eventdetect_igct, reference, metric = "recall"), 2)      # 0.32

#Plot
print(evtplot(test_igct, eventdetect_igct, reference))

##### 10. ifnc #####
#Detect
eventdetect_ifnc <- evtdet.eventdetect(na.omit(test_ifnc), w = 30)

#Evaluate
evaluate(eventdetect_ifnc, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     52     93   
# FALSE    13     91   

round(evaluate(eventdetect_ifnc, reference, metric = "F1"), 2)          # 0.50
round(evaluate(eventdetect_ifnc, reference, metric = "accuracy"), 2)    # 0.57
round(evaluate(eventdetect_ifnc, reference, metric = "sensitivity"), 2) # 0.80
round(evaluate(eventdetect_ifnc, reference, metric = "specificity"), 2) # 0.49
round(evaluate(eventdetect_ifnc, reference, metric = "precision"), 2)   # 0.36
round(evaluate(eventdetect_ifnc, reference, metric = "recall"), 2)      # 0.80

#Plot
print(evtplot(test_ifnc, eventdetect_ifnc, reference))

##### 11. ieex #####
#Detect
eventdetect_ieex <- evtdet.eventdetect(na.omit(test_ieex), w = 30)

#Evaluate
evaluate(eventdetect_ieex, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     48     141  
# FALSE    18     54 

round(evaluate(eventdetect_ieex, reference, metric = "F1"), 2)          # 0.38
round(evaluate(eventdetect_ieex, reference, metric = "accuracy"), 2)    # 0.39
round(evaluate(eventdetect_ieex, reference, metric = "sensitivity"), 2) # 0.73
round(evaluate(eventdetect_ieex, reference, metric = "specificity"), 2) # 0.28
round(evaluate(eventdetect_ieex, reference, metric = "precision"), 2)   # 0.25
round(evaluate(eventdetect_ieex, reference, metric = "recall"), 2)      # 0.73

#Plot
print(evtplot(test_ieex, eventdetect_ieex, reference))

#######################################
##### Auxiliary Model definitions #####
#######################################

ARIMA <- function(data) forecast::auto.arima(data)
AR <- function(data,p) forecast::Arima(data, order = c(p, 0, 0), seasonal = c(0, 0, 0))
garch <- function(data,spec,...) rugarch::ugarchfit(spec=spec,data=data,solver="hybrid", ...)@fit
ets <- function(data) forecast::ets(ts(data))
linreg <- function(data) {
  #browser()
  data <- as.data.frame(data)
  colnames(data) <- "x"
  data$t <- 1:nrow(data)
  
  #Adjusting a linear regression to the whole window
  lm(x~t, data)
}

#Garch specs
garch11 <- rugarch::ugarchspec(variance.model = list(model = "sGARCH", garchOrder = c(1, 1)), 
                               mean.model = list(armaOrder = c(1, 1), include.mean = TRUE), 
                               distribution.model = "norm")

####################################
##### Garch Volatility Outlier #####
####################################

##### 1. ibovespa #####
#Detect
garch_volatility_ibovespa <- evtdet.garch_volatility_outlier(test_ibovespa, spec = garch11, alpha = 1.5,
                                                             na.action = na.omit)

#Evaluate
evaluate(garch_volatility_ibovespa, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     12     7   
# FALSE    54     188  

round(evaluate(garch_volatility_ibovespa, reference, metric = "F1"), 2)          # 0.28
round(evaluate(garch_volatility_ibovespa, reference, metric = "accuracy"), 2)    # 0.77
round(evaluate(garch_volatility_ibovespa, reference, metric = "sensitivity"), 2) # 0.18
round(evaluate(garch_volatility_ibovespa, reference, metric = "specificity"), 2) # 0.96
round(evaluate(garch_volatility_ibovespa, reference, metric = "precision"), 2)   # 0.63
round(evaluate(garch_volatility_ibovespa, reference, metric = "recall"), 2)      # 0.18

#Plot
print(evtplot(test_ibovespa, garch_volatility_ibovespa, reference))

##### 2. ibrx100 #####
#Detect
garch_volatility_ibrx100 <- evtdet.garch_volatility_outlier(test_ibrx100, spec = garch11, alpha = 1.5,
                                                            na.action = na.omit)

#Evaluate
evaluate(garch_volatility_ibrx100, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     14     11  
# FALSE    52     184 

round(evaluate(garch_volatility_ibrx100, reference, metric = "F1"), 2)          # 0.31
round(evaluate(garch_volatility_ibrx100, reference, metric = "accuracy"), 2)    # 0.76
round(evaluate(garch_volatility_ibrx100, reference, metric = "sensitivity"), 2) # 0.21
round(evaluate(garch_volatility_ibrx100, reference, metric = "specificity"), 2) # 0.94
round(evaluate(garch_volatility_ibrx100, reference, metric = "precision"), 2)   # 0.56
round(evaluate(garch_volatility_ibrx100, reference, metric = "recall"), 2)      # 0.21

#Plot
print(evtplot(test_ibrx100, garch_volatility_ibrx100, reference))

##### 3. ibrx50 #####
#Detect
garch_volatility_ibrx50 <- evtdet.garch_volatility_outlier(test_ibrx50, spec = garch11, alpha = 1.5,
                                                           na.action = na.omit)

#Evaluate
evaluate(garch_volatility_ibrx50, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     10     10   
# FALSE    56     185  

round(evaluate(garch_volatility_ibrx50, reference, metric = "F1"), 2)          # 0.23
round(evaluate(garch_volatility_ibrx50, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(garch_volatility_ibrx50, reference, metric = "sensitivity"), 2) # 0.15
round(evaluate(garch_volatility_ibrx50, reference, metric = "specificity"), 2) # 0.95
round(evaluate(garch_volatility_ibrx50, reference, metric = "precision"), 2)   # 0.50
round(evaluate(garch_volatility_ibrx50, reference, metric = "recall"), 2)      # 0.15

#Plot
print(evtplot(test_ibrx50, garch_volatility_ibrx50, reference))

##### 4. ibra #####
#Detect
garch_volatility_ibra <- evtdet.garch_volatility_outlier(test_ibra, spec = garch11, alpha = 1.5,
                                                         na.action = na.omit)

#Evaluate
evaluate(garch_volatility_ibra, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     13     6    
# FALSE    52     178  

round(evaluate(garch_volatility_ibra, reference, metric = "F1"), 2)          # 0.31
round(evaluate(garch_volatility_ibra, reference, metric = "accuracy"), 2)    # 0.77
round(evaluate(garch_volatility_ibra, reference, metric = "sensitivity"), 2) # 0.20
round(evaluate(garch_volatility_ibra, reference, metric = "specificity"), 2) # 0.97
round(evaluate(garch_volatility_ibra, reference, metric = "precision"), 2)   # 0.68
round(evaluate(garch_volatility_ibra, reference, metric = "recall"), 2)      # 0.20

#Plot
print(evtplot(test_ibra, garch_volatility_ibra, reference))

##### 5. midlarge #####
#Detect
garch_volatility_midlarge <- evtdet.garch_volatility_outlier(test_midlarge, spec = garch11, alpha = 1.5,
                                                             na.action = na.omit)

#Evaluate
evaluate(garch_volatility_midlarge, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     13     6    
# FALSE    52     178  

round(evaluate(garch_volatility_midlarge, reference, metric = "F1"), 2)          # 0.31
round(evaluate(garch_volatility_midlarge, reference, metric = "accuracy"), 2)    # 0.77
round(evaluate(garch_volatility_midlarge, reference, metric = "sensitivity"), 2) # 0.20
round(evaluate(garch_volatility_midlarge, reference, metric = "specificity"), 2) # 0.97
round(evaluate(garch_volatility_midlarge, reference, metric = "precision"), 2)   # 0.68
round(evaluate(garch_volatility_midlarge, reference, metric = "recall"), 2)      # 0.20

#Plot
print(evtplot(test_midlarge, garch_volatility_midlarge, reference))

##### 6. smallcap #####
#Detect
garch_volatility_smallcap <- evtdet.garch_volatility_outlier(test_smallcap, spec = garch11, alpha = 1.5,
                                                             na.action = na.omit)

#Evaluate
evaluate(garch_volatility_smallcap, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     16     6    
# FALSE    49     178

round(evaluate(garch_volatility_smallcap, reference, metric = "F1"), 2)          # 0.37
round(evaluate(garch_volatility_smallcap, reference, metric = "accuracy"), 2)    # 0.78
round(evaluate(garch_volatility_smallcap, reference, metric = "sensitivity"), 2) # 0.25
round(evaluate(garch_volatility_smallcap, reference, metric = "specificity"), 2) # 0.97
round(evaluate(garch_volatility_smallcap, reference, metric = "precision"), 2)   # 0.73
round(evaluate(garch_volatility_smallcap, reference, metric = "recall"), 2)      # 0.25

#Plot
print(evtplot(test_smallcap, garch_volatility_smallcap, reference))

##### 7. igc #####
#Detect
garch_volatility_igc <- evtdet.garch_volatility_outlier(test_igc, spec = garch11, alpha = 1.5,
                                                        na.action = na.omit)

#Evaluate
evaluate(garch_volatility_igc, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     14     10 
# FALSE    51     174 

round(evaluate(garch_volatility_igc, reference, metric = "F1"), 2)          # 0.31
round(evaluate(garch_volatility_igc, reference, metric = "accuracy"), 2)    # 0.76
round(evaluate(garch_volatility_igc, reference, metric = "sensitivity"), 2) # 0.22
round(evaluate(garch_volatility_igc, reference, metric = "specificity"), 2) # 0.95
round(evaluate(garch_volatility_igc, reference, metric = "precision"), 2)   # 0.58
round(evaluate(garch_volatility_igc, reference, metric = "recall"), 2)      # 0.22

#Plot
print(evtplot(test_igc, garch_volatility_igc, reference))

##### 8. itag #####
#Detect
garch_volatility_itag <- evtdet.garch_volatility_outlier(test_itag, spec = garch11, alpha = 1.5,
                                                         na.action = na.omit)

#Evaluate
evaluate(garch_volatility_itag, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     12     10   
# FALSE    53     174 

round(evaluate(garch_volatility_itag, reference, metric = "F1"), 2)          # 0.28
round(evaluate(garch_volatility_itag, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(garch_volatility_itag, reference, metric = "sensitivity"), 2) # 0.18
round(evaluate(garch_volatility_itag, reference, metric = "specificity"), 2) # 0.95
round(evaluate(garch_volatility_itag, reference, metric = "precision"), 2)   # 0.55
round(evaluate(garch_volatility_itag, reference, metric = "recall"), 2)      # 0.18

#Plot
print(evtplot(test_itag, garch_volatility_itag, reference))

##### 9. igct #####
#Detect
garch_volatility_igct <- evtdet.garch_volatility_outlier(test_igct, spec = garch11, alpha = 1.5,
                                                         na.action = na.omit)

#Evaluate
evaluate(garch_volatility_igct, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     12     7 
# FALSE    53     177 

round(evaluate(garch_volatility_igct, reference, metric = "F1"), 2)          # 0.29
round(evaluate(garch_volatility_igct, reference, metric = "accuracy"), 2)    # 0.76
round(evaluate(garch_volatility_igct, reference, metric = "sensitivity"), 2) # 0.18
round(evaluate(garch_volatility_igct, reference, metric = "specificity"), 2) # 0.96
round(evaluate(garch_volatility_igct, reference, metric = "precision"), 2)   # 0.63
round(evaluate(garch_volatility_igct, reference, metric = "recall"), 2)      # 0.18

#Plot
print(evtplot(test_igct, garch_volatility_igct, reference))

##### 10. ifnc #####
#Detect
garch_volatility_ifnc <- evtdet.garch_volatility_outlier(test_ifnc, spec = garch11, alpha = 1.5,
                                                         na.action = na.omit)

#Evaluate
evaluate(garch_volatility_ifnc, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     11     13   
# FALSE    54     171  

round(evaluate(garch_volatility_ifnc, reference, metric = "F1"), 2)          # 0.25
round(evaluate(garch_volatility_ifnc, reference, metric = "accuracy"), 2)    # 0.73
round(evaluate(garch_volatility_ifnc, reference, metric = "sensitivity"), 2) # 0.17
round(evaluate(garch_volatility_ifnc, reference, metric = "specificity"), 2) # 0.93
round(evaluate(garch_volatility_ifnc, reference, metric = "precision"), 2)   # 0.46
round(evaluate(garch_volatility_ifnc, reference, metric = "recall"), 2)      # 0.17

#Plot
print(evtplot(test_ifnc, garch_volatility_ifnc, reference))

##### 11. ieex #####
#Detect
garch_volatility_ieex <- evtdet.garch_volatility_outlier(test_ieex, spec = garch11, alpha = 1.5,
                                                         na.action = na.omit)

#Evaluate
evaluate(garch_volatility_ieex, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     20     14   
# FALSE    46     181  

round(evaluate(garch_volatility_ieex, reference, metric = "F1"), 2)          # 0.40
round(evaluate(garch_volatility_ieex, reference, metric = "accuracy"), 2)    # 0.77
round(evaluate(garch_volatility_ieex, reference, metric = "sensitivity"), 2) # 0.30
round(evaluate(garch_volatility_ieex, reference, metric = "specificity"), 2) # 0.93
round(evaluate(garch_volatility_ieex, reference, metric = "precision"), 2)   # 0.59
round(evaluate(garch_volatility_ieex, reference, metric = "recall"), 2)      # 0.30

#Plot
print(evtplot(test_ieex, garch_volatility_ieex, reference))

#######################################
##### Seminal Change Point (1999) #####
#######################################

##### 1. ibovespa #####
#Detect
changepoint_ibovespa <- evtdet.seminalChangePoint2(test_ibovespa, w = 30, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_ibovespa, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     12     24      
# FALSE    54     171  

round(evaluate(changepoint_ibovespa, reference, metric = "F1"), 2)          # 0.24
round(evaluate(changepoint_ibovespa, reference, metric = "accuracy"), 2)    # 0.70
round(evaluate(changepoint_ibovespa, reference, metric = "sensitivity"), 2) # 0.18
round(evaluate(changepoint_ibovespa, reference, metric = "specificity"), 2) # 0.88
round(evaluate(changepoint_ibovespa, reference, metric = "precision"), 2)   # 0.33
round(evaluate(changepoint_ibovespa, reference, metric = "recall"), 2)      # 0.18

#Plot
print(evtplot(test_ibovespa, changepoint_ibovespa, reference))

##### 2. ibrx100 #####
#Detect
changepoint_ibrx100 <- evtdet.seminalChangePoint2(test_ibrx100, w = 30, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_ibrx100, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     12     38  
# FALSE    54     157  

round(evaluate(changepoint_ibrx100, reference, metric = "F1"), 2)          # 0.21
round(evaluate(changepoint_ibrx100, reference, metric = "accuracy"), 2)    # 0.65
round(evaluate(changepoint_ibrx100, reference, metric = "sensitivity"), 2) # 0.18
round(evaluate(changepoint_ibrx100, reference, metric = "specificity"), 2) # 0.81
round(evaluate(changepoint_ibrx100, reference, metric = "precision"), 2)   # 0.24
round(evaluate(changepoint_ibrx100, reference, metric = "recall"), 2)      # 0.18

#Plot
print(evtplot(test_ibrx100, changepoint_ibrx100, reference))

##### 3. ibrx50 #####
#Detect
changepoint_ibrx50 <- evtdet.seminalChangePoint2(test_ibrx50, w = 30, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_ibrx50, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     12     32    
# FALSE    54     163   

round(evaluate(changepoint_ibrx50, reference, metric = "F1"), 2)          # 0.22
round(evaluate(changepoint_ibrx50, reference, metric = "accuracy"), 2)    # 0.67
round(evaluate(changepoint_ibrx50, reference, metric = "sensitivity"), 2) # 0.18
round(evaluate(changepoint_ibrx50, reference, metric = "specificity"), 2) # 0.84
round(evaluate(changepoint_ibrx50, reference, metric = "precision"), 2)   # 0.27
round(evaluate(changepoint_ibrx50, reference, metric = "recall"), 2)      # 0.18

#Plot
print(evtplot(test_ibrx50, changepoint_ibrx50, reference))

##### 4. ibra #####
#Detect
changepoint_ibra <- evtdet.seminalChangePoint2(test_ibra, w = 30, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_ibra, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     13     21  
# FALSE    52     163  

round(evaluate(changepoint_ibra, reference, metric = "F1"), 2)          # 0.26
round(evaluate(changepoint_ibra, reference, metric = "accuracy"), 2)    # 0.71
round(evaluate(changepoint_ibra, reference, metric = "sensitivity"), 2) # 0.20
round(evaluate(changepoint_ibra, reference, metric = "specificity"), 2) # 0.89
round(evaluate(changepoint_ibra, reference, metric = "precision"), 2)   # 0.38
round(evaluate(changepoint_ibra, reference, metric = "recall"), 2)      # 0.20

#Plot
print(evtplot(test_ibra, changepoint_ibra, reference))

##### 5. midlarge #####
#Detect
changepoint_midlarge <- evtdet.seminalChangePoint2(test_midlarge, w = 30, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_midlarge, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     12     20  
# FALSE    53     164 

round(evaluate(changepoint_midlarge, reference, metric = "F1"), 2)          # 0.25
round(evaluate(changepoint_midlarge, reference, metric = "accuracy"), 2)    # 0.71
round(evaluate(changepoint_midlarge, reference, metric = "sensitivity"), 2) # 0.18
round(evaluate(changepoint_midlarge, reference, metric = "specificity"), 2) # 0.89
round(evaluate(changepoint_midlarge, reference, metric = "precision"), 2)   # 0.38
round(evaluate(changepoint_midlarge, reference, metric = "recall"), 2)      # 0.18

#Plot
print(evtplot(test_midlarge, changepoint_midlarge, reference))

##### 6. smallcap #####
#Detect
changepoint_smallcap <- evtdet.seminalChangePoint2(test_smallcap, w = 30, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_smallcap, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     10     9     
# FALSE    55     175  

round(evaluate(changepoint_smallcap, reference, metric = "F1"), 2)          # 0.24
round(evaluate(changepoint_smallcap, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(changepoint_smallcap, reference, metric = "sensitivity"), 2) # 0.15
round(evaluate(changepoint_smallcap, reference, metric = "specificity"), 2) # 0.95
round(evaluate(changepoint_smallcap, reference, metric = "precision"), 2)   # 0.53
round(evaluate(changepoint_smallcap, reference, metric = "recall"), 2)      # 0.15

#Plot
print(evtplot(test_smallcap, changepoint_smallcap, reference))

##### 7. igc #####
#Detect
changepoint_igc <- evtdet.seminalChangePoint2(test_igc, w = 30, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_igc, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     13     22    
# FALSE    52     162  

round(evaluate(changepoint_igc, reference, metric = "F1"), 2)          # 0.26
round(evaluate(changepoint_igc, reference, metric = "accuracy"), 2)    # 0.70
round(evaluate(changepoint_igc, reference, metric = "sensitivity"), 2) # 0.20
round(evaluate(changepoint_igc, reference, metric = "specificity"), 2) # 0.88
round(evaluate(changepoint_igc, reference, metric = "precision"), 2)   # 0.37
round(evaluate(changepoint_igc, reference, metric = "recall"), 2)      # 0.20

#Plot
print(evtplot(test_igc, changepoint_igc, reference))

##### 8. itag #####
#Detect
changepoint_itag <- evtdet.seminalChangePoint2(test_itag, w = 30, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_itag, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     10     24 
# FALSE    55     160  

round(evaluate(changepoint_itag, reference, metric = "F1"), 2)          # 0.20
round(evaluate(changepoint_itag, reference, metric = "accuracy"), 2)    # 0.68
round(evaluate(changepoint_itag, reference, metric = "sensitivity"), 2) # 0.15
round(evaluate(changepoint_itag, reference, metric = "specificity"), 2) # 0.87
round(evaluate(changepoint_itag, reference, metric = "precision"), 2)   # 0.29
round(evaluate(changepoint_itag, reference, metric = "recall"), 2)      # 0.15

#Plot
print(evtplot(test_itag, changepoint_itag, reference))

##### 9. igct #####
#Detect
changepoint_igct <- evtdet.seminalChangePoint2(test_igct, w = 30, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_igct, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     11     17
# FALSE    54     167 

round(evaluate(changepoint_igct, reference, metric = "F1"), 2)          # 0.24
round(evaluate(changepoint_igct, reference, metric = "accuracy"), 2)    # 0.71
round(evaluate(changepoint_igct, reference, metric = "sensitivity"), 2) # 0.17
round(evaluate(changepoint_igct, reference, metric = "specificity"), 2) # 0.91
round(evaluate(changepoint_igct, reference, metric = "precision"), 2)   # 0.39
round(evaluate(changepoint_igct, reference, metric = "recall"), 2)      # 0.17

#Plot
print(evtplot(test_igct, changepoint_igct, reference))

##### 10. ifnc #####
#Detect
changepoint_ifnc <- evtdet.seminalChangePoint2(test_ifnc, w = 30, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_ifnc, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     11     16   
# FALSE    54     168  

round(evaluate(changepoint_ifnc, reference, metric = "F1"), 2)          # 0.24
round(evaluate(changepoint_ifnc, reference, metric = "accuracy"), 2)    # 0.72
round(evaluate(changepoint_ifnc, reference, metric = "sensitivity"), 2) # 0.17
round(evaluate(changepoint_ifnc, reference, metric = "specificity"), 2) # 0.91
round(evaluate(changepoint_ifnc, reference, metric = "precision"), 2)   # 0.41
round(evaluate(changepoint_ifnc, reference, metric = "recall"), 2)      # 0.17

#Plot
print(evtplot(test_ifnc, changepoint_ifnc, reference))

##### 11. ieex #####
#Detect
changepoint_ieex <- evtdet.seminalChangePoint2(test_ieex, w = 30, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changepoint_ieex, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     15     31
# FALSE    51     164 

round(evaluate(changepoint_ieex, reference, metric = "F1"), 2)          # 0.27
round(evaluate(changepoint_ieex, reference, metric = "accuracy"), 2)    # 0.69
round(evaluate(changepoint_ieex, reference, metric = "sensitivity"), 2) # 0.23
round(evaluate(changepoint_ieex, reference, metric = "specificity"), 2) # 0.84
round(evaluate(changepoint_ieex, reference, metric = "precision"), 2)   # 0.33
round(evaluate(changepoint_ieex, reference, metric = "recall"), 2)      # 0.23

#Plot
print(evtplot(test_ieex, changepoint_ieex, reference))

###############################
##### ChangeFinder (2005) #####
###############################

##### 1. ibovespa #####
#Detect
changefinder_ibovespa <- evtdet.changeFinder(test_ibovespa, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_ibovespa, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     4      2
# FALSE    62     193   

round(evaluate(changefinder_ibovespa, reference, metric = "F1"), 2)          # 0.11
round(evaluate(changefinder_ibovespa, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(changefinder_ibovespa, reference, metric = "sensitivity"), 2) # 0.06
round(evaluate(changefinder_ibovespa, reference, metric = "specificity"), 2) # 0.99
round(evaluate(changefinder_ibovespa, reference, metric = "precision"), 2)   # 0.67
round(evaluate(changefinder_ibovespa, reference, metric = "recall"), 2)      # 0.06

#Plot
print(evtplot(test_ibovespa, changefinder_ibovespa, reference))

##### 2. ibrx100 #####
#Detect
changefinder_ibrx100 <- evtdet.changeFinder(test_ibrx100, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_ibrx100, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     14     3 
# FALSE    52     192  

round(evaluate(changefinder_ibrx100, reference, metric = "F1"), 2)          # 0.34
round(evaluate(changefinder_ibrx100, reference, metric = "accuracy"), 2)    # 0.79
round(evaluate(changefinder_ibrx100, reference, metric = "sensitivity"), 2) # 0.21
round(evaluate(changefinder_ibrx100, reference, metric = "specificity"), 2) # 0.98
round(evaluate(changefinder_ibrx100, reference, metric = "precision"), 2)   # 0.82
round(evaluate(changefinder_ibrx100, reference, metric = "recall"), 2)      # 0.21

#Plot
print(evtplot(test_ibrx100, changefinder_ibrx100, reference))

##### 3. ibrx50 #####
#Detect
changefinder_ibrx50 <- evtdet.changeFinder(test_ibrx50, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_ibrx50, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     9      1    
# FALSE    57     194

round(evaluate(changefinder_ibrx50, reference, metric = "F1"), 2)          # 0.24
round(evaluate(changefinder_ibrx50, reference, metric = "accuracy"), 2)    # 0.78
round(evaluate(changefinder_ibrx50, reference, metric = "sensitivity"), 2) # 0.14
round(evaluate(changefinder_ibrx50, reference, metric = "specificity"), 2) # 0.99
round(evaluate(changefinder_ibrx50, reference, metric = "precision"), 2)   # 0.90
round(evaluate(changefinder_ibrx50, reference, metric = "recall"), 2)      # 0.14

#Plot
print(evtplot(test_ibrx50, changefinder_ibrx50, reference))

##### 4. ibra #####
#Detect
changefinder_ibra <- evtdet.changeFinder(test_ibra, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_ibra, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     7      0  
# FALSE    58     184    

round(evaluate(changefinder_ibra, reference, metric = "F1"), 2)          # 0.19
round(evaluate(changefinder_ibra, reference, metric = "accuracy"), 2)    # 0.77
round(evaluate(changefinder_ibra, reference, metric = "sensitivity"), 2) # 0.11
round(evaluate(changefinder_ibra, reference, metric = "specificity"), 2) # 1.00
round(evaluate(changefinder_ibra, reference, metric = "precision"), 2)   # 1.00
round(evaluate(changefinder_ibra, reference, metric = "recall"), 2)      # 0.11

#Plot
print(evtplot(test_ibra, changefinder_ibra, reference))

##### 5. midlarge #####
#Detect
changefinder_midlarge <- evtdet.changeFinder(test_midlarge, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_midlarge, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     3      1 
# FALSE    62     183 

round(evaluate(changefinder_midlarge, reference, metric = "F1"), 2)          # 0.09
round(evaluate(changefinder_midlarge, reference, metric = "accuracy"), 2)    # 0.75
round(evaluate(changefinder_midlarge, reference, metric = "sensitivity"), 2) # 0.05
round(evaluate(changefinder_midlarge, reference, metric = "specificity"), 2) # 0.99
round(evaluate(changefinder_midlarge, reference, metric = "precision"), 2)   # 0.75
round(evaluate(changefinder_midlarge, reference, metric = "recall"), 2)      # 0.05

#Plot
print(evtplot(test_midlarge, changefinder_midlarge, reference))

##### 6. smallcap #####
#Detect
changefinder_smallcap <- evtdet.changeFinder(test_smallcap, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_smallcap, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     6      2 
# FALSE    59     182 

round(evaluate(changefinder_smallcap, reference, metric = "F1"), 2)          # 0.16
round(evaluate(changefinder_smallcap, reference, metric = "accuracy"), 2)    # 0.76
round(evaluate(changefinder_smallcap, reference, metric = "sensitivity"), 2) # 0.09
round(evaluate(changefinder_smallcap, reference, metric = "specificity"), 2) # 0.99
round(evaluate(changefinder_smallcap, reference, metric = "precision"), 2)   # 0.75
round(evaluate(changefinder_smallcap, reference, metric = "recall"), 2)      # 0.09

#Plot
print(evtplot(test_smallcap, changefinder_smallcap, reference))

##### 7. igc #####
#Detect
changefinder_igc <- evtdet.changeFinder(test_igc, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_igc, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     9      3   
# FALSE    56     181   

round(evaluate(changefinder_igc, reference, metric = "F1"), 2)          # 0.23
round(evaluate(changefinder_igc, reference, metric = "accuracy"), 2)    # 0.76
round(evaluate(changefinder_igc, reference, metric = "sensitivity"), 2) # 0.14
round(evaluate(changefinder_igc, reference, metric = "specificity"), 2) # 0.98
round(evaluate(changefinder_igc, reference, metric = "precision"), 2)   # 0.75
round(evaluate(changefinder_igc, reference, metric = "recall"), 2)      # 0.14

#Plot
print(evtplot(test_igc, changefinder_igc, reference))

##### 8. itag #####
#Detect
changefinder_itag <- evtdet.changeFinder(test_itag, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_itag, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     9      3 
# FALSE    56     181    

round(evaluate(changefinder_itag, reference, metric = "F1"), 2)          # 0.23
round(evaluate(changefinder_itag, reference, metric = "accuracy"), 2)    # 0.76
round(evaluate(changefinder_itag, reference, metric = "sensitivity"), 2) # 0.14
round(evaluate(changefinder_itag, reference, metric = "specificity"), 2) # 0.98
round(evaluate(changefinder_itag, reference, metric = "precision"), 2)   # 0.75
round(evaluate(changefinder_itag, reference, metric = "recall"), 2)      # 0.14

#Plot
print(evtplot(test_itag, changefinder_itag, reference))

##### 9. igct #####
#Detect
changefinder_igct <- evtdet.changeFinder(test_igct, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_igct, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     7      1    
# FALSE    58     183   

round(evaluate(changefinder_igct, reference, metric = "F1"), 2)          # 0.19
round(evaluate(changefinder_igct, reference, metric = "accuracy"), 2)    # 0.76
round(evaluate(changefinder_igct, reference, metric = "sensitivity"), 2) # 0.11
round(evaluate(changefinder_igct, reference, metric = "specificity"), 2) # 0.99
round(evaluate(changefinder_igct, reference, metric = "precision"), 2)   # 0.88
round(evaluate(changefinder_igct, reference, metric = "recall"), 2)      # 0.11

#Plot
print(evtplot(test_igct, changefinder_igct, reference))

##### 10. ifnc #####
#Detect
changefinder_ifnc <- evtdet.changeFinder(test_ifnc, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_ifnc, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     7      7    
# FALSE    58     177

round(evaluate(changefinder_ifnc, reference, metric = "F1"), 2)          # 0.18
round(evaluate(changefinder_ifnc, reference, metric = "accuracy"), 2)    # 0.74
round(evaluate(changefinder_ifnc, reference, metric = "sensitivity"), 2) # 0.11
round(evaluate(changefinder_ifnc, reference, metric = "specificity"), 2) # 0.96
round(evaluate(changefinder_ifnc, reference, metric = "precision"), 2)   # 0.50
round(evaluate(changefinder_ifnc, reference, metric = "recall"), 2)      # 0.11

#Plot
print(evtplot(test_ifnc, changefinder_ifnc, reference))

##### 11. ieex #####
#Detect
changefinder_ieex <- evtdet.changeFinder(test_ieex, mdl = linreg, na.action = na.omit)

#Evaluate
evaluate(changefinder_ieex, reference, metric = "confusion_matrix")
# Detected TRUE   FALSE
# TRUE     10     4   
# FALSE    56     191  

round(evaluate(changefinder_ieex, reference, metric = "F1"), 2)          # 0.25
round(evaluate(changefinder_ieex, reference, metric = "accuracy"), 2)    # 0.77
round(evaluate(changefinder_ieex, reference, metric = "sensitivity"), 2) # 0.15
round(evaluate(changefinder_ieex, reference, metric = "specificity"), 2) # 0.98
round(evaluate(changefinder_ieex, reference, metric = "precision"), 2)   # 0.71
round(evaluate(changefinder_ieex, reference, metric = "recall"), 2)      # 0.15

#Plot
print(evtplot(test_ieex, changefinder_ieex, reference))
